C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose_cb05 (ns,M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C     This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C     ns: matrix row number from the chemical species number
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE


      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION temp


C     Upper part.
      M(1, 47) = M(1, 47) / M(1, 1)

C     Upper part.
      M(2, 42) = M(2, 42) / M(2, 2)

C     Upper part.
      M(3, 42) = M(3, 42) / M(3, 3)

C     Upper part.
      M(4, 42) = M(4, 42) / M(4, 4)

C     Upper part.
      M(5, 42) = M(5, 42) / M(5, 5)

C     Upper part.
      M(6, 42) = M(6, 42) / M(6, 6)

C     Upper part.
      M(7, 42) = M(7, 42) / M(7, 7)

C     Upper part.
      temp = M(8, 7) * M(7, 42)
      M(8, 42) = ( M(8, 42) - temp ) / M(8, 8)

C     Upper part.
      M(9, 44) = M(9, 44) / M(9, 9)
C     Upper part.
      M(9, 52) = M(9, 52) / M(9, 9)

C     Upper part.
      M(10, 51) = M(10, 51) / M(10, 10)
C     Upper part.
      M(10, 52) = M(10, 52) / M(10, 10)

C     Upper part.
      M(11, 40) = M(11, 40) / M(11, 11)
C     Upper part.
      M(11, 42) = M(11, 42) / M(11, 11)

C     Upper part.
      temp = M(12, 5) * M(5, 42)
      temp = temp + M(12, 6) * M(6, 42)
      M(12, 42) = ( M(12, 42) - temp ) / M(12, 12)
C     Upper part.
      M(12, 48) = M(12, 48) / M(12, 12)

C     Upper part.
      M(13, 42) = M(13, 42) / M(13, 13)
C     Upper part.
      M(13, 50) = M(13, 50) / M(13, 13)
C     Upper part.
      M(13, 52) = M(13, 52) / M(13, 13)

C     Upper part.
      M(14, 42) = M(14, 42) / M(14, 14)
C     Upper part.
      M(14, 46) = M(14, 46) / M(14, 14)
C     Upper part.
      M(14, 52) = M(14, 52) / M(14, 14)

C     Upper part.
      M(15, 42) = M(15, 42) / M(15, 15)
C     Upper part.
      M(15, 48) = M(15, 48) / M(15, 15)
C     Upper part.
      M(15, 52) = M(15, 52) / M(15, 15)

C     Upper part.
      M(16, 34) = M(16, 34) / M(16, 16)
C     Upper part.
      M(16, 42) = M(16, 42) / M(16, 16)
C     Upper part.
      M(16, 52) = M(16, 52) / M(16, 16)

C     Upper part.
      M(17, 42) = M(17, 42) / M(17, 17)
C     Upper part.
      M(17, 43) = M(17, 43) / M(17, 17)
C     Upper part.
      M(17, 50) = M(17, 50) / M(17, 17)

C     Upper part.
      M(18, 41) = M(18, 41) / M(18, 18)
C     Upper part.
      M(18, 48) = M(18, 48) / M(18, 18)
C     Upper part.
      M(18, 50) = M(18, 50) / M(18, 18)

C     Upper part.
      M(19, 40) = M(19, 40) / M(19, 19)
C     Upper part.
      temp = M(19, 18) * M(18, 41)
      M(19, 41) = ( M(19, 41) - temp ) / M(19, 19)
C     Upper part.
      M(19, 42) = M(19, 42) / M(19, 19)
C     Upper part.
      temp = M(19, 18) * M(18, 48)
      M(19, 48) = ( M(19, 48) - temp ) / M(19, 19)
C     Upper part.
      temp = M(19, 18) * M(18, 50)
      M(19, 50) = ( M(19, 50) - temp ) / M(19, 19)

C     Upper part.
      M(20, 23) = M(20, 23) / M(20, 20)
C     Upper part.
      temp = M(20, 18) * M(18, 41)
      M(20, 41) = ( M(20, 41) - temp ) / M(20, 20)
C     Upper part.
      M(20, 42) = M(20, 42) / M(20, 20)
C     Upper part.
      M(20, 47) = M(20, 47) / M(20, 20)
C     Upper part.
      temp = M(20, 18) * M(18, 48)
      M(20, 48) = ( M(20, 48) - temp ) / M(20, 20)
C     Upper part.
      temp = M(20, 18) * M(18, 50)
      M(20, 50) = ( M(20, 50) - temp ) / M(20, 20)

C     Upper part.
      M(21, 39) = M(21, 39) / M(21, 21)
C     Upper part.
      M(21, 42) = M(21, 42) / M(21, 21)
C     Upper part.
      M(21, 49) = M(21, 49) / M(21, 21)
C     Upper part.
      M(21, 50) = M(21, 50) / M(21, 21)

C     Upper part.
      M(22, 42) = M(22, 42) / M(22, 22)
C     Upper part.
      M(22, 46) = M(22, 46) / M(22, 22)
C     Upper part.
      M(22, 50) = M(22, 50) / M(22, 22)
C     Upper part.
      M(22, 51) = M(22, 51) / M(22, 22)

C     Lower part.
      temp = M(42, 20) * M(20, 23)
      M(42, 23) = M(42, 23) - temp
C     Lower part.
      temp = M(50, 20) * M(20, 23)
      M(50, 23) = M(50, 23) - temp
C     Upper part.
      M(23, 42) = M(23, 42) / M(23, 23)
C     Upper part.
      M(23, 43) = M(23, 43) / M(23, 23)
C     Upper part.
      M(23, 44) = M(23, 44) / M(23, 23)
C     Upper part.
      M(23, 47) = M(23, 47) / M(23, 23)

C     Upper part.
      M(24, 42) = M(24, 42) / M(24, 24)
C     Upper part.
      M(24, 43) = M(24, 43) / M(24, 24)
C     Upper part.
      M(24, 44) = M(24, 44) / M(24, 24)
C     Upper part.
      M(24, 47) = M(24, 47) / M(24, 24)

C     Upper part.
      M(25, 42) = M(25, 42) / M(25, 25)
C     Upper part.
      M(25, 43) = M(25, 43) / M(25, 25)
C     Upper part.
      M(25, 44) = M(25, 44) / M(25, 25)
C     Upper part.
      M(25, 47) = M(25, 47) / M(25, 25)

C     Upper part.
      M(26, 42) = M(26, 42) / M(26, 26)
C     Upper part.
      M(26, 43) = M(26, 43) / M(26, 26)
C     Upper part.
      M(26, 44) = M(26, 44) / M(26, 26)
C     Upper part.
      M(26, 47) = M(26, 47) / M(26, 26)

C     Upper part.
      M(27, 30) = M(27, 30) / M(27, 27)
C     Upper part.
      temp = M(27, 5) * M(5, 42)
      temp = temp + M(27, 6) * M(6, 42)
      temp = temp + M(27, 12) * M(12, 42)
      M(27, 42) = ( M(27, 42) - temp ) / M(27, 27)
C     Upper part.
      M(27, 44) = M(27, 44) / M(27, 27)
C     Upper part.
      temp = M(27, 12) * M(12, 48)
      M(27, 48) = ( M(27, 48) - temp ) / M(27, 27)
C     Upper part.
      M(27, 50) = M(27, 50) / M(27, 27)

C     Upper part.
      temp = M(28, 27) * M(27, 30)
      M(28, 30) = ( M(28, 30) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 12) * M(12, 42)
      temp = temp + M(28, 27) * M(27, 42)
      M(28, 42) = ( M(28, 42) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 27) * M(27, 44)
      M(28, 44) = ( M(28, 44) - temp ) / M(28, 28)
C     Upper part.
      M(28, 47) = M(28, 47) / M(28, 28)
C     Upper part.
      temp = M(28, 12) * M(12, 48)
      temp = temp + M(28, 27) * M(27, 48)
      M(28, 48) = ( M(28, 48) - temp ) / M(28, 28)
C     Upper part.
      temp = M(28, 27) * M(27, 50)
      M(28, 50) = ( M(28, 50) - temp ) / M(28, 28)

C     Upper part.
      temp = M(29, 28) * M(28, 30)
      M(29, 30) = ( M(29, 30) - temp ) / M(29, 29)
C     Upper part.
      M(29, 32) = M(29, 32) / M(29, 29)
C     Upper part.
      temp = M(29, 6) * M(6, 42)
      temp = temp + M(29, 28) * M(28, 42)
      M(29, 42) = ( M(29, 42) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 28) * M(28, 44)
      M(29, 44) = ( M(29, 44) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 28) * M(28, 47)
      M(29, 47) = ( M(29, 47) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 28) * M(28, 48)
      M(29, 48) = ( M(29, 48) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 28) * M(28, 50)
      M(29, 50) = ( M(29, 50) - temp ) / M(29, 29)

C     Lower part.
      temp = M(30, 27) * M(27, 30)
      M(30, 30) = M(30, 30) - temp
C     Lower part.
      temp = M(35, 28) * M(28, 30)
      M(35, 30) = M(35, 30) - temp
C     Lower part.
      temp = M(37, 28) * M(28, 30)
      temp = temp + M(37, 29) * M(29, 30)
      M(37, 30) = M(37, 30) - temp
C     Lower part.
      temp = M(38, 27) * M(27, 30)
      M(38, 30) = M(38, 30) - temp
C     Lower part.
      temp = M(41, 28) * M(28, 30)
      M(41, 30) = M(41, 30) - temp
C     Lower part.
      temp = M(42, 27) * M(27, 30)
      temp = temp + M(42, 28) * M(28, 30)
      temp = temp + M(42, 29) * M(29, 30)
      M(42, 30) = M(42, 30) - temp
C     Lower part.
      temp = M(44, 27) * M(27, 30)
      M(44, 30) = M(44, 30) - temp
C     Lower part.
      temp = M(47, 28) * M(28, 30)
      M(47, 30) = M(47, 30) - temp
C     Lower part.
      temp = M(49, 27) * M(27, 30)
      temp = temp + M(49, 28) * M(28, 30)
      temp = temp + M(49, 29) * M(29, 30)
      M(49, 30) = M(49, 30) - temp
C     Lower part.
      temp = M(50, 27) * M(27, 30)
      temp = temp + M(50, 28) * M(28, 30)
      temp = temp + M(50, 29) * M(29, 30)
      M(50, 30) = M(50, 30) - temp
C     Lower part.
      temp = M(51, 28) * M(28, 30)
      temp = temp + M(51, 29) * M(29, 30)
      M(51, 30) = M(51, 30) - temp
C     Upper part.
      temp = M(30, 27) * M(27, 42)
      M(30, 42) = ( M(30, 42) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 27) * M(27, 44)
      M(30, 44) = ( M(30, 44) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 27) * M(27, 48)
      M(30, 48) = ( M(30, 48) - temp ) / M(30, 30)
C     Upper part.
      temp = M(30, 27) * M(27, 50)
      M(30, 50) = ( M(30, 50) - temp ) / M(30, 30)
C     Upper part.
      M(30, 52) = M(30, 52) / M(30, 30)

C     Upper part.
      M(31, 42) = M(31, 42) / M(31, 31)
C     Upper part.
      M(31, 43) = M(31, 43) / M(31, 31)
C     Upper part.
      M(31, 44) = M(31, 44) / M(31, 31)
C     Upper part.
      M(31, 47) = M(31, 47) / M(31, 31)
C     Upper part.
      M(31, 52) = M(31, 52) / M(31, 31)

C     Lower part.
      temp = M(37, 29) * M(29, 32)
      M(37, 32) = M(37, 32) - temp
C     Lower part.
      temp = M(42, 29) * M(29, 32)
      M(42, 32) = M(42, 32) - temp
C     Lower part.
      temp = M(49, 29) * M(29, 32)
      M(49, 32) = M(49, 32) - temp
C     Lower part.
      temp = M(50, 29) * M(29, 32)
      M(50, 32) = M(50, 32) - temp
C     Lower part.
      temp = M(51, 29) * M(29, 32)
      M(51, 32) = M(51, 32) - temp
C     Upper part.
      temp = M(32, 31) * M(31, 42)
      M(32, 42) = ( M(32, 42) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 31) * M(31, 43)
      M(32, 43) = ( M(32, 43) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 31) * M(31, 44)
      M(32, 44) = ( M(32, 44) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 31) * M(31, 47)
      M(32, 47) = ( M(32, 47) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 31) * M(31, 52)
      M(32, 52) = ( M(32, 52) - temp ) / M(32, 32)

C     Upper part.
      temp = M(33, 16) * M(16, 34)
      M(33, 34) = ( M(33, 34) - temp ) / M(33, 33)
C     Upper part.
      M(33, 39) = M(33, 39) / M(33, 33)
C     Upper part.
      temp = M(33, 12) * M(12, 42)
      temp = temp + M(33, 16) * M(16, 42)
      temp = temp + M(33, 26) * M(26, 42)
      temp = temp + M(33, 30) * M(30, 42)
      temp = temp + M(33, 31) * M(31, 42)
      temp = temp + M(33, 32) * M(32, 42)
      M(33, 42) = ( M(33, 42) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 26) * M(26, 43)
      temp = temp + M(33, 31) * M(31, 43)
      temp = temp + M(33, 32) * M(32, 43)
      M(33, 43) = ( M(33, 43) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 26) * M(26, 44)
      temp = temp + M(33, 30) * M(30, 44)
      temp = temp + M(33, 31) * M(31, 44)
      temp = temp + M(33, 32) * M(32, 44)
      M(33, 44) = ( M(33, 44) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 26) * M(26, 47)
      temp = temp + M(33, 31) * M(31, 47)
      temp = temp + M(33, 32) * M(32, 47)
      M(33, 47) = ( M(33, 47) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 12) * M(12, 48)
      temp = temp + M(33, 30) * M(30, 48)
      M(33, 48) = ( M(33, 48) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 30) * M(30, 50)
      M(33, 50) = ( M(33, 50) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 16) * M(16, 52)
      temp = temp + M(33, 30) * M(30, 52)
      temp = temp + M(33, 31) * M(31, 52)
      temp = temp + M(33, 32) * M(32, 52)
      M(33, 52) = ( M(33, 52) - temp ) / M(33, 33)

C     Lower part.
      temp = M(34, 16) * M(16, 34)
      temp = temp + M(34, 33) * M(33, 34)
      M(34, 34) = M(34, 34) - temp
C     Lower part.
      temp = M(35, 16) * M(16, 34)
      temp = temp + M(35, 33) * M(33, 34)
      M(35, 34) = M(35, 34) - temp
C     Lower part.
      temp = M(38, 33) * M(33, 34)
      M(38, 34) = M(38, 34) - temp
C     Lower part.
      temp = M(39, 16) * M(16, 34)
      M(39, 34) = M(39, 34) - temp
C     Lower part.
      temp = M(41, 33) * M(33, 34)
      M(41, 34) = M(41, 34) - temp
C     Lower part.
      temp = M(42, 33) * M(33, 34)
      M(42, 34) = M(42, 34) - temp
C     Lower part.
      temp = M(45, 16) * M(16, 34)
      temp = temp + M(45, 33) * M(33, 34)
      M(45, 34) = M(45, 34) - temp
C     Lower part.
      temp = M(49, 16) * M(16, 34)
      M(49, 34) = M(49, 34) - temp
C     Lower part.
      temp = M(50, 16) * M(16, 34)
      temp = temp + M(50, 33) * M(33, 34)
      M(50, 34) = M(50, 34) - temp
C     Lower part.
      temp = M(52, 16) * M(16, 34)
      temp = temp + M(52, 33) * M(33, 34)
      M(52, 34) = M(52, 34) - temp
C     Upper part.
      temp = M(34, 33) * M(33, 39)
      M(34, 39) = ( M(34, 39) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 6) * M(6, 42)
      temp = temp + M(34, 16) * M(16, 42)
      temp = temp + M(34, 24) * M(24, 42)
      temp = temp + M(34, 25) * M(25, 42)
      temp = temp + M(34, 26) * M(26, 42)
      temp = temp + M(34, 31) * M(31, 42)
      temp = temp + M(34, 32) * M(32, 42)
      temp = temp + M(34, 33) * M(33, 42)
      M(34, 42) = ( M(34, 42) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 24) * M(24, 43)
      temp = temp + M(34, 25) * M(25, 43)
      temp = temp + M(34, 26) * M(26, 43)
      temp = temp + M(34, 31) * M(31, 43)
      temp = temp + M(34, 32) * M(32, 43)
      temp = temp + M(34, 33) * M(33, 43)
      M(34, 43) = ( M(34, 43) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 24) * M(24, 44)
      temp = temp + M(34, 25) * M(25, 44)
      temp = temp + M(34, 26) * M(26, 44)
      temp = temp + M(34, 31) * M(31, 44)
      temp = temp + M(34, 32) * M(32, 44)
      temp = temp + M(34, 33) * M(33, 44)
      M(34, 44) = ( M(34, 44) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 24) * M(24, 47)
      temp = temp + M(34, 25) * M(25, 47)
      temp = temp + M(34, 26) * M(26, 47)
      temp = temp + M(34, 31) * M(31, 47)
      temp = temp + M(34, 32) * M(32, 47)
      temp = temp + M(34, 33) * M(33, 47)
      M(34, 47) = ( M(34, 47) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 48)
      M(34, 48) = ( M(34, 48) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 33) * M(33, 50)
      M(34, 50) = ( M(34, 50) - temp ) / M(34, 34)
C     Upper part.
      temp = M(34, 16) * M(16, 52)
      temp = temp + M(34, 31) * M(31, 52)
      temp = temp + M(34, 32) * M(32, 52)
      temp = temp + M(34, 33) * M(33, 52)
      M(34, 52) = ( M(34, 52) - temp ) / M(34, 34)

C     Upper part.
      temp = M(35, 21) * M(21, 39)
      temp = temp + M(35, 33) * M(33, 39)
      temp = temp + M(35, 34) * M(34, 39)
      M(35, 39) = ( M(35, 39) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 2) * M(2, 42)
      temp = temp + M(35, 16) * M(16, 42)
      temp = temp + M(35, 21) * M(21, 42)
      temp = temp + M(35, 23) * M(23, 42)
      temp = temp + M(35, 24) * M(24, 42)
      temp = temp + M(35, 25) * M(25, 42)
      temp = temp + M(35, 26) * M(26, 42)
      temp = temp + M(35, 28) * M(28, 42)
      temp = temp + M(35, 30) * M(30, 42)
      temp = temp + M(35, 31) * M(31, 42)
      temp = temp + M(35, 32) * M(32, 42)
      temp = temp + M(35, 33) * M(33, 42)
      temp = temp + M(35, 34) * M(34, 42)
      M(35, 42) = ( M(35, 42) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 23) * M(23, 43)
      temp = temp + M(35, 24) * M(24, 43)
      temp = temp + M(35, 25) * M(25, 43)
      temp = temp + M(35, 26) * M(26, 43)
      temp = temp + M(35, 31) * M(31, 43)
      temp = temp + M(35, 32) * M(32, 43)
      temp = temp + M(35, 33) * M(33, 43)
      temp = temp + M(35, 34) * M(34, 43)
      M(35, 43) = ( M(35, 43) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 23) * M(23, 44)
      temp = temp + M(35, 24) * M(24, 44)
      temp = temp + M(35, 25) * M(25, 44)
      temp = temp + M(35, 26) * M(26, 44)
      temp = temp + M(35, 28) * M(28, 44)
      temp = temp + M(35, 30) * M(30, 44)
      temp = temp + M(35, 31) * M(31, 44)
      temp = temp + M(35, 32) * M(32, 44)
      temp = temp + M(35, 33) * M(33, 44)
      temp = temp + M(35, 34) * M(34, 44)
      M(35, 44) = ( M(35, 44) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 23) * M(23, 47)
      temp = temp + M(35, 24) * M(24, 47)
      temp = temp + M(35, 25) * M(25, 47)
      temp = temp + M(35, 26) * M(26, 47)
      temp = temp + M(35, 28) * M(28, 47)
      temp = temp + M(35, 31) * M(31, 47)
      temp = temp + M(35, 32) * M(32, 47)
      temp = temp + M(35, 33) * M(33, 47)
      temp = temp + M(35, 34) * M(34, 47)
      M(35, 47) = ( M(35, 47) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 28) * M(28, 48)
      temp = temp + M(35, 30) * M(30, 48)
      temp = temp + M(35, 33) * M(33, 48)
      temp = temp + M(35, 34) * M(34, 48)
      M(35, 48) = ( M(35, 48) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 21) * M(21, 49)
      M(35, 49) = ( M(35, 49) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 21) * M(21, 50)
      temp = temp + M(35, 28) * M(28, 50)
      temp = temp + M(35, 30) * M(30, 50)
      temp = temp + M(35, 33) * M(33, 50)
      temp = temp + M(35, 34) * M(34, 50)
      M(35, 50) = ( M(35, 50) - temp ) / M(35, 35)
C     Upper part.
      temp = M(35, 16) * M(16, 52)
      temp = temp + M(35, 30) * M(30, 52)
      temp = temp + M(35, 31) * M(31, 52)
      temp = temp + M(35, 32) * M(32, 52)
      temp = temp + M(35, 33) * M(33, 52)
      temp = temp + M(35, 34) * M(34, 52)
      M(35, 52) = ( M(35, 52) - temp ) / M(35, 35)

C     Upper part.
      M(36, 40) = M(36, 40) / M(36, 36)
C     Upper part.
      M(36, 42) = M(36, 42) / M(36, 36)
C     Upper part.
      M(36, 46) = M(36, 46) / M(36, 36)
C     Upper part.
      M(36, 49) = M(36, 49) / M(36, 36)
C     Upper part.
      M(36, 50) = M(36, 50) / M(36, 36)
C     Upper part.
      M(36, 51) = M(36, 51) / M(36, 36)

C     Upper part.
      temp = M(37, 35) * M(35, 39)
      M(37, 39) = ( M(37, 39) - temp ) / M(37, 37)
C     Upper part.
      M(37, 41) = M(37, 41) / M(37, 37)
C     Upper part.
      temp = M(37, 23) * M(23, 42)
      temp = temp + M(37, 24) * M(24, 42)
      temp = temp + M(37, 25) * M(25, 42)
      temp = temp + M(37, 26) * M(26, 42)
      temp = temp + M(37, 28) * M(28, 42)
      temp = temp + M(37, 29) * M(29, 42)
      temp = temp + M(37, 30) * M(30, 42)
      temp = temp + M(37, 31) * M(31, 42)
      temp = temp + M(37, 32) * M(32, 42)
      temp = temp + M(37, 35) * M(35, 42)
      M(37, 42) = ( M(37, 42) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 23) * M(23, 43)
      temp = temp + M(37, 24) * M(24, 43)
      temp = temp + M(37, 25) * M(25, 43)
      temp = temp + M(37, 26) * M(26, 43)
      temp = temp + M(37, 31) * M(31, 43)
      temp = temp + M(37, 32) * M(32, 43)
      temp = temp + M(37, 35) * M(35, 43)
      M(37, 43) = ( M(37, 43) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 23) * M(23, 44)
      temp = temp + M(37, 24) * M(24, 44)
      temp = temp + M(37, 25) * M(25, 44)
      temp = temp + M(37, 26) * M(26, 44)
      temp = temp + M(37, 28) * M(28, 44)
      temp = temp + M(37, 29) * M(29, 44)
      temp = temp + M(37, 30) * M(30, 44)
      temp = temp + M(37, 31) * M(31, 44)
      temp = temp + M(37, 32) * M(32, 44)
      temp = temp + M(37, 35) * M(35, 44)
      M(37, 44) = ( M(37, 44) - temp ) / M(37, 37)
C     Upper part.
      M(37, 45) = M(37, 45) / M(37, 37)
C     Upper part.
      temp = M(37, 23) * M(23, 47)
      temp = temp + M(37, 24) * M(24, 47)
      temp = temp + M(37, 25) * M(25, 47)
      temp = temp + M(37, 26) * M(26, 47)
      temp = temp + M(37, 28) * M(28, 47)
      temp = temp + M(37, 29) * M(29, 47)
      temp = temp + M(37, 31) * M(31, 47)
      temp = temp + M(37, 32) * M(32, 47)
      temp = temp + M(37, 35) * M(35, 47)
      M(37, 47) = ( M(37, 47) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 28) * M(28, 48)
      temp = temp + M(37, 29) * M(29, 48)
      temp = temp + M(37, 30) * M(30, 48)
      temp = temp + M(37, 35) * M(35, 48)
      M(37, 48) = ( M(37, 48) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 35) * M(35, 49)
      M(37, 49) = ( M(37, 49) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 28) * M(28, 50)
      temp = temp + M(37, 29) * M(29, 50)
      temp = temp + M(37, 30) * M(30, 50)
      temp = temp + M(37, 35) * M(35, 50)
      M(37, 50) = ( M(37, 50) - temp ) / M(37, 37)
C     Upper part.
      temp = M(37, 30) * M(30, 52)
      temp = temp + M(37, 31) * M(31, 52)
      temp = temp + M(37, 32) * M(32, 52)
      temp = temp + M(37, 35) * M(35, 52)
      M(37, 52) = ( M(37, 52) - temp ) / M(37, 37)

C     Upper part.
      temp = M(38, 33) * M(33, 39)
      temp = temp + M(38, 34) * M(34, 39)
      temp = temp + M(38, 35) * M(35, 39)
      M(38, 39) = ( M(38, 39) - temp ) / M(38, 38)
C     Upper part.
      M(38, 41) = M(38, 41) / M(38, 38)
C     Upper part.
      temp = M(38, 27) * M(27, 42)
      temp = temp + M(38, 30) * M(30, 42)
      temp = temp + M(38, 32) * M(32, 42)
      temp = temp + M(38, 33) * M(33, 42)
      temp = temp + M(38, 34) * M(34, 42)
      temp = temp + M(38, 35) * M(35, 42)
      M(38, 42) = ( M(38, 42) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 32) * M(32, 43)
      temp = temp + M(38, 33) * M(33, 43)
      temp = temp + M(38, 34) * M(34, 43)
      temp = temp + M(38, 35) * M(35, 43)
      M(38, 43) = ( M(38, 43) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 9) * M(9, 44)
      temp = temp + M(38, 27) * M(27, 44)
      temp = temp + M(38, 30) * M(30, 44)
      temp = temp + M(38, 32) * M(32, 44)
      temp = temp + M(38, 33) * M(33, 44)
      temp = temp + M(38, 34) * M(34, 44)
      temp = temp + M(38, 35) * M(35, 44)
      M(38, 44) = ( M(38, 44) - temp ) / M(38, 38)
C     Upper part.
      M(38, 45) = M(38, 45) / M(38, 38)
C     Upper part.
      temp = M(38, 32) * M(32, 47)
      temp = temp + M(38, 33) * M(33, 47)
      temp = temp + M(38, 34) * M(34, 47)
      temp = temp + M(38, 35) * M(35, 47)
      M(38, 47) = ( M(38, 47) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 27) * M(27, 48)
      temp = temp + M(38, 30) * M(30, 48)
      temp = temp + M(38, 33) * M(33, 48)
      temp = temp + M(38, 34) * M(34, 48)
      temp = temp + M(38, 35) * M(35, 48)
      M(38, 48) = ( M(38, 48) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 35) * M(35, 49)
      M(38, 49) = ( M(38, 49) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 27) * M(27, 50)
      temp = temp + M(38, 30) * M(30, 50)
      temp = temp + M(38, 33) * M(33, 50)
      temp = temp + M(38, 34) * M(34, 50)
      temp = temp + M(38, 35) * M(35, 50)
      M(38, 50) = ( M(38, 50) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 9) * M(9, 52)
      temp = temp + M(38, 30) * M(30, 52)
      temp = temp + M(38, 32) * M(32, 52)
      temp = temp + M(38, 33) * M(33, 52)
      temp = temp + M(38, 34) * M(34, 52)
      temp = temp + M(38, 35) * M(35, 52)
      M(38, 52) = ( M(38, 52) - temp ) / M(38, 38)

C     Lower part.
      temp = M(39, 34) * M(34, 39)
      M(39, 39) = M(39, 39) - temp
C     Lower part.
      temp = M(40, 35) * M(35, 39)
      M(40, 39) = M(40, 39) - temp
C     Lower part.
      temp = M(41, 33) * M(33, 39)
      temp = temp + M(41, 34) * M(34, 39)
      M(41, 39) = M(41, 39) - temp
C     Lower part.
      temp = M(42, 21) * M(21, 39)
      temp = temp + M(42, 33) * M(33, 39)
      temp = temp + M(42, 34) * M(34, 39)
      temp = temp + M(42, 35) * M(35, 39)
      temp = temp + M(42, 37) * M(37, 39)
      temp = temp + M(42, 38) * M(38, 39)
      M(42, 39) = M(42, 39) - temp
C     Lower part.
      temp = M(43, 35) * M(35, 39)
      M(43, 39) = M(43, 39) - temp
C     Lower part.
      temp = M(44, 35) * M(35, 39)
      temp = temp + M(44, 38) * M(38, 39)
      M(44, 39) = M(44, 39) - temp
C     Lower part.
      temp = M(45, 21) * M(21, 39)
      temp = temp + M(45, 33) * M(33, 39)
      temp = temp + M(45, 34) * M(34, 39)
      M(45, 39) = M(45, 39) - temp
C     Lower part.
      temp = M(46, 35) * M(35, 39)
      M(46, 39) = M(46, 39) - temp
C     Lower part.
      temp = M(49, 21) * M(21, 39)
      temp = temp + M(49, 34) * M(34, 39)
      M(49, 39) = M(49, 39) - temp
C     Lower part.
      temp = M(50, 21) * M(21, 39)
      temp = temp + M(50, 33) * M(33, 39)
      temp = temp + M(50, 34) * M(34, 39)
      temp = temp + M(50, 35) * M(35, 39)
      temp = temp + M(50, 37) * M(37, 39)
      M(50, 39) = M(50, 39) - temp
C     Lower part.
      temp = M(52, 33) * M(33, 39)
      temp = temp + M(52, 34) * M(34, 39)
      temp = temp + M(52, 38) * M(38, 39)
      M(52, 39) = M(52, 39) - temp
C     Upper part.
      temp = M(39, 4) * M(4, 42)
      temp = temp + M(39, 16) * M(16, 42)
      temp = temp + M(39, 24) * M(24, 42)
      temp = temp + M(39, 26) * M(26, 42)
      temp = temp + M(39, 31) * M(31, 42)
      temp = temp + M(39, 34) * M(34, 42)
      M(39, 42) = ( M(39, 42) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 24) * M(24, 43)
      temp = temp + M(39, 26) * M(26, 43)
      temp = temp + M(39, 31) * M(31, 43)
      temp = temp + M(39, 34) * M(34, 43)
      M(39, 43) = ( M(39, 43) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 24) * M(24, 44)
      temp = temp + M(39, 26) * M(26, 44)
      temp = temp + M(39, 31) * M(31, 44)
      temp = temp + M(39, 34) * M(34, 44)
      M(39, 44) = ( M(39, 44) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 24) * M(24, 47)
      temp = temp + M(39, 26) * M(26, 47)
      temp = temp + M(39, 31) * M(31, 47)
      temp = temp + M(39, 34) * M(34, 47)
      M(39, 47) = ( M(39, 47) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 34) * M(34, 48)
      M(39, 48) = ( M(39, 48) - temp ) / M(39, 39)
C     Upper part.
      M(39, 49) = M(39, 49) / M(39, 39)
C     Upper part.
      temp = M(39, 34) * M(34, 50)
      M(39, 50) = ( M(39, 50) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 16) * M(16, 52)
      temp = temp + M(39, 31) * M(31, 52)
      temp = temp + M(39, 34) * M(34, 52)
      M(39, 52) = ( M(39, 52) - temp ) / M(39, 39)

C     Lower part.
      temp = M(40, 19) * M(19, 40)
      temp = temp + M(40, 36) * M(36, 40)
      M(40, 40) = M(40, 40) - temp
C     Lower part.
      temp = M(41, 11) * M(11, 40)
      temp = temp + M(41, 19) * M(19, 40)
      M(41, 40) = M(41, 40) - temp
C     Lower part.
      temp = M(42, 11) * M(11, 40)
      temp = temp + M(42, 19) * M(19, 40)
      temp = temp + M(42, 36) * M(36, 40)
      M(42, 40) = M(42, 40) - temp
C     Lower part.
      temp = M(49, 19) * M(19, 40)
      M(49, 40) = M(49, 40) - temp
C     Lower part.
      temp = M(50, 11) * M(11, 40)
      temp = temp + M(50, 19) * M(19, 40)
      M(50, 40) = M(50, 40) - temp
C     Upper part.
      temp = M(40, 19) * M(19, 41)
      M(40, 41) = ( M(40, 41) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 3) * M(3, 42)
      temp = temp + M(40, 19) * M(19, 42)
      temp = temp + M(40, 22) * M(22, 42)
      temp = temp + M(40, 35) * M(35, 42)
      temp = temp + M(40, 36) * M(36, 42)
      temp = temp + M(40, 39) * M(39, 42)
      M(40, 42) = ( M(40, 42) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 35) * M(35, 43)
      temp = temp + M(40, 39) * M(39, 43)
      M(40, 43) = ( M(40, 43) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 35) * M(35, 44)
      temp = temp + M(40, 39) * M(39, 44)
      M(40, 44) = ( M(40, 44) - temp ) / M(40, 40)
C     Upper part.
      M(40, 45) = M(40, 45) / M(40, 40)
C     Upper part.
      temp = M(40, 22) * M(22, 46)
      temp = temp + M(40, 36) * M(36, 46)
      M(40, 46) = ( M(40, 46) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 35) * M(35, 47)
      temp = temp + M(40, 39) * M(39, 47)
      M(40, 47) = ( M(40, 47) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 19) * M(19, 48)
      temp = temp + M(40, 35) * M(35, 48)
      temp = temp + M(40, 39) * M(39, 48)
      M(40, 48) = ( M(40, 48) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 35) * M(35, 49)
      temp = temp + M(40, 36) * M(36, 49)
      temp = temp + M(40, 39) * M(39, 49)
      M(40, 49) = ( M(40, 49) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 19) * M(19, 50)
      temp = temp + M(40, 22) * M(22, 50)
      temp = temp + M(40, 35) * M(35, 50)
      temp = temp + M(40, 36) * M(36, 50)
      temp = temp + M(40, 39) * M(39, 50)
      M(40, 50) = ( M(40, 50) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 22) * M(22, 51)
      temp = temp + M(40, 36) * M(36, 51)
      M(40, 51) = ( M(40, 51) - temp ) / M(40, 40)
C     Upper part.
      temp = M(40, 35) * M(35, 52)
      temp = temp + M(40, 39) * M(39, 52)
      M(40, 52) = ( M(40, 52) - temp ) / M(40, 40)

C     Lower part.
      temp = M(41, 18) * M(18, 41)
      temp = temp + M(41, 19) * M(19, 41)
      temp = temp + M(41, 40) * M(40, 41)
      M(41, 41) = M(41, 41) - temp
C     Lower part.
      temp = M(42, 19) * M(19, 41)
      temp = temp + M(42, 20) * M(20, 41)
      temp = temp + M(42, 37) * M(37, 41)
      temp = temp + M(42, 38) * M(38, 41)
      temp = temp + M(42, 40) * M(40, 41)
      M(42, 41) = M(42, 41) - temp
C     Lower part.
      temp = M(44, 38) * M(38, 41)
      M(44, 41) = M(44, 41) - temp
C     Lower part.
      temp = M(45, 40) * M(40, 41)
      M(45, 41) = M(45, 41) - temp
C     Lower part.
      temp = M(48, 18) * M(18, 41)
      temp = temp + M(48, 40) * M(40, 41)
      M(48, 41) = M(48, 41) - temp
C     Lower part.
      temp = M(49, 19) * M(19, 41)
      temp = temp + M(49, 40) * M(40, 41)
      M(49, 41) = M(49, 41) - temp
C     Lower part.
      temp = M(50, 18) * M(18, 41)
      temp = temp + M(50, 19) * M(19, 41)
      temp = temp + M(50, 20) * M(20, 41)
      temp = temp + M(50, 37) * M(37, 41)
      temp = temp + M(50, 40) * M(40, 41)
      M(50, 41) = M(50, 41) - temp
C     Lower part.
      temp = M(51, 40) * M(40, 41)
      M(51, 41) = M(51, 41) - temp
C     Lower part.
      temp = M(52, 18) * M(18, 41)
      temp = temp + M(52, 38) * M(38, 41)
      temp = temp + M(52, 40) * M(40, 41)
      M(52, 41) = M(52, 41) - temp
C     Upper part.
      temp = M(41, 2) * M(2, 42)
      temp = temp + M(41, 11) * M(11, 42)
      temp = temp + M(41, 19) * M(19, 42)
      temp = temp + M(41, 23) * M(23, 42)
      temp = temp + M(41, 24) * M(24, 42)
      temp = temp + M(41, 25) * M(25, 42)
      temp = temp + M(41, 26) * M(26, 42)
      temp = temp + M(41, 28) * M(28, 42)
      temp = temp + M(41, 30) * M(30, 42)
      temp = temp + M(41, 31) * M(31, 42)
      temp = temp + M(41, 32) * M(32, 42)
      temp = temp + M(41, 33) * M(33, 42)
      temp = temp + M(41, 34) * M(34, 42)
      temp = temp + M(41, 39) * M(39, 42)
      temp = temp + M(41, 40) * M(40, 42)
      M(41, 42) = ( M(41, 42) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 23) * M(23, 43)
      temp = temp + M(41, 24) * M(24, 43)
      temp = temp + M(41, 25) * M(25, 43)
      temp = temp + M(41, 26) * M(26, 43)
      temp = temp + M(41, 31) * M(31, 43)
      temp = temp + M(41, 32) * M(32, 43)
      temp = temp + M(41, 33) * M(33, 43)
      temp = temp + M(41, 34) * M(34, 43)
      temp = temp + M(41, 39) * M(39, 43)
      temp = temp + M(41, 40) * M(40, 43)
      M(41, 43) = ( M(41, 43) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 23) * M(23, 44)
      temp = temp + M(41, 24) * M(24, 44)
      temp = temp + M(41, 25) * M(25, 44)
      temp = temp + M(41, 26) * M(26, 44)
      temp = temp + M(41, 28) * M(28, 44)
      temp = temp + M(41, 30) * M(30, 44)
      temp = temp + M(41, 31) * M(31, 44)
      temp = temp + M(41, 32) * M(32, 44)
      temp = temp + M(41, 33) * M(33, 44)
      temp = temp + M(41, 34) * M(34, 44)
      temp = temp + M(41, 39) * M(39, 44)
      temp = temp + M(41, 40) * M(40, 44)
      M(41, 44) = ( M(41, 44) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 45)
      M(41, 45) = ( M(41, 45) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 46)
      M(41, 46) = ( M(41, 46) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 23) * M(23, 47)
      temp = temp + M(41, 24) * M(24, 47)
      temp = temp + M(41, 25) * M(25, 47)
      temp = temp + M(41, 26) * M(26, 47)
      temp = temp + M(41, 28) * M(28, 47)
      temp = temp + M(41, 31) * M(31, 47)
      temp = temp + M(41, 32) * M(32, 47)
      temp = temp + M(41, 33) * M(33, 47)
      temp = temp + M(41, 34) * M(34, 47)
      temp = temp + M(41, 39) * M(39, 47)
      temp = temp + M(41, 40) * M(40, 47)
      M(41, 47) = ( M(41, 47) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 18) * M(18, 48)
      temp = temp + M(41, 19) * M(19, 48)
      temp = temp + M(41, 28) * M(28, 48)
      temp = temp + M(41, 30) * M(30, 48)
      temp = temp + M(41, 33) * M(33, 48)
      temp = temp + M(41, 34) * M(34, 48)
      temp = temp + M(41, 39) * M(39, 48)
      temp = temp + M(41, 40) * M(40, 48)
      M(41, 48) = ( M(41, 48) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 39) * M(39, 49)
      temp = temp + M(41, 40) * M(40, 49)
      M(41, 49) = ( M(41, 49) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 18) * M(18, 50)
      temp = temp + M(41, 19) * M(19, 50)
      temp = temp + M(41, 28) * M(28, 50)
      temp = temp + M(41, 30) * M(30, 50)
      temp = temp + M(41, 33) * M(33, 50)
      temp = temp + M(41, 34) * M(34, 50)
      temp = temp + M(41, 39) * M(39, 50)
      temp = temp + M(41, 40) * M(40, 50)
      M(41, 50) = ( M(41, 50) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 40) * M(40, 51)
      M(41, 51) = ( M(41, 51) - temp ) / M(41, 41)
C     Upper part.
      temp = M(41, 30) * M(30, 52)
      temp = temp + M(41, 31) * M(31, 52)
      temp = temp + M(41, 32) * M(32, 52)
      temp = temp + M(41, 33) * M(33, 52)
      temp = temp + M(41, 34) * M(34, 52)
      temp = temp + M(41, 39) * M(39, 52)
      temp = temp + M(41, 40) * M(40, 52)
      M(41, 52) = ( M(41, 52) - temp ) / M(41, 41)

C     Lower part.
      temp = M(42, 2) * M(2, 42)
      temp = temp + M(42, 3) * M(3, 42)
      temp = temp + M(42, 4) * M(4, 42)
      temp = temp + M(42, 5) * M(5, 42)
      temp = temp + M(42, 6) * M(6, 42)
      temp = temp + M(42, 7) * M(7, 42)
      temp = temp + M(42, 11) * M(11, 42)
      temp = temp + M(42, 13) * M(13, 42)
      temp = temp + M(42, 14) * M(14, 42)
      temp = temp + M(42, 15) * M(15, 42)
      temp = temp + M(42, 17) * M(17, 42)
      temp = temp + M(42, 19) * M(19, 42)
      temp = temp + M(42, 20) * M(20, 42)
      temp = temp + M(42, 21) * M(21, 42)
      temp = temp + M(42, 22) * M(22, 42)
      temp = temp + M(42, 23) * M(23, 42)
      temp = temp + M(42, 24) * M(24, 42)
      temp = temp + M(42, 25) * M(25, 42)
      temp = temp + M(42, 26) * M(26, 42)
      temp = temp + M(42, 27) * M(27, 42)
      temp = temp + M(42, 28) * M(28, 42)
      temp = temp + M(42, 29) * M(29, 42)
      temp = temp + M(42, 30) * M(30, 42)
      temp = temp + M(42, 31) * M(31, 42)
      temp = temp + M(42, 32) * M(32, 42)
      temp = temp + M(42, 33) * M(33, 42)
      temp = temp + M(42, 34) * M(34, 42)
      temp = temp + M(42, 35) * M(35, 42)
      temp = temp + M(42, 36) * M(36, 42)
      temp = temp + M(42, 37) * M(37, 42)
      temp = temp + M(42, 38) * M(38, 42)
      temp = temp + M(42, 39) * M(39, 42)
      temp = temp + M(42, 40) * M(40, 42)
      temp = temp + M(42, 41) * M(41, 42)
      M(42, 42) = M(42, 42) - temp
C     Lower part.
      temp = M(43, 17) * M(17, 42)
      temp = temp + M(43, 23) * M(23, 42)
      temp = temp + M(43, 24) * M(24, 42)
      temp = temp + M(43, 25) * M(25, 42)
      temp = temp + M(43, 26) * M(26, 42)
      temp = temp + M(43, 31) * M(31, 42)
      temp = temp + M(43, 35) * M(35, 42)
      temp = temp + M(43, 39) * M(39, 42)
      temp = temp + M(43, 41) * M(41, 42)
      M(43, 42) = M(43, 42) - temp
C     Lower part.
      temp = M(44, 13) * M(13, 42)
      temp = temp + M(44, 23) * M(23, 42)
      temp = temp + M(44, 24) * M(24, 42)
      temp = temp + M(44, 25) * M(25, 42)
      temp = temp + M(44, 26) * M(26, 42)
      temp = temp + M(44, 27) * M(27, 42)
      temp = temp + M(44, 30) * M(30, 42)
      temp = temp + M(44, 31) * M(31, 42)
      temp = temp + M(44, 32) * M(32, 42)
      temp = temp + M(44, 35) * M(35, 42)
      temp = temp + M(44, 38) * M(38, 42)
      temp = temp + M(44, 39) * M(39, 42)
      temp = temp + M(44, 41) * M(41, 42)
      M(44, 42) = M(44, 42) - temp
C     Lower part.
      temp = M(45, 2) * M(2, 42)
      temp = temp + M(45, 4) * M(4, 42)
      temp = temp + M(45, 14) * M(14, 42)
      temp = temp + M(45, 16) * M(16, 42)
      temp = temp + M(45, 21) * M(21, 42)
      temp = temp + M(45, 24) * M(24, 42)
      temp = temp + M(45, 25) * M(25, 42)
      temp = temp + M(45, 32) * M(32, 42)
      temp = temp + M(45, 33) * M(33, 42)
      temp = temp + M(45, 34) * M(34, 42)
      temp = temp + M(45, 39) * M(39, 42)
      temp = temp + M(45, 40) * M(40, 42)
      temp = temp + M(45, 41) * M(41, 42)
      M(45, 42) = M(45, 42) - temp
C     Lower part.
      temp = M(46, 14) * M(14, 42)
      temp = temp + M(46, 26) * M(26, 42)
      temp = temp + M(46, 31) * M(31, 42)
      temp = temp + M(46, 32) * M(32, 42)
      temp = temp + M(46, 35) * M(35, 42)
      temp = temp + M(46, 39) * M(39, 42)
      M(46, 42) = M(46, 42) - temp
C     Lower part.
      temp = M(47, 23) * M(23, 42)
      temp = temp + M(47, 24) * M(24, 42)
      temp = temp + M(47, 25) * M(25, 42)
      temp = temp + M(47, 26) * M(26, 42)
      temp = temp + M(47, 28) * M(28, 42)
      temp = temp + M(47, 30) * M(30, 42)
      temp = temp + M(47, 31) * M(31, 42)
      temp = temp + M(47, 32) * M(32, 42)
      M(47, 42) = M(47, 42) - temp
C     Lower part.
      temp = M(48, 12) * M(12, 42)
      temp = temp + M(48, 15) * M(15, 42)
      temp = temp + M(48, 31) * M(31, 42)
      temp = temp + M(48, 39) * M(39, 42)
      temp = temp + M(48, 40) * M(40, 42)
      temp = temp + M(48, 41) * M(41, 42)
      M(48, 42) = M(48, 42) - temp
C     Lower part.
      temp = M(49, 2) * M(2, 42)
      temp = temp + M(49, 4) * M(4, 42)
      temp = temp + M(49, 5) * M(5, 42)
      temp = temp + M(49, 6) * M(6, 42)
      temp = temp + M(49, 16) * M(16, 42)
      temp = temp + M(49, 19) * M(19, 42)
      temp = temp + M(49, 21) * M(21, 42)
      temp = temp + M(49, 23) * M(23, 42)
      temp = temp + M(49, 24) * M(24, 42)
      temp = temp + M(49, 25) * M(25, 42)
      temp = temp + M(49, 26) * M(26, 42)
      temp = temp + M(49, 27) * M(27, 42)
      temp = temp + M(49, 28) * M(28, 42)
      temp = temp + M(49, 29) * M(29, 42)
      temp = temp + M(49, 30) * M(30, 42)
      temp = temp + M(49, 31) * M(31, 42)
      temp = temp + M(49, 32) * M(32, 42)
      temp = temp + M(49, 34) * M(34, 42)
      temp = temp + M(49, 39) * M(39, 42)
      temp = temp + M(49, 40) * M(40, 42)
      temp = temp + M(49, 41) * M(41, 42)
      M(49, 42) = M(49, 42) - temp
C     Lower part.
      temp = M(50, 2) * M(2, 42)
      temp = temp + M(50, 4) * M(4, 42)
      temp = temp + M(50, 5) * M(5, 42)
      temp = temp + M(50, 6) * M(6, 42)
      temp = temp + M(50, 7) * M(7, 42)
      temp = temp + M(50, 11) * M(11, 42)
      temp = temp + M(50, 12) * M(12, 42)
      temp = temp + M(50, 13) * M(13, 42)
      temp = temp + M(50, 16) * M(16, 42)
      temp = temp + M(50, 17) * M(17, 42)
      temp = temp + M(50, 19) * M(19, 42)
      temp = temp + M(50, 20) * M(20, 42)
      temp = temp + M(50, 21) * M(21, 42)
      temp = temp + M(50, 23) * M(23, 42)
      temp = temp + M(50, 24) * M(24, 42)
      temp = temp + M(50, 25) * M(25, 42)
      temp = temp + M(50, 26) * M(26, 42)
      temp = temp + M(50, 27) * M(27, 42)
      temp = temp + M(50, 28) * M(28, 42)
      temp = temp + M(50, 29) * M(29, 42)
      temp = temp + M(50, 30) * M(30, 42)
      temp = temp + M(50, 31) * M(31, 42)
      temp = temp + M(50, 32) * M(32, 42)
      temp = temp + M(50, 33) * M(33, 42)
      temp = temp + M(50, 34) * M(34, 42)
      temp = temp + M(50, 35) * M(35, 42)
      temp = temp + M(50, 37) * M(37, 42)
      temp = temp + M(50, 39) * M(39, 42)
      temp = temp + M(50, 40) * M(40, 42)
      temp = temp + M(50, 41) * M(41, 42)
      M(50, 42) = M(50, 42) - temp
C     Lower part.
      temp = M(51, 22) * M(22, 42)
      temp = temp + M(51, 28) * M(28, 42)
      temp = temp + M(51, 29) * M(29, 42)
      temp = temp + M(51, 30) * M(30, 42)
      temp = temp + M(51, 32) * M(32, 42)
      temp = temp + M(51, 40) * M(40, 42)
      temp = temp + M(51, 41) * M(41, 42)
      M(51, 42) = M(51, 42) - temp
C     Lower part.
      temp = M(52, 12) * M(12, 42)
      temp = temp + M(52, 13) * M(13, 42)
      temp = temp + M(52, 14) * M(14, 42)
      temp = temp + M(52, 15) * M(15, 42)
      temp = temp + M(52, 16) * M(16, 42)
      temp = temp + M(52, 23) * M(23, 42)
      temp = temp + M(52, 24) * M(24, 42)
      temp = temp + M(52, 25) * M(25, 42)
      temp = temp + M(52, 26) * M(26, 42)
      temp = temp + M(52, 30) * M(30, 42)
      temp = temp + M(52, 31) * M(31, 42)
      temp = temp + M(52, 33) * M(33, 42)
      temp = temp + M(52, 34) * M(34, 42)
      temp = temp + M(52, 38) * M(38, 42)
      temp = temp + M(52, 39) * M(39, 42)
      temp = temp + M(52, 40) * M(40, 42)
      temp = temp + M(52, 41) * M(41, 42)
      M(52, 42) = M(52, 42) - temp
C     Upper part.
      temp = M(42, 17) * M(17, 43)
      temp = temp + M(42, 23) * M(23, 43)
      temp = temp + M(42, 24) * M(24, 43)
      temp = temp + M(42, 25) * M(25, 43)
      temp = temp + M(42, 26) * M(26, 43)
      temp = temp + M(42, 31) * M(31, 43)
      temp = temp + M(42, 32) * M(32, 43)
      temp = temp + M(42, 33) * M(33, 43)
      temp = temp + M(42, 34) * M(34, 43)
      temp = temp + M(42, 35) * M(35, 43)
      temp = temp + M(42, 37) * M(37, 43)
      temp = temp + M(42, 38) * M(38, 43)
      temp = temp + M(42, 39) * M(39, 43)
      temp = temp + M(42, 40) * M(40, 43)
      temp = temp + M(42, 41) * M(41, 43)
      M(42, 43) = ( M(42, 43) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 23) * M(23, 44)
      temp = temp + M(42, 24) * M(24, 44)
      temp = temp + M(42, 25) * M(25, 44)
      temp = temp + M(42, 26) * M(26, 44)
      temp = temp + M(42, 27) * M(27, 44)
      temp = temp + M(42, 28) * M(28, 44)
      temp = temp + M(42, 29) * M(29, 44)
      temp = temp + M(42, 30) * M(30, 44)
      temp = temp + M(42, 31) * M(31, 44)
      temp = temp + M(42, 32) * M(32, 44)
      temp = temp + M(42, 33) * M(33, 44)
      temp = temp + M(42, 34) * M(34, 44)
      temp = temp + M(42, 35) * M(35, 44)
      temp = temp + M(42, 37) * M(37, 44)
      temp = temp + M(42, 38) * M(38, 44)
      temp = temp + M(42, 39) * M(39, 44)
      temp = temp + M(42, 40) * M(40, 44)
      temp = temp + M(42, 41) * M(41, 44)
      M(42, 44) = ( M(42, 44) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 37) * M(37, 45)
      temp = temp + M(42, 38) * M(38, 45)
      temp = temp + M(42, 40) * M(40, 45)
      temp = temp + M(42, 41) * M(41, 45)
      M(42, 45) = ( M(42, 45) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 14) * M(14, 46)
      temp = temp + M(42, 22) * M(22, 46)
      temp = temp + M(42, 36) * M(36, 46)
      temp = temp + M(42, 40) * M(40, 46)
      temp = temp + M(42, 41) * M(41, 46)
      M(42, 46) = ( M(42, 46) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 1) * M(1, 47)
      temp = temp + M(42, 20) * M(20, 47)
      temp = temp + M(42, 23) * M(23, 47)
      temp = temp + M(42, 24) * M(24, 47)
      temp = temp + M(42, 25) * M(25, 47)
      temp = temp + M(42, 26) * M(26, 47)
      temp = temp + M(42, 28) * M(28, 47)
      temp = temp + M(42, 29) * M(29, 47)
      temp = temp + M(42, 31) * M(31, 47)
      temp = temp + M(42, 32) * M(32, 47)
      temp = temp + M(42, 33) * M(33, 47)
      temp = temp + M(42, 34) * M(34, 47)
      temp = temp + M(42, 35) * M(35, 47)
      temp = temp + M(42, 37) * M(37, 47)
      temp = temp + M(42, 38) * M(38, 47)
      temp = temp + M(42, 39) * M(39, 47)
      temp = temp + M(42, 40) * M(40, 47)
      temp = temp + M(42, 41) * M(41, 47)
      M(42, 47) = ( M(42, 47) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 15) * M(15, 48)
      temp = temp + M(42, 19) * M(19, 48)
      temp = temp + M(42, 20) * M(20, 48)
      temp = temp + M(42, 27) * M(27, 48)
      temp = temp + M(42, 28) * M(28, 48)
      temp = temp + M(42, 29) * M(29, 48)
      temp = temp + M(42, 30) * M(30, 48)
      temp = temp + M(42, 33) * M(33, 48)
      temp = temp + M(42, 34) * M(34, 48)
      temp = temp + M(42, 35) * M(35, 48)
      temp = temp + M(42, 37) * M(37, 48)
      temp = temp + M(42, 38) * M(38, 48)
      temp = temp + M(42, 39) * M(39, 48)
      temp = temp + M(42, 40) * M(40, 48)
      temp = temp + M(42, 41) * M(41, 48)
      M(42, 48) = ( M(42, 48) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 21) * M(21, 49)
      temp = temp + M(42, 35) * M(35, 49)
      temp = temp + M(42, 36) * M(36, 49)
      temp = temp + M(42, 37) * M(37, 49)
      temp = temp + M(42, 38) * M(38, 49)
      temp = temp + M(42, 39) * M(39, 49)
      temp = temp + M(42, 40) * M(40, 49)
      temp = temp + M(42, 41) * M(41, 49)
      M(42, 49) = ( M(42, 49) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 13) * M(13, 50)
      temp = temp + M(42, 17) * M(17, 50)
      temp = temp + M(42, 19) * M(19, 50)
      temp = temp + M(42, 20) * M(20, 50)
      temp = temp + M(42, 21) * M(21, 50)
      temp = temp + M(42, 22) * M(22, 50)
      temp = temp + M(42, 27) * M(27, 50)
      temp = temp + M(42, 28) * M(28, 50)
      temp = temp + M(42, 29) * M(29, 50)
      temp = temp + M(42, 30) * M(30, 50)
      temp = temp + M(42, 33) * M(33, 50)
      temp = temp + M(42, 34) * M(34, 50)
      temp = temp + M(42, 35) * M(35, 50)
      temp = temp + M(42, 36) * M(36, 50)
      temp = temp + M(42, 37) * M(37, 50)
      temp = temp + M(42, 38) * M(38, 50)
      temp = temp + M(42, 39) * M(39, 50)
      temp = temp + M(42, 40) * M(40, 50)
      temp = temp + M(42, 41) * M(41, 50)
      M(42, 50) = ( M(42, 50) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 22) * M(22, 51)
      temp = temp + M(42, 36) * M(36, 51)
      temp = temp + M(42, 40) * M(40, 51)
      temp = temp + M(42, 41) * M(41, 51)
      M(42, 51) = ( M(42, 51) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 13) * M(13, 52)
      temp = temp + M(42, 14) * M(14, 52)
      temp = temp + M(42, 15) * M(15, 52)
      temp = temp + M(42, 30) * M(30, 52)
      temp = temp + M(42, 31) * M(31, 52)
      temp = temp + M(42, 32) * M(32, 52)
      temp = temp + M(42, 33) * M(33, 52)
      temp = temp + M(42, 34) * M(34, 52)
      temp = temp + M(42, 35) * M(35, 52)
      temp = temp + M(42, 37) * M(37, 52)
      temp = temp + M(42, 38) * M(38, 52)
      temp = temp + M(42, 39) * M(39, 52)
      temp = temp + M(42, 40) * M(40, 52)
      temp = temp + M(42, 41) * M(41, 52)
      M(42, 52) = ( M(42, 52) - temp ) / M(42, 42)

C     Lower part.
      temp = M(43, 17) * M(17, 43)
      temp = temp + M(43, 23) * M(23, 43)
      temp = temp + M(43, 24) * M(24, 43)
      temp = temp + M(43, 25) * M(25, 43)
      temp = temp + M(43, 26) * M(26, 43)
      temp = temp + M(43, 31) * M(31, 43)
      temp = temp + M(43, 35) * M(35, 43)
      temp = temp + M(43, 39) * M(39, 43)
      temp = temp + M(43, 41) * M(41, 43)
      temp = temp + M(43, 42) * M(42, 43)
      M(43, 43) = M(43, 43) - temp
C     Lower part.
      temp = M(44, 23) * M(23, 43)
      temp = temp + M(44, 24) * M(24, 43)
      temp = temp + M(44, 25) * M(25, 43)
      temp = temp + M(44, 26) * M(26, 43)
      temp = temp + M(44, 31) * M(31, 43)
      temp = temp + M(44, 32) * M(32, 43)
      temp = temp + M(44, 35) * M(35, 43)
      temp = temp + M(44, 38) * M(38, 43)
      temp = temp + M(44, 39) * M(39, 43)
      temp = temp + M(44, 41) * M(41, 43)
      temp = temp + M(44, 42) * M(42, 43)
      M(44, 43) = M(44, 43) - temp
C     Lower part.
      temp = M(45, 24) * M(24, 43)
      temp = temp + M(45, 25) * M(25, 43)
      temp = temp + M(45, 32) * M(32, 43)
      temp = temp + M(45, 33) * M(33, 43)
      temp = temp + M(45, 34) * M(34, 43)
      temp = temp + M(45, 39) * M(39, 43)
      temp = temp + M(45, 40) * M(40, 43)
      temp = temp + M(45, 41) * M(41, 43)
      temp = temp + M(45, 42) * M(42, 43)
      M(45, 43) = M(45, 43) - temp
C     Lower part.
      temp = M(46, 26) * M(26, 43)
      temp = temp + M(46, 31) * M(31, 43)
      temp = temp + M(46, 32) * M(32, 43)
      temp = temp + M(46, 35) * M(35, 43)
      temp = temp + M(46, 39) * M(39, 43)
      temp = temp + M(46, 42) * M(42, 43)
      M(46, 43) = M(46, 43) - temp
C     Lower part.
      temp = M(47, 23) * M(23, 43)
      temp = temp + M(47, 24) * M(24, 43)
      temp = temp + M(47, 25) * M(25, 43)
      temp = temp + M(47, 26) * M(26, 43)
      temp = temp + M(47, 31) * M(31, 43)
      temp = temp + M(47, 32) * M(32, 43)
      temp = temp + M(47, 42) * M(42, 43)
      M(47, 43) = M(47, 43) - temp
C     Lower part.
      temp = M(48, 31) * M(31, 43)
      temp = temp + M(48, 39) * M(39, 43)
      temp = temp + M(48, 40) * M(40, 43)
      temp = temp + M(48, 41) * M(41, 43)
      temp = temp + M(48, 42) * M(42, 43)
      M(48, 43) = M(48, 43) - temp
C     Lower part.
      temp = M(49, 23) * M(23, 43)
      temp = temp + M(49, 24) * M(24, 43)
      temp = temp + M(49, 25) * M(25, 43)
      temp = temp + M(49, 26) * M(26, 43)
      temp = temp + M(49, 31) * M(31, 43)
      temp = temp + M(49, 32) * M(32, 43)
      temp = temp + M(49, 34) * M(34, 43)
      temp = temp + M(49, 39) * M(39, 43)
      temp = temp + M(49, 40) * M(40, 43)
      temp = temp + M(49, 41) * M(41, 43)
      temp = temp + M(49, 42) * M(42, 43)
      M(49, 43) = M(49, 43) - temp
C     Lower part.
      temp = M(50, 17) * M(17, 43)
      temp = temp + M(50, 23) * M(23, 43)
      temp = temp + M(50, 24) * M(24, 43)
      temp = temp + M(50, 25) * M(25, 43)
      temp = temp + M(50, 26) * M(26, 43)
      temp = temp + M(50, 31) * M(31, 43)
      temp = temp + M(50, 32) * M(32, 43)
      temp = temp + M(50, 33) * M(33, 43)
      temp = temp + M(50, 34) * M(34, 43)
      temp = temp + M(50, 35) * M(35, 43)
      temp = temp + M(50, 37) * M(37, 43)
      temp = temp + M(50, 39) * M(39, 43)
      temp = temp + M(50, 40) * M(40, 43)
      temp = temp + M(50, 41) * M(41, 43)
      temp = temp + M(50, 42) * M(42, 43)
      M(50, 43) = M(50, 43) - temp
C     Lower part.
      temp = M(51, 32) * M(32, 43)
      temp = temp + M(51, 40) * M(40, 43)
      temp = temp + M(51, 41) * M(41, 43)
      temp = temp + M(51, 42) * M(42, 43)
      M(51, 43) = M(51, 43) - temp
C     Lower part.
      temp = M(52, 23) * M(23, 43)
      temp = temp + M(52, 24) * M(24, 43)
      temp = temp + M(52, 25) * M(25, 43)
      temp = temp + M(52, 26) * M(26, 43)
      temp = temp + M(52, 31) * M(31, 43)
      temp = temp + M(52, 33) * M(33, 43)
      temp = temp + M(52, 34) * M(34, 43)
      temp = temp + M(52, 38) * M(38, 43)
      temp = temp + M(52, 39) * M(39, 43)
      temp = temp + M(52, 40) * M(40, 43)
      temp = temp + M(52, 41) * M(41, 43)
      temp = temp + M(52, 42) * M(42, 43)
      M(52, 43) = M(52, 43) - temp
C     Upper part.
      temp = M(43, 23) * M(23, 44)
      temp = temp + M(43, 24) * M(24, 44)
      temp = temp + M(43, 25) * M(25, 44)
      temp = temp + M(43, 26) * M(26, 44)
      temp = temp + M(43, 31) * M(31, 44)
      temp = temp + M(43, 35) * M(35, 44)
      temp = temp + M(43, 39) * M(39, 44)
      temp = temp + M(43, 41) * M(41, 44)
      temp = temp + M(43, 42) * M(42, 44)
      M(43, 44) = ( M(43, 44) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 41) * M(41, 45)
      temp = temp + M(43, 42) * M(42, 45)
      M(43, 45) = ( M(43, 45) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 41) * M(41, 46)
      temp = temp + M(43, 42) * M(42, 46)
      M(43, 46) = ( M(43, 46) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 1) * M(1, 47)
      temp = temp + M(43, 23) * M(23, 47)
      temp = temp + M(43, 24) * M(24, 47)
      temp = temp + M(43, 25) * M(25, 47)
      temp = temp + M(43, 26) * M(26, 47)
      temp = temp + M(43, 31) * M(31, 47)
      temp = temp + M(43, 35) * M(35, 47)
      temp = temp + M(43, 39) * M(39, 47)
      temp = temp + M(43, 41) * M(41, 47)
      temp = temp + M(43, 42) * M(42, 47)
      M(43, 47) = ( M(43, 47) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 35) * M(35, 48)
      temp = temp + M(43, 39) * M(39, 48)
      temp = temp + M(43, 41) * M(41, 48)
      temp = temp + M(43, 42) * M(42, 48)
      M(43, 48) = ( M(43, 48) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 35) * M(35, 49)
      temp = temp + M(43, 39) * M(39, 49)
      temp = temp + M(43, 41) * M(41, 49)
      temp = temp + M(43, 42) * M(42, 49)
      M(43, 49) = ( M(43, 49) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 17) * M(17, 50)
      temp = temp + M(43, 35) * M(35, 50)
      temp = temp + M(43, 39) * M(39, 50)
      temp = temp + M(43, 41) * M(41, 50)
      temp = temp + M(43, 42) * M(42, 50)
      M(43, 50) = ( M(43, 50) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 41) * M(41, 51)
      temp = temp + M(43, 42) * M(42, 51)
      M(43, 51) = ( M(43, 51) - temp ) / M(43, 43)
C     Upper part.
      temp = M(43, 31) * M(31, 52)
      temp = temp + M(43, 35) * M(35, 52)
      temp = temp + M(43, 39) * M(39, 52)
      temp = temp + M(43, 41) * M(41, 52)
      temp = temp + M(43, 42) * M(42, 52)
      M(43, 52) = ( M(43, 52) - temp ) / M(43, 43)

C     Lower part.
      temp = M(44, 9) * M(9, 44)
      temp = temp + M(44, 23) * M(23, 44)
      temp = temp + M(44, 24) * M(24, 44)
      temp = temp + M(44, 25) * M(25, 44)
      temp = temp + M(44, 26) * M(26, 44)
      temp = temp + M(44, 27) * M(27, 44)
      temp = temp + M(44, 30) * M(30, 44)
      temp = temp + M(44, 31) * M(31, 44)
      temp = temp + M(44, 32) * M(32, 44)
      temp = temp + M(44, 35) * M(35, 44)
      temp = temp + M(44, 38) * M(38, 44)
      temp = temp + M(44, 39) * M(39, 44)
      temp = temp + M(44, 41) * M(41, 44)
      temp = temp + M(44, 42) * M(42, 44)
      temp = temp + M(44, 43) * M(43, 44)
      M(44, 44) = M(44, 44) - temp
C     Lower part.
      temp = M(45, 24) * M(24, 44)
      temp = temp + M(45, 25) * M(25, 44)
      temp = temp + M(45, 32) * M(32, 44)
      temp = temp + M(45, 33) * M(33, 44)
      temp = temp + M(45, 34) * M(34, 44)
      temp = temp + M(45, 39) * M(39, 44)
      temp = temp + M(45, 40) * M(40, 44)
      temp = temp + M(45, 41) * M(41, 44)
      temp = temp + M(45, 42) * M(42, 44)
      temp = temp + M(45, 43) * M(43, 44)
      M(45, 44) = M(45, 44) - temp
C     Lower part.
      temp = M(46, 26) * M(26, 44)
      temp = temp + M(46, 31) * M(31, 44)
      temp = temp + M(46, 32) * M(32, 44)
      temp = temp + M(46, 35) * M(35, 44)
      temp = temp + M(46, 39) * M(39, 44)
      temp = temp + M(46, 42) * M(42, 44)
      temp = temp + M(46, 43) * M(43, 44)
      M(46, 44) = M(46, 44) - temp
C     Lower part.
      temp = M(47, 23) * M(23, 44)
      temp = temp + M(47, 24) * M(24, 44)
      temp = temp + M(47, 25) * M(25, 44)
      temp = temp + M(47, 26) * M(26, 44)
      temp = temp + M(47, 28) * M(28, 44)
      temp = temp + M(47, 30) * M(30, 44)
      temp = temp + M(47, 31) * M(31, 44)
      temp = temp + M(47, 32) * M(32, 44)
      temp = temp + M(47, 42) * M(42, 44)
      temp = temp + M(47, 43) * M(43, 44)
      M(47, 44) = M(47, 44) - temp
C     Lower part.
      temp = M(48, 31) * M(31, 44)
      temp = temp + M(48, 39) * M(39, 44)
      temp = temp + M(48, 40) * M(40, 44)
      temp = temp + M(48, 41) * M(41, 44)
      temp = temp + M(48, 42) * M(42, 44)
      temp = temp + M(48, 43) * M(43, 44)
      M(48, 44) = M(48, 44) - temp
C     Lower part.
      temp = M(49, 23) * M(23, 44)
      temp = temp + M(49, 24) * M(24, 44)
      temp = temp + M(49, 25) * M(25, 44)
      temp = temp + M(49, 26) * M(26, 44)
      temp = temp + M(49, 27) * M(27, 44)
      temp = temp + M(49, 28) * M(28, 44)
      temp = temp + M(49, 29) * M(29, 44)
      temp = temp + M(49, 30) * M(30, 44)
      temp = temp + M(49, 31) * M(31, 44)
      temp = temp + M(49, 32) * M(32, 44)
      temp = temp + M(49, 34) * M(34, 44)
      temp = temp + M(49, 39) * M(39, 44)
      temp = temp + M(49, 40) * M(40, 44)
      temp = temp + M(49, 41) * M(41, 44)
      temp = temp + M(49, 42) * M(42, 44)
      temp = temp + M(49, 43) * M(43, 44)
      M(49, 44) = M(49, 44) - temp
C     Lower part.
      temp = M(50, 23) * M(23, 44)
      temp = temp + M(50, 24) * M(24, 44)
      temp = temp + M(50, 25) * M(25, 44)
      temp = temp + M(50, 26) * M(26, 44)
      temp = temp + M(50, 27) * M(27, 44)
      temp = temp + M(50, 28) * M(28, 44)
      temp = temp + M(50, 29) * M(29, 44)
      temp = temp + M(50, 30) * M(30, 44)
      temp = temp + M(50, 31) * M(31, 44)
      temp = temp + M(50, 32) * M(32, 44)
      temp = temp + M(50, 33) * M(33, 44)
      temp = temp + M(50, 34) * M(34, 44)
      temp = temp + M(50, 35) * M(35, 44)
      temp = temp + M(50, 37) * M(37, 44)
      temp = temp + M(50, 39) * M(39, 44)
      temp = temp + M(50, 40) * M(40, 44)
      temp = temp + M(50, 41) * M(41, 44)
      temp = temp + M(50, 42) * M(42, 44)
      temp = temp + M(50, 43) * M(43, 44)
      M(50, 44) = M(50, 44) - temp
C     Lower part.
      temp = M(51, 28) * M(28, 44)
      temp = temp + M(51, 29) * M(29, 44)
      temp = temp + M(51, 30) * M(30, 44)
      temp = temp + M(51, 32) * M(32, 44)
      temp = temp + M(51, 40) * M(40, 44)
      temp = temp + M(51, 41) * M(41, 44)
      temp = temp + M(51, 42) * M(42, 44)
      temp = temp + M(51, 43) * M(43, 44)
      M(51, 44) = M(51, 44) - temp
C     Lower part.
      temp = M(52, 9) * M(9, 44)
      temp = temp + M(52, 23) * M(23, 44)
      temp = temp + M(52, 24) * M(24, 44)
      temp = temp + M(52, 25) * M(25, 44)
      temp = temp + M(52, 26) * M(26, 44)
      temp = temp + M(52, 30) * M(30, 44)
      temp = temp + M(52, 31) * M(31, 44)
      temp = temp + M(52, 33) * M(33, 44)
      temp = temp + M(52, 34) * M(34, 44)
      temp = temp + M(52, 38) * M(38, 44)
      temp = temp + M(52, 39) * M(39, 44)
      temp = temp + M(52, 40) * M(40, 44)
      temp = temp + M(52, 41) * M(41, 44)
      temp = temp + M(52, 42) * M(42, 44)
      temp = temp + M(52, 43) * M(43, 44)
      M(52, 44) = M(52, 44) - temp
C     Upper part.
      temp = M(44, 38) * M(38, 45)
      temp = temp + M(44, 41) * M(41, 45)
      temp = temp + M(44, 42) * M(42, 45)
      temp = temp + M(44, 43) * M(43, 45)
      M(44, 45) = ( M(44, 45) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 41) * M(41, 46)
      temp = temp + M(44, 42) * M(42, 46)
      temp = temp + M(44, 43) * M(43, 46)
      M(44, 46) = ( M(44, 46) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 23) * M(23, 47)
      temp = temp + M(44, 24) * M(24, 47)
      temp = temp + M(44, 25) * M(25, 47)
      temp = temp + M(44, 26) * M(26, 47)
      temp = temp + M(44, 31) * M(31, 47)
      temp = temp + M(44, 32) * M(32, 47)
      temp = temp + M(44, 35) * M(35, 47)
      temp = temp + M(44, 38) * M(38, 47)
      temp = temp + M(44, 39) * M(39, 47)
      temp = temp + M(44, 41) * M(41, 47)
      temp = temp + M(44, 42) * M(42, 47)
      temp = temp + M(44, 43) * M(43, 47)
      M(44, 47) = ( M(44, 47) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 27) * M(27, 48)
      temp = temp + M(44, 30) * M(30, 48)
      temp = temp + M(44, 35) * M(35, 48)
      temp = temp + M(44, 38) * M(38, 48)
      temp = temp + M(44, 39) * M(39, 48)
      temp = temp + M(44, 41) * M(41, 48)
      temp = temp + M(44, 42) * M(42, 48)
      temp = temp + M(44, 43) * M(43, 48)
      M(44, 48) = ( M(44, 48) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 35) * M(35, 49)
      temp = temp + M(44, 38) * M(38, 49)
      temp = temp + M(44, 39) * M(39, 49)
      temp = temp + M(44, 41) * M(41, 49)
      temp = temp + M(44, 42) * M(42, 49)
      temp = temp + M(44, 43) * M(43, 49)
      M(44, 49) = ( M(44, 49) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 13) * M(13, 50)
      temp = temp + M(44, 27) * M(27, 50)
      temp = temp + M(44, 30) * M(30, 50)
      temp = temp + M(44, 35) * M(35, 50)
      temp = temp + M(44, 38) * M(38, 50)
      temp = temp + M(44, 39) * M(39, 50)
      temp = temp + M(44, 41) * M(41, 50)
      temp = temp + M(44, 42) * M(42, 50)
      temp = temp + M(44, 43) * M(43, 50)
      M(44, 50) = ( M(44, 50) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 41) * M(41, 51)
      temp = temp + M(44, 42) * M(42, 51)
      temp = temp + M(44, 43) * M(43, 51)
      M(44, 51) = ( M(44, 51) - temp ) / M(44, 44)
C     Upper part.
      temp = M(44, 9) * M(9, 52)
      temp = temp + M(44, 13) * M(13, 52)
      temp = temp + M(44, 30) * M(30, 52)
      temp = temp + M(44, 31) * M(31, 52)
      temp = temp + M(44, 32) * M(32, 52)
      temp = temp + M(44, 35) * M(35, 52)
      temp = temp + M(44, 38) * M(38, 52)
      temp = temp + M(44, 39) * M(39, 52)
      temp = temp + M(44, 41) * M(41, 52)
      temp = temp + M(44, 42) * M(42, 52)
      temp = temp + M(44, 43) * M(43, 52)
      M(44, 52) = ( M(44, 52) - temp ) / M(44, 44)

C     Lower part.
      temp = M(45, 40) * M(40, 45)
      temp = temp + M(45, 41) * M(41, 45)
      temp = temp + M(45, 42) * M(42, 45)
      temp = temp + M(45, 43) * M(43, 45)
      temp = temp + M(45, 44) * M(44, 45)
      M(45, 45) = M(45, 45) - temp
C     Lower part.
      temp = M(46, 42) * M(42, 45)
      temp = temp + M(46, 43) * M(43, 45)
      temp = temp + M(46, 44) * M(44, 45)
      M(46, 45) = M(46, 45) - temp
C     Lower part.
      temp = M(47, 42) * M(42, 45)
      temp = temp + M(47, 43) * M(43, 45)
      temp = temp + M(47, 44) * M(44, 45)
      M(47, 45) = M(47, 45) - temp
C     Lower part.
      temp = M(48, 40) * M(40, 45)
      temp = temp + M(48, 41) * M(41, 45)
      temp = temp + M(48, 42) * M(42, 45)
      temp = temp + M(48, 43) * M(43, 45)
      temp = temp + M(48, 44) * M(44, 45)
      M(48, 45) = M(48, 45) - temp
C     Lower part.
      temp = M(49, 40) * M(40, 45)
      temp = temp + M(49, 41) * M(41, 45)
      temp = temp + M(49, 42) * M(42, 45)
      temp = temp + M(49, 43) * M(43, 45)
      temp = temp + M(49, 44) * M(44, 45)
      M(49, 45) = M(49, 45) - temp
C     Lower part.
      temp = M(50, 37) * M(37, 45)
      temp = temp + M(50, 40) * M(40, 45)
      temp = temp + M(50, 41) * M(41, 45)
      temp = temp + M(50, 42) * M(42, 45)
      temp = temp + M(50, 43) * M(43, 45)
      temp = temp + M(50, 44) * M(44, 45)
      M(50, 45) = M(50, 45) - temp
C     Lower part.
      temp = M(51, 40) * M(40, 45)
      temp = temp + M(51, 41) * M(41, 45)
      temp = temp + M(51, 42) * M(42, 45)
      temp = temp + M(51, 43) * M(43, 45)
      temp = temp + M(51, 44) * M(44, 45)
      M(51, 45) = M(51, 45) - temp
C     Lower part.
      temp = M(52, 38) * M(38, 45)
      temp = temp + M(52, 40) * M(40, 45)
      temp = temp + M(52, 41) * M(41, 45)
      temp = temp + M(52, 42) * M(42, 45)
      temp = temp + M(52, 43) * M(43, 45)
      temp = temp + M(52, 44) * M(44, 45)
      M(52, 45) = M(52, 45) - temp
C     Upper part.
      temp = M(45, 14) * M(14, 46)
      temp = temp + M(45, 40) * M(40, 46)
      temp = temp + M(45, 41) * M(41, 46)
      temp = temp + M(45, 42) * M(42, 46)
      temp = temp + M(45, 43) * M(43, 46)
      temp = temp + M(45, 44) * M(44, 46)
      M(45, 46) = ( M(45, 46) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 24) * M(24, 47)
      temp = temp + M(45, 25) * M(25, 47)
      temp = temp + M(45, 32) * M(32, 47)
      temp = temp + M(45, 33) * M(33, 47)
      temp = temp + M(45, 34) * M(34, 47)
      temp = temp + M(45, 39) * M(39, 47)
      temp = temp + M(45, 40) * M(40, 47)
      temp = temp + M(45, 41) * M(41, 47)
      temp = temp + M(45, 42) * M(42, 47)
      temp = temp + M(45, 43) * M(43, 47)
      temp = temp + M(45, 44) * M(44, 47)
      M(45, 47) = ( M(45, 47) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 33) * M(33, 48)
      temp = temp + M(45, 34) * M(34, 48)
      temp = temp + M(45, 39) * M(39, 48)
      temp = temp + M(45, 40) * M(40, 48)
      temp = temp + M(45, 41) * M(41, 48)
      temp = temp + M(45, 42) * M(42, 48)
      temp = temp + M(45, 43) * M(43, 48)
      temp = temp + M(45, 44) * M(44, 48)
      M(45, 48) = ( M(45, 48) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 21) * M(21, 49)
      temp = temp + M(45, 39) * M(39, 49)
      temp = temp + M(45, 40) * M(40, 49)
      temp = temp + M(45, 41) * M(41, 49)
      temp = temp + M(45, 42) * M(42, 49)
      temp = temp + M(45, 43) * M(43, 49)
      temp = temp + M(45, 44) * M(44, 49)
      M(45, 49) = ( M(45, 49) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 21) * M(21, 50)
      temp = temp + M(45, 33) * M(33, 50)
      temp = temp + M(45, 34) * M(34, 50)
      temp = temp + M(45, 39) * M(39, 50)
      temp = temp + M(45, 40) * M(40, 50)
      temp = temp + M(45, 41) * M(41, 50)
      temp = temp + M(45, 42) * M(42, 50)
      temp = temp + M(45, 43) * M(43, 50)
      temp = temp + M(45, 44) * M(44, 50)
      M(45, 50) = ( M(45, 50) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 40) * M(40, 51)
      temp = temp + M(45, 41) * M(41, 51)
      temp = temp + M(45, 42) * M(42, 51)
      temp = temp + M(45, 43) * M(43, 51)
      temp = temp + M(45, 44) * M(44, 51)
      M(45, 51) = ( M(45, 51) - temp ) / M(45, 45)
C     Upper part.
      temp = M(45, 14) * M(14, 52)
      temp = temp + M(45, 16) * M(16, 52)
      temp = temp + M(45, 32) * M(32, 52)
      temp = temp + M(45, 33) * M(33, 52)
      temp = temp + M(45, 34) * M(34, 52)
      temp = temp + M(45, 39) * M(39, 52)
      temp = temp + M(45, 40) * M(40, 52)
      temp = temp + M(45, 41) * M(41, 52)
      temp = temp + M(45, 42) * M(42, 52)
      temp = temp + M(45, 43) * M(43, 52)
      temp = temp + M(45, 44) * M(44, 52)
      M(45, 52) = ( M(45, 52) - temp ) / M(45, 45)

C     Lower part.
      temp = M(46, 14) * M(14, 46)
      temp = temp + M(46, 42) * M(42, 46)
      temp = temp + M(46, 43) * M(43, 46)
      temp = temp + M(46, 44) * M(44, 46)
      temp = temp + M(46, 45) * M(45, 46)
      M(46, 46) = M(46, 46) - temp
C     Lower part.
      temp = M(47, 42) * M(42, 46)
      temp = temp + M(47, 43) * M(43, 46)
      temp = temp + M(47, 44) * M(44, 46)
      temp = temp + M(47, 45) * M(45, 46)
      M(47, 46) = M(47, 46) - temp
C     Lower part.
      temp = M(48, 40) * M(40, 46)
      temp = temp + M(48, 41) * M(41, 46)
      temp = temp + M(48, 42) * M(42, 46)
      temp = temp + M(48, 43) * M(43, 46)
      temp = temp + M(48, 44) * M(44, 46)
      temp = temp + M(48, 45) * M(45, 46)
      M(48, 46) = M(48, 46) - temp
C     Lower part.
      temp = M(49, 40) * M(40, 46)
      temp = temp + M(49, 41) * M(41, 46)
      temp = temp + M(49, 42) * M(42, 46)
      temp = temp + M(49, 43) * M(43, 46)
      temp = temp + M(49, 44) * M(44, 46)
      temp = temp + M(49, 45) * M(45, 46)
      M(49, 46) = M(49, 46) - temp
C     Lower part.
      temp = M(50, 40) * M(40, 46)
      temp = temp + M(50, 41) * M(41, 46)
      temp = temp + M(50, 42) * M(42, 46)
      temp = temp + M(50, 43) * M(43, 46)
      temp = temp + M(50, 44) * M(44, 46)
      temp = temp + M(50, 45) * M(45, 46)
      M(50, 46) = M(50, 46) - temp
C     Lower part.
      temp = M(51, 22) * M(22, 46)
      temp = temp + M(51, 40) * M(40, 46)
      temp = temp + M(51, 41) * M(41, 46)
      temp = temp + M(51, 42) * M(42, 46)
      temp = temp + M(51, 43) * M(43, 46)
      temp = temp + M(51, 44) * M(44, 46)
      temp = temp + M(51, 45) * M(45, 46)
      M(51, 46) = M(51, 46) - temp
C     Lower part.
      temp = M(52, 14) * M(14, 46)
      temp = temp + M(52, 40) * M(40, 46)
      temp = temp + M(52, 41) * M(41, 46)
      temp = temp + M(52, 42) * M(42, 46)
      temp = temp + M(52, 43) * M(43, 46)
      temp = temp + M(52, 44) * M(44, 46)
      temp = temp + M(52, 45) * M(45, 46)
      M(52, 46) = M(52, 46) - temp
C     Upper part.
      temp = M(46, 26) * M(26, 47)
      temp = temp + M(46, 31) * M(31, 47)
      temp = temp + M(46, 32) * M(32, 47)
      temp = temp + M(46, 35) * M(35, 47)
      temp = temp + M(46, 39) * M(39, 47)
      temp = temp + M(46, 42) * M(42, 47)
      temp = temp + M(46, 43) * M(43, 47)
      temp = temp + M(46, 44) * M(44, 47)
      temp = temp + M(46, 45) * M(45, 47)
      M(46, 47) = ( M(46, 47) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 35) * M(35, 48)
      temp = temp + M(46, 39) * M(39, 48)
      temp = temp + M(46, 42) * M(42, 48)
      temp = temp + M(46, 43) * M(43, 48)
      temp = temp + M(46, 44) * M(44, 48)
      temp = temp + M(46, 45) * M(45, 48)
      M(46, 48) = ( M(46, 48) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 35) * M(35, 49)
      temp = temp + M(46, 39) * M(39, 49)
      temp = temp + M(46, 42) * M(42, 49)
      temp = temp + M(46, 43) * M(43, 49)
      temp = temp + M(46, 44) * M(44, 49)
      temp = temp + M(46, 45) * M(45, 49)
      M(46, 49) = ( M(46, 49) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 35) * M(35, 50)
      temp = temp + M(46, 39) * M(39, 50)
      temp = temp + M(46, 42) * M(42, 50)
      temp = temp + M(46, 43) * M(43, 50)
      temp = temp + M(46, 44) * M(44, 50)
      temp = temp + M(46, 45) * M(45, 50)
      M(46, 50) = ( M(46, 50) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 42) * M(42, 51)
      temp = temp + M(46, 43) * M(43, 51)
      temp = temp + M(46, 44) * M(44, 51)
      temp = temp + M(46, 45) * M(45, 51)
      M(46, 51) = ( M(46, 51) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 14) * M(14, 52)
      temp = temp + M(46, 31) * M(31, 52)
      temp = temp + M(46, 32) * M(32, 52)
      temp = temp + M(46, 35) * M(35, 52)
      temp = temp + M(46, 39) * M(39, 52)
      temp = temp + M(46, 42) * M(42, 52)
      temp = temp + M(46, 43) * M(43, 52)
      temp = temp + M(46, 44) * M(44, 52)
      temp = temp + M(46, 45) * M(45, 52)
      M(46, 52) = ( M(46, 52) - temp ) / M(46, 46)

C     Lower part.
      temp = M(47, 23) * M(23, 47)
      temp = temp + M(47, 24) * M(24, 47)
      temp = temp + M(47, 25) * M(25, 47)
      temp = temp + M(47, 26) * M(26, 47)
      temp = temp + M(47, 28) * M(28, 47)
      temp = temp + M(47, 31) * M(31, 47)
      temp = temp + M(47, 32) * M(32, 47)
      temp = temp + M(47, 42) * M(42, 47)
      temp = temp + M(47, 43) * M(43, 47)
      temp = temp + M(47, 44) * M(44, 47)
      temp = temp + M(47, 45) * M(45, 47)
      temp = temp + M(47, 46) * M(46, 47)
      M(47, 47) = M(47, 47) - temp
C     Lower part.
      temp = M(48, 31) * M(31, 47)
      temp = temp + M(48, 39) * M(39, 47)
      temp = temp + M(48, 40) * M(40, 47)
      temp = temp + M(48, 41) * M(41, 47)
      temp = temp + M(48, 42) * M(42, 47)
      temp = temp + M(48, 43) * M(43, 47)
      temp = temp + M(48, 44) * M(44, 47)
      temp = temp + M(48, 45) * M(45, 47)
      temp = temp + M(48, 46) * M(46, 47)
      M(48, 47) = M(48, 47) - temp
C     Lower part.
      temp = M(49, 23) * M(23, 47)
      temp = temp + M(49, 24) * M(24, 47)
      temp = temp + M(49, 25) * M(25, 47)
      temp = temp + M(49, 26) * M(26, 47)
      temp = temp + M(49, 28) * M(28, 47)
      temp = temp + M(49, 29) * M(29, 47)
      temp = temp + M(49, 31) * M(31, 47)
      temp = temp + M(49, 32) * M(32, 47)
      temp = temp + M(49, 34) * M(34, 47)
      temp = temp + M(49, 39) * M(39, 47)
      temp = temp + M(49, 40) * M(40, 47)
      temp = temp + M(49, 41) * M(41, 47)
      temp = temp + M(49, 42) * M(42, 47)
      temp = temp + M(49, 43) * M(43, 47)
      temp = temp + M(49, 44) * M(44, 47)
      temp = temp + M(49, 45) * M(45, 47)
      temp = temp + M(49, 46) * M(46, 47)
      M(49, 47) = M(49, 47) - temp
C     Lower part.
      temp = M(50, 1) * M(1, 47)
      temp = temp + M(50, 20) * M(20, 47)
      temp = temp + M(50, 23) * M(23, 47)
      temp = temp + M(50, 24) * M(24, 47)
      temp = temp + M(50, 25) * M(25, 47)
      temp = temp + M(50, 26) * M(26, 47)
      temp = temp + M(50, 28) * M(28, 47)
      temp = temp + M(50, 29) * M(29, 47)
      temp = temp + M(50, 31) * M(31, 47)
      temp = temp + M(50, 32) * M(32, 47)
      temp = temp + M(50, 33) * M(33, 47)
      temp = temp + M(50, 34) * M(34, 47)
      temp = temp + M(50, 35) * M(35, 47)
      temp = temp + M(50, 37) * M(37, 47)
      temp = temp + M(50, 39) * M(39, 47)
      temp = temp + M(50, 40) * M(40, 47)
      temp = temp + M(50, 41) * M(41, 47)
      temp = temp + M(50, 42) * M(42, 47)
      temp = temp + M(50, 43) * M(43, 47)
      temp = temp + M(50, 44) * M(44, 47)
      temp = temp + M(50, 45) * M(45, 47)
      temp = temp + M(50, 46) * M(46, 47)
      M(50, 47) = M(50, 47) - temp
C     Lower part.
      temp = M(51, 28) * M(28, 47)
      temp = temp + M(51, 29) * M(29, 47)
      temp = temp + M(51, 32) * M(32, 47)
      temp = temp + M(51, 40) * M(40, 47)
      temp = temp + M(51, 41) * M(41, 47)
      temp = temp + M(51, 42) * M(42, 47)
      temp = temp + M(51, 43) * M(43, 47)
      temp = temp + M(51, 44) * M(44, 47)
      temp = temp + M(51, 45) * M(45, 47)
      temp = temp + M(51, 46) * M(46, 47)
      M(51, 47) = M(51, 47) - temp
C     Lower part.
      temp = M(52, 23) * M(23, 47)
      temp = temp + M(52, 24) * M(24, 47)
      temp = temp + M(52, 25) * M(25, 47)
      temp = temp + M(52, 26) * M(26, 47)
      temp = temp + M(52, 31) * M(31, 47)
      temp = temp + M(52, 33) * M(33, 47)
      temp = temp + M(52, 34) * M(34, 47)
      temp = temp + M(52, 38) * M(38, 47)
      temp = temp + M(52, 39) * M(39, 47)
      temp = temp + M(52, 40) * M(40, 47)
      temp = temp + M(52, 41) * M(41, 47)
      temp = temp + M(52, 42) * M(42, 47)
      temp = temp + M(52, 43) * M(43, 47)
      temp = temp + M(52, 44) * M(44, 47)
      temp = temp + M(52, 45) * M(45, 47)
      temp = temp + M(52, 46) * M(46, 47)
      M(52, 47) = M(52, 47) - temp
C     Upper part.
      temp = M(47, 28) * M(28, 48)
      temp = temp + M(47, 30) * M(30, 48)
      temp = temp + M(47, 42) * M(42, 48)
      temp = temp + M(47, 43) * M(43, 48)
      temp = temp + M(47, 44) * M(44, 48)
      temp = temp + M(47, 45) * M(45, 48)
      temp = temp + M(47, 46) * M(46, 48)
      M(47, 48) = ( M(47, 48) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 42) * M(42, 49)
      temp = temp + M(47, 43) * M(43, 49)
      temp = temp + M(47, 44) * M(44, 49)
      temp = temp + M(47, 45) * M(45, 49)
      temp = temp + M(47, 46) * M(46, 49)
      M(47, 49) = ( M(47, 49) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 28) * M(28, 50)
      temp = temp + M(47, 30) * M(30, 50)
      temp = temp + M(47, 42) * M(42, 50)
      temp = temp + M(47, 43) * M(43, 50)
      temp = temp + M(47, 44) * M(44, 50)
      temp = temp + M(47, 45) * M(45, 50)
      temp = temp + M(47, 46) * M(46, 50)
      M(47, 50) = ( M(47, 50) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 42) * M(42, 51)
      temp = temp + M(47, 43) * M(43, 51)
      temp = temp + M(47, 44) * M(44, 51)
      temp = temp + M(47, 45) * M(45, 51)
      temp = temp + M(47, 46) * M(46, 51)
      M(47, 51) = ( M(47, 51) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 30) * M(30, 52)
      temp = temp + M(47, 31) * M(31, 52)
      temp = temp + M(47, 32) * M(32, 52)
      temp = temp + M(47, 42) * M(42, 52)
      temp = temp + M(47, 43) * M(43, 52)
      temp = temp + M(47, 44) * M(44, 52)
      temp = temp + M(47, 45) * M(45, 52)
      temp = temp + M(47, 46) * M(46, 52)
      M(47, 52) = ( M(47, 52) - temp ) / M(47, 47)

C     Lower part.
      temp = M(48, 12) * M(12, 48)
      temp = temp + M(48, 15) * M(15, 48)
      temp = temp + M(48, 18) * M(18, 48)
      temp = temp + M(48, 39) * M(39, 48)
      temp = temp + M(48, 40) * M(40, 48)
      temp = temp + M(48, 41) * M(41, 48)
      temp = temp + M(48, 42) * M(42, 48)
      temp = temp + M(48, 43) * M(43, 48)
      temp = temp + M(48, 44) * M(44, 48)
      temp = temp + M(48, 45) * M(45, 48)
      temp = temp + M(48, 46) * M(46, 48)
      temp = temp + M(48, 47) * M(47, 48)
      M(48, 48) = M(48, 48) - temp
C     Lower part.
      temp = M(49, 19) * M(19, 48)
      temp = temp + M(49, 27) * M(27, 48)
      temp = temp + M(49, 28) * M(28, 48)
      temp = temp + M(49, 29) * M(29, 48)
      temp = temp + M(49, 30) * M(30, 48)
      temp = temp + M(49, 34) * M(34, 48)
      temp = temp + M(49, 39) * M(39, 48)
      temp = temp + M(49, 40) * M(40, 48)
      temp = temp + M(49, 41) * M(41, 48)
      temp = temp + M(49, 42) * M(42, 48)
      temp = temp + M(49, 43) * M(43, 48)
      temp = temp + M(49, 44) * M(44, 48)
      temp = temp + M(49, 45) * M(45, 48)
      temp = temp + M(49, 46) * M(46, 48)
      temp = temp + M(49, 47) * M(47, 48)
      M(49, 48) = M(49, 48) - temp
C     Lower part.
      temp = M(50, 12) * M(12, 48)
      temp = temp + M(50, 18) * M(18, 48)
      temp = temp + M(50, 19) * M(19, 48)
      temp = temp + M(50, 20) * M(20, 48)
      temp = temp + M(50, 27) * M(27, 48)
      temp = temp + M(50, 28) * M(28, 48)
      temp = temp + M(50, 29) * M(29, 48)
      temp = temp + M(50, 30) * M(30, 48)
      temp = temp + M(50, 33) * M(33, 48)
      temp = temp + M(50, 34) * M(34, 48)
      temp = temp + M(50, 35) * M(35, 48)
      temp = temp + M(50, 37) * M(37, 48)
      temp = temp + M(50, 39) * M(39, 48)
      temp = temp + M(50, 40) * M(40, 48)
      temp = temp + M(50, 41) * M(41, 48)
      temp = temp + M(50, 42) * M(42, 48)
      temp = temp + M(50, 43) * M(43, 48)
      temp = temp + M(50, 44) * M(44, 48)
      temp = temp + M(50, 45) * M(45, 48)
      temp = temp + M(50, 46) * M(46, 48)
      temp = temp + M(50, 47) * M(47, 48)
      M(50, 48) = M(50, 48) - temp
C     Lower part.
      temp = M(51, 28) * M(28, 48)
      temp = temp + M(51, 29) * M(29, 48)
      temp = temp + M(51, 30) * M(30, 48)
      temp = temp + M(51, 40) * M(40, 48)
      temp = temp + M(51, 41) * M(41, 48)
      temp = temp + M(51, 42) * M(42, 48)
      temp = temp + M(51, 43) * M(43, 48)
      temp = temp + M(51, 44) * M(44, 48)
      temp = temp + M(51, 45) * M(45, 48)
      temp = temp + M(51, 46) * M(46, 48)
      temp = temp + M(51, 47) * M(47, 48)
      M(51, 48) = M(51, 48) - temp
C     Lower part.
      temp = M(52, 12) * M(12, 48)
      temp = temp + M(52, 15) * M(15, 48)
      temp = temp + M(52, 18) * M(18, 48)
      temp = temp + M(52, 30) * M(30, 48)
      temp = temp + M(52, 33) * M(33, 48)
      temp = temp + M(52, 34) * M(34, 48)
      temp = temp + M(52, 38) * M(38, 48)
      temp = temp + M(52, 39) * M(39, 48)
      temp = temp + M(52, 40) * M(40, 48)
      temp = temp + M(52, 41) * M(41, 48)
      temp = temp + M(52, 42) * M(42, 48)
      temp = temp + M(52, 43) * M(43, 48)
      temp = temp + M(52, 44) * M(44, 48)
      temp = temp + M(52, 45) * M(45, 48)
      temp = temp + M(52, 46) * M(46, 48)
      temp = temp + M(52, 47) * M(47, 48)
      M(52, 48) = M(52, 48) - temp
C     Upper part.
      temp = M(48, 39) * M(39, 49)
      temp = temp + M(48, 40) * M(40, 49)
      temp = temp + M(48, 41) * M(41, 49)
      temp = temp + M(48, 42) * M(42, 49)
      temp = temp + M(48, 43) * M(43, 49)
      temp = temp + M(48, 44) * M(44, 49)
      temp = temp + M(48, 45) * M(45, 49)
      temp = temp + M(48, 46) * M(46, 49)
      temp = temp + M(48, 47) * M(47, 49)
      M(48, 49) = ( M(48, 49) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 18) * M(18, 50)
      temp = temp + M(48, 39) * M(39, 50)
      temp = temp + M(48, 40) * M(40, 50)
      temp = temp + M(48, 41) * M(41, 50)
      temp = temp + M(48, 42) * M(42, 50)
      temp = temp + M(48, 43) * M(43, 50)
      temp = temp + M(48, 44) * M(44, 50)
      temp = temp + M(48, 45) * M(45, 50)
      temp = temp + M(48, 46) * M(46, 50)
      temp = temp + M(48, 47) * M(47, 50)
      M(48, 50) = ( M(48, 50) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 40) * M(40, 51)
      temp = temp + M(48, 41) * M(41, 51)
      temp = temp + M(48, 42) * M(42, 51)
      temp = temp + M(48, 43) * M(43, 51)
      temp = temp + M(48, 44) * M(44, 51)
      temp = temp + M(48, 45) * M(45, 51)
      temp = temp + M(48, 46) * M(46, 51)
      temp = temp + M(48, 47) * M(47, 51)
      M(48, 51) = ( M(48, 51) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 15) * M(15, 52)
      temp = temp + M(48, 31) * M(31, 52)
      temp = temp + M(48, 39) * M(39, 52)
      temp = temp + M(48, 40) * M(40, 52)
      temp = temp + M(48, 41) * M(41, 52)
      temp = temp + M(48, 42) * M(42, 52)
      temp = temp + M(48, 43) * M(43, 52)
      temp = temp + M(48, 44) * M(44, 52)
      temp = temp + M(48, 45) * M(45, 52)
      temp = temp + M(48, 46) * M(46, 52)
      temp = temp + M(48, 47) * M(47, 52)
      M(48, 52) = ( M(48, 52) - temp ) / M(48, 48)

C     Lower part.
      temp = M(49, 21) * M(21, 49)
      temp = temp + M(49, 39) * M(39, 49)
      temp = temp + M(49, 40) * M(40, 49)
      temp = temp + M(49, 41) * M(41, 49)
      temp = temp + M(49, 42) * M(42, 49)
      temp = temp + M(49, 43) * M(43, 49)
      temp = temp + M(49, 44) * M(44, 49)
      temp = temp + M(49, 45) * M(45, 49)
      temp = temp + M(49, 46) * M(46, 49)
      temp = temp + M(49, 47) * M(47, 49)
      temp = temp + M(49, 48) * M(48, 49)
      M(49, 49) = M(49, 49) - temp
C     Lower part.
      temp = M(50, 21) * M(21, 49)
      temp = temp + M(50, 35) * M(35, 49)
      temp = temp + M(50, 37) * M(37, 49)
      temp = temp + M(50, 39) * M(39, 49)
      temp = temp + M(50, 40) * M(40, 49)
      temp = temp + M(50, 41) * M(41, 49)
      temp = temp + M(50, 42) * M(42, 49)
      temp = temp + M(50, 43) * M(43, 49)
      temp = temp + M(50, 44) * M(44, 49)
      temp = temp + M(50, 45) * M(45, 49)
      temp = temp + M(50, 46) * M(46, 49)
      temp = temp + M(50, 47) * M(47, 49)
      temp = temp + M(50, 48) * M(48, 49)
      M(50, 49) = M(50, 49) - temp
C     Lower part.
      temp = M(51, 40) * M(40, 49)
      temp = temp + M(51, 41) * M(41, 49)
      temp = temp + M(51, 42) * M(42, 49)
      temp = temp + M(51, 43) * M(43, 49)
      temp = temp + M(51, 44) * M(44, 49)
      temp = temp + M(51, 45) * M(45, 49)
      temp = temp + M(51, 46) * M(46, 49)
      temp = temp + M(51, 47) * M(47, 49)
      temp = temp + M(51, 48) * M(48, 49)
      M(51, 49) = M(51, 49) - temp
C     Lower part.
      temp = M(52, 38) * M(38, 49)
      temp = temp + M(52, 39) * M(39, 49)
      temp = temp + M(52, 40) * M(40, 49)
      temp = temp + M(52, 41) * M(41, 49)
      temp = temp + M(52, 42) * M(42, 49)
      temp = temp + M(52, 43) * M(43, 49)
      temp = temp + M(52, 44) * M(44, 49)
      temp = temp + M(52, 45) * M(45, 49)
      temp = temp + M(52, 46) * M(46, 49)
      temp = temp + M(52, 47) * M(47, 49)
      temp = temp + M(52, 48) * M(48, 49)
      M(52, 49) = M(52, 49) - temp
C     Upper part.
      temp = M(49, 19) * M(19, 50)
      temp = temp + M(49, 21) * M(21, 50)
      temp = temp + M(49, 27) * M(27, 50)
      temp = temp + M(49, 28) * M(28, 50)
      temp = temp + M(49, 29) * M(29, 50)
      temp = temp + M(49, 30) * M(30, 50)
      temp = temp + M(49, 34) * M(34, 50)
      temp = temp + M(49, 39) * M(39, 50)
      temp = temp + M(49, 40) * M(40, 50)
      temp = temp + M(49, 41) * M(41, 50)
      temp = temp + M(49, 42) * M(42, 50)
      temp = temp + M(49, 43) * M(43, 50)
      temp = temp + M(49, 44) * M(44, 50)
      temp = temp + M(49, 45) * M(45, 50)
      temp = temp + M(49, 46) * M(46, 50)
      temp = temp + M(49, 47) * M(47, 50)
      temp = temp + M(49, 48) * M(48, 50)
      M(49, 50) = ( M(49, 50) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 40) * M(40, 51)
      temp = temp + M(49, 41) * M(41, 51)
      temp = temp + M(49, 42) * M(42, 51)
      temp = temp + M(49, 43) * M(43, 51)
      temp = temp + M(49, 44) * M(44, 51)
      temp = temp + M(49, 45) * M(45, 51)
      temp = temp + M(49, 46) * M(46, 51)
      temp = temp + M(49, 47) * M(47, 51)
      temp = temp + M(49, 48) * M(48, 51)
      M(49, 51) = ( M(49, 51) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 16) * M(16, 52)
      temp = temp + M(49, 30) * M(30, 52)
      temp = temp + M(49, 31) * M(31, 52)
      temp = temp + M(49, 32) * M(32, 52)
      temp = temp + M(49, 34) * M(34, 52)
      temp = temp + M(49, 39) * M(39, 52)
      temp = temp + M(49, 40) * M(40, 52)
      temp = temp + M(49, 41) * M(41, 52)
      temp = temp + M(49, 42) * M(42, 52)
      temp = temp + M(49, 43) * M(43, 52)
      temp = temp + M(49, 44) * M(44, 52)
      temp = temp + M(49, 45) * M(45, 52)
      temp = temp + M(49, 46) * M(46, 52)
      temp = temp + M(49, 47) * M(47, 52)
      temp = temp + M(49, 48) * M(48, 52)
      M(49, 52) = ( M(49, 52) - temp ) / M(49, 49)

C     Lower part.
      temp = M(50, 13) * M(13, 50)
      temp = temp + M(50, 17) * M(17, 50)
      temp = temp + M(50, 18) * M(18, 50)
      temp = temp + M(50, 19) * M(19, 50)
      temp = temp + M(50, 20) * M(20, 50)
      temp = temp + M(50, 21) * M(21, 50)
      temp = temp + M(50, 27) * M(27, 50)
      temp = temp + M(50, 28) * M(28, 50)
      temp = temp + M(50, 29) * M(29, 50)
      temp = temp + M(50, 30) * M(30, 50)
      temp = temp + M(50, 33) * M(33, 50)
      temp = temp + M(50, 34) * M(34, 50)
      temp = temp + M(50, 35) * M(35, 50)
      temp = temp + M(50, 37) * M(37, 50)
      temp = temp + M(50, 39) * M(39, 50)
      temp = temp + M(50, 40) * M(40, 50)
      temp = temp + M(50, 41) * M(41, 50)
      temp = temp + M(50, 42) * M(42, 50)
      temp = temp + M(50, 43) * M(43, 50)
      temp = temp + M(50, 44) * M(44, 50)
      temp = temp + M(50, 45) * M(45, 50)
      temp = temp + M(50, 46) * M(46, 50)
      temp = temp + M(50, 47) * M(47, 50)
      temp = temp + M(50, 48) * M(48, 50)
      temp = temp + M(50, 49) * M(49, 50)
      M(50, 50) = M(50, 50) - temp
C     Lower part.
      temp = M(51, 22) * M(22, 50)
      temp = temp + M(51, 28) * M(28, 50)
      temp = temp + M(51, 29) * M(29, 50)
      temp = temp + M(51, 30) * M(30, 50)
      temp = temp + M(51, 40) * M(40, 50)
      temp = temp + M(51, 41) * M(41, 50)
      temp = temp + M(51, 42) * M(42, 50)
      temp = temp + M(51, 43) * M(43, 50)
      temp = temp + M(51, 44) * M(44, 50)
      temp = temp + M(51, 45) * M(45, 50)
      temp = temp + M(51, 46) * M(46, 50)
      temp = temp + M(51, 47) * M(47, 50)
      temp = temp + M(51, 48) * M(48, 50)
      temp = temp + M(51, 49) * M(49, 50)
      M(51, 50) = M(51, 50) - temp
C     Lower part.
      temp = M(52, 13) * M(13, 50)
      temp = temp + M(52, 18) * M(18, 50)
      temp = temp + M(52, 30) * M(30, 50)
      temp = temp + M(52, 33) * M(33, 50)
      temp = temp + M(52, 34) * M(34, 50)
      temp = temp + M(52, 38) * M(38, 50)
      temp = temp + M(52, 39) * M(39, 50)
      temp = temp + M(52, 40) * M(40, 50)
      temp = temp + M(52, 41) * M(41, 50)
      temp = temp + M(52, 42) * M(42, 50)
      temp = temp + M(52, 43) * M(43, 50)
      temp = temp + M(52, 44) * M(44, 50)
      temp = temp + M(52, 45) * M(45, 50)
      temp = temp + M(52, 46) * M(46, 50)
      temp = temp + M(52, 47) * M(47, 50)
      temp = temp + M(52, 48) * M(48, 50)
      temp = temp + M(52, 49) * M(49, 50)
      M(52, 50) = M(52, 50) - temp
C     Upper part.
      temp = M(50, 40) * M(40, 51)
      temp = temp + M(50, 41) * M(41, 51)
      temp = temp + M(50, 42) * M(42, 51)
      temp = temp + M(50, 43) * M(43, 51)
      temp = temp + M(50, 44) * M(44, 51)
      temp = temp + M(50, 45) * M(45, 51)
      temp = temp + M(50, 46) * M(46, 51)
      temp = temp + M(50, 47) * M(47, 51)
      temp = temp + M(50, 48) * M(48, 51)
      temp = temp + M(50, 49) * M(49, 51)
      M(50, 51) = ( M(50, 51) - temp ) / M(50, 50)
C     Upper part.
      temp = M(50, 13) * M(13, 52)
      temp = temp + M(50, 16) * M(16, 52)
      temp = temp + M(50, 30) * M(30, 52)
      temp = temp + M(50, 31) * M(31, 52)
      temp = temp + M(50, 32) * M(32, 52)
      temp = temp + M(50, 33) * M(33, 52)
      temp = temp + M(50, 34) * M(34, 52)
      temp = temp + M(50, 35) * M(35, 52)
      temp = temp + M(50, 37) * M(37, 52)
      temp = temp + M(50, 39) * M(39, 52)
      temp = temp + M(50, 40) * M(40, 52)
      temp = temp + M(50, 41) * M(41, 52)
      temp = temp + M(50, 42) * M(42, 52)
      temp = temp + M(50, 43) * M(43, 52)
      temp = temp + M(50, 44) * M(44, 52)
      temp = temp + M(50, 45) * M(45, 52)
      temp = temp + M(50, 46) * M(46, 52)
      temp = temp + M(50, 47) * M(47, 52)
      temp = temp + M(50, 48) * M(48, 52)
      temp = temp + M(50, 49) * M(49, 52)
      M(50, 52) = ( M(50, 52) - temp ) / M(50, 50)

C     Lower part.
      temp = M(51, 10) * M(10, 51)
      temp = temp + M(51, 22) * M(22, 51)
      temp = temp + M(51, 40) * M(40, 51)
      temp = temp + M(51, 41) * M(41, 51)
      temp = temp + M(51, 42) * M(42, 51)
      temp = temp + M(51, 43) * M(43, 51)
      temp = temp + M(51, 44) * M(44, 51)
      temp = temp + M(51, 45) * M(45, 51)
      temp = temp + M(51, 46) * M(46, 51)
      temp = temp + M(51, 47) * M(47, 51)
      temp = temp + M(51, 48) * M(48, 51)
      temp = temp + M(51, 49) * M(49, 51)
      temp = temp + M(51, 50) * M(50, 51)
      M(51, 51) = M(51, 51) - temp
C     Lower part.
      temp = M(52, 10) * M(10, 51)
      temp = temp + M(52, 40) * M(40, 51)
      temp = temp + M(52, 41) * M(41, 51)
      temp = temp + M(52, 42) * M(42, 51)
      temp = temp + M(52, 43) * M(43, 51)
      temp = temp + M(52, 44) * M(44, 51)
      temp = temp + M(52, 45) * M(45, 51)
      temp = temp + M(52, 46) * M(46, 51)
      temp = temp + M(52, 47) * M(47, 51)
      temp = temp + M(52, 48) * M(48, 51)
      temp = temp + M(52, 49) * M(49, 51)
      temp = temp + M(52, 50) * M(50, 51)
      M(52, 51) = M(52, 51) - temp
C     Upper part.
      temp = M(51, 10) * M(10, 52)
      temp = temp + M(51, 30) * M(30, 52)
      temp = temp + M(51, 32) * M(32, 52)
      temp = temp + M(51, 40) * M(40, 52)
      temp = temp + M(51, 41) * M(41, 52)
      temp = temp + M(51, 42) * M(42, 52)
      temp = temp + M(51, 43) * M(43, 52)
      temp = temp + M(51, 44) * M(44, 52)
      temp = temp + M(51, 45) * M(45, 52)
      temp = temp + M(51, 46) * M(46, 52)
      temp = temp + M(51, 47) * M(47, 52)
      temp = temp + M(51, 48) * M(48, 52)
      temp = temp + M(51, 49) * M(49, 52)
      temp = temp + M(51, 50) * M(50, 52)
      M(51, 52) = ( M(51, 52) - temp ) / M(51, 51)

C     Lower part.
      temp = M(52, 9) * M(9, 52)
      temp = temp + M(52, 10) * M(10, 52)
      temp = temp + M(52, 13) * M(13, 52)
      temp = temp + M(52, 14) * M(14, 52)
      temp = temp + M(52, 15) * M(15, 52)
      temp = temp + M(52, 16) * M(16, 52)
      temp = temp + M(52, 30) * M(30, 52)
      temp = temp + M(52, 31) * M(31, 52)
      temp = temp + M(52, 33) * M(33, 52)
      temp = temp + M(52, 34) * M(34, 52)
      temp = temp + M(52, 38) * M(38, 52)
      temp = temp + M(52, 39) * M(39, 52)
      temp = temp + M(52, 40) * M(40, 52)
      temp = temp + M(52, 41) * M(41, 52)
      temp = temp + M(52, 42) * M(42, 52)
      temp = temp + M(52, 43) * M(43, 52)
      temp = temp + M(52, 44) * M(44, 52)
      temp = temp + M(52, 45) * M(45, 52)
      temp = temp + M(52, 46) * M(46, 52)
      temp = temp + M(52, 47) * M(47, 52)
      temp = temp + M(52, 48) * M(48, 52)
      temp = temp + M(52, 49) * M(49, 52)
      temp = temp + M(52, 50) * M(50, 52)
      temp = temp + M(52, 51) * M(51, 52)
      M(52, 52) = M(52, 52) - temp


      END
