C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_solve_cb05 (ns, M, x)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine solves M * y = x where M is an LU factorization
C     computed by LU_decompose.
C     This routine is automatically generated by LU.cpp
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C     
C     ns: matrix row number from the chemical species number
C     M: LU factorization computed by LU_decompose.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     x: on entry, the right-hand side of the equation. On exit,
C     the solution of the equation.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE

      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION x(ns)
      DOUBLE PRECISION temp


C     Forward substitution.

      x(1) = x(1) / M(1, 1)

      x(2) = x(2) / M(2, 2)

      x(3) = x(3) / M(3, 3)

      x(4) = x(4) / M(4, 4)

      x(5) = x(5) / M(5, 5)

      x(6) = x(6) / M(6, 6)

      x(7) = x(7) / M(7, 7)

      temp = M(8, 7) * x(7)
      x(8) = ( x(8) - temp ) / M(8, 8)

      x(9) = x(9) / M(9, 9)

      x(10) = x(10) / M(10, 10)

      x(11) = x(11) / M(11, 11)

      temp = M(12, 5) * x(5)
      temp = temp + M(12, 6) * x(6)
      x(12) = ( x(12) - temp ) / M(12, 12)

      x(13) = x(13) / M(13, 13)

      x(14) = x(14) / M(14, 14)

      x(15) = x(15) / M(15, 15)

      x(16) = x(16) / M(16, 16)

      x(17) = x(17) / M(17, 17)

      x(18) = x(18) / M(18, 18)

      temp = M(19, 18) * x(18)
      x(19) = ( x(19) - temp ) / M(19, 19)

      temp = M(20, 18) * x(18)
      x(20) = ( x(20) - temp ) / M(20, 20)

      x(21) = x(21) / M(21, 21)

      x(22) = x(22) / M(22, 22)

      x(23) = x(23) / M(23, 23)

      x(24) = x(24) / M(24, 24)

      x(25) = x(25) / M(25, 25)

      x(26) = x(26) / M(26, 26)

      temp = M(27, 5) * x(5)
      temp = temp + M(27, 6) * x(6)
      temp = temp + M(27, 12) * x(12)
      x(27) = ( x(27) - temp ) / M(27, 27)

      temp = M(28, 12) * x(12)
      temp = temp + M(28, 27) * x(27)
      x(28) = ( x(28) - temp ) / M(28, 28)

      temp = M(29, 6) * x(6)
      temp = temp + M(29, 28) * x(28)
      x(29) = ( x(29) - temp ) / M(29, 29)

      temp = M(30, 27) * x(27)
      x(30) = ( x(30) - temp ) / M(30, 30)

      x(31) = x(31) / M(31, 31)

      temp = M(32, 31) * x(31)
      x(32) = ( x(32) - temp ) / M(32, 32)

      temp = M(33, 12) * x(12)
      temp = temp + M(33, 16) * x(16)
      temp = temp + M(33, 26) * x(26)
      temp = temp + M(33, 30) * x(30)
      temp = temp + M(33, 31) * x(31)
      temp = temp + M(33, 32) * x(32)
      x(33) = ( x(33) - temp ) / M(33, 33)

      temp = M(34, 6) * x(6)
      temp = temp + M(34, 16) * x(16)
      temp = temp + M(34, 24) * x(24)
      temp = temp + M(34, 25) * x(25)
      temp = temp + M(34, 26) * x(26)
      temp = temp + M(34, 31) * x(31)
      temp = temp + M(34, 32) * x(32)
      temp = temp + M(34, 33) * x(33)
      x(34) = ( x(34) - temp ) / M(34, 34)

      temp = M(35, 2) * x(2)
      temp = temp + M(35, 16) * x(16)
      temp = temp + M(35, 21) * x(21)
      temp = temp + M(35, 23) * x(23)
      temp = temp + M(35, 24) * x(24)
      temp = temp + M(35, 25) * x(25)
      temp = temp + M(35, 26) * x(26)
      temp = temp + M(35, 28) * x(28)
      temp = temp + M(35, 30) * x(30)
      temp = temp + M(35, 31) * x(31)
      temp = temp + M(35, 32) * x(32)
      temp = temp + M(35, 33) * x(33)
      temp = temp + M(35, 34) * x(34)
      x(35) = ( x(35) - temp ) / M(35, 35)

      x(36) = x(36) / M(36, 36)

      temp = M(37, 23) * x(23)
      temp = temp + M(37, 24) * x(24)
      temp = temp + M(37, 25) * x(25)
      temp = temp + M(37, 26) * x(26)
      temp = temp + M(37, 28) * x(28)
      temp = temp + M(37, 29) * x(29)
      temp = temp + M(37, 30) * x(30)
      temp = temp + M(37, 31) * x(31)
      temp = temp + M(37, 32) * x(32)
      temp = temp + M(37, 35) * x(35)
      x(37) = ( x(37) - temp ) / M(37, 37)

      temp = M(38, 9) * x(9)
      temp = temp + M(38, 27) * x(27)
      temp = temp + M(38, 30) * x(30)
      temp = temp + M(38, 32) * x(32)
      temp = temp + M(38, 33) * x(33)
      temp = temp + M(38, 34) * x(34)
      temp = temp + M(38, 35) * x(35)
      x(38) = ( x(38) - temp ) / M(38, 38)

      temp = M(39, 4) * x(4)
      temp = temp + M(39, 16) * x(16)
      temp = temp + M(39, 24) * x(24)
      temp = temp + M(39, 26) * x(26)
      temp = temp + M(39, 31) * x(31)
      temp = temp + M(39, 34) * x(34)
      x(39) = ( x(39) - temp ) / M(39, 39)

      temp = M(40, 3) * x(3)
      temp = temp + M(40, 19) * x(19)
      temp = temp + M(40, 22) * x(22)
      temp = temp + M(40, 35) * x(35)
      temp = temp + M(40, 36) * x(36)
      temp = temp + M(40, 39) * x(39)
      x(40) = ( x(40) - temp ) / M(40, 40)

      temp = M(41, 2) * x(2)
      temp = temp + M(41, 11) * x(11)
      temp = temp + M(41, 18) * x(18)
      temp = temp + M(41, 19) * x(19)
      temp = temp + M(41, 23) * x(23)
      temp = temp + M(41, 24) * x(24)
      temp = temp + M(41, 25) * x(25)
      temp = temp + M(41, 26) * x(26)
      temp = temp + M(41, 28) * x(28)
      temp = temp + M(41, 30) * x(30)
      temp = temp + M(41, 31) * x(31)
      temp = temp + M(41, 32) * x(32)
      temp = temp + M(41, 33) * x(33)
      temp = temp + M(41, 34) * x(34)
      temp = temp + M(41, 39) * x(39)
      temp = temp + M(41, 40) * x(40)
      x(41) = ( x(41) - temp ) / M(41, 41)

      temp = M(42, 1) * x(1)
      temp = temp + M(42, 2) * x(2)
      temp = temp + M(42, 3) * x(3)
      temp = temp + M(42, 4) * x(4)
      temp = temp + M(42, 5) * x(5)
      temp = temp + M(42, 6) * x(6)
      temp = temp + M(42, 7) * x(7)
      temp = temp + M(42, 11) * x(11)
      temp = temp + M(42, 13) * x(13)
      temp = temp + M(42, 14) * x(14)
      temp = temp + M(42, 15) * x(15)
      temp = temp + M(42, 17) * x(17)
      temp = temp + M(42, 19) * x(19)
      temp = temp + M(42, 20) * x(20)
      temp = temp + M(42, 21) * x(21)
      temp = temp + M(42, 22) * x(22)
      temp = temp + M(42, 23) * x(23)
      temp = temp + M(42, 24) * x(24)
      temp = temp + M(42, 25) * x(25)
      temp = temp + M(42, 26) * x(26)
      temp = temp + M(42, 27) * x(27)
      temp = temp + M(42, 28) * x(28)
      temp = temp + M(42, 29) * x(29)
      temp = temp + M(42, 30) * x(30)
      temp = temp + M(42, 31) * x(31)
      temp = temp + M(42, 32) * x(32)
      temp = temp + M(42, 33) * x(33)
      temp = temp + M(42, 34) * x(34)
      temp = temp + M(42, 35) * x(35)
      temp = temp + M(42, 36) * x(36)
      temp = temp + M(42, 37) * x(37)
      temp = temp + M(42, 38) * x(38)
      temp = temp + M(42, 39) * x(39)
      temp = temp + M(42, 40) * x(40)
      temp = temp + M(42, 41) * x(41)
      x(42) = ( x(42) - temp ) / M(42, 42)

      temp = M(43, 1) * x(1)
      temp = temp + M(43, 17) * x(17)
      temp = temp + M(43, 23) * x(23)
      temp = temp + M(43, 24) * x(24)
      temp = temp + M(43, 25) * x(25)
      temp = temp + M(43, 26) * x(26)
      temp = temp + M(43, 31) * x(31)
      temp = temp + M(43, 35) * x(35)
      temp = temp + M(43, 39) * x(39)
      temp = temp + M(43, 41) * x(41)
      temp = temp + M(43, 42) * x(42)
      x(43) = ( x(43) - temp ) / M(43, 43)

      temp = M(44, 9) * x(9)
      temp = temp + M(44, 13) * x(13)
      temp = temp + M(44, 23) * x(23)
      temp = temp + M(44, 24) * x(24)
      temp = temp + M(44, 25) * x(25)
      temp = temp + M(44, 26) * x(26)
      temp = temp + M(44, 27) * x(27)
      temp = temp + M(44, 30) * x(30)
      temp = temp + M(44, 31) * x(31)
      temp = temp + M(44, 32) * x(32)
      temp = temp + M(44, 35) * x(35)
      temp = temp + M(44, 38) * x(38)
      temp = temp + M(44, 39) * x(39)
      temp = temp + M(44, 41) * x(41)
      temp = temp + M(44, 42) * x(42)
      temp = temp + M(44, 43) * x(43)
      x(44) = ( x(44) - temp ) / M(44, 44)

      temp = M(45, 2) * x(2)
      temp = temp + M(45, 4) * x(4)
      temp = temp + M(45, 14) * x(14)
      temp = temp + M(45, 16) * x(16)
      temp = temp + M(45, 21) * x(21)
      temp = temp + M(45, 24) * x(24)
      temp = temp + M(45, 25) * x(25)
      temp = temp + M(45, 32) * x(32)
      temp = temp + M(45, 33) * x(33)
      temp = temp + M(45, 34) * x(34)
      temp = temp + M(45, 39) * x(39)
      temp = temp + M(45, 40) * x(40)
      temp = temp + M(45, 41) * x(41)
      temp = temp + M(45, 42) * x(42)
      temp = temp + M(45, 43) * x(43)
      temp = temp + M(45, 44) * x(44)
      x(45) = ( x(45) - temp ) / M(45, 45)

      temp = M(46, 14) * x(14)
      temp = temp + M(46, 26) * x(26)
      temp = temp + M(46, 31) * x(31)
      temp = temp + M(46, 32) * x(32)
      temp = temp + M(46, 35) * x(35)
      temp = temp + M(46, 39) * x(39)
      temp = temp + M(46, 42) * x(42)
      temp = temp + M(46, 43) * x(43)
      temp = temp + M(46, 44) * x(44)
      temp = temp + M(46, 45) * x(45)
      x(46) = ( x(46) - temp ) / M(46, 46)

      temp = M(47, 23) * x(23)
      temp = temp + M(47, 24) * x(24)
      temp = temp + M(47, 25) * x(25)
      temp = temp + M(47, 26) * x(26)
      temp = temp + M(47, 28) * x(28)
      temp = temp + M(47, 30) * x(30)
      temp = temp + M(47, 31) * x(31)
      temp = temp + M(47, 32) * x(32)
      temp = temp + M(47, 42) * x(42)
      temp = temp + M(47, 43) * x(43)
      temp = temp + M(47, 44) * x(44)
      temp = temp + M(47, 45) * x(45)
      temp = temp + M(47, 46) * x(46)
      x(47) = ( x(47) - temp ) / M(47, 47)

      temp = M(48, 12) * x(12)
      temp = temp + M(48, 15) * x(15)
      temp = temp + M(48, 18) * x(18)
      temp = temp + M(48, 31) * x(31)
      temp = temp + M(48, 39) * x(39)
      temp = temp + M(48, 40) * x(40)
      temp = temp + M(48, 41) * x(41)
      temp = temp + M(48, 42) * x(42)
      temp = temp + M(48, 43) * x(43)
      temp = temp + M(48, 44) * x(44)
      temp = temp + M(48, 45) * x(45)
      temp = temp + M(48, 46) * x(46)
      temp = temp + M(48, 47) * x(47)
      x(48) = ( x(48) - temp ) / M(48, 48)

      temp = M(49, 2) * x(2)
      temp = temp + M(49, 4) * x(4)
      temp = temp + M(49, 5) * x(5)
      temp = temp + M(49, 6) * x(6)
      temp = temp + M(49, 16) * x(16)
      temp = temp + M(49, 19) * x(19)
      temp = temp + M(49, 21) * x(21)
      temp = temp + M(49, 23) * x(23)
      temp = temp + M(49, 24) * x(24)
      temp = temp + M(49, 25) * x(25)
      temp = temp + M(49, 26) * x(26)
      temp = temp + M(49, 27) * x(27)
      temp = temp + M(49, 28) * x(28)
      temp = temp + M(49, 29) * x(29)
      temp = temp + M(49, 30) * x(30)
      temp = temp + M(49, 31) * x(31)
      temp = temp + M(49, 32) * x(32)
      temp = temp + M(49, 34) * x(34)
      temp = temp + M(49, 39) * x(39)
      temp = temp + M(49, 40) * x(40)
      temp = temp + M(49, 41) * x(41)
      temp = temp + M(49, 42) * x(42)
      temp = temp + M(49, 43) * x(43)
      temp = temp + M(49, 44) * x(44)
      temp = temp + M(49, 45) * x(45)
      temp = temp + M(49, 46) * x(46)
      temp = temp + M(49, 47) * x(47)
      temp = temp + M(49, 48) * x(48)
      x(49) = ( x(49) - temp ) / M(49, 49)

      temp = M(50, 1) * x(1)
      temp = temp + M(50, 2) * x(2)
      temp = temp + M(50, 4) * x(4)
      temp = temp + M(50, 5) * x(5)
      temp = temp + M(50, 6) * x(6)
      temp = temp + M(50, 7) * x(7)
      temp = temp + M(50, 11) * x(11)
      temp = temp + M(50, 12) * x(12)
      temp = temp + M(50, 13) * x(13)
      temp = temp + M(50, 16) * x(16)
      temp = temp + M(50, 17) * x(17)
      temp = temp + M(50, 18) * x(18)
      temp = temp + M(50, 19) * x(19)
      temp = temp + M(50, 20) * x(20)
      temp = temp + M(50, 21) * x(21)
      temp = temp + M(50, 23) * x(23)
      temp = temp + M(50, 24) * x(24)
      temp = temp + M(50, 25) * x(25)
      temp = temp + M(50, 26) * x(26)
      temp = temp + M(50, 27) * x(27)
      temp = temp + M(50, 28) * x(28)
      temp = temp + M(50, 29) * x(29)
      temp = temp + M(50, 30) * x(30)
      temp = temp + M(50, 31) * x(31)
      temp = temp + M(50, 32) * x(32)
      temp = temp + M(50, 33) * x(33)
      temp = temp + M(50, 34) * x(34)
      temp = temp + M(50, 35) * x(35)
      temp = temp + M(50, 37) * x(37)
      temp = temp + M(50, 39) * x(39)
      temp = temp + M(50, 40) * x(40)
      temp = temp + M(50, 41) * x(41)
      temp = temp + M(50, 42) * x(42)
      temp = temp + M(50, 43) * x(43)
      temp = temp + M(50, 44) * x(44)
      temp = temp + M(50, 45) * x(45)
      temp = temp + M(50, 46) * x(46)
      temp = temp + M(50, 47) * x(47)
      temp = temp + M(50, 48) * x(48)
      temp = temp + M(50, 49) * x(49)
      x(50) = ( x(50) - temp ) / M(50, 50)

      temp = M(51, 10) * x(10)
      temp = temp + M(51, 22) * x(22)
      temp = temp + M(51, 28) * x(28)
      temp = temp + M(51, 29) * x(29)
      temp = temp + M(51, 30) * x(30)
      temp = temp + M(51, 32) * x(32)
      temp = temp + M(51, 40) * x(40)
      temp = temp + M(51, 41) * x(41)
      temp = temp + M(51, 42) * x(42)
      temp = temp + M(51, 43) * x(43)
      temp = temp + M(51, 44) * x(44)
      temp = temp + M(51, 45) * x(45)
      temp = temp + M(51, 46) * x(46)
      temp = temp + M(51, 47) * x(47)
      temp = temp + M(51, 48) * x(48)
      temp = temp + M(51, 49) * x(49)
      temp = temp + M(51, 50) * x(50)
      x(51) = ( x(51) - temp ) / M(51, 51)

      temp = M(52, 9) * x(9)
      temp = temp + M(52, 10) * x(10)
      temp = temp + M(52, 12) * x(12)
      temp = temp + M(52, 13) * x(13)
      temp = temp + M(52, 14) * x(14)
      temp = temp + M(52, 15) * x(15)
      temp = temp + M(52, 16) * x(16)
      temp = temp + M(52, 18) * x(18)
      temp = temp + M(52, 23) * x(23)
      temp = temp + M(52, 24) * x(24)
      temp = temp + M(52, 25) * x(25)
      temp = temp + M(52, 26) * x(26)
      temp = temp + M(52, 30) * x(30)
      temp = temp + M(52, 31) * x(31)
      temp = temp + M(52, 33) * x(33)
      temp = temp + M(52, 34) * x(34)
      temp = temp + M(52, 38) * x(38)
      temp = temp + M(52, 39) * x(39)
      temp = temp + M(52, 40) * x(40)
      temp = temp + M(52, 41) * x(41)
      temp = temp + M(52, 42) * x(42)
      temp = temp + M(52, 43) * x(43)
      temp = temp + M(52, 44) * x(44)
      temp = temp + M(52, 45) * x(45)
      temp = temp + M(52, 46) * x(46)
      temp = temp + M(52, 47) * x(47)
      temp = temp + M(52, 48) * x(48)
      temp = temp + M(52, 49) * x(49)
      temp = temp + M(52, 50) * x(50)
      temp = temp + M(52, 51) * x(51)
      x(52) = ( x(52) - temp ) / M(52, 52)


C     Backward substitution.

      temp = M(51, 52) * x(52)
      x(51) = x(51) - temp

      temp = M(50, 51) * x(51)
      temp = temp + M(50, 52) * x(52)
      x(50) = x(50) - temp

      temp = M(49, 50) * x(50)
      temp = temp + M(49, 51) * x(51)
      temp = temp + M(49, 52) * x(52)
      x(49) = x(49) - temp

      temp = M(48, 49) * x(49)
      temp = temp + M(48, 50) * x(50)
      temp = temp + M(48, 51) * x(51)
      temp = temp + M(48, 52) * x(52)
      x(48) = x(48) - temp

      temp = M(47, 48) * x(48)
      temp = temp + M(47, 49) * x(49)
      temp = temp + M(47, 50) * x(50)
      temp = temp + M(47, 51) * x(51)
      temp = temp + M(47, 52) * x(52)
      x(47) = x(47) - temp

      temp = M(46, 47) * x(47)
      temp = temp + M(46, 48) * x(48)
      temp = temp + M(46, 49) * x(49)
      temp = temp + M(46, 50) * x(50)
      temp = temp + M(46, 51) * x(51)
      temp = temp + M(46, 52) * x(52)
      x(46) = x(46) - temp

      temp = M(45, 46) * x(46)
      temp = temp + M(45, 47) * x(47)
      temp = temp + M(45, 48) * x(48)
      temp = temp + M(45, 49) * x(49)
      temp = temp + M(45, 50) * x(50)
      temp = temp + M(45, 51) * x(51)
      temp = temp + M(45, 52) * x(52)
      x(45) = x(45) - temp

      temp = M(44, 45) * x(45)
      temp = temp + M(44, 46) * x(46)
      temp = temp + M(44, 47) * x(47)
      temp = temp + M(44, 48) * x(48)
      temp = temp + M(44, 49) * x(49)
      temp = temp + M(44, 50) * x(50)
      temp = temp + M(44, 51) * x(51)
      temp = temp + M(44, 52) * x(52)
      x(44) = x(44) - temp

      temp = M(43, 44) * x(44)
      temp = temp + M(43, 45) * x(45)
      temp = temp + M(43, 46) * x(46)
      temp = temp + M(43, 47) * x(47)
      temp = temp + M(43, 48) * x(48)
      temp = temp + M(43, 49) * x(49)
      temp = temp + M(43, 50) * x(50)
      temp = temp + M(43, 51) * x(51)
      temp = temp + M(43, 52) * x(52)
      x(43) = x(43) - temp

      temp = M(42, 43) * x(43)
      temp = temp + M(42, 44) * x(44)
      temp = temp + M(42, 45) * x(45)
      temp = temp + M(42, 46) * x(46)
      temp = temp + M(42, 47) * x(47)
      temp = temp + M(42, 48) * x(48)
      temp = temp + M(42, 49) * x(49)
      temp = temp + M(42, 50) * x(50)
      temp = temp + M(42, 51) * x(51)
      temp = temp + M(42, 52) * x(52)
      x(42) = x(42) - temp

      temp = M(41, 42) * x(42)
      temp = temp + M(41, 43) * x(43)
      temp = temp + M(41, 44) * x(44)
      temp = temp + M(41, 45) * x(45)
      temp = temp + M(41, 46) * x(46)
      temp = temp + M(41, 47) * x(47)
      temp = temp + M(41, 48) * x(48)
      temp = temp + M(41, 49) * x(49)
      temp = temp + M(41, 50) * x(50)
      temp = temp + M(41, 51) * x(51)
      temp = temp + M(41, 52) * x(52)
      x(41) = x(41) - temp

      temp = M(40, 41) * x(41)
      temp = temp + M(40, 42) * x(42)
      temp = temp + M(40, 43) * x(43)
      temp = temp + M(40, 44) * x(44)
      temp = temp + M(40, 45) * x(45)
      temp = temp + M(40, 46) * x(46)
      temp = temp + M(40, 47) * x(47)
      temp = temp + M(40, 48) * x(48)
      temp = temp + M(40, 49) * x(49)
      temp = temp + M(40, 50) * x(50)
      temp = temp + M(40, 51) * x(51)
      temp = temp + M(40, 52) * x(52)
      x(40) = x(40) - temp

      temp = M(39, 42) * x(42)
      temp = temp + M(39, 43) * x(43)
      temp = temp + M(39, 44) * x(44)
      temp = temp + M(39, 47) * x(47)
      temp = temp + M(39, 48) * x(48)
      temp = temp + M(39, 49) * x(49)
      temp = temp + M(39, 50) * x(50)
      temp = temp + M(39, 52) * x(52)
      x(39) = x(39) - temp

      temp = M(38, 39) * x(39)
      temp = temp + M(38, 41) * x(41)
      temp = temp + M(38, 42) * x(42)
      temp = temp + M(38, 43) * x(43)
      temp = temp + M(38, 44) * x(44)
      temp = temp + M(38, 45) * x(45)
      temp = temp + M(38, 47) * x(47)
      temp = temp + M(38, 48) * x(48)
      temp = temp + M(38, 49) * x(49)
      temp = temp + M(38, 50) * x(50)
      temp = temp + M(38, 52) * x(52)
      x(38) = x(38) - temp

      temp = M(37, 39) * x(39)
      temp = temp + M(37, 41) * x(41)
      temp = temp + M(37, 42) * x(42)
      temp = temp + M(37, 43) * x(43)
      temp = temp + M(37, 44) * x(44)
      temp = temp + M(37, 45) * x(45)
      temp = temp + M(37, 47) * x(47)
      temp = temp + M(37, 48) * x(48)
      temp = temp + M(37, 49) * x(49)
      temp = temp + M(37, 50) * x(50)
      temp = temp + M(37, 52) * x(52)
      x(37) = x(37) - temp

      temp = M(36, 40) * x(40)
      temp = temp + M(36, 42) * x(42)
      temp = temp + M(36, 46) * x(46)
      temp = temp + M(36, 49) * x(49)
      temp = temp + M(36, 50) * x(50)
      temp = temp + M(36, 51) * x(51)
      x(36) = x(36) - temp

      temp = M(35, 39) * x(39)
      temp = temp + M(35, 42) * x(42)
      temp = temp + M(35, 43) * x(43)
      temp = temp + M(35, 44) * x(44)
      temp = temp + M(35, 47) * x(47)
      temp = temp + M(35, 48) * x(48)
      temp = temp + M(35, 49) * x(49)
      temp = temp + M(35, 50) * x(50)
      temp = temp + M(35, 52) * x(52)
      x(35) = x(35) - temp

      temp = M(34, 39) * x(39)
      temp = temp + M(34, 42) * x(42)
      temp = temp + M(34, 43) * x(43)
      temp = temp + M(34, 44) * x(44)
      temp = temp + M(34, 47) * x(47)
      temp = temp + M(34, 48) * x(48)
      temp = temp + M(34, 50) * x(50)
      temp = temp + M(34, 52) * x(52)
      x(34) = x(34) - temp

      temp = M(33, 34) * x(34)
      temp = temp + M(33, 39) * x(39)
      temp = temp + M(33, 42) * x(42)
      temp = temp + M(33, 43) * x(43)
      temp = temp + M(33, 44) * x(44)
      temp = temp + M(33, 47) * x(47)
      temp = temp + M(33, 48) * x(48)
      temp = temp + M(33, 50) * x(50)
      temp = temp + M(33, 52) * x(52)
      x(33) = x(33) - temp

      temp = M(32, 42) * x(42)
      temp = temp + M(32, 43) * x(43)
      temp = temp + M(32, 44) * x(44)
      temp = temp + M(32, 47) * x(47)
      temp = temp + M(32, 52) * x(52)
      x(32) = x(32) - temp

      temp = M(31, 42) * x(42)
      temp = temp + M(31, 43) * x(43)
      temp = temp + M(31, 44) * x(44)
      temp = temp + M(31, 47) * x(47)
      temp = temp + M(31, 52) * x(52)
      x(31) = x(31) - temp

      temp = M(30, 42) * x(42)
      temp = temp + M(30, 44) * x(44)
      temp = temp + M(30, 48) * x(48)
      temp = temp + M(30, 50) * x(50)
      temp = temp + M(30, 52) * x(52)
      x(30) = x(30) - temp

      temp = M(29, 30) * x(30)
      temp = temp + M(29, 32) * x(32)
      temp = temp + M(29, 42) * x(42)
      temp = temp + M(29, 44) * x(44)
      temp = temp + M(29, 47) * x(47)
      temp = temp + M(29, 48) * x(48)
      temp = temp + M(29, 50) * x(50)
      x(29) = x(29) - temp

      temp = M(28, 30) * x(30)
      temp = temp + M(28, 42) * x(42)
      temp = temp + M(28, 44) * x(44)
      temp = temp + M(28, 47) * x(47)
      temp = temp + M(28, 48) * x(48)
      temp = temp + M(28, 50) * x(50)
      x(28) = x(28) - temp

      temp = M(27, 30) * x(30)
      temp = temp + M(27, 42) * x(42)
      temp = temp + M(27, 44) * x(44)
      temp = temp + M(27, 48) * x(48)
      temp = temp + M(27, 50) * x(50)
      x(27) = x(27) - temp

      temp = M(26, 42) * x(42)
      temp = temp + M(26, 43) * x(43)
      temp = temp + M(26, 44) * x(44)
      temp = temp + M(26, 47) * x(47)
      x(26) = x(26) - temp

      temp = M(25, 42) * x(42)
      temp = temp + M(25, 43) * x(43)
      temp = temp + M(25, 44) * x(44)
      temp = temp + M(25, 47) * x(47)
      x(25) = x(25) - temp

      temp = M(24, 42) * x(42)
      temp = temp + M(24, 43) * x(43)
      temp = temp + M(24, 44) * x(44)
      temp = temp + M(24, 47) * x(47)
      x(24) = x(24) - temp

      temp = M(23, 42) * x(42)
      temp = temp + M(23, 43) * x(43)
      temp = temp + M(23, 44) * x(44)
      temp = temp + M(23, 47) * x(47)
      x(23) = x(23) - temp

      temp = M(22, 42) * x(42)
      temp = temp + M(22, 46) * x(46)
      temp = temp + M(22, 50) * x(50)
      temp = temp + M(22, 51) * x(51)
      x(22) = x(22) - temp

      temp = M(21, 39) * x(39)
      temp = temp + M(21, 42) * x(42)
      temp = temp + M(21, 49) * x(49)
      temp = temp + M(21, 50) * x(50)
      x(21) = x(21) - temp

      temp = M(20, 23) * x(23)
      temp = temp + M(20, 41) * x(41)
      temp = temp + M(20, 42) * x(42)
      temp = temp + M(20, 47) * x(47)
      temp = temp + M(20, 48) * x(48)
      temp = temp + M(20, 50) * x(50)
      x(20) = x(20) - temp

      temp = M(19, 40) * x(40)
      temp = temp + M(19, 41) * x(41)
      temp = temp + M(19, 42) * x(42)
      temp = temp + M(19, 48) * x(48)
      temp = temp + M(19, 50) * x(50)
      x(19) = x(19) - temp

      temp = M(18, 41) * x(41)
      temp = temp + M(18, 48) * x(48)
      temp = temp + M(18, 50) * x(50)
      x(18) = x(18) - temp

      temp = M(17, 42) * x(42)
      temp = temp + M(17, 43) * x(43)
      temp = temp + M(17, 50) * x(50)
      x(17) = x(17) - temp

      temp = M(16, 34) * x(34)
      temp = temp + M(16, 42) * x(42)
      temp = temp + M(16, 52) * x(52)
      x(16) = x(16) - temp

      temp = M(15, 42) * x(42)
      temp = temp + M(15, 48) * x(48)
      temp = temp + M(15, 52) * x(52)
      x(15) = x(15) - temp

      temp = M(14, 42) * x(42)
      temp = temp + M(14, 46) * x(46)
      temp = temp + M(14, 52) * x(52)
      x(14) = x(14) - temp

      temp = M(13, 42) * x(42)
      temp = temp + M(13, 50) * x(50)
      temp = temp + M(13, 52) * x(52)
      x(13) = x(13) - temp

      temp = M(12, 42) * x(42)
      temp = temp + M(12, 48) * x(48)
      x(12) = x(12) - temp

      temp = M(11, 40) * x(40)
      temp = temp + M(11, 42) * x(42)
      x(11) = x(11) - temp

      temp = M(10, 51) * x(51)
      temp = temp + M(10, 52) * x(52)
      x(10) = x(10) - temp

      temp = M(9, 44) * x(44)
      temp = temp + M(9, 52) * x(52)
      x(9) = x(9) - temp

      temp = M(8, 42) * x(42)
      x(8) = x(8) - temp

      temp = M(7, 42) * x(42)
      x(7) = x(7) - temp

      temp = M(6, 42) * x(42)
      x(6) = x(6) - temp

      temp = M(5, 42) * x(42)
      x(5) = x(5) - temp

      temp = M(4, 42) * x(42)
      x(4) = x(4) - temp

      temp = M(3, 42) * x(42)
      x(3) = x(3) - temp

      temp = M(2, 42) * x(42)
      x(2) = x(2) - temp

      temp = M(1, 47) * x(47)
      x(1) = x(1) - temp


      END
