C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine fexchem_cb05  (ns,nr,y,rk,ZCsourc,convers_factor,chem)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the chemical production term.
C     This routine is automatically generated by SPACK.
C     Mechanism: CB05                
C     Species: _ciCB05             
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     ZCSOURC: volumic emissions.
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     CHEM: array of chemical production terms.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer nr,ns,i
      double precision w(nr),rk(nr),y(ns),chem(ns),ZCsourc(ns)
      double precision conc(ns), convers_factor(ns)
 
      do i=1,ns
       chem(i)=0.d0
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
C     Compute reaction rates.
 
      call rates_cb05  (ns,nr,rk,conc,w)
 
C     Chemical production terms.
 
      chem( 43) = chem( 43) + w(  1)
      chem( 48) = chem( 48) + w(  1)
      chem( 52) = chem( 52) - w(  1)
      chem( 43) = chem( 43) - w(  2)
      chem( 47) = chem( 47) + w(  2)
      chem( 47) = chem( 47) - w(  3)
      chem( 48) = chem( 48) - w(  3)
      chem( 52) = chem( 52) + w(  3)
      chem( 43) = chem( 43) - w(  4)
      chem( 48) = chem( 48) + w(  4)
      chem( 52) = chem( 52) - w(  4)
      chem( 43) = chem( 43) - w(  5)
      chem( 44) = chem( 44) + w(  5)
      chem( 52) = chem( 52) - w(  5)
      chem( 43) = chem( 43) - w(  6)
      chem( 48) = chem( 48) - w(  6)
      chem( 52) = chem( 52) + w(  6)
      chem( 44) = chem( 44) + w(  7)
      chem( 47) = chem( 47) - w(  7)
      chem( 52) = chem( 52) - w(  7)
      chem( 43) = chem( 43) + w(  8)
      chem( 47) = chem( 47) - w(  8)
      chem(  1) = chem(  1) + w(  9)
      chem( 47) = chem( 47) - w(  9)
      chem(  1) = chem(  1) - w( 10)
      chem( 43) = chem( 43) + w( 10)
      chem(  1) = chem(  1) - w( 11)
      chem( 42) = chem( 42) +  0.2000000000000000D+01 * w( 11)
      chem( 42) = chem( 42) - w( 12)
      chem( 47) = chem( 47) - w( 12)
      chem( 50) = chem( 50) + w( 12)
      chem( 42) = chem( 42) + w( 13)
      chem( 47) = chem( 47) - w( 13)
      chem( 50) = chem( 50) - w( 13)
      chem( 43) = chem( 43) + w( 14)
      chem( 44) = chem( 44) - w( 14)
      chem( 52) = chem( 52) + w( 14)
      chem( 44) = chem( 44) - w( 15)
      chem( 48) = chem( 48) + w( 15)
      chem( 44) = chem( 44) - w( 16)
      chem( 48) = chem( 48) - w( 16)
      chem( 52) = chem( 52) +  0.2000000000000000D+01 * w( 16)
      chem( 44) = chem( 44) - w( 17)
      chem( 48) = chem( 48) + w( 17)
      chem(  9) = chem(  9) + w( 18)
      chem( 44) = chem( 44) - w( 18)
      chem( 52) = chem( 52) - w( 18)
      chem(  9) = chem(  9) - w( 19)
      chem( 38) = chem( 38) +  0.2000000000000000D+01 * w( 19)
      chem(  9) = chem(  9) - w( 20)
      chem( 44) = chem( 44) + w( 20)
      chem( 52) = chem( 52) + w( 20)
      chem( 48) = chem( 48) -  0.2000000000000000D+01 * w( 21)
      chem( 52) = chem( 52) +  0.2000000000000000D+01 * w( 21)
      chem( 15) = chem( 15) +  0.2000000000000000D+01 * w( 22)
      chem( 48) = chem( 48) - w( 22)
      chem( 52) = chem( 52) - w( 22)
      chem( 15) = chem( 15) + w( 23)
      chem( 42) = chem( 42) - w( 23)
      chem( 48) = chem( 48) - w( 23)
      chem( 15) = chem( 15) - w( 24)
      chem( 42) = chem( 42) + w( 24)
      chem( 48) = chem( 48) + w( 24)
      chem( 15) = chem( 15) - w( 25)
      chem( 42) = chem( 42) - w( 25)
      chem( 52) = chem( 52) + w( 25)
      chem( 15) = chem( 15) -  0.2000000000000000D+01 * w( 26)
      chem( 48) = chem( 48) + w( 26)
      chem( 52) = chem( 52) + w( 26)
      chem( 38) = chem( 38) + w( 27)
      chem( 42) = chem( 42) - w( 27)
      chem( 52) = chem( 52) - w( 27)
      chem( 38) = chem( 38) - w( 28)
      chem( 42) = chem( 42) - w( 28)
      chem( 44) = chem( 44) + w( 28)
      chem( 42) = chem( 42) + w( 29)
      chem( 48) = chem( 48) - w( 29)
      chem( 50) = chem( 50) - w( 29)
      chem( 52) = chem( 52) + w( 29)
      chem( 13) = chem( 13) + w( 30)
      chem( 50) = chem( 50) - w( 30)
      chem( 52) = chem( 52) - w( 30)
      chem( 13) = chem( 13) - w( 31)
      chem( 50) = chem( 50) + w( 31)
      chem( 52) = chem( 52) + w( 31)
      chem( 13) = chem( 13) - w( 32)
      chem( 42) = chem( 42) - w( 32)
      chem( 52) = chem( 52) + w( 32)
      chem( 17) = chem( 17) + w( 33)
      chem( 50) = chem( 50) -  0.2000000000000000D+01 * w( 33)
      chem( 17) = chem( 17) + w( 34)
      chem( 50) = chem( 50) -  0.2000000000000000D+01 * w( 34)
      chem( 17) = chem( 17) - w( 35)
      chem( 42) = chem( 42) +  0.2000000000000000D+01 * w( 35)
      chem( 17) = chem( 17) - w( 36)
      chem( 42) = chem( 42) - w( 36)
      chem( 50) = chem( 50) + w( 36)
      chem(  1) = chem(  1) - w( 37)
      chem( 42) = chem( 42) + w( 37)
      chem( 50) = chem( 50) + w( 37)
      chem( 42) = chem( 42) - w( 38)
      chem( 50) = chem( 50) + w( 38)
      chem( 42) = chem( 42) - w( 39)
      chem( 43) = chem( 43) - w( 39)
      chem( 50) = chem( 50) + w( 39)
      chem( 42) = chem( 42) -  0.2000000000000000D+01 * w( 40)
      chem( 43) = chem( 43) + w( 40)
      chem( 17) = chem( 17) + w( 41)
      chem( 42) = chem( 42) -  0.2000000000000000D+01 * w( 41)
      chem( 42) = chem( 42) - w( 42)
      chem( 50) = chem( 50) - w( 42)
      chem( 42) = chem( 42) + w( 43)
      chem( 43) = chem( 43) - w( 43)
      chem( 50) = chem( 50) - w( 43)
      chem( 17) = chem( 17) - w( 44)
      chem( 42) = chem( 42) + w( 44)
      chem( 43) = chem( 43) - w( 44)
      chem( 50) = chem( 50) + w( 44)
      chem( 43) = chem( 43) - w( 45)
      chem( 44) = chem( 44) - w( 45)
      chem( 52) = chem( 52) + w( 45)
      chem( 42) = chem( 42) - w( 46)
      chem( 44) = chem( 44) - w( 46)
      chem( 50) = chem( 50) + w( 46)
      chem( 52) = chem( 52) + w( 46)
      chem( 38) = chem( 38) + w( 47)
      chem( 44) = chem( 44) - w( 47)
      chem( 50) = chem( 50) - w( 47)
      chem( 44) = chem( 44) - w( 48)
      chem( 47) = chem( 47) - w( 48)
      chem( 52) = chem( 52) + w( 48)
      chem( 44) = chem( 44) -  0.2000000000000000D+01 * w( 49)
      chem( 52) = chem( 52) +  0.2000000000000000D+01 * w( 49)
      chem( 13) = chem( 13) - w( 50)
      chem( 42) = chem( 42) +  0.3900000000000000D+00 * w( 50)
      chem( 44) = chem( 44) +  0.3900000000000000D+00 * w( 50)
      chem( 50) = chem( 50) +  0.6100000000000000D+00 * w( 50)
      chem( 52) = chem( 52) +  0.6100000000000000D+00 * w( 50)
      chem( 38) = chem( 38) - w( 51)
      chem( 42) = chem( 42) + w( 51)
      chem( 52) = chem( 52) + w( 51)
      chem(  9) = chem(  9) - w( 52)
      chem( 44) = chem( 44) + w( 52)
      chem( 52) = chem( 52) + w( 52)
      chem( 48) = chem( 48) - w( 53)
      chem( 49) = chem( 49) - w( 53)
      chem( 52) = chem( 52) + w( 53)
      chem( 33) = chem( 33) + w( 54)
      chem( 39) = chem( 39) - w( 54)
      chem( 48) = chem( 48) - w( 54)
      chem( 21) = chem( 21) + w( 55)
      chem( 49) = chem( 49) - w( 55)
      chem( 50) = chem( 50) - w( 55)
      chem( 21) = chem( 21) + w( 56)
      chem( 39) = chem( 39) - w( 56)
      chem( 50) = chem( 50) - w( 56)
      chem( 49) = chem( 49) -  0.2000000000000000D+01 * w( 57)
      chem( 39) = chem( 39) -  0.2000000000000000D+01 * w( 58)
      chem( 39) = chem( 39) - w( 59)
      chem( 49) = chem( 49) - w( 59)
      chem( 33) = chem( 33) - w( 60)
      chem( 34) = chem( 34) +  0.6600000000000000D+00 * w( 60)
      chem( 35) = chem( 35) +  0.3300000000000000D+00 * w( 60)
      chem( 38) = chem( 38) + w( 60)
      chem( 41) = chem( 41) +  0.3300000000000000D+00 * w( 60)
      chem( 42) = chem( 42) - w( 60)
      chem( 45) = chem( 45) +  0.3300000000000000D+00 * w( 60)
      chem( 50) = chem( 50) + w( 60)
      chem( 33) = chem( 33) - w( 61)
      chem( 34) = chem( 34) +  0.6600000000000000D+00 * w( 61)
      chem( 35) = chem( 35) +  0.3300000000000000D+00 * w( 61)
      chem( 41) = chem( 41) +  0.3300000000000000D+00 * w( 61)
      chem( 45) = chem( 45) +  0.3300000000000000D+00 * w( 61)
      chem( 50) = chem( 50) + w( 61)
      chem( 52) = chem( 52) + w( 61)
      chem( 21) = chem( 21) - w( 62)
      chem( 35) = chem( 35) +  0.5000000000000000D+00 * w( 62)
      chem( 42) = chem( 42) - w( 62)
      chem( 45) = chem( 45) +  0.5000000000000000D+00 * w( 62)
      chem( 49) = chem( 49) + w( 62)
      chem( 21) = chem( 21) - w( 63)
      chem( 35) = chem( 35) +  0.5000000000000000D+00 * w( 63)
      chem( 42) = chem( 42) + w( 63)
      chem( 45) = chem( 45) +  0.5000000000000000D+00 * w( 63)
      chem( 50) = chem( 50) + w( 63)
      chem( 37) = chem( 37) - w( 64)
      chem( 42) = chem( 42) - w( 64)
      chem( 50) = chem( 50) + w( 64)
      chem(  3) = chem(  3) - w( 65)
      chem( 40) = chem( 40) + w( 65)
      chem( 42) = chem( 42) - w( 65)
      chem( 40) = chem( 40) - w( 66)
      chem( 41) = chem( 41) + w( 66)
      chem( 48) = chem( 48) - w( 66)
      chem( 50) = chem( 50) + w( 66)
      chem( 52) = chem( 52) + w( 66)
      chem( 19) = chem( 19) + w( 67)
      chem( 40) = chem( 40) - w( 67)
      chem( 50) = chem( 50) - w( 67)
      chem( 11) = chem( 11) +  0.6300000000000000D+00 * w( 68)
      chem( 40) = chem( 40) -  0.2000000000000000D+01 * w( 68)
      chem( 41) = chem( 41) +  0.1370000000000000D+01 * w( 68)
      chem( 50) = chem( 50) +  0.7400000000000000D+00 * w( 68)
      chem( 19) = chem( 19) - w( 69)
      chem( 40) = chem( 40) +  0.7000000000000000D+00 * w( 69)
      chem( 42) = chem( 42) - w( 69)
      chem( 49) = chem( 49) +  0.3000000000000000D+00 * w( 69)
      chem( 50) = chem( 50) +  0.3000000000000000D-01 * w( 69)
      chem( 19) = chem( 19) - w( 70)
      chem( 41) = chem( 41) + w( 70)
      chem( 42) = chem( 42) + w( 70)
      chem( 50) = chem( 50) + w( 70)
      chem( 11) = chem( 11) - w( 71)
      chem( 41) = chem( 41) + w( 71)
      chem( 42) = chem( 42) - w( 71)
      chem( 50) = chem( 50) + w( 71)
      chem( 37) = chem( 37) + w( 72)
      chem( 41) = chem( 41) - w( 72)
      chem( 42) = chem( 42) - w( 72)
      chem( 50) = chem( 50) + w( 72)
      chem( 37) = chem( 37) + w( 73)
      chem( 41) = chem( 41) - w( 73)
      chem( 50) = chem( 50) +  0.2000000000000000D+01 * w( 73)
      chem( 37) = chem( 37) + w( 74)
      chem( 41) = chem( 41) - w( 74)
      chem( 37) = chem( 37) + w( 75)
      chem( 41) = chem( 41) - w( 75)
      chem( 42) = chem( 42) + w( 75)
      chem( 43) = chem( 43) - w( 75)
      chem( 50) = chem( 50) + w( 75)
      chem( 37) = chem( 37) + w( 76)
      chem( 38) = chem( 38) + w( 76)
      chem( 41) = chem( 41) - w( 76)
      chem( 44) = chem( 44) - w( 76)
      chem( 50) = chem( 50) + w( 76)
      chem( 18) = chem( 18) + w( 77)
      chem( 41) = chem( 41) - w( 77)
      chem( 50) = chem( 50) - w( 77)
      chem( 18) = chem( 18) - w( 78)
      chem( 41) = chem( 41) + w( 78)
      chem( 50) = chem( 50) + w( 78)
      chem( 18) = chem( 18) - w( 79)
      chem( 20) = chem( 20) + w( 79)
      chem( 48) = chem( 48) - w( 79)
      chem( 50) = chem( 50) + w( 79)
      chem( 52) = chem( 52) + w( 79)
      chem( 18) = chem( 18) - w( 80)
      chem( 19) = chem( 19) + w( 80)
      chem( 50) = chem( 50) - w( 80)
      chem( 20) = chem( 20) - w( 81)
      chem( 42) = chem( 42) - w( 81)
      chem( 50) = chem( 50) + w( 81)
      chem( 42) = chem( 42) + w( 82)
      chem( 43) = chem( 43) - w( 82)
      chem( 45) = chem( 45) - w( 82)
      chem( 51) = chem( 51) + w( 82)
      chem( 42) = chem( 42) - w( 83)
      chem( 45) = chem( 45) - w( 83)
      chem( 51) = chem( 51) + w( 83)
      chem( 38) = chem( 38) + w( 84)
      chem( 44) = chem( 44) - w( 84)
      chem( 45) = chem( 45) - w( 84)
      chem( 51) = chem( 51) + w( 84)
      chem( 37) = chem( 37) + w( 85)
      chem( 40) = chem( 40) + w( 85)
      chem( 45) = chem( 45) - w( 85)
      chem( 50) = chem( 50) + w( 85)
      chem( 40) = chem( 40) + w( 86)
      chem( 48) = chem( 48) - w( 86)
      chem( 51) = chem( 51) - w( 86)
      chem( 52) = chem( 52) + w( 86)
      chem( 10) = chem( 10) + w( 87)
      chem( 51) = chem( 51) - w( 87)
      chem( 52) = chem( 52) - w( 87)
      chem( 10) = chem( 10) - w( 88)
      chem( 51) = chem( 51) + w( 88)
      chem( 52) = chem( 52) + w( 88)
      chem( 10) = chem( 10) - w( 89)
      chem( 51) = chem( 51) + w( 89)
      chem( 52) = chem( 52) + w( 89)
      chem( 22) = chem( 22) +  0.8000000000000000D+00 * w( 90)
      chem( 36) = chem( 36) +  0.2000000000000000D+00 * w( 90)
      chem( 47) = chem( 47) +  0.2000000000000000D+00 * w( 90)
      chem( 50) = chem( 50) - w( 90)
      chem( 51) = chem( 51) - w( 90)
      chem( 36) = chem( 36) +  0.1000000000000000D+00 * w( 91)
      chem( 40) = chem( 40) -  0.9999999999999998D-01 * w( 91)
      chem( 41) = chem( 41) + w( 91)
      chem( 50) = chem( 50) +  0.9000000000000000D+00 * w( 91)
      chem( 51) = chem( 51) - w( 91)
      chem( 36) = chem( 36) +  0.1000000000000000D+00 * w( 92)
      chem( 40) = chem( 40) +  0.9000000000000000D+00 * w( 92)
      chem( 49) = chem( 49) - w( 92)
      chem( 51) = chem( 51) - w( 92)
      chem( 40) = chem( 40) +  0.2000000000000000D+01 * w( 93)
      chem( 51) = chem( 51) -  0.2000000000000000D+01 * w( 93)
      chem( 22) = chem( 22) - w( 94)
      chem( 42) = chem( 42) - w( 94)
      chem( 51) = chem( 51) + w( 94)
      chem( 22) = chem( 22) - w( 95)
      chem( 40) = chem( 40) + w( 95)
      chem( 42) = chem( 42) + w( 95)
      chem( 36) = chem( 36) - w( 96)
      chem( 40) = chem( 40) + w( 96)
      chem( 42) = chem( 42) - w( 96)
      chem( 35) = chem( 35) - w( 97)
      chem( 42) = chem( 42) + w( 97)
      chem( 43) = chem( 43) - w( 97)
      chem( 46) = chem( 46) + w( 97)
      chem( 35) = chem( 35) - w( 98)
      chem( 42) = chem( 42) - w( 98)
      chem( 46) = chem( 46) + w( 98)
      chem( 35) = chem( 35) - w( 99)
      chem( 38) = chem( 38) + w( 99)
      chem( 44) = chem( 44) - w( 99)
      chem( 46) = chem( 46) + w( 99)
      chem( 35) = chem( 35) - w(100)
      chem( 37) = chem( 37) + w(100)
      chem( 40) = chem( 40) + w(100)
      chem( 50) = chem( 50) + w(100)
      chem( 45) = chem( 45) + w(101)
      chem( 46) = chem( 46) - w(101)
      chem( 48) = chem( 48) - w(101)
      chem( 49) = chem( 49) + w(101)
      chem( 50) = chem( 50) + w(101)
      chem( 52) = chem( 52) + w(101)
      chem( 14) = chem( 14) + w(102)
      chem( 46) = chem( 46) - w(102)
      chem( 52) = chem( 52) - w(102)
      chem( 14) = chem( 14) - w(103)
      chem( 46) = chem( 46) + w(103)
      chem( 52) = chem( 52) + w(103)
      chem( 14) = chem( 14) - w(104)
      chem( 46) = chem( 46) + w(104)
      chem( 52) = chem( 52) + w(104)
      chem( 14) = chem( 14) - w(105)
      chem( 42) = chem( 42) - w(105)
      chem( 45) = chem( 45) + w(105)
      chem( 52) = chem( 52) + w(105)
      chem( 22) = chem( 22) +  0.8000000000000000D+00 * w(106)
      chem( 36) = chem( 36) +  0.2000000000000000D+00 * w(106)
      chem( 46) = chem( 46) - w(106)
      chem( 47) = chem( 47) +  0.2000000000000000D+00 * w(106)
      chem( 50) = chem( 50) - w(106)
      chem( 36) = chem( 36) +  0.1000000000000000D+00 * w(107)
      chem( 40) = chem( 40) - w(107)
      chem( 41) = chem( 41) +  0.1000000000000000D+00 * w(107)
      chem( 45) = chem( 45) +  0.9000000000000000D+00 * w(107)
      chem( 49) = chem( 49) +  0.9000000000000000D+00 * w(107)
      chem( 50) = chem( 50) + w(107)
      chem( 51) = chem( 51) - w(107)
      chem( 36) = chem( 36) +  0.1000000000000000D+00 * w(108)
      chem( 45) = chem( 45) +  0.9000000000000000D+00 * w(108)
      chem( 49) = chem( 49) - w(108)
      chem( 51) = chem( 51) - w(108)
      chem( 45) = chem( 45) +  0.2000000000000000D+01 * w(109)
      chem( 46) = chem( 46) -  0.2000000000000000D+01 * w(109)
      chem( 49) = chem( 49) +  0.2000000000000000D+01 * w(109)
      chem( 50) = chem( 50) +  0.2000000000000000D+01 * w(109)
      chem( 40) = chem( 40) + w(110)
      chem( 45) = chem( 45) + w(110)
      chem( 46) = chem( 46) - w(110)
      chem( 49) = chem( 49) + w(110)
      chem( 50) = chem( 50) + w(110)
      chem( 51) = chem( 51) - w(110)
      chem( 16) = chem( 16) +  0.7600000000000000D+00 * w(111)
      chem( 34) = chem( 34) -  0.8900000000000000D+00 * w(111)
      chem( 35) = chem( 35) +  0.5000000000000000D-01 * w(111)
      chem( 39) = chem( 39) +  0.1300000000000000D+00 * w(111)
      chem( 42) = chem( 42) - w(111)
      chem( 45) = chem( 45) +  0.6000000000000000D-01 * w(111)
      chem( 49) = chem( 49) +  0.8700000000000000D+00 * w(111)
      chem( 50) = chem( 50) +  0.1100000000000000D+00 * w(111)
      chem( 16) = chem( 16) -  0.9800000000000000D+00 * w(112)
      chem( 34) = chem( 34) +  0.2100000000000000D+01 * w(112)
      chem( 35) = chem( 35) +  0.5000000000000000D+00 * w(112)
      chem( 39) = chem( 39) +  0.4000000000000000D-01 * w(112)
      chem( 45) = chem( 45) +  0.6000000000000000D+00 * w(112)
      chem( 49) = chem( 49) +  0.9600000000000000D+00 * w(112)
      chem( 50) = chem( 50) +  0.9399999999999999D+00 * w(112)
      chem( 16) = chem( 16) - w(113)
      chem( 50) = chem( 50) + w(113)
      chem( 16) = chem( 16) - w(114)
      chem( 33) = chem( 33) + w(114)
      chem( 52) = chem( 52) - w(114)
      chem( 24) = chem( 24) - w(115)
      chem( 34) = chem( 34) +  0.2000000000000000D+00 * w(115)
      chem( 35) = chem( 35) +  0.3000000000000000D+00 * w(115)
      chem( 37) = chem( 37) +  0.2000000000000000D+00 * w(115)
      chem( 39) = chem( 39) +  0.1000000000000000D-01 * w(115)
      chem( 41) = chem( 41) +  0.2000000000000000D+00 * w(115)
      chem( 42) = chem( 42) +  0.1000000000000000D+00 * w(115)
      chem( 43) = chem( 43) - w(115)
      chem( 45) = chem( 45) +  0.2000000000000000D+00 * w(115)
      chem( 49) = chem( 49) +  0.2000000000000000D+00 * w(115)
      chem( 50) = chem( 50) +  0.3000000000000000D+00 * w(115)
      chem( 24) = chem( 24) - w(116)
      chem( 34) = chem( 34) +  0.7000000000000000D+00 * w(116)
      chem( 35) = chem( 35) +  0.6200000000000000D+00 * w(116)
      chem( 41) = chem( 41) +  0.8000000000000000D+00 * w(116)
      chem( 42) = chem( 42) - w(116)
      chem( 45) = chem( 45) +  0.3300000000000000D+00 * w(116)
      chem( 49) = chem( 49) +  0.8000000000000000D+00 * w(116)
      chem( 50) = chem( 50) +  0.9500000000000000D+00 * w(116)
      chem( 24) = chem( 24) - w(117)
      chem( 34) = chem( 34) + w(117)
      chem( 35) = chem( 35) +  0.3200000000000000D+00 * w(117)
      chem( 37) = chem( 37) +  0.3300000000000000D+00 * w(117)
      chem( 41) = chem( 41) +  0.7400000000000000D+00 * w(117)
      chem( 42) = chem( 42) +  0.1000000000000000D+00 * w(117)
      chem( 45) = chem( 45) +  0.1800000000000000D+00 * w(117)
      chem( 47) = chem( 47) - w(117)
      chem( 49) = chem( 49) +  0.2200000000000000D+00 * w(117)
      chem( 50) = chem( 50) +  0.4400000000000000D+00 * w(117)
      chem( 24) = chem( 24) - w(118)
      chem( 34) = chem( 34) + w(118)
      chem( 35) = chem( 35) +  0.5600000000000001D+00 * w(118)
      chem( 39) = chem( 39) +  0.9000000000000000D-01 * w(118)
      chem( 41) = chem( 41) + w(118)
      chem( 44) = chem( 44) - w(118)
      chem( 45) = chem( 45) +  0.3500000000000000D+00 * w(118)
      chem( 49) = chem( 49) +  0.9100000000000000D+00 * w(118)
      chem( 52) = chem( 52) + w(118)
      chem( 23) = chem( 23) - w(119)
      chem( 37) = chem( 37) + w(119)
      chem( 41) = chem( 41) + w(119)
      chem( 42) = chem( 42) +  0.3000000000000000D+00 * w(119)
      chem( 43) = chem( 43) - w(119)
      chem( 49) = chem( 49) +  0.7000000000000000D+00 * w(119)
      chem( 50) = chem( 50) +  0.1700000000000000D+01 * w(119)
      chem( 23) = chem( 23) - w(120)
      chem( 35) = chem( 35) +  0.2200000000000000D+00 * w(120)
      chem( 41) = chem( 41) +  0.1560000000000000D+01 * w(120)
      chem( 42) = chem( 42) - w(120)
      chem( 49) = chem( 49) + w(120)
      chem( 50) = chem( 50) + w(120)
      chem( 20) = chem( 20) +  0.3700000000000000D+00 * w(121)
      chem( 23) = chem( 23) - w(121)
      chem( 37) = chem( 37) +  0.6300000000000000D+00 * w(121)
      chem( 41) = chem( 41) + w(121)
      chem( 42) = chem( 42) +  0.1300000000000000D+00 * w(121)
      chem( 47) = chem( 47) - w(121)
      chem( 50) = chem( 50) +  0.1300000000000000D+00 * w(121)
      chem( 23) = chem( 23) - w(122)
      chem( 41) = chem( 41) +  0.2000000000000000D+01 * w(122)
      chem( 44) = chem( 44) - w(122)
      chem( 49) = chem( 49) + w(122)
      chem( 52) = chem( 52) + w(122)
      chem( 25) = chem( 25) - w(123)
      chem( 34) = chem( 34) +  0.1000000000000000D+00 * w(123)
      chem( 35) = chem( 35) +  0.6600000000000000D+00 * w(123)
      chem( 37) = chem( 37) +  0.1000000000000000D+00 * w(123)
      chem( 43) = chem( 43) - w(123)
      chem( 45) = chem( 45) +  0.1240000000000000D+01 * w(123)
      chem( 49) = chem( 49) +  0.1000000000000000D+00 * w(123)
      chem( 50) = chem( 50) +  0.1000000000000000D+00 * w(123)
      chem( 25) = chem( 25) - w(124)
      chem( 35) = chem( 35) +  0.7000000000000000D+00 * w(124)
      chem( 42) = chem( 42) - w(124)
      chem( 45) = chem( 45) +  0.1300000000000000D+01 * w(124)
      chem( 49) = chem( 49) + w(124)
      chem( 50) = chem( 50) + w(124)
      chem( 25) = chem( 25) - w(125)
      chem( 35) = chem( 35) +  0.3500000000000000D+00 * w(125)
      chem( 37) = chem( 37) +  0.2500000000000000D+00 * w(125)
      chem( 41) = chem( 41) +  0.2500000000000000D+00 * w(125)
      chem( 42) = chem( 42) +  0.5000000000000000D+00 * w(125)
      chem( 43) = chem( 43) +  0.5000000000000000D+00 * w(125)
      chem( 45) = chem( 45) +  0.6500000000000000D+00 * w(125)
      chem( 47) = chem( 47) - w(125)
      chem( 50) = chem( 50) +  0.5000000000000000D+00 * w(125)
      chem( 25) = chem( 25) - w(126)
      chem( 35) = chem( 35) +  0.6400000000000000D+00 * w(126)
      chem( 44) = chem( 44) - w(126)
      chem( 45) = chem( 45) +  0.1180000000000000D+01 * w(126)
      chem( 50) = chem( 50) + w(126)
      chem( 52) = chem( 52) + w(126)
      chem(  5) = chem(  5) - w(127)
      chem( 12) = chem( 12) +  0.5600000000000001D+00 * w(127)
      chem( 27) = chem( 27) +  0.3600000000000000D+00 * w(127)
      chem( 42) = chem( 42) - w(127)
      chem( 49) = chem( 49) +  0.8000000000000000D-01 * w(127)
      chem( 50) = chem( 50) +  0.4400000000000000D+00 * w(127)
      chem( 12) = chem( 12) - w(128)
      chem( 28) = chem( 28) +  0.9000000000000000D+00 * w(128)
      chem( 33) = chem( 33) +  0.1000000000000000D+00 * w(128)
      chem( 48) = chem( 48) - w(128)
      chem( 50) = chem( 50) +  0.9000000000000000D+00 * w(128)
      chem( 52) = chem( 52) +  0.9000000000000000D+00 * w(128)
      chem( 12) = chem( 12) - w(129)
      chem( 27) = chem( 27) + w(129)
      chem( 50) = chem( 50) + w(129)
      chem( 27) = chem( 27) - w(130)
      chem( 28) = chem( 28) +  0.3000000000000000D+00 * w(130)
      chem( 30) = chem( 30) +  0.4000000000000000D+00 * w(130)
      chem( 42) = chem( 42) - w(130)
      chem( 49) = chem( 49) +  0.6000000000000000D+00 * w(130)
      chem( 50) = chem( 50) +  0.6000000000000000D+00 * w(130)
      chem( 27) = chem( 27) - w(131)
      chem( 30) = chem( 30) + w(131)
      chem( 38) = chem( 38) + w(131)
      chem( 44) = chem( 44) - w(131)
      chem( 30) = chem( 30) - w(132)
      chem( 33) = chem( 33) + w(132)
      chem( 52) = chem( 52) - w(132)
      chem( 27) = chem( 27) + w(133)
      chem( 30) = chem( 30) - w(133)
      chem( 50) = chem( 50) - w(133)
      chem( 28) = chem( 28) - w(134)
      chem( 37) = chem( 37) + w(134)
      chem( 50) = chem( 50) + w(134)
      chem( 51) = chem( 51) + w(134)
      chem( 28) = chem( 28) - w(135)
      chem( 37) = chem( 37) +  0.2000000000000000D+01 * w(135)
      chem( 41) = chem( 41) + w(135)
      chem( 42) = chem( 42) - w(135)
      chem( 49) = chem( 49) + w(135)
      chem( 50) = chem( 50) +  0.2000000000000000D+01 * w(135)
      chem( 51) = chem( 51) + w(135)
      chem( 28) = chem( 28) - w(136)
      chem( 29) = chem( 29) +  0.2000000000000000D+00 * w(136)
      chem( 35) = chem( 35) +  0.3000000000000000D-01 * w(136)
      chem( 37) = chem( 37) +  0.6899999999999999D+00 * w(136)
      chem( 41) = chem( 41) +  0.7000000000000000D+00 * w(136)
      chem( 42) = chem( 42) +  0.8000000000000000D-01 * w(136)
      chem( 47) = chem( 47) - w(136)
      chem( 49) = chem( 49) +  0.3000000000000000D-01 * w(136)
      chem( 50) = chem( 50) +  0.7600000000000000D+00 * w(136)
      chem( 51) = chem( 51) +  0.6200000000000000D+00 * w(136)
      chem(  6) = chem(  6) - w(137)
      chem( 12) = chem( 12) +  0.3000000000000000D+00 * w(137)
      chem( 27) = chem( 27) +  0.2000000000000000D-01 * w(137)
      chem( 29) = chem( 29) +  0.8000000000000000D+00 * w(137)
      chem( 34) = chem( 34) +  0.1100000000000000D+01 * w(137)
      chem( 42) = chem( 42) - w(137)
      chem( 49) = chem( 49) +  0.5000000000000000D+00 * w(137)
      chem( 50) = chem( 50) +  0.7000000000000000D+00 * w(137)
      chem( 29) = chem( 29) - w(138)
      chem( 42) = chem( 42) - w(138)
      chem( 49) = chem( 49) + w(138)
      chem( 51) = chem( 51) + w(138)
      chem( 29) = chem( 29) - w(139)
      chem( 37) = chem( 37) + w(139)
      chem( 50) = chem( 50) + w(139)
      chem( 51) = chem( 51) + w(139)
      chem( 31) = chem( 31) - w(140)
      chem( 32) = chem( 32) +  0.7500000000000000D+00 * w(140)
      chem( 34) = chem( 34) +  0.2500000000000000D+00 * w(140)
      chem( 41) = chem( 41) +  0.5000000000000000D+00 * w(140)
      chem( 43) = chem( 43) - w(140)
      chem( 46) = chem( 46) +  0.2500000000000000D+00 * w(140)
      chem( 49) = chem( 49) +  0.2500000000000000D+00 * w(140)
      chem( 50) = chem( 50) +  0.2500000000000000D+00 * w(140)
      chem( 31) = chem( 31) - w(141)
      chem( 32) = chem( 32) +  0.9120000000000000D+00 * w(141)
      chem( 39) = chem( 39) +  0.8799999999999999D-01 * w(141)
      chem( 41) = chem( 41) +  0.6290000000000000D+00 * w(141)
      chem( 42) = chem( 42) - w(141)
      chem( 49) = chem( 49) +  0.9910000000000000D+00 * w(141)
      chem( 50) = chem( 50) +  0.9120000000000000D+00 * w(141)
      chem( 31) = chem( 31) - w(142)
      chem( 32) = chem( 32) +  0.6500000000000000D+00 * w(142)
      chem( 34) = chem( 34) +  0.3500000000000000D+00 * w(142)
      chem( 35) = chem( 35) +  0.1500000000000000D+00 * w(142)
      chem( 37) = chem( 37) +  0.6600000000000000D-01 * w(142)
      chem( 41) = chem( 41) +  0.6000000000000000D+00 * w(142)
      chem( 42) = chem( 42) +  0.2660000000000000D+00 * w(142)
      chem( 46) = chem( 46) +  0.2000000000000000D+00 * w(142)
      chem( 47) = chem( 47) - w(142)
      chem( 49) = chem( 49) +  0.2000000000000000D+00 * w(142)
      chem( 50) = chem( 50) +  0.6600000000000000D-01 * w(142)
      chem( 31) = chem( 31) - w(143)
      chem( 32) = chem( 32) +  0.2000000000000000D+00 * w(143)
      chem( 33) = chem( 33) +  0.8000000000000000D+00 * w(143)
      chem( 34) = chem( 34) +  0.2400000000000000D+01 * w(143)
      chem( 35) = chem( 35) +  0.8000000000000000D+00 * w(143)
      chem( 44) = chem( 44) - w(143)
      chem( 49) = chem( 49) + w(143)
      chem( 50) = chem( 50) +  0.8000000000000000D+00 * w(143)
      chem( 52) = chem( 52) +  0.2000000000000000D+00 * w(143)
      chem( 29) = chem( 29) +  0.1680000000000000D+00 * w(144)
      chem( 32) = chem( 32) - w(144)
      chem( 34) = chem( 34) +  0.1565000000000000D+01 * w(144)
      chem( 35) = chem( 35) +  0.1200000000000000D+00 * w(144)
      chem( 37) = chem( 37) +  0.3340000000000000D+00 * w(144)
      chem( 41) = chem( 41) +  0.1670000000000000D+00 * w(144)
      chem( 42) = chem( 42) - w(144)
      chem( 45) = chem( 45) +  0.2520000000000000D+00 * w(144)
      chem( 46) = chem( 46) +  0.2500000000000000D+00 * w(144)
      chem( 49) = chem( 49) +  0.7130000000000000D+00 * w(144)
      chem( 50) = chem( 50) +  0.5030000000000000D+00 * w(144)
      chem( 51) = chem( 51) +  0.2100000000000000D+00 * w(144)
      chem( 29) = chem( 29) +  0.8500000000000000D+00 * w(145)
      chem( 32) = chem( 32) - w(145)
      chem( 34) = chem( 34) +  0.3600000000000000D+00 * w(145)
      chem( 37) = chem( 37) +  0.2250000000000000D+00 * w(145)
      chem( 41) = chem( 41) +  0.1500000000000000D+00 * w(145)
      chem( 42) = chem( 42) +  0.2680000000000000D+00 * w(145)
      chem( 45) = chem( 45) +  0.2000000000000000D-01 * w(145)
      chem( 47) = chem( 47) - w(145)
      chem( 49) = chem( 49) +  0.6400000000000000D-01 * w(145)
      chem( 50) = chem( 50) +  0.1540000000000000D+00 * w(145)
      chem( 51) = chem( 51) +  0.1140000000000000D+00 * w(145)
      chem( 32) = chem( 32) - w(146)
      chem( 33) = chem( 33) +  0.8500000000000000D+00 * w(146)
      chem( 34) = chem( 34) +  0.1282000000000000D+01 * w(146)
      chem( 35) = chem( 35) +  0.3570000000000000D+00 * w(146)
      chem( 37) = chem( 37) +  0.6430000000000000D+00 * w(146)
      chem( 38) = chem( 38) +  0.1500000000000000D+00 * w(146)
      chem( 41) = chem( 41) +  0.2820000000000000D+00 * w(146)
      chem( 44) = chem( 44) - w(146)
      chem( 46) = chem( 46) +  0.7500000000000000D-01 * w(146)
      chem( 49) = chem( 49) +  0.7500000000000000D-01 * w(146)
      chem( 50) = chem( 50) +  0.9250000000000000D+00 * w(146)
      chem( 32) = chem( 32) - w(147)
      chem( 34) = chem( 34) +  0.8320000000000000D+00 * w(147)
      chem( 37) = chem( 37) +  0.3330000000000000D+00 * w(147)
      chem( 41) = chem( 41) +  0.9000000000000000D+00 * w(147)
      chem( 45) = chem( 45) +  0.6700000000000000D-01 * w(147)
      chem( 49) = chem( 49) +  0.7000000000000000D+00 * w(147)
      chem( 50) = chem( 50) +  0.1033000000000000D+01 * w(147)
      chem( 51) = chem( 51) +  0.9670000000000000D+00 * w(147)
      chem( 26) = chem( 26) - w(148)
      chem( 34) = chem( 34) +  0.5120000000000000D+01 * w(148)
      chem( 35) = chem( 35) +  0.1500000000000000D+00 * w(148)
      chem( 43) = chem( 43) - w(148)
      chem( 26) = chem( 26) - w(149)
      chem( 34) = chem( 34) +  0.1660000000000000D+01 * w(149)
      chem( 35) = chem( 35) +  0.4700000000000000D+00 * w(149)
      chem( 39) = chem( 39) +  0.2500000000000000D+00 * w(149)
      chem( 41) = chem( 41) +  0.2800000000000000D+00 * w(149)
      chem( 42) = chem( 42) - w(149)
      chem( 49) = chem( 49) +  0.1250000000000000D+01 * w(149)
      chem( 50) = chem( 50) +  0.7500000000000000D+00 * w(149)
      chem( 26) = chem( 26) - w(150)
      chem( 34) = chem( 34) +  0.7000000000000000D+01 * w(150)
      chem( 35) = chem( 35) +  0.2100000000000000D+00 * w(150)
      chem( 37) = chem( 37) +  0.1000000000000000D-02 * w(150)
      chem( 39) = chem( 39) +  0.1800000000000000D+00 * w(150)
      chem( 41) = chem( 41) +  0.2400000000000000D+00 * w(150)
      chem( 42) = chem( 42) +  0.5700000000000000D+00 * w(150)
      chem( 46) = chem( 46) +  0.3900000000000000D+00 * w(150)
      chem( 47) = chem( 47) - w(150)
      chem( 49) = chem( 49) +  0.7600000000000000D+00 * w(150)
      chem( 50) = chem( 50) +  0.7000000000000001D-01 * w(150)
      chem( 26) = chem( 26) - w(151)
      chem( 33) = chem( 33) +  0.5300000000000000D+00 * w(151)
      chem( 35) = chem( 35) +  0.4700000000000000D+00 * w(151)
      chem( 39) = chem( 39) +  0.2500000000000000D+00 * w(151)
      chem( 44) = chem( 44) - w(151)
      chem( 49) = chem( 49) +  0.1030000000000000D+01 * w(151)
      chem( 50) = chem( 50) +  0.2800000000000000D+00 * w(151)
      chem( 52) = chem( 52) +  0.4700000000000000D+00 * w(151)
      chem(  7) = chem(  7) - w(152)
      chem(  8) = chem(  8) + w(152)
      chem( 42) = chem( 42) - w(152)
      chem( 50) = chem( 50) + w(152)
      chem(  2) = chem(  2) - w(153)
      chem( 35) = chem( 35) +  0.5000000000000000D-01 * w(153)
      chem( 41) = chem( 41) +  0.1000000000000000D+00 * w(153)
      chem( 42) = chem( 42) - w(153)
      chem( 45) = chem( 45) +  0.9000000000000000D+00 * w(153)
      chem( 49) = chem( 49) +  0.1000000000000000D+00 * w(153)
      chem( 50) = chem( 50) + w(153)
      chem(  4) = chem(  4) - w(154)
      chem( 39) = chem( 39) +  0.8999999999999999D-02 * w(154)
      chem( 42) = chem( 42) - w(154)
      chem( 45) = chem( 45) +  0.9910000000000000D+00 * w(154)
      chem( 49) = chem( 49) +  0.9910000000000000D+00 * w(154)
      chem( 50) = chem( 50) + w(154)
      chem( 31) = chem( 31) - w(155)
      chem( 32) = chem( 32) +  0.2000000000000000D+00 * w(155)
      chem( 33) = chem( 33) +  0.8000000000000000D+00 * w(155)
      chem( 34) = chem( 34) +  0.2400000000000000D+01 * w(155)
      chem( 35) = chem( 35) +  0.8000000000000000D+00 * w(155)
      chem( 48) = chem( 48) +  0.2000000000000000D+00 * w(155)
      chem( 49) = chem( 49) + w(155)
      chem( 50) = chem( 50) +  0.8000000000000000D+00 * w(155)
      chem( 52) = chem( 52) - w(155)
 
C    Conversion molecules/cm3 to mug/m3.
 
      do i = 1, ns
         chem(i) = chem(i) / convers_factor(i)
      enddo
 
C     Volumic source terms.
 
      do i=1,ns
      chem(i)=chem(i)+ZCsourc(i)
      enddo
 
      RETURN
      END
 
