C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C
C     This file is part of the air quality modeling system Polyphemus.
C
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C
C     Polyphemus is free software; you can redistribute i and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C------------------------------------------------------------------------
 
      subroutine jacdchemdc_cb05  (ns,nr,y,convers_factor,
     $                    convers_factor_jac,rk,JacC)
 
C------------------------------------------------------------------------
C
C     -- DESCRIPTION
C
C     This routine computes the Jacobian matrix for the gas-phase.
C     This routine is automatically generated by SPACK.
C     Mechanism: CB05                
C     Species: _ciCB05             
C
C------------------------------------------------------------------------
C
C     -- INPUT VARIABLES
C
C     Ns: chemical species number.
C     NR: reaction number.
C     Y: chemical concentrations.
C     RK: kinetic rates.
C     convers_factor: unity conversion factor of mug/m3 to molecules/cm3.
C     convers_factor_jac: Wmol(i)/Wmol(j) for JacC(i,j)
C
C     -- INPUT/OUTPUT VARIABLES
C
C     -- OUTPUT VARIABLES
C
C     JACC: Jacobian matrix.
C
C------------------------------------------------------------------------
C
C     -- REMARKS
C
C     The matrix JACC could be stored in a low-dimensional vector.
C
C------------------------------------------------------------------------
C
C     -- MODIFICATIONS
C
C------------------------------------------------------------------------
C
C     -- AUTHOR(S)
C
C     SPACK.
C
C------------------------------------------------------------------------
 
      implicit none
 
      integer i,j,nr,ns
      double precision dw(nr,ns),rk(nr),y(ns),JacC(ns,ns)
      double precision convers_factor(ns)
      double precision convers_factor_jac(ns,ns)
      double precision conc(ns)
 
      do j=1,ns
       do i=1,ns
        JacC(i,j)=0.d0
       enddo
      enddo
 
C     Conversion mug/m3 to molecules/cm3.
 
      do i = 1, ns
         conc(i) = y(i) * convers_factor(i)
      enddo
 
      call dratedc_cb05  (ns,nr,rk,conc,dw)
 
      JacC( 43, 52) = JacC( 43, 52) + dw(  1, 52)
      JacC( 48, 52) = JacC( 48, 52) + dw(  1, 52)
      JacC( 52, 52) = JacC( 52, 52) - dw(  1, 52)
      JacC( 43, 43) = JacC( 43, 43) - dw(  2, 43)
      JacC( 47, 43) = JacC( 47, 43) + dw(  2, 43)
      JacC( 47, 47) = JacC( 47, 47) - dw(  3, 47)
      JacC( 47, 48) = JacC( 47, 48) - dw(  3, 48)
      JacC( 48, 47) = JacC( 48, 47) - dw(  3, 47)
      JacC( 48, 48) = JacC( 48, 48) - dw(  3, 48)
      JacC( 52, 47) = JacC( 52, 47) + dw(  3, 47)
      JacC( 52, 48) = JacC( 52, 48) + dw(  3, 48)
      JacC( 43, 43) = JacC( 43, 43) - dw(  4, 43)
      JacC( 43, 52) = JacC( 43, 52) - dw(  4, 52)
      JacC( 48, 43) = JacC( 48, 43) + dw(  4, 43)
      JacC( 48, 52) = JacC( 48, 52) + dw(  4, 52)
      JacC( 52, 43) = JacC( 52, 43) - dw(  4, 43)
      JacC( 52, 52) = JacC( 52, 52) - dw(  4, 52)
      JacC( 43, 43) = JacC( 43, 43) - dw(  5, 43)
      JacC( 43, 52) = JacC( 43, 52) - dw(  5, 52)
      JacC( 44, 43) = JacC( 44, 43) + dw(  5, 43)
      JacC( 44, 52) = JacC( 44, 52) + dw(  5, 52)
      JacC( 52, 43) = JacC( 52, 43) - dw(  5, 43)
      JacC( 52, 52) = JacC( 52, 52) - dw(  5, 52)
      JacC( 43, 43) = JacC( 43, 43) - dw(  6, 43)
      JacC( 43, 48) = JacC( 43, 48) - dw(  6, 48)
      JacC( 48, 43) = JacC( 48, 43) - dw(  6, 43)
      JacC( 48, 48) = JacC( 48, 48) - dw(  6, 48)
      JacC( 52, 43) = JacC( 52, 43) + dw(  6, 43)
      JacC( 52, 48) = JacC( 52, 48) + dw(  6, 48)
      JacC( 44, 52) = JacC( 44, 52) + dw(  7, 52)
      JacC( 44, 47) = JacC( 44, 47) + dw(  7, 47)
      JacC( 47, 52) = JacC( 47, 52) - dw(  7, 52)
      JacC( 47, 47) = JacC( 47, 47) - dw(  7, 47)
      JacC( 52, 52) = JacC( 52, 52) - dw(  7, 52)
      JacC( 52, 47) = JacC( 52, 47) - dw(  7, 47)
      JacC( 43, 47) = JacC( 43, 47) + dw(  8, 47)
      JacC( 47, 47) = JacC( 47, 47) - dw(  8, 47)
      JacC(  1, 47) = JacC(  1, 47) + dw(  9, 47)
      JacC( 47, 47) = JacC( 47, 47) - dw(  9, 47)
      JacC(  1,  1) = JacC(  1,  1) - dw( 10,  1)
      JacC( 43,  1) = JacC( 43,  1) + dw( 10,  1)
      JacC(  1,  1) = JacC(  1,  1) - dw( 11,  1)
      JacC( 42,  1) = JacC( 42,  1)+ 0.2000000000000000D+01*dw( 11,  1)
      JacC( 42, 47) = JacC( 42, 47) - dw( 12, 47)
      JacC( 42, 42) = JacC( 42, 42) - dw( 12, 42)
      JacC( 47, 47) = JacC( 47, 47) - dw( 12, 47)
      JacC( 47, 42) = JacC( 47, 42) - dw( 12, 42)
      JacC( 50, 47) = JacC( 50, 47) + dw( 12, 47)
      JacC( 50, 42) = JacC( 50, 42) + dw( 12, 42)
      JacC( 42, 47) = JacC( 42, 47) + dw( 13, 47)
      JacC( 42, 50) = JacC( 42, 50) + dw( 13, 50)
      JacC( 47, 47) = JacC( 47, 47) - dw( 13, 47)
      JacC( 47, 50) = JacC( 47, 50) - dw( 13, 50)
      JacC( 50, 47) = JacC( 50, 47) - dw( 13, 47)
      JacC( 50, 50) = JacC( 50, 50) - dw( 13, 50)
      JacC( 43, 44) = JacC( 43, 44) + dw( 14, 44)
      JacC( 44, 44) = JacC( 44, 44) - dw( 14, 44)
      JacC( 52, 44) = JacC( 52, 44) + dw( 14, 44)
      JacC( 44, 44) = JacC( 44, 44) - dw( 15, 44)
      JacC( 48, 44) = JacC( 48, 44) + dw( 15, 44)
      JacC( 44, 44) = JacC( 44, 44) - dw( 16, 44)
      JacC( 44, 48) = JacC( 44, 48) - dw( 16, 48)
      JacC( 48, 44) = JacC( 48, 44) - dw( 16, 44)
      JacC( 48, 48) = JacC( 48, 48) - dw( 16, 48)
      JacC( 52, 44) = JacC( 52, 44)+ 0.2000000000000000D+01*dw( 16, 44)
      JacC( 52, 48) = JacC( 52, 48)+ 0.2000000000000000D+01*dw( 16, 48)
      JacC( 44, 44) = JacC( 44, 44) - dw( 17, 44)
      JacC( 44, 52) = JacC( 44, 52) - dw( 17, 52)
      JacC( 48, 44) = JacC( 48, 44) + dw( 17, 44)
      JacC( 48, 52) = JacC( 48, 52) + dw( 17, 52)
      JacC(  9, 44) = JacC(  9, 44) + dw( 18, 44)
      JacC(  9, 52) = JacC(  9, 52) + dw( 18, 52)
      JacC( 44, 44) = JacC( 44, 44) - dw( 18, 44)
      JacC( 44, 52) = JacC( 44, 52) - dw( 18, 52)
      JacC( 52, 44) = JacC( 52, 44) - dw( 18, 44)
      JacC( 52, 52) = JacC( 52, 52) - dw( 18, 52)
      JacC(  9,  9) = JacC(  9,  9) - dw( 19,  9)
      JacC( 38,  9) = JacC( 38,  9)+ 0.2000000000000000D+01*dw( 19,  9)
      JacC(  9,  9) = JacC(  9,  9) - dw( 20,  9)
      JacC( 44,  9) = JacC( 44,  9) + dw( 20,  9)
      JacC( 52,  9) = JacC( 52,  9) + dw( 20,  9)
      JacC( 48, 48) = JacC( 48, 48)- 0.2000000000000000D+01*dw( 21, 48)
      JacC( 48, 48) = JacC( 48, 48)- 0.2000000000000000D+01*dw( 21, 48)
      JacC( 52, 48) = JacC( 52, 48)+ 0.2000000000000000D+01*dw( 21, 48)
      JacC( 52, 48) = JacC( 52, 48)+ 0.2000000000000000D+01*dw( 21, 48)
      JacC( 15, 48) = JacC( 15, 48)+ 0.2000000000000000D+01*dw( 22, 48)
      JacC( 15, 52) = JacC( 15, 52)+ 0.2000000000000000D+01*dw( 22, 52)
      JacC( 48, 48) = JacC( 48, 48) - dw( 22, 48)
      JacC( 48, 52) = JacC( 48, 52) - dw( 22, 52)
      JacC( 52, 48) = JacC( 52, 48) - dw( 22, 48)
      JacC( 52, 52) = JacC( 52, 52) - dw( 22, 52)
      JacC( 15, 42) = JacC( 15, 42) + dw( 23, 42)
      JacC( 15, 48) = JacC( 15, 48) + dw( 23, 48)
      JacC( 42, 42) = JacC( 42, 42) - dw( 23, 42)
      JacC( 42, 48) = JacC( 42, 48) - dw( 23, 48)
      JacC( 48, 42) = JacC( 48, 42) - dw( 23, 42)
      JacC( 48, 48) = JacC( 48, 48) - dw( 23, 48)
      JacC( 15, 15) = JacC( 15, 15) - dw( 24, 15)
      JacC( 42, 15) = JacC( 42, 15) + dw( 24, 15)
      JacC( 48, 15) = JacC( 48, 15) + dw( 24, 15)
      JacC( 15, 42) = JacC( 15, 42) - dw( 25, 42)
      JacC( 15, 15) = JacC( 15, 15) - dw( 25, 15)
      JacC( 42, 42) = JacC( 42, 42) - dw( 25, 42)
      JacC( 42, 15) = JacC( 42, 15) - dw( 25, 15)
      JacC( 52, 42) = JacC( 52, 42) + dw( 25, 42)
      JacC( 52, 15) = JacC( 52, 15) + dw( 25, 15)
      JacC( 15, 15) = JacC( 15, 15)- 0.2000000000000000D+01*dw( 26, 15)
      JacC( 15, 15) = JacC( 15, 15)- 0.2000000000000000D+01*dw( 26, 15)
      JacC( 48, 15) = JacC( 48, 15) + dw( 26, 15)
      JacC( 48, 15) = JacC( 48, 15) + dw( 26, 15)
      JacC( 52, 15) = JacC( 52, 15) + dw( 26, 15)
      JacC( 52, 15) = JacC( 52, 15) + dw( 26, 15)
      JacC( 38, 52) = JacC( 38, 52) + dw( 27, 52)
      JacC( 38, 42) = JacC( 38, 42) + dw( 27, 42)
      JacC( 42, 52) = JacC( 42, 52) - dw( 27, 52)
      JacC( 42, 42) = JacC( 42, 42) - dw( 27, 42)
      JacC( 52, 52) = JacC( 52, 52) - dw( 27, 52)
      JacC( 52, 42) = JacC( 52, 42) - dw( 27, 42)
      JacC( 38, 42) = JacC( 38, 42) - dw( 28, 42)
      JacC( 38, 38) = JacC( 38, 38) - dw( 28, 38)
      JacC( 42, 42) = JacC( 42, 42) - dw( 28, 42)
      JacC( 42, 38) = JacC( 42, 38) - dw( 28, 38)
      JacC( 44, 42) = JacC( 44, 42) + dw( 28, 42)
      JacC( 44, 38) = JacC( 44, 38) + dw( 28, 38)
      JacC( 42, 50) = JacC( 42, 50) + dw( 29, 50)
      JacC( 42, 48) = JacC( 42, 48) + dw( 29, 48)
      JacC( 48, 50) = JacC( 48, 50) - dw( 29, 50)
      JacC( 48, 48) = JacC( 48, 48) - dw( 29, 48)
      JacC( 50, 50) = JacC( 50, 50) - dw( 29, 50)
      JacC( 50, 48) = JacC( 50, 48) - dw( 29, 48)
      JacC( 52, 50) = JacC( 52, 50) + dw( 29, 50)
      JacC( 52, 48) = JacC( 52, 48) + dw( 29, 48)
      JacC( 13, 50) = JacC( 13, 50) + dw( 30, 50)
      JacC( 13, 52) = JacC( 13, 52) + dw( 30, 52)
      JacC( 50, 50) = JacC( 50, 50) - dw( 30, 50)
      JacC( 50, 52) = JacC( 50, 52) - dw( 30, 52)
      JacC( 52, 50) = JacC( 52, 50) - dw( 30, 50)
      JacC( 52, 52) = JacC( 52, 52) - dw( 30, 52)
      JacC( 13, 13) = JacC( 13, 13) - dw( 31, 13)
      JacC( 50, 13) = JacC( 50, 13) + dw( 31, 13)
      JacC( 52, 13) = JacC( 52, 13) + dw( 31, 13)
      JacC( 13, 42) = JacC( 13, 42) - dw( 32, 42)
      JacC( 13, 13) = JacC( 13, 13) - dw( 32, 13)
      JacC( 42, 42) = JacC( 42, 42) - dw( 32, 42)
      JacC( 42, 13) = JacC( 42, 13) - dw( 32, 13)
      JacC( 52, 42) = JacC( 52, 42) + dw( 32, 42)
      JacC( 52, 13) = JacC( 52, 13) + dw( 32, 13)
      JacC( 17, 50) = JacC( 17, 50) + dw( 33, 50)
      JacC( 17, 50) = JacC( 17, 50) + dw( 33, 50)
      JacC( 50, 50) = JacC( 50, 50)- 0.2000000000000000D+01*dw( 33, 50)
      JacC( 50, 50) = JacC( 50, 50)- 0.2000000000000000D+01*dw( 33, 50)
      JacC( 17, 50) = JacC( 17, 50) + dw( 34, 50)
      JacC( 17, 50) = JacC( 17, 50) + dw( 34, 50)
      JacC( 50, 50) = JacC( 50, 50)- 0.2000000000000000D+01*dw( 34, 50)
      JacC( 50, 50) = JacC( 50, 50)- 0.2000000000000000D+01*dw( 34, 50)
      JacC( 17, 17) = JacC( 17, 17) - dw( 35, 17)
      JacC( 42, 17) = JacC( 42, 17)+ 0.2000000000000000D+01*dw( 35, 17)
      JacC( 17, 42) = JacC( 17, 42) - dw( 36, 42)
      JacC( 17, 17) = JacC( 17, 17) - dw( 36, 17)
      JacC( 42, 42) = JacC( 42, 42) - dw( 36, 42)
      JacC( 42, 17) = JacC( 42, 17) - dw( 36, 17)
      JacC( 50, 42) = JacC( 50, 42) + dw( 36, 42)
      JacC( 50, 17) = JacC( 50, 17) + dw( 36, 17)
      JacC(  1,  1) = JacC(  1,  1) - dw( 37,  1)
      JacC( 42,  1) = JacC( 42,  1) + dw( 37,  1)
      JacC( 50,  1) = JacC( 50,  1) + dw( 37,  1)
      JacC( 42, 42) = JacC( 42, 42) - dw( 38, 42)
      JacC( 50, 42) = JacC( 50, 42) + dw( 38, 42)
      JacC( 42, 42) = JacC( 42, 42) - dw( 39, 42)
      JacC( 42, 43) = JacC( 42, 43) - dw( 39, 43)
      JacC( 43, 42) = JacC( 43, 42) - dw( 39, 42)
      JacC( 43, 43) = JacC( 43, 43) - dw( 39, 43)
      JacC( 50, 42) = JacC( 50, 42) + dw( 39, 42)
      JacC( 50, 43) = JacC( 50, 43) + dw( 39, 43)
      JacC( 42, 42) = JacC( 42, 42)- 0.2000000000000000D+01*dw( 40, 42)
      JacC( 42, 42) = JacC( 42, 42)- 0.2000000000000000D+01*dw( 40, 42)
      JacC( 43, 42) = JacC( 43, 42) + dw( 40, 42)
      JacC( 43, 42) = JacC( 43, 42) + dw( 40, 42)
      JacC( 17, 42) = JacC( 17, 42) + dw( 41, 42)
      JacC( 17, 42) = JacC( 17, 42) + dw( 41, 42)
      JacC( 42, 42) = JacC( 42, 42)- 0.2000000000000000D+01*dw( 41, 42)
      JacC( 42, 42) = JacC( 42, 42)- 0.2000000000000000D+01*dw( 41, 42)
      JacC( 42, 42) = JacC( 42, 42) - dw( 42, 42)
      JacC( 42, 50) = JacC( 42, 50) - dw( 42, 50)
      JacC( 50, 42) = JacC( 50, 42) - dw( 42, 42)
      JacC( 50, 50) = JacC( 50, 50) - dw( 42, 50)
      JacC( 42, 50) = JacC( 42, 50) + dw( 43, 50)
      JacC( 42, 43) = JacC( 42, 43) + dw( 43, 43)
      JacC( 43, 50) = JacC( 43, 50) - dw( 43, 50)
      JacC( 43, 43) = JacC( 43, 43) - dw( 43, 43)
      JacC( 50, 50) = JacC( 50, 50) - dw( 43, 50)
      JacC( 50, 43) = JacC( 50, 43) - dw( 43, 43)
      JacC( 17, 17) = JacC( 17, 17) - dw( 44, 17)
      JacC( 17, 43) = JacC( 17, 43) - dw( 44, 43)
      JacC( 42, 17) = JacC( 42, 17) + dw( 44, 17)
      JacC( 42, 43) = JacC( 42, 43) + dw( 44, 43)
      JacC( 43, 17) = JacC( 43, 17) - dw( 44, 17)
      JacC( 43, 43) = JacC( 43, 43) - dw( 44, 43)
      JacC( 50, 17) = JacC( 50, 17) + dw( 44, 17)
      JacC( 50, 43) = JacC( 50, 43) + dw( 44, 43)
      JacC( 43, 44) = JacC( 43, 44) - dw( 45, 44)
      JacC( 43, 43) = JacC( 43, 43) - dw( 45, 43)
      JacC( 44, 44) = JacC( 44, 44) - dw( 45, 44)
      JacC( 44, 43) = JacC( 44, 43) - dw( 45, 43)
      JacC( 52, 44) = JacC( 52, 44) + dw( 45, 44)
      JacC( 52, 43) = JacC( 52, 43) + dw( 45, 43)
      JacC( 42, 44) = JacC( 42, 44) - dw( 46, 44)
      JacC( 42, 42) = JacC( 42, 42) - dw( 46, 42)
      JacC( 44, 44) = JacC( 44, 44) - dw( 46, 44)
      JacC( 44, 42) = JacC( 44, 42) - dw( 46, 42)
      JacC( 50, 44) = JacC( 50, 44) + dw( 46, 44)
      JacC( 50, 42) = JacC( 50, 42) + dw( 46, 42)
      JacC( 52, 44) = JacC( 52, 44) + dw( 46, 44)
      JacC( 52, 42) = JacC( 52, 42) + dw( 46, 42)
      JacC( 38, 44) = JacC( 38, 44) + dw( 47, 44)
      JacC( 38, 50) = JacC( 38, 50) + dw( 47, 50)
      JacC( 44, 44) = JacC( 44, 44) - dw( 47, 44)
      JacC( 44, 50) = JacC( 44, 50) - dw( 47, 50)
      JacC( 50, 44) = JacC( 50, 44) - dw( 47, 44)
      JacC( 50, 50) = JacC( 50, 50) - dw( 47, 50)
      JacC( 44, 44) = JacC( 44, 44) - dw( 48, 44)
      JacC( 44, 47) = JacC( 44, 47) - dw( 48, 47)
      JacC( 47, 44) = JacC( 47, 44) - dw( 48, 44)
      JacC( 47, 47) = JacC( 47, 47) - dw( 48, 47)
      JacC( 52, 44) = JacC( 52, 44) + dw( 48, 44)
      JacC( 52, 47) = JacC( 52, 47) + dw( 48, 47)
      JacC( 44, 44) = JacC( 44, 44)- 0.2000000000000000D+01*dw( 49, 44)
      JacC( 44, 44) = JacC( 44, 44)- 0.2000000000000000D+01*dw( 49, 44)
      JacC( 52, 44) = JacC( 52, 44)+ 0.2000000000000000D+01*dw( 49, 44)
      JacC( 52, 44) = JacC( 52, 44)+ 0.2000000000000000D+01*dw( 49, 44)
      JacC( 13, 13) = JacC( 13, 13) - dw( 50, 13)
      JacC( 42, 13) = JacC( 42, 13)+ 0.3900000000000000D+00*dw( 50, 13)
      JacC( 44, 13) = JacC( 44, 13)+ 0.3900000000000000D+00*dw( 50, 13)
      JacC( 50, 13) = JacC( 50, 13)+ 0.6100000000000000D+00*dw( 50, 13)
      JacC( 52, 13) = JacC( 52, 13)+ 0.6100000000000000D+00*dw( 50, 13)
      JacC( 38, 38) = JacC( 38, 38) - dw( 51, 38)
      JacC( 42, 38) = JacC( 42, 38) + dw( 51, 38)
      JacC( 52, 38) = JacC( 52, 38) + dw( 51, 38)
      JacC(  9,  9) = JacC(  9,  9) - dw( 52,  9)
      JacC( 44,  9) = JacC( 44,  9) + dw( 52,  9)
      JacC( 52,  9) = JacC( 52,  9) + dw( 52,  9)
      JacC( 48, 49) = JacC( 48, 49) - dw( 53, 49)
      JacC( 48, 48) = JacC( 48, 48) - dw( 53, 48)
      JacC( 49, 49) = JacC( 49, 49) - dw( 53, 49)
      JacC( 49, 48) = JacC( 49, 48) - dw( 53, 48)
      JacC( 52, 49) = JacC( 52, 49) + dw( 53, 49)
      JacC( 52, 48) = JacC( 52, 48) + dw( 53, 48)
      JacC( 33, 39) = JacC( 33, 39) + dw( 54, 39)
      JacC( 33, 48) = JacC( 33, 48) + dw( 54, 48)
      JacC( 39, 39) = JacC( 39, 39) - dw( 54, 39)
      JacC( 39, 48) = JacC( 39, 48) - dw( 54, 48)
      JacC( 48, 39) = JacC( 48, 39) - dw( 54, 39)
      JacC( 48, 48) = JacC( 48, 48) - dw( 54, 48)
      JacC( 21, 49) = JacC( 21, 49) + dw( 55, 49)
      JacC( 21, 50) = JacC( 21, 50) + dw( 55, 50)
      JacC( 49, 49) = JacC( 49, 49) - dw( 55, 49)
      JacC( 49, 50) = JacC( 49, 50) - dw( 55, 50)
      JacC( 50, 49) = JacC( 50, 49) - dw( 55, 49)
      JacC( 50, 50) = JacC( 50, 50) - dw( 55, 50)
      JacC( 21, 39) = JacC( 21, 39) + dw( 56, 39)
      JacC( 21, 50) = JacC( 21, 50) + dw( 56, 50)
      JacC( 39, 39) = JacC( 39, 39) - dw( 56, 39)
      JacC( 39, 50) = JacC( 39, 50) - dw( 56, 50)
      JacC( 50, 39) = JacC( 50, 39) - dw( 56, 39)
      JacC( 50, 50) = JacC( 50, 50) - dw( 56, 50)
      JacC( 49, 49) = JacC( 49, 49)- 0.2000000000000000D+01*dw( 57, 49)
      JacC( 49, 49) = JacC( 49, 49)- 0.2000000000000000D+01*dw( 57, 49)
      JacC( 39, 39) = JacC( 39, 39)- 0.2000000000000000D+01*dw( 58, 39)
      JacC( 39, 39) = JacC( 39, 39)- 0.2000000000000000D+01*dw( 58, 39)
      JacC( 39, 49) = JacC( 39, 49) - dw( 59, 49)
      JacC( 39, 39) = JacC( 39, 39) - dw( 59, 39)
      JacC( 49, 49) = JacC( 49, 49) - dw( 59, 49)
      JacC( 49, 39) = JacC( 49, 39) - dw( 59, 39)
      JacC( 33, 33) = JacC( 33, 33) - dw( 60, 33)
      JacC( 33, 42) = JacC( 33, 42) - dw( 60, 42)
      JacC( 34, 33) = JacC( 34, 33)+ 0.6600000000000000D+00*dw( 60, 33)
      JacC( 34, 42) = JacC( 34, 42)+ 0.6600000000000000D+00*dw( 60, 42)
      JacC( 35, 33) = JacC( 35, 33)+ 0.3300000000000000D+00*dw( 60, 33)
      JacC( 35, 42) = JacC( 35, 42)+ 0.3300000000000000D+00*dw( 60, 42)
      JacC( 38, 33) = JacC( 38, 33) + dw( 60, 33)
      JacC( 38, 42) = JacC( 38, 42) + dw( 60, 42)
      JacC( 41, 33) = JacC( 41, 33)+ 0.3300000000000000D+00*dw( 60, 33)
      JacC( 41, 42) = JacC( 41, 42)+ 0.3300000000000000D+00*dw( 60, 42)
      JacC( 42, 33) = JacC( 42, 33) - dw( 60, 33)
      JacC( 42, 42) = JacC( 42, 42) - dw( 60, 42)
      JacC( 45, 33) = JacC( 45, 33)+ 0.3300000000000000D+00*dw( 60, 33)
      JacC( 45, 42) = JacC( 45, 42)+ 0.3300000000000000D+00*dw( 60, 42)
      JacC( 50, 33) = JacC( 50, 33) + dw( 60, 33)
      JacC( 50, 42) = JacC( 50, 42) + dw( 60, 42)
      JacC( 33, 33) = JacC( 33, 33) - dw( 61, 33)
      JacC( 34, 33) = JacC( 34, 33)+ 0.6600000000000000D+00*dw( 61, 33)
      JacC( 35, 33) = JacC( 35, 33)+ 0.3300000000000000D+00*dw( 61, 33)
      JacC( 41, 33) = JacC( 41, 33)+ 0.3300000000000000D+00*dw( 61, 33)
      JacC( 45, 33) = JacC( 45, 33)+ 0.3300000000000000D+00*dw( 61, 33)
      JacC( 50, 33) = JacC( 50, 33) + dw( 61, 33)
      JacC( 52, 33) = JacC( 52, 33) + dw( 61, 33)
      JacC( 21, 21) = JacC( 21, 21) - dw( 62, 21)
      JacC( 21, 42) = JacC( 21, 42) - dw( 62, 42)
      JacC( 35, 21) = JacC( 35, 21)+ 0.5000000000000000D+00*dw( 62, 21)
      JacC( 35, 42) = JacC( 35, 42)+ 0.5000000000000000D+00*dw( 62, 42)
      JacC( 42, 21) = JacC( 42, 21) - dw( 62, 21)
      JacC( 42, 42) = JacC( 42, 42) - dw( 62, 42)
      JacC( 45, 21) = JacC( 45, 21)+ 0.5000000000000000D+00*dw( 62, 21)
      JacC( 45, 42) = JacC( 45, 42)+ 0.5000000000000000D+00*dw( 62, 42)
      JacC( 49, 21) = JacC( 49, 21) + dw( 62, 21)
      JacC( 49, 42) = JacC( 49, 42) + dw( 62, 42)
      JacC( 21, 21) = JacC( 21, 21) - dw( 63, 21)
      JacC( 35, 21) = JacC( 35, 21)+ 0.5000000000000000D+00*dw( 63, 21)
      JacC( 42, 21) = JacC( 42, 21) + dw( 63, 21)
      JacC( 45, 21) = JacC( 45, 21)+ 0.5000000000000000D+00*dw( 63, 21)
      JacC( 50, 21) = JacC( 50, 21) + dw( 63, 21)
      JacC( 37, 42) = JacC( 37, 42) - dw( 64, 42)
      JacC( 37, 37) = JacC( 37, 37) - dw( 64, 37)
      JacC( 42, 42) = JacC( 42, 42) - dw( 64, 42)
      JacC( 42, 37) = JacC( 42, 37) - dw( 64, 37)
      JacC( 50, 42) = JacC( 50, 42) + dw( 64, 42)
      JacC( 50, 37) = JacC( 50, 37) + dw( 64, 37)
      JacC(  3, 42) = JacC(  3, 42) - dw( 65, 42)
      JacC(  3,  3) = JacC(  3,  3) - dw( 65,  3)
      JacC( 40, 42) = JacC( 40, 42) + dw( 65, 42)
      JacC( 40,  3) = JacC( 40,  3) + dw( 65,  3)
      JacC( 42, 42) = JacC( 42, 42) - dw( 65, 42)
      JacC( 42,  3) = JacC( 42,  3) - dw( 65,  3)
      JacC( 40, 40) = JacC( 40, 40) - dw( 66, 40)
      JacC( 40, 48) = JacC( 40, 48) - dw( 66, 48)
      JacC( 41, 40) = JacC( 41, 40) + dw( 66, 40)
      JacC( 41, 48) = JacC( 41, 48) + dw( 66, 48)
      JacC( 48, 40) = JacC( 48, 40) - dw( 66, 40)
      JacC( 48, 48) = JacC( 48, 48) - dw( 66, 48)
      JacC( 50, 40) = JacC( 50, 40) + dw( 66, 40)
      JacC( 50, 48) = JacC( 50, 48) + dw( 66, 48)
      JacC( 52, 40) = JacC( 52, 40) + dw( 66, 40)
      JacC( 52, 48) = JacC( 52, 48) + dw( 66, 48)
      JacC( 19, 40) = JacC( 19, 40) + dw( 67, 40)
      JacC( 19, 50) = JacC( 19, 50) + dw( 67, 50)
      JacC( 40, 40) = JacC( 40, 40) - dw( 67, 40)
      JacC( 40, 50) = JacC( 40, 50) - dw( 67, 50)
      JacC( 50, 40) = JacC( 50, 40) - dw( 67, 40)
      JacC( 50, 50) = JacC( 50, 50) - dw( 67, 50)
      JacC( 11, 40) = JacC( 11, 40)+ 0.6300000000000000D+00*dw( 68, 40)
      JacC( 11, 40) = JacC( 11, 40)+ 0.6300000000000000D+00*dw( 68, 40)
      JacC( 40, 40) = JacC( 40, 40)- 0.2000000000000000D+01*dw( 68, 40)
      JacC( 40, 40) = JacC( 40, 40)- 0.2000000000000000D+01*dw( 68, 40)
      JacC( 41, 40) = JacC( 41, 40)+ 0.1370000000000000D+01*dw( 68, 40)
      JacC( 41, 40) = JacC( 41, 40)+ 0.1370000000000000D+01*dw( 68, 40)
      JacC( 50, 40) = JacC( 50, 40)+ 0.7400000000000000D+00*dw( 68, 40)
      JacC( 50, 40) = JacC( 50, 40)+ 0.7400000000000000D+00*dw( 68, 40)
      JacC( 19, 19) = JacC( 19, 19) - dw( 69, 19)
      JacC( 19, 42) = JacC( 19, 42) - dw( 69, 42)
      JacC( 40, 19) = JacC( 40, 19)+ 0.7000000000000000D+00*dw( 69, 19)
      JacC( 40, 42) = JacC( 40, 42)+ 0.7000000000000000D+00*dw( 69, 42)
      JacC( 42, 19) = JacC( 42, 19) - dw( 69, 19)
      JacC( 42, 42) = JacC( 42, 42) - dw( 69, 42)
      JacC( 49, 19) = JacC( 49, 19)+ 0.3000000000000000D+00*dw( 69, 19)
      JacC( 49, 42) = JacC( 49, 42)+ 0.3000000000000000D+00*dw( 69, 42)
      JacC( 50, 19) = JacC( 50, 19)+ 0.3000000000000000D-01*dw( 69, 19)
      JacC( 50, 42) = JacC( 50, 42)+ 0.3000000000000000D-01*dw( 69, 42)
      JacC( 19, 19) = JacC( 19, 19) - dw( 70, 19)
      JacC( 41, 19) = JacC( 41, 19) + dw( 70, 19)
      JacC( 42, 19) = JacC( 42, 19) + dw( 70, 19)
      JacC( 50, 19) = JacC( 50, 19) + dw( 70, 19)
      JacC( 11, 11) = JacC( 11, 11) - dw( 71, 11)
      JacC( 11, 42) = JacC( 11, 42) - dw( 71, 42)
      JacC( 41, 11) = JacC( 41, 11) + dw( 71, 11)
      JacC( 41, 42) = JacC( 41, 42) + dw( 71, 42)
      JacC( 42, 11) = JacC( 42, 11) - dw( 71, 11)
      JacC( 42, 42) = JacC( 42, 42) - dw( 71, 42)
      JacC( 50, 11) = JacC( 50, 11) + dw( 71, 11)
      JacC( 50, 42) = JacC( 50, 42) + dw( 71, 42)
      JacC( 37, 41) = JacC( 37, 41) + dw( 72, 41)
      JacC( 37, 42) = JacC( 37, 42) + dw( 72, 42)
      JacC( 41, 41) = JacC( 41, 41) - dw( 72, 41)
      JacC( 41, 42) = JacC( 41, 42) - dw( 72, 42)
      JacC( 42, 41) = JacC( 42, 41) - dw( 72, 41)
      JacC( 42, 42) = JacC( 42, 42) - dw( 72, 42)
      JacC( 50, 41) = JacC( 50, 41) + dw( 72, 41)
      JacC( 50, 42) = JacC( 50, 42) + dw( 72, 42)
      JacC( 37, 41) = JacC( 37, 41) + dw( 73, 41)
      JacC( 41, 41) = JacC( 41, 41) - dw( 73, 41)
      JacC( 50, 41) = JacC( 50, 41)+ 0.2000000000000000D+01*dw( 73, 41)
      JacC( 37, 41) = JacC( 37, 41) + dw( 74, 41)
      JacC( 41, 41) = JacC( 41, 41) - dw( 74, 41)
      JacC( 37, 41) = JacC( 37, 41) + dw( 75, 41)
      JacC( 37, 43) = JacC( 37, 43) + dw( 75, 43)
      JacC( 41, 41) = JacC( 41, 41) - dw( 75, 41)
      JacC( 41, 43) = JacC( 41, 43) - dw( 75, 43)
      JacC( 42, 41) = JacC( 42, 41) + dw( 75, 41)
      JacC( 42, 43) = JacC( 42, 43) + dw( 75, 43)
      JacC( 43, 41) = JacC( 43, 41) - dw( 75, 41)
      JacC( 43, 43) = JacC( 43, 43) - dw( 75, 43)
      JacC( 50, 41) = JacC( 50, 41) + dw( 75, 41)
      JacC( 50, 43) = JacC( 50, 43) + dw( 75, 43)
      JacC( 37, 41) = JacC( 37, 41) + dw( 76, 41)
      JacC( 37, 44) = JacC( 37, 44) + dw( 76, 44)
      JacC( 38, 41) = JacC( 38, 41) + dw( 76, 41)
      JacC( 38, 44) = JacC( 38, 44) + dw( 76, 44)
      JacC( 41, 41) = JacC( 41, 41) - dw( 76, 41)
      JacC( 41, 44) = JacC( 41, 44) - dw( 76, 44)
      JacC( 44, 41) = JacC( 44, 41) - dw( 76, 41)
      JacC( 44, 44) = JacC( 44, 44) - dw( 76, 44)
      JacC( 50, 41) = JacC( 50, 41) + dw( 76, 41)
      JacC( 50, 44) = JacC( 50, 44) + dw( 76, 44)
      JacC( 18, 41) = JacC( 18, 41) + dw( 77, 41)
      JacC( 18, 50) = JacC( 18, 50) + dw( 77, 50)
      JacC( 41, 41) = JacC( 41, 41) - dw( 77, 41)
      JacC( 41, 50) = JacC( 41, 50) - dw( 77, 50)
      JacC( 50, 41) = JacC( 50, 41) - dw( 77, 41)
      JacC( 50, 50) = JacC( 50, 50) - dw( 77, 50)
      JacC( 18, 18) = JacC( 18, 18) - dw( 78, 18)
      JacC( 41, 18) = JacC( 41, 18) + dw( 78, 18)
      JacC( 50, 18) = JacC( 50, 18) + dw( 78, 18)
      JacC( 18, 18) = JacC( 18, 18) - dw( 79, 18)
      JacC( 18, 48) = JacC( 18, 48) - dw( 79, 48)
      JacC( 20, 18) = JacC( 20, 18) + dw( 79, 18)
      JacC( 20, 48) = JacC( 20, 48) + dw( 79, 48)
      JacC( 48, 18) = JacC( 48, 18) - dw( 79, 18)
      JacC( 48, 48) = JacC( 48, 48) - dw( 79, 48)
      JacC( 50, 18) = JacC( 50, 18) + dw( 79, 18)
      JacC( 50, 48) = JacC( 50, 48) + dw( 79, 48)
      JacC( 52, 18) = JacC( 52, 18) + dw( 79, 18)
      JacC( 52, 48) = JacC( 52, 48) + dw( 79, 48)
      JacC( 18, 18) = JacC( 18, 18) - dw( 80, 18)
      JacC( 18, 50) = JacC( 18, 50) - dw( 80, 50)
      JacC( 19, 18) = JacC( 19, 18) + dw( 80, 18)
      JacC( 19, 50) = JacC( 19, 50) + dw( 80, 50)
      JacC( 50, 18) = JacC( 50, 18) - dw( 80, 18)
      JacC( 50, 50) = JacC( 50, 50) - dw( 80, 50)
      JacC( 20, 20) = JacC( 20, 20) - dw( 81, 20)
      JacC( 20, 42) = JacC( 20, 42) - dw( 81, 42)
      JacC( 42, 20) = JacC( 42, 20) - dw( 81, 20)
      JacC( 42, 42) = JacC( 42, 42) - dw( 81, 42)
      JacC( 50, 20) = JacC( 50, 20) + dw( 81, 20)
      JacC( 50, 42) = JacC( 50, 42) + dw( 81, 42)
      JacC( 42, 45) = JacC( 42, 45) + dw( 82, 45)
      JacC( 42, 43) = JacC( 42, 43) + dw( 82, 43)
      JacC( 43, 45) = JacC( 43, 45) - dw( 82, 45)
      JacC( 43, 43) = JacC( 43, 43) - dw( 82, 43)
      JacC( 45, 45) = JacC( 45, 45) - dw( 82, 45)
      JacC( 45, 43) = JacC( 45, 43) - dw( 82, 43)
      JacC( 51, 45) = JacC( 51, 45) + dw( 82, 45)
      JacC( 51, 43) = JacC( 51, 43) + dw( 82, 43)
      JacC( 42, 45) = JacC( 42, 45) - dw( 83, 45)
      JacC( 42, 42) = JacC( 42, 42) - dw( 83, 42)
      JacC( 45, 45) = JacC( 45, 45) - dw( 83, 45)
      JacC( 45, 42) = JacC( 45, 42) - dw( 83, 42)
      JacC( 51, 45) = JacC( 51, 45) + dw( 83, 45)
      JacC( 51, 42) = JacC( 51, 42) + dw( 83, 42)
      JacC( 38, 45) = JacC( 38, 45) + dw( 84, 45)
      JacC( 38, 44) = JacC( 38, 44) + dw( 84, 44)
      JacC( 44, 45) = JacC( 44, 45) - dw( 84, 45)
      JacC( 44, 44) = JacC( 44, 44) - dw( 84, 44)
      JacC( 45, 45) = JacC( 45, 45) - dw( 84, 45)
      JacC( 45, 44) = JacC( 45, 44) - dw( 84, 44)
      JacC( 51, 45) = JacC( 51, 45) + dw( 84, 45)
      JacC( 51, 44) = JacC( 51, 44) + dw( 84, 44)
      JacC( 37, 45) = JacC( 37, 45) + dw( 85, 45)
      JacC( 40, 45) = JacC( 40, 45) + dw( 85, 45)
      JacC( 45, 45) = JacC( 45, 45) - dw( 85, 45)
      JacC( 50, 45) = JacC( 50, 45) + dw( 85, 45)
      JacC( 40, 51) = JacC( 40, 51) + dw( 86, 51)
      JacC( 40, 48) = JacC( 40, 48) + dw( 86, 48)
      JacC( 48, 51) = JacC( 48, 51) - dw( 86, 51)
      JacC( 48, 48) = JacC( 48, 48) - dw( 86, 48)
      JacC( 51, 51) = JacC( 51, 51) - dw( 86, 51)
      JacC( 51, 48) = JacC( 51, 48) - dw( 86, 48)
      JacC( 52, 51) = JacC( 52, 51) + dw( 86, 51)
      JacC( 52, 48) = JacC( 52, 48) + dw( 86, 48)
      JacC( 10, 51) = JacC( 10, 51) + dw( 87, 51)
      JacC( 10, 52) = JacC( 10, 52) + dw( 87, 52)
      JacC( 51, 51) = JacC( 51, 51) - dw( 87, 51)
      JacC( 51, 52) = JacC( 51, 52) - dw( 87, 52)
      JacC( 52, 51) = JacC( 52, 51) - dw( 87, 51)
      JacC( 52, 52) = JacC( 52, 52) - dw( 87, 52)
      JacC( 10, 10) = JacC( 10, 10) - dw( 88, 10)
      JacC( 51, 10) = JacC( 51, 10) + dw( 88, 10)
      JacC( 52, 10) = JacC( 52, 10) + dw( 88, 10)
      JacC( 10, 10) = JacC( 10, 10) - dw( 89, 10)
      JacC( 51, 10) = JacC( 51, 10) + dw( 89, 10)
      JacC( 52, 10) = JacC( 52, 10) + dw( 89, 10)
      JacC( 22, 51) = JacC( 22, 51)+ 0.8000000000000000D+00*dw( 90, 51)
      JacC( 22, 50) = JacC( 22, 50)+ 0.8000000000000000D+00*dw( 90, 50)
      JacC( 36, 51) = JacC( 36, 51)+ 0.2000000000000000D+00*dw( 90, 51)
      JacC( 36, 50) = JacC( 36, 50)+ 0.2000000000000000D+00*dw( 90, 50)
      JacC( 47, 51) = JacC( 47, 51)+ 0.2000000000000000D+00*dw( 90, 51)
      JacC( 47, 50) = JacC( 47, 50)+ 0.2000000000000000D+00*dw( 90, 50)
      JacC( 50, 51) = JacC( 50, 51) - dw( 90, 51)
      JacC( 50, 50) = JacC( 50, 50) - dw( 90, 50)
      JacC( 51, 51) = JacC( 51, 51) - dw( 90, 51)
      JacC( 51, 50) = JacC( 51, 50) - dw( 90, 50)
      JacC( 36, 51) = JacC( 36, 51)+ 0.1000000000000000D+00*dw( 91, 51)
      JacC( 36, 40) = JacC( 36, 40)+ 0.1000000000000000D+00*dw( 91, 40)
      JacC( 40, 51) = JacC( 40, 51)- 0.9999999999999998D-01*dw( 91, 51)
      JacC( 40, 40) = JacC( 40, 40)- 0.9999999999999998D-01*dw( 91, 40)
      JacC( 41, 51) = JacC( 41, 51) + dw( 91, 51)
      JacC( 41, 40) = JacC( 41, 40) + dw( 91, 40)
      JacC( 50, 51) = JacC( 50, 51)+ 0.9000000000000000D+00*dw( 91, 51)
      JacC( 50, 40) = JacC( 50, 40)+ 0.9000000000000000D+00*dw( 91, 40)
      JacC( 51, 51) = JacC( 51, 51) - dw( 91, 51)
      JacC( 51, 40) = JacC( 51, 40) - dw( 91, 40)
      JacC( 36, 51) = JacC( 36, 51)+ 0.1000000000000000D+00*dw( 92, 51)
      JacC( 36, 49) = JacC( 36, 49)+ 0.1000000000000000D+00*dw( 92, 49)
      JacC( 40, 51) = JacC( 40, 51)+ 0.9000000000000000D+00*dw( 92, 51)
      JacC( 40, 49) = JacC( 40, 49)+ 0.9000000000000000D+00*dw( 92, 49)
      JacC( 49, 51) = JacC( 49, 51) - dw( 92, 51)
      JacC( 49, 49) = JacC( 49, 49) - dw( 92, 49)
      JacC( 51, 51) = JacC( 51, 51) - dw( 92, 51)
      JacC( 51, 49) = JacC( 51, 49) - dw( 92, 49)
      JacC( 40, 51) = JacC( 40, 51)+ 0.2000000000000000D+01*dw( 93, 51)
      JacC( 40, 51) = JacC( 40, 51)+ 0.2000000000000000D+01*dw( 93, 51)
      JacC( 51, 51) = JacC( 51, 51)- 0.2000000000000000D+01*dw( 93, 51)
      JacC( 51, 51) = JacC( 51, 51)- 0.2000000000000000D+01*dw( 93, 51)
      JacC( 22, 22) = JacC( 22, 22) - dw( 94, 22)
      JacC( 22, 42) = JacC( 22, 42) - dw( 94, 42)
      JacC( 42, 22) = JacC( 42, 22) - dw( 94, 22)
      JacC( 42, 42) = JacC( 42, 42) - dw( 94, 42)
      JacC( 51, 22) = JacC( 51, 22) + dw( 94, 22)
      JacC( 51, 42) = JacC( 51, 42) + dw( 94, 42)
      JacC( 22, 22) = JacC( 22, 22) - dw( 95, 22)
      JacC( 40, 22) = JacC( 40, 22) + dw( 95, 22)
      JacC( 42, 22) = JacC( 42, 22) + dw( 95, 22)
      JacC( 36, 36) = JacC( 36, 36) - dw( 96, 36)
      JacC( 36, 42) = JacC( 36, 42) - dw( 96, 42)
      JacC( 40, 36) = JacC( 40, 36) + dw( 96, 36)
      JacC( 40, 42) = JacC( 40, 42) + dw( 96, 42)
      JacC( 42, 36) = JacC( 42, 36) - dw( 96, 36)
      JacC( 42, 42) = JacC( 42, 42) - dw( 96, 42)
      JacC( 35, 35) = JacC( 35, 35) - dw( 97, 35)
      JacC( 35, 43) = JacC( 35, 43) - dw( 97, 43)
      JacC( 42, 35) = JacC( 42, 35) + dw( 97, 35)
      JacC( 42, 43) = JacC( 42, 43) + dw( 97, 43)
      JacC( 43, 35) = JacC( 43, 35) - dw( 97, 35)
      JacC( 43, 43) = JacC( 43, 43) - dw( 97, 43)
      JacC( 46, 35) = JacC( 46, 35) + dw( 97, 35)
      JacC( 46, 43) = JacC( 46, 43) + dw( 97, 43)
      JacC( 35, 35) = JacC( 35, 35) - dw( 98, 35)
      JacC( 35, 42) = JacC( 35, 42) - dw( 98, 42)
      JacC( 42, 35) = JacC( 42, 35) - dw( 98, 35)
      JacC( 42, 42) = JacC( 42, 42) - dw( 98, 42)
      JacC( 46, 35) = JacC( 46, 35) + dw( 98, 35)
      JacC( 46, 42) = JacC( 46, 42) + dw( 98, 42)
      JacC( 35, 35) = JacC( 35, 35) - dw( 99, 35)
      JacC( 35, 44) = JacC( 35, 44) - dw( 99, 44)
      JacC( 38, 35) = JacC( 38, 35) + dw( 99, 35)
      JacC( 38, 44) = JacC( 38, 44) + dw( 99, 44)
      JacC( 44, 35) = JacC( 44, 35) - dw( 99, 35)
      JacC( 44, 44) = JacC( 44, 44) - dw( 99, 44)
      JacC( 46, 35) = JacC( 46, 35) + dw( 99, 35)
      JacC( 46, 44) = JacC( 46, 44) + dw( 99, 44)
      JacC( 35, 35) = JacC( 35, 35) - dw(100, 35)
      JacC( 37, 35) = JacC( 37, 35) + dw(100, 35)
      JacC( 40, 35) = JacC( 40, 35) + dw(100, 35)
      JacC( 50, 35) = JacC( 50, 35) + dw(100, 35)
      JacC( 45, 46) = JacC( 45, 46) + dw(101, 46)
      JacC( 45, 48) = JacC( 45, 48) + dw(101, 48)
      JacC( 46, 46) = JacC( 46, 46) - dw(101, 46)
      JacC( 46, 48) = JacC( 46, 48) - dw(101, 48)
      JacC( 48, 46) = JacC( 48, 46) - dw(101, 46)
      JacC( 48, 48) = JacC( 48, 48) - dw(101, 48)
      JacC( 49, 46) = JacC( 49, 46) + dw(101, 46)
      JacC( 49, 48) = JacC( 49, 48) + dw(101, 48)
      JacC( 50, 46) = JacC( 50, 46) + dw(101, 46)
      JacC( 50, 48) = JacC( 50, 48) + dw(101, 48)
      JacC( 52, 46) = JacC( 52, 46) + dw(101, 46)
      JacC( 52, 48) = JacC( 52, 48) + dw(101, 48)
      JacC( 14, 46) = JacC( 14, 46) + dw(102, 46)
      JacC( 14, 52) = JacC( 14, 52) + dw(102, 52)
      JacC( 46, 46) = JacC( 46, 46) - dw(102, 46)
      JacC( 46, 52) = JacC( 46, 52) - dw(102, 52)
      JacC( 52, 46) = JacC( 52, 46) - dw(102, 46)
      JacC( 52, 52) = JacC( 52, 52) - dw(102, 52)
      JacC( 14, 14) = JacC( 14, 14) - dw(103, 14)
      JacC( 46, 14) = JacC( 46, 14) + dw(103, 14)
      JacC( 52, 14) = JacC( 52, 14) + dw(103, 14)
      JacC( 14, 14) = JacC( 14, 14) - dw(104, 14)
      JacC( 46, 14) = JacC( 46, 14) + dw(104, 14)
      JacC( 52, 14) = JacC( 52, 14) + dw(104, 14)
      JacC( 14, 14) = JacC( 14, 14) - dw(105, 14)
      JacC( 14, 42) = JacC( 14, 42) - dw(105, 42)
      JacC( 42, 14) = JacC( 42, 14) - dw(105, 14)
      JacC( 42, 42) = JacC( 42, 42) - dw(105, 42)
      JacC( 45, 14) = JacC( 45, 14) + dw(105, 14)
      JacC( 45, 42) = JacC( 45, 42) + dw(105, 42)
      JacC( 52, 14) = JacC( 52, 14) + dw(105, 14)
      JacC( 52, 42) = JacC( 52, 42) + dw(105, 42)
      JacC( 22, 46) = JacC( 22, 46)+ 0.8000000000000000D+00*dw(106, 46)
      JacC( 22, 50) = JacC( 22, 50)+ 0.8000000000000000D+00*dw(106, 50)
      JacC( 36, 46) = JacC( 36, 46)+ 0.2000000000000000D+00*dw(106, 46)
      JacC( 36, 50) = JacC( 36, 50)+ 0.2000000000000000D+00*dw(106, 50)
      JacC( 46, 46) = JacC( 46, 46) - dw(106, 46)
      JacC( 46, 50) = JacC( 46, 50) - dw(106, 50)
      JacC( 47, 46) = JacC( 47, 46)+ 0.2000000000000000D+00*dw(106, 46)
      JacC( 47, 50) = JacC( 47, 50)+ 0.2000000000000000D+00*dw(106, 50)
      JacC( 50, 46) = JacC( 50, 46) - dw(106, 46)
      JacC( 50, 50) = JacC( 50, 50) - dw(106, 50)
      JacC( 36, 51) = JacC( 36, 51)+ 0.1000000000000000D+00*dw(107, 51)
      JacC( 36, 40) = JacC( 36, 40)+ 0.1000000000000000D+00*dw(107, 40)
      JacC( 40, 51) = JacC( 40, 51) - dw(107, 51)
      JacC( 40, 40) = JacC( 40, 40) - dw(107, 40)
      JacC( 41, 51) = JacC( 41, 51)+ 0.1000000000000000D+00*dw(107, 51)
      JacC( 41, 40) = JacC( 41, 40)+ 0.1000000000000000D+00*dw(107, 40)
      JacC( 45, 51) = JacC( 45, 51)+ 0.9000000000000000D+00*dw(107, 51)
      JacC( 45, 40) = JacC( 45, 40)+ 0.9000000000000000D+00*dw(107, 40)
      JacC( 49, 51) = JacC( 49, 51)+ 0.9000000000000000D+00*dw(107, 51)
      JacC( 49, 40) = JacC( 49, 40)+ 0.9000000000000000D+00*dw(107, 40)
      JacC( 50, 51) = JacC( 50, 51) + dw(107, 51)
      JacC( 50, 40) = JacC( 50, 40) + dw(107, 40)
      JacC( 51, 51) = JacC( 51, 51) - dw(107, 51)
      JacC( 51, 40) = JacC( 51, 40) - dw(107, 40)
      JacC( 36, 51) = JacC( 36, 51)+ 0.1000000000000000D+00*dw(108, 51)
      JacC( 36, 49) = JacC( 36, 49)+ 0.1000000000000000D+00*dw(108, 49)
      JacC( 45, 51) = JacC( 45, 51)+ 0.9000000000000000D+00*dw(108, 51)
      JacC( 45, 49) = JacC( 45, 49)+ 0.9000000000000000D+00*dw(108, 49)
      JacC( 49, 51) = JacC( 49, 51) - dw(108, 51)
      JacC( 49, 49) = JacC( 49, 49) - dw(108, 49)
      JacC( 51, 51) = JacC( 51, 51) - dw(108, 51)
      JacC( 51, 49) = JacC( 51, 49) - dw(108, 49)
      JacC( 45, 46) = JacC( 45, 46)+ 0.2000000000000000D+01*dw(109, 46)
      JacC( 45, 46) = JacC( 45, 46)+ 0.2000000000000000D+01*dw(109, 46)
      JacC( 46, 46) = JacC( 46, 46)- 0.2000000000000000D+01*dw(109, 46)
      JacC( 46, 46) = JacC( 46, 46)- 0.2000000000000000D+01*dw(109, 46)
      JacC( 49, 46) = JacC( 49, 46)+ 0.2000000000000000D+01*dw(109, 46)
      JacC( 49, 46) = JacC( 49, 46)+ 0.2000000000000000D+01*dw(109, 46)
      JacC( 50, 46) = JacC( 50, 46)+ 0.2000000000000000D+01*dw(109, 46)
      JacC( 50, 46) = JacC( 50, 46)+ 0.2000000000000000D+01*dw(109, 46)
      JacC( 40, 46) = JacC( 40, 46) + dw(110, 46)
      JacC( 40, 51) = JacC( 40, 51) + dw(110, 51)
      JacC( 45, 46) = JacC( 45, 46) + dw(110, 46)
      JacC( 45, 51) = JacC( 45, 51) + dw(110, 51)
      JacC( 46, 46) = JacC( 46, 46) - dw(110, 46)
      JacC( 46, 51) = JacC( 46, 51) - dw(110, 51)
      JacC( 49, 46) = JacC( 49, 46) + dw(110, 46)
      JacC( 49, 51) = JacC( 49, 51) + dw(110, 51)
      JacC( 50, 46) = JacC( 50, 46) + dw(110, 46)
      JacC( 50, 51) = JacC( 50, 51) + dw(110, 51)
      JacC( 51, 46) = JacC( 51, 46) - dw(110, 46)
      JacC( 51, 51) = JacC( 51, 51) - dw(110, 51)
      JacC( 16, 34) = JacC( 16, 34)+ 0.7600000000000000D+00*dw(111, 34)
      JacC( 16, 42) = JacC( 16, 42)+ 0.7600000000000000D+00*dw(111, 42)
      JacC( 34, 34) = JacC( 34, 34)- 0.8900000000000000D+00*dw(111, 34)
      JacC( 34, 42) = JacC( 34, 42)- 0.8900000000000000D+00*dw(111, 42)
      JacC( 35, 34) = JacC( 35, 34)+ 0.5000000000000000D-01*dw(111, 34)
      JacC( 35, 42) = JacC( 35, 42)+ 0.5000000000000000D-01*dw(111, 42)
      JacC( 39, 34) = JacC( 39, 34)+ 0.1300000000000000D+00*dw(111, 34)
      JacC( 39, 42) = JacC( 39, 42)+ 0.1300000000000000D+00*dw(111, 42)
      JacC( 42, 34) = JacC( 42, 34) - dw(111, 34)
      JacC( 42, 42) = JacC( 42, 42) - dw(111, 42)
      JacC( 45, 34) = JacC( 45, 34)+ 0.6000000000000000D-01*dw(111, 34)
      JacC( 45, 42) = JacC( 45, 42)+ 0.6000000000000000D-01*dw(111, 42)
      JacC( 49, 34) = JacC( 49, 34)+ 0.8700000000000000D+00*dw(111, 34)
      JacC( 49, 42) = JacC( 49, 42)+ 0.8700000000000000D+00*dw(111, 42)
      JacC( 50, 34) = JacC( 50, 34)+ 0.1100000000000000D+00*dw(111, 34)
      JacC( 50, 42) = JacC( 50, 42)+ 0.1100000000000000D+00*dw(111, 42)
      JacC( 16, 16) = JacC( 16, 16)- 0.9800000000000000D+00*dw(112, 16)
      JacC( 34, 16) = JacC( 34, 16)+ 0.2100000000000000D+01*dw(112, 16)
      JacC( 35, 16) = JacC( 35, 16)+ 0.5000000000000000D+00*dw(112, 16)
      JacC( 39, 16) = JacC( 39, 16)+ 0.4000000000000000D-01*dw(112, 16)
      JacC( 45, 16) = JacC( 45, 16)+ 0.6000000000000000D+00*dw(112, 16)
      JacC( 49, 16) = JacC( 49, 16)+ 0.9600000000000000D+00*dw(112, 16)
      JacC( 50, 16) = JacC( 50, 16)+ 0.9399999999999999D+00*dw(112, 16)
      JacC( 16, 16) = JacC( 16, 16) - dw(113, 16)
      JacC( 50, 16) = JacC( 50, 16) + dw(113, 16)
      JacC( 16, 16) = JacC( 16, 16) - dw(114, 16)
      JacC( 16, 52) = JacC( 16, 52) - dw(114, 52)
      JacC( 33, 16) = JacC( 33, 16) + dw(114, 16)
      JacC( 33, 52) = JacC( 33, 52) + dw(114, 52)
      JacC( 52, 16) = JacC( 52, 16) - dw(114, 16)
      JacC( 52, 52) = JacC( 52, 52) - dw(114, 52)
      JacC( 24, 43) = JacC( 24, 43) - dw(115, 43)
      JacC( 24, 24) = JacC( 24, 24) - dw(115, 24)
      JacC( 34, 43) = JacC( 34, 43)+ 0.2000000000000000D+00*dw(115, 43)
      JacC( 34, 24) = JacC( 34, 24)+ 0.2000000000000000D+00*dw(115, 24)
      JacC( 35, 43) = JacC( 35, 43)+ 0.3000000000000000D+00*dw(115, 43)
      JacC( 35, 24) = JacC( 35, 24)+ 0.3000000000000000D+00*dw(115, 24)
      JacC( 37, 43) = JacC( 37, 43)+ 0.2000000000000000D+00*dw(115, 43)
      JacC( 37, 24) = JacC( 37, 24)+ 0.2000000000000000D+00*dw(115, 24)
      JacC( 39, 43) = JacC( 39, 43)+ 0.1000000000000000D-01*dw(115, 43)
      JacC( 39, 24) = JacC( 39, 24)+ 0.1000000000000000D-01*dw(115, 24)
      JacC( 41, 43) = JacC( 41, 43)+ 0.2000000000000000D+00*dw(115, 43)
      JacC( 41, 24) = JacC( 41, 24)+ 0.2000000000000000D+00*dw(115, 24)
      JacC( 42, 43) = JacC( 42, 43)+ 0.1000000000000000D+00*dw(115, 43)
      JacC( 42, 24) = JacC( 42, 24)+ 0.1000000000000000D+00*dw(115, 24)
      JacC( 43, 43) = JacC( 43, 43) - dw(115, 43)
      JacC( 43, 24) = JacC( 43, 24) - dw(115, 24)
      JacC( 45, 43) = JacC( 45, 43)+ 0.2000000000000000D+00*dw(115, 43)
      JacC( 45, 24) = JacC( 45, 24)+ 0.2000000000000000D+00*dw(115, 24)
      JacC( 49, 43) = JacC( 49, 43)+ 0.2000000000000000D+00*dw(115, 43)
      JacC( 49, 24) = JacC( 49, 24)+ 0.2000000000000000D+00*dw(115, 24)
      JacC( 50, 43) = JacC( 50, 43)+ 0.3000000000000000D+00*dw(115, 43)
      JacC( 50, 24) = JacC( 50, 24)+ 0.3000000000000000D+00*dw(115, 24)
      JacC( 24, 42) = JacC( 24, 42) - dw(116, 42)
      JacC( 24, 24) = JacC( 24, 24) - dw(116, 24)
      JacC( 34, 42) = JacC( 34, 42)+ 0.7000000000000000D+00*dw(116, 42)
      JacC( 34, 24) = JacC( 34, 24)+ 0.7000000000000000D+00*dw(116, 24)
      JacC( 35, 42) = JacC( 35, 42)+ 0.6200000000000000D+00*dw(116, 42)
      JacC( 35, 24) = JacC( 35, 24)+ 0.6200000000000000D+00*dw(116, 24)
      JacC( 41, 42) = JacC( 41, 42)+ 0.8000000000000000D+00*dw(116, 42)
      JacC( 41, 24) = JacC( 41, 24)+ 0.8000000000000000D+00*dw(116, 24)
      JacC( 42, 42) = JacC( 42, 42) - dw(116, 42)
      JacC( 42, 24) = JacC( 42, 24) - dw(116, 24)
      JacC( 45, 42) = JacC( 45, 42)+ 0.3300000000000000D+00*dw(116, 42)
      JacC( 45, 24) = JacC( 45, 24)+ 0.3300000000000000D+00*dw(116, 24)
      JacC( 49, 42) = JacC( 49, 42)+ 0.8000000000000000D+00*dw(116, 42)
      JacC( 49, 24) = JacC( 49, 24)+ 0.8000000000000000D+00*dw(116, 24)
      JacC( 50, 42) = JacC( 50, 42)+ 0.9500000000000000D+00*dw(116, 42)
      JacC( 50, 24) = JacC( 50, 24)+ 0.9500000000000000D+00*dw(116, 24)
      JacC( 24, 47) = JacC( 24, 47) - dw(117, 47)
      JacC( 24, 24) = JacC( 24, 24) - dw(117, 24)
      JacC( 34, 47) = JacC( 34, 47) + dw(117, 47)
      JacC( 34, 24) = JacC( 34, 24) + dw(117, 24)
      JacC( 35, 47) = JacC( 35, 47)+ 0.3200000000000000D+00*dw(117, 47)
      JacC( 35, 24) = JacC( 35, 24)+ 0.3200000000000000D+00*dw(117, 24)
      JacC( 37, 47) = JacC( 37, 47)+ 0.3300000000000000D+00*dw(117, 47)
      JacC( 37, 24) = JacC( 37, 24)+ 0.3300000000000000D+00*dw(117, 24)
      JacC( 41, 47) = JacC( 41, 47)+ 0.7400000000000000D+00*dw(117, 47)
      JacC( 41, 24) = JacC( 41, 24)+ 0.7400000000000000D+00*dw(117, 24)
      JacC( 42, 47) = JacC( 42, 47)+ 0.1000000000000000D+00*dw(117, 47)
      JacC( 42, 24) = JacC( 42, 24)+ 0.1000000000000000D+00*dw(117, 24)
      JacC( 45, 47) = JacC( 45, 47)+ 0.1800000000000000D+00*dw(117, 47)
      JacC( 45, 24) = JacC( 45, 24)+ 0.1800000000000000D+00*dw(117, 24)
      JacC( 47, 47) = JacC( 47, 47) - dw(117, 47)
      JacC( 47, 24) = JacC( 47, 24) - dw(117, 24)
      JacC( 49, 47) = JacC( 49, 47)+ 0.2200000000000000D+00*dw(117, 47)
      JacC( 49, 24) = JacC( 49, 24)+ 0.2200000000000000D+00*dw(117, 24)
      JacC( 50, 47) = JacC( 50, 47)+ 0.4400000000000000D+00*dw(117, 47)
      JacC( 50, 24) = JacC( 50, 24)+ 0.4400000000000000D+00*dw(117, 24)
      JacC( 24, 44) = JacC( 24, 44) - dw(118, 44)
      JacC( 24, 24) = JacC( 24, 24) - dw(118, 24)
      JacC( 34, 44) = JacC( 34, 44) + dw(118, 44)
      JacC( 34, 24) = JacC( 34, 24) + dw(118, 24)
      JacC( 35, 44) = JacC( 35, 44)+ 0.5600000000000001D+00*dw(118, 44)
      JacC( 35, 24) = JacC( 35, 24)+ 0.5600000000000001D+00*dw(118, 24)
      JacC( 39, 44) = JacC( 39, 44)+ 0.9000000000000000D-01*dw(118, 44)
      JacC( 39, 24) = JacC( 39, 24)+ 0.9000000000000000D-01*dw(118, 24)
      JacC( 41, 44) = JacC( 41, 44) + dw(118, 44)
      JacC( 41, 24) = JacC( 41, 24) + dw(118, 24)
      JacC( 44, 44) = JacC( 44, 44) - dw(118, 44)
      JacC( 44, 24) = JacC( 44, 24) - dw(118, 24)
      JacC( 45, 44) = JacC( 45, 44)+ 0.3500000000000000D+00*dw(118, 44)
      JacC( 45, 24) = JacC( 45, 24)+ 0.3500000000000000D+00*dw(118, 24)
      JacC( 49, 44) = JacC( 49, 44)+ 0.9100000000000000D+00*dw(118, 44)
      JacC( 49, 24) = JacC( 49, 24)+ 0.9100000000000000D+00*dw(118, 24)
      JacC( 52, 44) = JacC( 52, 44) + dw(118, 44)
      JacC( 52, 24) = JacC( 52, 24) + dw(118, 24)
      JacC( 23, 43) = JacC( 23, 43) - dw(119, 43)
      JacC( 23, 23) = JacC( 23, 23) - dw(119, 23)
      JacC( 37, 43) = JacC( 37, 43) + dw(119, 43)
      JacC( 37, 23) = JacC( 37, 23) + dw(119, 23)
      JacC( 41, 43) = JacC( 41, 43) + dw(119, 43)
      JacC( 41, 23) = JacC( 41, 23) + dw(119, 23)
      JacC( 42, 43) = JacC( 42, 43)+ 0.3000000000000000D+00*dw(119, 43)
      JacC( 42, 23) = JacC( 42, 23)+ 0.3000000000000000D+00*dw(119, 23)
      JacC( 43, 43) = JacC( 43, 43) - dw(119, 43)
      JacC( 43, 23) = JacC( 43, 23) - dw(119, 23)
      JacC( 49, 43) = JacC( 49, 43)+ 0.7000000000000000D+00*dw(119, 43)
      JacC( 49, 23) = JacC( 49, 23)+ 0.7000000000000000D+00*dw(119, 23)
      JacC( 50, 43) = JacC( 50, 43)+ 0.1700000000000000D+01*dw(119, 43)
      JacC( 50, 23) = JacC( 50, 23)+ 0.1700000000000000D+01*dw(119, 23)
      JacC( 23, 42) = JacC( 23, 42) - dw(120, 42)
      JacC( 23, 23) = JacC( 23, 23) - dw(120, 23)
      JacC( 35, 42) = JacC( 35, 42)+ 0.2200000000000000D+00*dw(120, 42)
      JacC( 35, 23) = JacC( 35, 23)+ 0.2200000000000000D+00*dw(120, 23)
      JacC( 41, 42) = JacC( 41, 42)+ 0.1560000000000000D+01*dw(120, 42)
      JacC( 41, 23) = JacC( 41, 23)+ 0.1560000000000000D+01*dw(120, 23)
      JacC( 42, 42) = JacC( 42, 42) - dw(120, 42)
      JacC( 42, 23) = JacC( 42, 23) - dw(120, 23)
      JacC( 49, 42) = JacC( 49, 42) + dw(120, 42)
      JacC( 49, 23) = JacC( 49, 23) + dw(120, 23)
      JacC( 50, 42) = JacC( 50, 42) + dw(120, 42)
      JacC( 50, 23) = JacC( 50, 23) + dw(120, 23)
      JacC( 20, 47) = JacC( 20, 47)+ 0.3700000000000000D+00*dw(121, 47)
      JacC( 20, 23) = JacC( 20, 23)+ 0.3700000000000000D+00*dw(121, 23)
      JacC( 23, 47) = JacC( 23, 47) - dw(121, 47)
      JacC( 23, 23) = JacC( 23, 23) - dw(121, 23)
      JacC( 37, 47) = JacC( 37, 47)+ 0.6300000000000000D+00*dw(121, 47)
      JacC( 37, 23) = JacC( 37, 23)+ 0.6300000000000000D+00*dw(121, 23)
      JacC( 41, 47) = JacC( 41, 47) + dw(121, 47)
      JacC( 41, 23) = JacC( 41, 23) + dw(121, 23)
      JacC( 42, 47) = JacC( 42, 47)+ 0.1300000000000000D+00*dw(121, 47)
      JacC( 42, 23) = JacC( 42, 23)+ 0.1300000000000000D+00*dw(121, 23)
      JacC( 47, 47) = JacC( 47, 47) - dw(121, 47)
      JacC( 47, 23) = JacC( 47, 23) - dw(121, 23)
      JacC( 50, 47) = JacC( 50, 47)+ 0.1300000000000000D+00*dw(121, 47)
      JacC( 50, 23) = JacC( 50, 23)+ 0.1300000000000000D+00*dw(121, 23)
      JacC( 23, 44) = JacC( 23, 44) - dw(122, 44)
      JacC( 23, 23) = JacC( 23, 23) - dw(122, 23)
      JacC( 41, 44) = JacC( 41, 44)+ 0.2000000000000000D+01*dw(122, 44)
      JacC( 41, 23) = JacC( 41, 23)+ 0.2000000000000000D+01*dw(122, 23)
      JacC( 44, 44) = JacC( 44, 44) - dw(122, 44)
      JacC( 44, 23) = JacC( 44, 23) - dw(122, 23)
      JacC( 49, 44) = JacC( 49, 44) + dw(122, 44)
      JacC( 49, 23) = JacC( 49, 23) + dw(122, 23)
      JacC( 52, 44) = JacC( 52, 44) + dw(122, 44)
      JacC( 52, 23) = JacC( 52, 23) + dw(122, 23)
      JacC( 25, 25) = JacC( 25, 25) - dw(123, 25)
      JacC( 25, 43) = JacC( 25, 43) - dw(123, 43)
      JacC( 34, 25) = JacC( 34, 25)+ 0.1000000000000000D+00*dw(123, 25)
      JacC( 34, 43) = JacC( 34, 43)+ 0.1000000000000000D+00*dw(123, 43)
      JacC( 35, 25) = JacC( 35, 25)+ 0.6600000000000000D+00*dw(123, 25)
      JacC( 35, 43) = JacC( 35, 43)+ 0.6600000000000000D+00*dw(123, 43)
      JacC( 37, 25) = JacC( 37, 25)+ 0.1000000000000000D+00*dw(123, 25)
      JacC( 37, 43) = JacC( 37, 43)+ 0.1000000000000000D+00*dw(123, 43)
      JacC( 43, 25) = JacC( 43, 25) - dw(123, 25)
      JacC( 43, 43) = JacC( 43, 43) - dw(123, 43)
      JacC( 45, 25) = JacC( 45, 25)+ 0.1240000000000000D+01*dw(123, 25)
      JacC( 45, 43) = JacC( 45, 43)+ 0.1240000000000000D+01*dw(123, 43)
      JacC( 49, 25) = JacC( 49, 25)+ 0.1000000000000000D+00*dw(123, 25)
      JacC( 49, 43) = JacC( 49, 43)+ 0.1000000000000000D+00*dw(123, 43)
      JacC( 50, 25) = JacC( 50, 25)+ 0.1000000000000000D+00*dw(123, 25)
      JacC( 50, 43) = JacC( 50, 43)+ 0.1000000000000000D+00*dw(123, 43)
      JacC( 25, 25) = JacC( 25, 25) - dw(124, 25)
      JacC( 25, 42) = JacC( 25, 42) - dw(124, 42)
      JacC( 35, 25) = JacC( 35, 25)+ 0.7000000000000000D+00*dw(124, 25)
      JacC( 35, 42) = JacC( 35, 42)+ 0.7000000000000000D+00*dw(124, 42)
      JacC( 42, 25) = JacC( 42, 25) - dw(124, 25)
      JacC( 42, 42) = JacC( 42, 42) - dw(124, 42)
      JacC( 45, 25) = JacC( 45, 25)+ 0.1300000000000000D+01*dw(124, 25)
      JacC( 45, 42) = JacC( 45, 42)+ 0.1300000000000000D+01*dw(124, 42)
      JacC( 49, 25) = JacC( 49, 25) + dw(124, 25)
      JacC( 49, 42) = JacC( 49, 42) + dw(124, 42)
      JacC( 50, 25) = JacC( 50, 25) + dw(124, 25)
      JacC( 50, 42) = JacC( 50, 42) + dw(124, 42)
      JacC( 25, 25) = JacC( 25, 25) - dw(125, 25)
      JacC( 25, 47) = JacC( 25, 47) - dw(125, 47)
      JacC( 35, 25) = JacC( 35, 25)+ 0.3500000000000000D+00*dw(125, 25)
      JacC( 35, 47) = JacC( 35, 47)+ 0.3500000000000000D+00*dw(125, 47)
      JacC( 37, 25) = JacC( 37, 25)+ 0.2500000000000000D+00*dw(125, 25)
      JacC( 37, 47) = JacC( 37, 47)+ 0.2500000000000000D+00*dw(125, 47)
      JacC( 41, 25) = JacC( 41, 25)+ 0.2500000000000000D+00*dw(125, 25)
      JacC( 41, 47) = JacC( 41, 47)+ 0.2500000000000000D+00*dw(125, 47)
      JacC( 42, 25) = JacC( 42, 25)+ 0.5000000000000000D+00*dw(125, 25)
      JacC( 42, 47) = JacC( 42, 47)+ 0.5000000000000000D+00*dw(125, 47)
      JacC( 43, 25) = JacC( 43, 25)+ 0.5000000000000000D+00*dw(125, 25)
      JacC( 43, 47) = JacC( 43, 47)+ 0.5000000000000000D+00*dw(125, 47)
      JacC( 45, 25) = JacC( 45, 25)+ 0.6500000000000000D+00*dw(125, 25)
      JacC( 45, 47) = JacC( 45, 47)+ 0.6500000000000000D+00*dw(125, 47)
      JacC( 47, 25) = JacC( 47, 25) - dw(125, 25)
      JacC( 47, 47) = JacC( 47, 47) - dw(125, 47)
      JacC( 50, 25) = JacC( 50, 25)+ 0.5000000000000000D+00*dw(125, 25)
      JacC( 50, 47) = JacC( 50, 47)+ 0.5000000000000000D+00*dw(125, 47)
      JacC( 25, 25) = JacC( 25, 25) - dw(126, 25)
      JacC( 25, 44) = JacC( 25, 44) - dw(126, 44)
      JacC( 35, 25) = JacC( 35, 25)+ 0.6400000000000000D+00*dw(126, 25)
      JacC( 35, 44) = JacC( 35, 44)+ 0.6400000000000000D+00*dw(126, 44)
      JacC( 44, 25) = JacC( 44, 25) - dw(126, 25)
      JacC( 44, 44) = JacC( 44, 44) - dw(126, 44)
      JacC( 45, 25) = JacC( 45, 25)+ 0.1180000000000000D+01*dw(126, 25)
      JacC( 45, 44) = JacC( 45, 44)+ 0.1180000000000000D+01*dw(126, 44)
      JacC( 50, 25) = JacC( 50, 25) + dw(126, 25)
      JacC( 50, 44) = JacC( 50, 44) + dw(126, 44)
      JacC( 52, 25) = JacC( 52, 25) + dw(126, 25)
      JacC( 52, 44) = JacC( 52, 44) + dw(126, 44)
      JacC(  5,  5) = JacC(  5,  5) - dw(127,  5)
      JacC(  5, 42) = JacC(  5, 42) - dw(127, 42)
      JacC( 12,  5) = JacC( 12,  5)+ 0.5600000000000001D+00*dw(127,  5)
      JacC( 12, 42) = JacC( 12, 42)+ 0.5600000000000001D+00*dw(127, 42)
      JacC( 27,  5) = JacC( 27,  5)+ 0.3600000000000000D+00*dw(127,  5)
      JacC( 27, 42) = JacC( 27, 42)+ 0.3600000000000000D+00*dw(127, 42)
      JacC( 42,  5) = JacC( 42,  5) - dw(127,  5)
      JacC( 42, 42) = JacC( 42, 42) - dw(127, 42)
      JacC( 49,  5) = JacC( 49,  5)+ 0.8000000000000000D-01*dw(127,  5)
      JacC( 49, 42) = JacC( 49, 42)+ 0.8000000000000000D-01*dw(127, 42)
      JacC( 50,  5) = JacC( 50,  5)+ 0.4400000000000000D+00*dw(127,  5)
      JacC( 50, 42) = JacC( 50, 42)+ 0.4400000000000000D+00*dw(127, 42)
      JacC( 12, 12) = JacC( 12, 12) - dw(128, 12)
      JacC( 12, 48) = JacC( 12, 48) - dw(128, 48)
      JacC( 28, 12) = JacC( 28, 12)+ 0.9000000000000000D+00*dw(128, 12)
      JacC( 28, 48) = JacC( 28, 48)+ 0.9000000000000000D+00*dw(128, 48)
      JacC( 33, 12) = JacC( 33, 12)+ 0.1000000000000000D+00*dw(128, 12)
      JacC( 33, 48) = JacC( 33, 48)+ 0.1000000000000000D+00*dw(128, 48)
      JacC( 48, 12) = JacC( 48, 12) - dw(128, 12)
      JacC( 48, 48) = JacC( 48, 48) - dw(128, 48)
      JacC( 50, 12) = JacC( 50, 12)+ 0.9000000000000000D+00*dw(128, 12)
      JacC( 50, 48) = JacC( 50, 48)+ 0.9000000000000000D+00*dw(128, 48)
      JacC( 52, 12) = JacC( 52, 12)+ 0.9000000000000000D+00*dw(128, 12)
      JacC( 52, 48) = JacC( 52, 48)+ 0.9000000000000000D+00*dw(128, 48)
      JacC( 12, 12) = JacC( 12, 12) - dw(129, 12)
      JacC( 27, 12) = JacC( 27, 12) + dw(129, 12)
      JacC( 50, 12) = JacC( 50, 12) + dw(129, 12)
      JacC( 27, 42) = JacC( 27, 42) - dw(130, 42)
      JacC( 27, 27) = JacC( 27, 27) - dw(130, 27)
      JacC( 28, 42) = JacC( 28, 42)+ 0.3000000000000000D+00*dw(130, 42)
      JacC( 28, 27) = JacC( 28, 27)+ 0.3000000000000000D+00*dw(130, 27)
      JacC( 30, 42) = JacC( 30, 42)+ 0.4000000000000000D+00*dw(130, 42)
      JacC( 30, 27) = JacC( 30, 27)+ 0.4000000000000000D+00*dw(130, 27)
      JacC( 42, 42) = JacC( 42, 42) - dw(130, 42)
      JacC( 42, 27) = JacC( 42, 27) - dw(130, 27)
      JacC( 49, 42) = JacC( 49, 42)+ 0.6000000000000000D+00*dw(130, 42)
      JacC( 49, 27) = JacC( 49, 27)+ 0.6000000000000000D+00*dw(130, 27)
      JacC( 50, 42) = JacC( 50, 42)+ 0.6000000000000000D+00*dw(130, 42)
      JacC( 50, 27) = JacC( 50, 27)+ 0.6000000000000000D+00*dw(130, 27)
      JacC( 27, 27) = JacC( 27, 27) - dw(131, 27)
      JacC( 27, 44) = JacC( 27, 44) - dw(131, 44)
      JacC( 30, 27) = JacC( 30, 27) + dw(131, 27)
      JacC( 30, 44) = JacC( 30, 44) + dw(131, 44)
      JacC( 38, 27) = JacC( 38, 27) + dw(131, 27)
      JacC( 38, 44) = JacC( 38, 44) + dw(131, 44)
      JacC( 44, 27) = JacC( 44, 27) - dw(131, 27)
      JacC( 44, 44) = JacC( 44, 44) - dw(131, 44)
      JacC( 30, 30) = JacC( 30, 30) - dw(132, 30)
      JacC( 30, 52) = JacC( 30, 52) - dw(132, 52)
      JacC( 33, 30) = JacC( 33, 30) + dw(132, 30)
      JacC( 33, 52) = JacC( 33, 52) + dw(132, 52)
      JacC( 52, 30) = JacC( 52, 30) - dw(132, 30)
      JacC( 52, 52) = JacC( 52, 52) - dw(132, 52)
      JacC( 27, 30) = JacC( 27, 30) + dw(133, 30)
      JacC( 27, 50) = JacC( 27, 50) + dw(133, 50)
      JacC( 30, 30) = JacC( 30, 30) - dw(133, 30)
      JacC( 30, 50) = JacC( 30, 50) - dw(133, 50)
      JacC( 50, 30) = JacC( 50, 30) - dw(133, 30)
      JacC( 50, 50) = JacC( 50, 50) - dw(133, 50)
      JacC( 28, 28) = JacC( 28, 28) - dw(134, 28)
      JacC( 37, 28) = JacC( 37, 28) + dw(134, 28)
      JacC( 50, 28) = JacC( 50, 28) + dw(134, 28)
      JacC( 51, 28) = JacC( 51, 28) + dw(134, 28)
      JacC( 28, 28) = JacC( 28, 28) - dw(135, 28)
      JacC( 28, 42) = JacC( 28, 42) - dw(135, 42)
      JacC( 37, 28) = JacC( 37, 28)+ 0.2000000000000000D+01*dw(135, 28)
      JacC( 37, 42) = JacC( 37, 42)+ 0.2000000000000000D+01*dw(135, 42)
      JacC( 41, 28) = JacC( 41, 28) + dw(135, 28)
      JacC( 41, 42) = JacC( 41, 42) + dw(135, 42)
      JacC( 42, 28) = JacC( 42, 28) - dw(135, 28)
      JacC( 42, 42) = JacC( 42, 42) - dw(135, 42)
      JacC( 49, 28) = JacC( 49, 28) + dw(135, 28)
      JacC( 49, 42) = JacC( 49, 42) + dw(135, 42)
      JacC( 50, 28) = JacC( 50, 28)+ 0.2000000000000000D+01*dw(135, 28)
      JacC( 50, 42) = JacC( 50, 42)+ 0.2000000000000000D+01*dw(135, 42)
      JacC( 51, 28) = JacC( 51, 28) + dw(135, 28)
      JacC( 51, 42) = JacC( 51, 42) + dw(135, 42)
      JacC( 28, 28) = JacC( 28, 28) - dw(136, 28)
      JacC( 28, 47) = JacC( 28, 47) - dw(136, 47)
      JacC( 29, 28) = JacC( 29, 28)+ 0.2000000000000000D+00*dw(136, 28)
      JacC( 29, 47) = JacC( 29, 47)+ 0.2000000000000000D+00*dw(136, 47)
      JacC( 35, 28) = JacC( 35, 28)+ 0.3000000000000000D-01*dw(136, 28)
      JacC( 35, 47) = JacC( 35, 47)+ 0.3000000000000000D-01*dw(136, 47)
      JacC( 37, 28) = JacC( 37, 28)+ 0.6899999999999999D+00*dw(136, 28)
      JacC( 37, 47) = JacC( 37, 47)+ 0.6899999999999999D+00*dw(136, 47)
      JacC( 41, 28) = JacC( 41, 28)+ 0.7000000000000000D+00*dw(136, 28)
      JacC( 41, 47) = JacC( 41, 47)+ 0.7000000000000000D+00*dw(136, 47)
      JacC( 42, 28) = JacC( 42, 28)+ 0.8000000000000000D-01*dw(136, 28)
      JacC( 42, 47) = JacC( 42, 47)+ 0.8000000000000000D-01*dw(136, 47)
      JacC( 47, 28) = JacC( 47, 28) - dw(136, 28)
      JacC( 47, 47) = JacC( 47, 47) - dw(136, 47)
      JacC( 49, 28) = JacC( 49, 28)+ 0.3000000000000000D-01*dw(136, 28)
      JacC( 49, 47) = JacC( 49, 47)+ 0.3000000000000000D-01*dw(136, 47)
      JacC( 50, 28) = JacC( 50, 28)+ 0.7600000000000000D+00*dw(136, 28)
      JacC( 50, 47) = JacC( 50, 47)+ 0.7600000000000000D+00*dw(136, 47)
      JacC( 51, 28) = JacC( 51, 28)+ 0.6200000000000000D+00*dw(136, 28)
      JacC( 51, 47) = JacC( 51, 47)+ 0.6200000000000000D+00*dw(136, 47)
      JacC(  6, 42) = JacC(  6, 42) - dw(137, 42)
      JacC(  6,  6) = JacC(  6,  6) - dw(137,  6)
      JacC( 12, 42) = JacC( 12, 42)+ 0.3000000000000000D+00*dw(137, 42)
      JacC( 12,  6) = JacC( 12,  6)+ 0.3000000000000000D+00*dw(137,  6)
      JacC( 27, 42) = JacC( 27, 42)+ 0.2000000000000000D-01*dw(137, 42)
      JacC( 27,  6) = JacC( 27,  6)+ 0.2000000000000000D-01*dw(137,  6)
      JacC( 29, 42) = JacC( 29, 42)+ 0.8000000000000000D+00*dw(137, 42)
      JacC( 29,  6) = JacC( 29,  6)+ 0.8000000000000000D+00*dw(137,  6)
      JacC( 34, 42) = JacC( 34, 42)+ 0.1100000000000000D+01*dw(137, 42)
      JacC( 34,  6) = JacC( 34,  6)+ 0.1100000000000000D+01*dw(137,  6)
      JacC( 42, 42) = JacC( 42, 42) - dw(137, 42)
      JacC( 42,  6) = JacC( 42,  6) - dw(137,  6)
      JacC( 49, 42) = JacC( 49, 42)+ 0.5000000000000000D+00*dw(137, 42)
      JacC( 49,  6) = JacC( 49,  6)+ 0.5000000000000000D+00*dw(137,  6)
      JacC( 50, 42) = JacC( 50, 42)+ 0.7000000000000000D+00*dw(137, 42)
      JacC( 50,  6) = JacC( 50,  6)+ 0.7000000000000000D+00*dw(137,  6)
      JacC( 29, 42) = JacC( 29, 42) - dw(138, 42)
      JacC( 29, 29) = JacC( 29, 29) - dw(138, 29)
      JacC( 42, 42) = JacC( 42, 42) - dw(138, 42)
      JacC( 42, 29) = JacC( 42, 29) - dw(138, 29)
      JacC( 49, 42) = JacC( 49, 42) + dw(138, 42)
      JacC( 49, 29) = JacC( 49, 29) + dw(138, 29)
      JacC( 51, 42) = JacC( 51, 42) + dw(138, 42)
      JacC( 51, 29) = JacC( 51, 29) + dw(138, 29)
      JacC( 29, 29) = JacC( 29, 29) - dw(139, 29)
      JacC( 37, 29) = JacC( 37, 29) + dw(139, 29)
      JacC( 50, 29) = JacC( 50, 29) + dw(139, 29)
      JacC( 51, 29) = JacC( 51, 29) + dw(139, 29)
      JacC( 31, 43) = JacC( 31, 43) - dw(140, 43)
      JacC( 31, 31) = JacC( 31, 31) - dw(140, 31)
      JacC( 32, 43) = JacC( 32, 43)+ 0.7500000000000000D+00*dw(140, 43)
      JacC( 32, 31) = JacC( 32, 31)+ 0.7500000000000000D+00*dw(140, 31)
      JacC( 34, 43) = JacC( 34, 43)+ 0.2500000000000000D+00*dw(140, 43)
      JacC( 34, 31) = JacC( 34, 31)+ 0.2500000000000000D+00*dw(140, 31)
      JacC( 41, 43) = JacC( 41, 43)+ 0.5000000000000000D+00*dw(140, 43)
      JacC( 41, 31) = JacC( 41, 31)+ 0.5000000000000000D+00*dw(140, 31)
      JacC( 43, 43) = JacC( 43, 43) - dw(140, 43)
      JacC( 43, 31) = JacC( 43, 31) - dw(140, 31)
      JacC( 46, 43) = JacC( 46, 43)+ 0.2500000000000000D+00*dw(140, 43)
      JacC( 46, 31) = JacC( 46, 31)+ 0.2500000000000000D+00*dw(140, 31)
      JacC( 49, 43) = JacC( 49, 43)+ 0.2500000000000000D+00*dw(140, 43)
      JacC( 49, 31) = JacC( 49, 31)+ 0.2500000000000000D+00*dw(140, 31)
      JacC( 50, 43) = JacC( 50, 43)+ 0.2500000000000000D+00*dw(140, 43)
      JacC( 50, 31) = JacC( 50, 31)+ 0.2500000000000000D+00*dw(140, 31)
      JacC( 31, 42) = JacC( 31, 42) - dw(141, 42)
      JacC( 31, 31) = JacC( 31, 31) - dw(141, 31)
      JacC( 32, 42) = JacC( 32, 42)+ 0.9120000000000000D+00*dw(141, 42)
      JacC( 32, 31) = JacC( 32, 31)+ 0.9120000000000000D+00*dw(141, 31)
      JacC( 39, 42) = JacC( 39, 42)+ 0.8799999999999999D-01*dw(141, 42)
      JacC( 39, 31) = JacC( 39, 31)+ 0.8799999999999999D-01*dw(141, 31)
      JacC( 41, 42) = JacC( 41, 42)+ 0.6290000000000000D+00*dw(141, 42)
      JacC( 41, 31) = JacC( 41, 31)+ 0.6290000000000000D+00*dw(141, 31)
      JacC( 42, 42) = JacC( 42, 42) - dw(141, 42)
      JacC( 42, 31) = JacC( 42, 31) - dw(141, 31)
      JacC( 49, 42) = JacC( 49, 42)+ 0.9910000000000000D+00*dw(141, 42)
      JacC( 49, 31) = JacC( 49, 31)+ 0.9910000000000000D+00*dw(141, 31)
      JacC( 50, 42) = JacC( 50, 42)+ 0.9120000000000000D+00*dw(141, 42)
      JacC( 50, 31) = JacC( 50, 31)+ 0.9120000000000000D+00*dw(141, 31)
      JacC( 31, 47) = JacC( 31, 47) - dw(142, 47)
      JacC( 31, 31) = JacC( 31, 31) - dw(142, 31)
      JacC( 32, 47) = JacC( 32, 47)+ 0.6500000000000000D+00*dw(142, 47)
      JacC( 32, 31) = JacC( 32, 31)+ 0.6500000000000000D+00*dw(142, 31)
      JacC( 34, 47) = JacC( 34, 47)+ 0.3500000000000000D+00*dw(142, 47)
      JacC( 34, 31) = JacC( 34, 31)+ 0.3500000000000000D+00*dw(142, 31)
      JacC( 35, 47) = JacC( 35, 47)+ 0.1500000000000000D+00*dw(142, 47)
      JacC( 35, 31) = JacC( 35, 31)+ 0.1500000000000000D+00*dw(142, 31)
      JacC( 37, 47) = JacC( 37, 47)+ 0.6600000000000000D-01*dw(142, 47)
      JacC( 37, 31) = JacC( 37, 31)+ 0.6600000000000000D-01*dw(142, 31)
      JacC( 41, 47) = JacC( 41, 47)+ 0.6000000000000000D+00*dw(142, 47)
      JacC( 41, 31) = JacC( 41, 31)+ 0.6000000000000000D+00*dw(142, 31)
      JacC( 42, 47) = JacC( 42, 47)+ 0.2660000000000000D+00*dw(142, 47)
      JacC( 42, 31) = JacC( 42, 31)+ 0.2660000000000000D+00*dw(142, 31)
      JacC( 46, 47) = JacC( 46, 47)+ 0.2000000000000000D+00*dw(142, 47)
      JacC( 46, 31) = JacC( 46, 31)+ 0.2000000000000000D+00*dw(142, 31)
      JacC( 47, 47) = JacC( 47, 47) - dw(142, 47)
      JacC( 47, 31) = JacC( 47, 31) - dw(142, 31)
      JacC( 49, 47) = JacC( 49, 47)+ 0.2000000000000000D+00*dw(142, 47)
      JacC( 49, 31) = JacC( 49, 31)+ 0.2000000000000000D+00*dw(142, 31)
      JacC( 50, 47) = JacC( 50, 47)+ 0.6600000000000000D-01*dw(142, 47)
      JacC( 50, 31) = JacC( 50, 31)+ 0.6600000000000000D-01*dw(142, 31)
      JacC( 31, 44) = JacC( 31, 44) - dw(143, 44)
      JacC( 31, 31) = JacC( 31, 31) - dw(143, 31)
      JacC( 32, 44) = JacC( 32, 44)+ 0.2000000000000000D+00*dw(143, 44)
      JacC( 32, 31) = JacC( 32, 31)+ 0.2000000000000000D+00*dw(143, 31)
      JacC( 33, 44) = JacC( 33, 44)+ 0.8000000000000000D+00*dw(143, 44)
      JacC( 33, 31) = JacC( 33, 31)+ 0.8000000000000000D+00*dw(143, 31)
      JacC( 34, 44) = JacC( 34, 44)+ 0.2400000000000000D+01*dw(143, 44)
      JacC( 34, 31) = JacC( 34, 31)+ 0.2400000000000000D+01*dw(143, 31)
      JacC( 35, 44) = JacC( 35, 44)+ 0.8000000000000000D+00*dw(143, 44)
      JacC( 35, 31) = JacC( 35, 31)+ 0.8000000000000000D+00*dw(143, 31)
      JacC( 44, 44) = JacC( 44, 44) - dw(143, 44)
      JacC( 44, 31) = JacC( 44, 31) - dw(143, 31)
      JacC( 49, 44) = JacC( 49, 44) + dw(143, 44)
      JacC( 49, 31) = JacC( 49, 31) + dw(143, 31)
      JacC( 50, 44) = JacC( 50, 44)+ 0.8000000000000000D+00*dw(143, 44)
      JacC( 50, 31) = JacC( 50, 31)+ 0.8000000000000000D+00*dw(143, 31)
      JacC( 52, 44) = JacC( 52, 44)+ 0.2000000000000000D+00*dw(143, 44)
      JacC( 52, 31) = JacC( 52, 31)+ 0.2000000000000000D+00*dw(143, 31)
      JacC( 29, 42) = JacC( 29, 42)+ 0.1680000000000000D+00*dw(144, 42)
      JacC( 29, 32) = JacC( 29, 32)+ 0.1680000000000000D+00*dw(144, 32)
      JacC( 32, 42) = JacC( 32, 42) - dw(144, 42)
      JacC( 32, 32) = JacC( 32, 32) - dw(144, 32)
      JacC( 34, 42) = JacC( 34, 42)+ 0.1565000000000000D+01*dw(144, 42)
      JacC( 34, 32) = JacC( 34, 32)+ 0.1565000000000000D+01*dw(144, 32)
      JacC( 35, 42) = JacC( 35, 42)+ 0.1200000000000000D+00*dw(144, 42)
      JacC( 35, 32) = JacC( 35, 32)+ 0.1200000000000000D+00*dw(144, 32)
      JacC( 37, 42) = JacC( 37, 42)+ 0.3340000000000000D+00*dw(144, 42)
      JacC( 37, 32) = JacC( 37, 32)+ 0.3340000000000000D+00*dw(144, 32)
      JacC( 41, 42) = JacC( 41, 42)+ 0.1670000000000000D+00*dw(144, 42)
      JacC( 41, 32) = JacC( 41, 32)+ 0.1670000000000000D+00*dw(144, 32)
      JacC( 42, 42) = JacC( 42, 42) - dw(144, 42)
      JacC( 42, 32) = JacC( 42, 32) - dw(144, 32)
      JacC( 45, 42) = JacC( 45, 42)+ 0.2520000000000000D+00*dw(144, 42)
      JacC( 45, 32) = JacC( 45, 32)+ 0.2520000000000000D+00*dw(144, 32)
      JacC( 46, 42) = JacC( 46, 42)+ 0.2500000000000000D+00*dw(144, 42)
      JacC( 46, 32) = JacC( 46, 32)+ 0.2500000000000000D+00*dw(144, 32)
      JacC( 49, 42) = JacC( 49, 42)+ 0.7130000000000000D+00*dw(144, 42)
      JacC( 49, 32) = JacC( 49, 32)+ 0.7130000000000000D+00*dw(144, 32)
      JacC( 50, 42) = JacC( 50, 42)+ 0.5030000000000000D+00*dw(144, 42)
      JacC( 50, 32) = JacC( 50, 32)+ 0.5030000000000000D+00*dw(144, 32)
      JacC( 51, 42) = JacC( 51, 42)+ 0.2100000000000000D+00*dw(144, 42)
      JacC( 51, 32) = JacC( 51, 32)+ 0.2100000000000000D+00*dw(144, 32)
      JacC( 29, 47) = JacC( 29, 47)+ 0.8500000000000000D+00*dw(145, 47)
      JacC( 29, 32) = JacC( 29, 32)+ 0.8500000000000000D+00*dw(145, 32)
      JacC( 32, 47) = JacC( 32, 47) - dw(145, 47)
      JacC( 32, 32) = JacC( 32, 32) - dw(145, 32)
      JacC( 34, 47) = JacC( 34, 47)+ 0.3600000000000000D+00*dw(145, 47)
      JacC( 34, 32) = JacC( 34, 32)+ 0.3600000000000000D+00*dw(145, 32)
      JacC( 37, 47) = JacC( 37, 47)+ 0.2250000000000000D+00*dw(145, 47)
      JacC( 37, 32) = JacC( 37, 32)+ 0.2250000000000000D+00*dw(145, 32)
      JacC( 41, 47) = JacC( 41, 47)+ 0.1500000000000000D+00*dw(145, 47)
      JacC( 41, 32) = JacC( 41, 32)+ 0.1500000000000000D+00*dw(145, 32)
      JacC( 42, 47) = JacC( 42, 47)+ 0.2680000000000000D+00*dw(145, 47)
      JacC( 42, 32) = JacC( 42, 32)+ 0.2680000000000000D+00*dw(145, 32)
      JacC( 45, 47) = JacC( 45, 47)+ 0.2000000000000000D-01*dw(145, 47)
      JacC( 45, 32) = JacC( 45, 32)+ 0.2000000000000000D-01*dw(145, 32)
      JacC( 47, 47) = JacC( 47, 47) - dw(145, 47)
      JacC( 47, 32) = JacC( 47, 32) - dw(145, 32)
      JacC( 49, 47) = JacC( 49, 47)+ 0.6400000000000000D-01*dw(145, 47)
      JacC( 49, 32) = JacC( 49, 32)+ 0.6400000000000000D-01*dw(145, 32)
      JacC( 50, 47) = JacC( 50, 47)+ 0.1540000000000000D+00*dw(145, 47)
      JacC( 50, 32) = JacC( 50, 32)+ 0.1540000000000000D+00*dw(145, 32)
      JacC( 51, 47) = JacC( 51, 47)+ 0.1140000000000000D+00*dw(145, 47)
      JacC( 51, 32) = JacC( 51, 32)+ 0.1140000000000000D+00*dw(145, 32)
      JacC( 32, 44) = JacC( 32, 44) - dw(146, 44)
      JacC( 32, 32) = JacC( 32, 32) - dw(146, 32)
      JacC( 33, 44) = JacC( 33, 44)+ 0.8500000000000000D+00*dw(146, 44)
      JacC( 33, 32) = JacC( 33, 32)+ 0.8500000000000000D+00*dw(146, 32)
      JacC( 34, 44) = JacC( 34, 44)+ 0.1282000000000000D+01*dw(146, 44)
      JacC( 34, 32) = JacC( 34, 32)+ 0.1282000000000000D+01*dw(146, 32)
      JacC( 35, 44) = JacC( 35, 44)+ 0.3570000000000000D+00*dw(146, 44)
      JacC( 35, 32) = JacC( 35, 32)+ 0.3570000000000000D+00*dw(146, 32)
      JacC( 37, 44) = JacC( 37, 44)+ 0.6430000000000000D+00*dw(146, 44)
      JacC( 37, 32) = JacC( 37, 32)+ 0.6430000000000000D+00*dw(146, 32)
      JacC( 38, 44) = JacC( 38, 44)+ 0.1500000000000000D+00*dw(146, 44)
      JacC( 38, 32) = JacC( 38, 32)+ 0.1500000000000000D+00*dw(146, 32)
      JacC( 41, 44) = JacC( 41, 44)+ 0.2820000000000000D+00*dw(146, 44)
      JacC( 41, 32) = JacC( 41, 32)+ 0.2820000000000000D+00*dw(146, 32)
      JacC( 44, 44) = JacC( 44, 44) - dw(146, 44)
      JacC( 44, 32) = JacC( 44, 32) - dw(146, 32)
      JacC( 46, 44) = JacC( 46, 44)+ 0.7500000000000000D-01*dw(146, 44)
      JacC( 46, 32) = JacC( 46, 32)+ 0.7500000000000000D-01*dw(146, 32)
      JacC( 49, 44) = JacC( 49, 44)+ 0.7500000000000000D-01*dw(146, 44)
      JacC( 49, 32) = JacC( 49, 32)+ 0.7500000000000000D-01*dw(146, 32)
      JacC( 50, 44) = JacC( 50, 44)+ 0.9250000000000000D+00*dw(146, 44)
      JacC( 50, 32) = JacC( 50, 32)+ 0.9250000000000000D+00*dw(146, 32)
      JacC( 32, 32) = JacC( 32, 32) - dw(147, 32)
      JacC( 34, 32) = JacC( 34, 32)+ 0.8320000000000000D+00*dw(147, 32)
      JacC( 37, 32) = JacC( 37, 32)+ 0.3330000000000000D+00*dw(147, 32)
      JacC( 41, 32) = JacC( 41, 32)+ 0.9000000000000000D+00*dw(147, 32)
      JacC( 45, 32) = JacC( 45, 32)+ 0.6700000000000000D-01*dw(147, 32)
      JacC( 49, 32) = JacC( 49, 32)+ 0.7000000000000000D+00*dw(147, 32)
      JacC( 50, 32) = JacC( 50, 32)+ 0.1033000000000000D+01*dw(147, 32)
      JacC( 51, 32) = JacC( 51, 32)+ 0.9670000000000000D+00*dw(147, 32)
      JacC( 26, 26) = JacC( 26, 26) - dw(148, 26)
      JacC( 26, 43) = JacC( 26, 43) - dw(148, 43)
      JacC( 34, 26) = JacC( 34, 26)+ 0.5120000000000000D+01*dw(148, 26)
      JacC( 34, 43) = JacC( 34, 43)+ 0.5120000000000000D+01*dw(148, 43)
      JacC( 35, 26) = JacC( 35, 26)+ 0.1500000000000000D+00*dw(148, 26)
      JacC( 35, 43) = JacC( 35, 43)+ 0.1500000000000000D+00*dw(148, 43)
      JacC( 43, 26) = JacC( 43, 26) - dw(148, 26)
      JacC( 43, 43) = JacC( 43, 43) - dw(148, 43)
      JacC( 26, 26) = JacC( 26, 26) - dw(149, 26)
      JacC( 26, 42) = JacC( 26, 42) - dw(149, 42)
      JacC( 34, 26) = JacC( 34, 26)+ 0.1660000000000000D+01*dw(149, 26)
      JacC( 34, 42) = JacC( 34, 42)+ 0.1660000000000000D+01*dw(149, 42)
      JacC( 35, 26) = JacC( 35, 26)+ 0.4700000000000000D+00*dw(149, 26)
      JacC( 35, 42) = JacC( 35, 42)+ 0.4700000000000000D+00*dw(149, 42)
      JacC( 39, 26) = JacC( 39, 26)+ 0.2500000000000000D+00*dw(149, 26)
      JacC( 39, 42) = JacC( 39, 42)+ 0.2500000000000000D+00*dw(149, 42)
      JacC( 41, 26) = JacC( 41, 26)+ 0.2800000000000000D+00*dw(149, 26)
      JacC( 41, 42) = JacC( 41, 42)+ 0.2800000000000000D+00*dw(149, 42)
      JacC( 42, 26) = JacC( 42, 26) - dw(149, 26)
      JacC( 42, 42) = JacC( 42, 42) - dw(149, 42)
      JacC( 49, 26) = JacC( 49, 26)+ 0.1250000000000000D+01*dw(149, 26)
      JacC( 49, 42) = JacC( 49, 42)+ 0.1250000000000000D+01*dw(149, 42)
      JacC( 50, 26) = JacC( 50, 26)+ 0.7500000000000000D+00*dw(149, 26)
      JacC( 50, 42) = JacC( 50, 42)+ 0.7500000000000000D+00*dw(149, 42)
      JacC( 26, 26) = JacC( 26, 26) - dw(150, 26)
      JacC( 26, 47) = JacC( 26, 47) - dw(150, 47)
      JacC( 34, 26) = JacC( 34, 26)+ 0.7000000000000000D+01*dw(150, 26)
      JacC( 34, 47) = JacC( 34, 47)+ 0.7000000000000000D+01*dw(150, 47)
      JacC( 35, 26) = JacC( 35, 26)+ 0.2100000000000000D+00*dw(150, 26)
      JacC( 35, 47) = JacC( 35, 47)+ 0.2100000000000000D+00*dw(150, 47)
      JacC( 37, 26) = JacC( 37, 26)+ 0.1000000000000000D-02*dw(150, 26)
      JacC( 37, 47) = JacC( 37, 47)+ 0.1000000000000000D-02*dw(150, 47)
      JacC( 39, 26) = JacC( 39, 26)+ 0.1800000000000000D+00*dw(150, 26)
      JacC( 39, 47) = JacC( 39, 47)+ 0.1800000000000000D+00*dw(150, 47)
      JacC( 41, 26) = JacC( 41, 26)+ 0.2400000000000000D+00*dw(150, 26)
      JacC( 41, 47) = JacC( 41, 47)+ 0.2400000000000000D+00*dw(150, 47)
      JacC( 42, 26) = JacC( 42, 26)+ 0.5700000000000000D+00*dw(150, 26)
      JacC( 42, 47) = JacC( 42, 47)+ 0.5700000000000000D+00*dw(150, 47)
      JacC( 46, 26) = JacC( 46, 26)+ 0.3900000000000000D+00*dw(150, 26)
      JacC( 46, 47) = JacC( 46, 47)+ 0.3900000000000000D+00*dw(150, 47)
      JacC( 47, 26) = JacC( 47, 26) - dw(150, 26)
      JacC( 47, 47) = JacC( 47, 47) - dw(150, 47)
      JacC( 49, 26) = JacC( 49, 26)+ 0.7600000000000000D+00*dw(150, 26)
      JacC( 49, 47) = JacC( 49, 47)+ 0.7600000000000000D+00*dw(150, 47)
      JacC( 50, 26) = JacC( 50, 26)+ 0.7000000000000001D-01*dw(150, 26)
      JacC( 50, 47) = JacC( 50, 47)+ 0.7000000000000001D-01*dw(150, 47)
      JacC( 26, 26) = JacC( 26, 26) - dw(151, 26)
      JacC( 26, 44) = JacC( 26, 44) - dw(151, 44)
      JacC( 33, 26) = JacC( 33, 26)+ 0.5300000000000000D+00*dw(151, 26)
      JacC( 33, 44) = JacC( 33, 44)+ 0.5300000000000000D+00*dw(151, 44)
      JacC( 35, 26) = JacC( 35, 26)+ 0.4700000000000000D+00*dw(151, 26)
      JacC( 35, 44) = JacC( 35, 44)+ 0.4700000000000000D+00*dw(151, 44)
      JacC( 39, 26) = JacC( 39, 26)+ 0.2500000000000000D+00*dw(151, 26)
      JacC( 39, 44) = JacC( 39, 44)+ 0.2500000000000000D+00*dw(151, 44)
      JacC( 44, 26) = JacC( 44, 26) - dw(151, 26)
      JacC( 44, 44) = JacC( 44, 44) - dw(151, 44)
      JacC( 49, 26) = JacC( 49, 26)+ 0.1030000000000000D+01*dw(151, 26)
      JacC( 49, 44) = JacC( 49, 44)+ 0.1030000000000000D+01*dw(151, 44)
      JacC( 50, 26) = JacC( 50, 26)+ 0.2800000000000000D+00*dw(151, 26)
      JacC( 50, 44) = JacC( 50, 44)+ 0.2800000000000000D+00*dw(151, 44)
      JacC( 52, 26) = JacC( 52, 26)+ 0.4700000000000000D+00*dw(151, 26)
      JacC( 52, 44) = JacC( 52, 44)+ 0.4700000000000000D+00*dw(151, 44)
      JacC(  7,  7) = JacC(  7,  7) - dw(152,  7)
      JacC(  7, 42) = JacC(  7, 42) - dw(152, 42)
      JacC(  8,  7) = JacC(  8,  7) + dw(152,  7)
      JacC(  8, 42) = JacC(  8, 42) + dw(152, 42)
      JacC( 42,  7) = JacC( 42,  7) - dw(152,  7)
      JacC( 42, 42) = JacC( 42, 42) - dw(152, 42)
      JacC( 50,  7) = JacC( 50,  7) + dw(152,  7)
      JacC( 50, 42) = JacC( 50, 42) + dw(152, 42)
      JacC(  2, 42) = JacC(  2, 42) - dw(153, 42)
      JacC(  2,  2) = JacC(  2,  2) - dw(153,  2)
      JacC( 35, 42) = JacC( 35, 42)+ 0.5000000000000000D-01*dw(153, 42)
      JacC( 35,  2) = JacC( 35,  2)+ 0.5000000000000000D-01*dw(153,  2)
      JacC( 41, 42) = JacC( 41, 42)+ 0.1000000000000000D+00*dw(153, 42)
      JacC( 41,  2) = JacC( 41,  2)+ 0.1000000000000000D+00*dw(153,  2)
      JacC( 42, 42) = JacC( 42, 42) - dw(153, 42)
      JacC( 42,  2) = JacC( 42,  2) - dw(153,  2)
      JacC( 45, 42) = JacC( 45, 42)+ 0.9000000000000000D+00*dw(153, 42)
      JacC( 45,  2) = JacC( 45,  2)+ 0.9000000000000000D+00*dw(153,  2)
      JacC( 49, 42) = JacC( 49, 42)+ 0.1000000000000000D+00*dw(153, 42)
      JacC( 49,  2) = JacC( 49,  2)+ 0.1000000000000000D+00*dw(153,  2)
      JacC( 50, 42) = JacC( 50, 42) + dw(153, 42)
      JacC( 50,  2) = JacC( 50,  2) + dw(153,  2)
      JacC(  4, 42) = JacC(  4, 42) - dw(154, 42)
      JacC(  4,  4) = JacC(  4,  4) - dw(154,  4)
      JacC( 39, 42) = JacC( 39, 42)+ 0.8999999999999999D-02*dw(154, 42)
      JacC( 39,  4) = JacC( 39,  4)+ 0.8999999999999999D-02*dw(154,  4)
      JacC( 42, 42) = JacC( 42, 42) - dw(154, 42)
      JacC( 42,  4) = JacC( 42,  4) - dw(154,  4)
      JacC( 45, 42) = JacC( 45, 42)+ 0.9910000000000000D+00*dw(154, 42)
      JacC( 45,  4) = JacC( 45,  4)+ 0.9910000000000000D+00*dw(154,  4)
      JacC( 49, 42) = JacC( 49, 42)+ 0.9910000000000000D+00*dw(154, 42)
      JacC( 49,  4) = JacC( 49,  4)+ 0.9910000000000000D+00*dw(154,  4)
      JacC( 50, 42) = JacC( 50, 42) + dw(154, 42)
      JacC( 50,  4) = JacC( 50,  4) + dw(154,  4)
      JacC( 31, 52) = JacC( 31, 52) - dw(155, 52)
      JacC( 31, 31) = JacC( 31, 31) - dw(155, 31)
      JacC( 32, 52) = JacC( 32, 52)+ 0.2000000000000000D+00*dw(155, 52)
      JacC( 32, 31) = JacC( 32, 31)+ 0.2000000000000000D+00*dw(155, 31)
      JacC( 33, 52) = JacC( 33, 52)+ 0.8000000000000000D+00*dw(155, 52)
      JacC( 33, 31) = JacC( 33, 31)+ 0.8000000000000000D+00*dw(155, 31)
      JacC( 34, 52) = JacC( 34, 52)+ 0.2400000000000000D+01*dw(155, 52)
      JacC( 34, 31) = JacC( 34, 31)+ 0.2400000000000000D+01*dw(155, 31)
      JacC( 35, 52) = JacC( 35, 52)+ 0.8000000000000000D+00*dw(155, 52)
      JacC( 35, 31) = JacC( 35, 31)+ 0.8000000000000000D+00*dw(155, 31)
      JacC( 48, 52) = JacC( 48, 52)+ 0.2000000000000000D+00*dw(155, 52)
      JacC( 48, 31) = JacC( 48, 31)+ 0.2000000000000000D+00*dw(155, 31)
      JacC( 49, 52) = JacC( 49, 52) + dw(155, 52)
      JacC( 49, 31) = JacC( 49, 31) + dw(155, 31)
      JacC( 50, 52) = JacC( 50, 52)+ 0.8000000000000000D+00*dw(155, 52)
      JacC( 50, 31) = JacC( 50, 31)+ 0.8000000000000000D+00*dw(155, 31)
      JacC( 52, 52) = JacC( 52, 52) - dw(155, 52)
      JacC( 52, 31) = JacC( 52, 31) - dw(155, 31)
 
      do j = 1, ns
         do i = 1, ns
            JacC(i,j) = JacC(i,j) * convers_factor_jac(i,j)
         enddo
      enddo
 
 
      RETURN
      END
 
