C------------------------------------------------------------------------
C     Copyright (C) 2001-2008, ENPC - INRIA - EDF R&D
C     
C     This file is part of the air quality modeling system Polyphemus.
C    
C     Polyphemus is developed in the INRIA - ENPC joint project-team
C     CLIME and in the ENPC - EDF R&D joint laboratory CEREA.
C    
C     Polyphemus is free software; you can redistribute it and/or modify
C     it under the terms of the GNU General Public License as published
C     by the Free Software Foundation; either version 2 of the License,
C     or (at your option) any later version.
C     
C     Polyphemus is distributed in the hope that it will be useful, but
C     WITHOUT ANY WARRANTY; without even the implied warranty of
C     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
C     General Public License for more details.
C     
C     For more information, visit the Polyphemus web site:
C     http://cerea.enpc.fr/polyphemus/
C
C------------------------------------------------------------------------

      SUBROUTINE LU_decompose_racm2 (ns,M)

C------------------------------------------------------------------------
C     
C     -- DESCRIPTION 
C     
C     This routine computes an LU factorization of M.
C     This routine is automatically generated by "LU.cpp".
C     
C------------------------------------------------------------------------
C     
C     -- INPUT VARIABLES
C
C     ns: matrix row number from the chemical species number.
C     
C     -- INPUT/OUTPUT VARIABLES
C     
C     M: on entry, an invertible matrix. On exit, an LU factorization
C     of M.
C     
C     -- OUTPUT VARIABLES
C     
C------------------------------------------------------------------------
C     
C     -- REMARKS
C     
C------------------------------------------------------------------------
C     
C     -- MODIFICATIONS
C     
C------------------------------------------------------------------------
C     
C     -- AUTHOR(S)
C     
C------------------------------------------------------------------------

      IMPLICIT NONE


      INTEGER ns
      DOUBLE PRECISION M(ns,ns)
      DOUBLE PRECISION temp


C     Upper part.
      M(1, 81) = M(1, 81) / M(1, 1)

C     Upper part.
      M(2, 112) = M(2, 112) / M(2, 2)

C     Upper part.
      temp = M(3, 2) * M(2, 112)
      M(3, 112) = ( M(3, 112) - temp ) / M(3, 3)

C     Upper part.
      M(4, 112) = M(4, 112) / M(4, 4)

C     Upper part.
      M(5, 112) = M(5, 112) / M(5, 5)

C     Upper part.
      M(6, 112) = M(6, 112) / M(6, 6)

C     Upper part.
      M(7, 112) = M(7, 112) / M(7, 7)

C     Upper part.
      M(8, 112) = M(8, 112) / M(8, 8)

C     Upper part.
      M(9, 112) = M(9, 112) / M(9, 9)

C     Upper part.
      temp = M(10, 9) * M(9, 112)
      M(10, 112) = ( M(10, 112) - temp ) / M(10, 10)

C     Upper part.
      M(11, 112) = M(11, 112) / M(11, 11)

C     Upper part.
      temp = M(12, 11) * M(11, 112)
      M(12, 112) = ( M(12, 112) - temp ) / M(12, 12)

C     Upper part.
      M(13, 112) = M(13, 112) / M(13, 13)

C     Upper part.
      temp = M(14, 13) * M(13, 112)
      M(14, 112) = ( M(14, 112) - temp ) / M(14, 14)

C     Upper part.
      M(15, 102) = M(15, 102) / M(15, 15)
C     Upper part.
      M(15, 112) = M(15, 112) / M(15, 15)

C     Upper part.
      M(16, 109) = M(16, 109) / M(16, 16)
C     Upper part.
      M(16, 110) = M(16, 110) / M(16, 16)

C     Upper part.
      M(17, 39) = M(17, 39) / M(17, 17)
C     Upper part.
      M(17, 112) = M(17, 112) / M(17, 17)

C     Upper part.
      M(18, 109) = M(18, 109) / M(18, 18)
C     Upper part.
      temp = M(18, 5) * M(5, 112)
      M(18, 112) = ( M(18, 112) - temp ) / M(18, 18)

C     Upper part.
      M(19, 81) = M(19, 81) / M(19, 19)
C     Upper part.
      M(19, 109) = M(19, 109) / M(19, 19)
C     Upper part.
      M(19, 112) = M(19, 112) / M(19, 19)

C     Upper part.
      M(20, 81) = M(20, 81) / M(20, 20)
C     Upper part.
      M(20, 109) = M(20, 109) / M(20, 20)
C     Upper part.
      M(20, 112) = M(20, 112) / M(20, 20)

C     Upper part.
      M(21, 100) = M(21, 100) / M(21, 21)
C     Upper part.
      M(21, 104) = M(21, 104) / M(21, 21)
C     Upper part.
      M(21, 112) = M(21, 112) / M(21, 21)

C     Upper part.
      M(22, 81) = M(22, 81) / M(22, 22)
C     Upper part.
      M(22, 109) = M(22, 109) / M(22, 22)
C     Upper part.
      temp = M(22, 10) * M(10, 112)
      temp = temp + M(22, 12) * M(12, 112)
      temp = temp + M(22, 14) * M(14, 112)
      M(22, 112) = ( M(22, 112) - temp ) / M(22, 22)

C     Upper part.
      M(23, 81) = M(23, 81) / M(23, 23)
C     Upper part.
      M(23, 109) = M(23, 109) / M(23, 23)
C     Upper part.
      M(23, 112) = M(23, 112) / M(23, 23)

C     Upper part.
      M(24, 88) = M(24, 88) / M(24, 24)
C     Upper part.
      M(24, 100) = M(24, 100) / M(24, 24)
C     Upper part.
      M(24, 112) = M(24, 112) / M(24, 24)

C     Upper part.
      M(25, 59) = M(25, 59) / M(25, 25)
C     Upper part.
      M(25, 111) = M(25, 111) / M(25, 25)
C     Upper part.
      M(25, 112) = M(25, 112) / M(25, 25)

C     Upper part.
      M(26, 81) = M(26, 81) / M(26, 26)
C     Upper part.
      M(26, 109) = M(26, 109) / M(26, 26)
C     Upper part.
      M(26, 112) = M(26, 112) / M(26, 26)

C     Upper part.
      M(27, 81) = M(27, 81) / M(27, 27)
C     Upper part.
      M(27, 109) = M(27, 109) / M(27, 27)
C     Upper part.
      M(27, 112) = M(27, 112) / M(27, 27)

C     Upper part.
      M(28, 95) = M(28, 95) / M(28, 28)
C     Upper part.
      M(28, 111) = M(28, 111) / M(28, 28)
C     Upper part.
      M(28, 112) = M(28, 112) / M(28, 28)

C     Upper part.
      M(29, 47) = M(29, 47) / M(29, 29)
C     Upper part.
      temp = M(29, 18) * M(18, 109)
      M(29, 109) = ( M(29, 109) - temp ) / M(29, 29)
C     Upper part.
      temp = M(29, 18) * M(18, 112)
      M(29, 112) = ( M(29, 112) - temp ) / M(29, 29)

C     Upper part.
      M(30, 86) = M(30, 86) / M(30, 30)
C     Upper part.
      M(30, 102) = M(30, 102) / M(30, 30)
C     Upper part.
      M(30, 112) = M(30, 112) / M(30, 30)

C     Upper part.
      temp = M(31, 20) * M(20, 81)
      temp = temp + M(31, 27) * M(27, 81)
      M(31, 81) = ( M(31, 81) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 20) * M(20, 109)
      temp = temp + M(31, 27) * M(27, 109)
      M(31, 109) = ( M(31, 109) - temp ) / M(31, 31)
C     Upper part.
      temp = M(31, 20) * M(20, 112)
      temp = temp + M(31, 27) * M(27, 112)
      M(31, 112) = ( M(31, 112) - temp ) / M(31, 31)

C     Upper part.
      M(32, 69) = M(32, 69) / M(32, 32)
C     Upper part.
      temp = M(32, 31) * M(31, 81)
      M(32, 81) = ( M(32, 81) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 31) * M(31, 109)
      M(32, 109) = ( M(32, 109) - temp ) / M(32, 32)
C     Upper part.
      temp = M(32, 31) * M(31, 112)
      M(32, 112) = ( M(32, 112) - temp ) / M(32, 32)

C     Upper part.
      M(33, 69) = M(33, 69) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 81)
      M(33, 81) = ( M(33, 81) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 109)
      M(33, 109) = ( M(33, 109) - temp ) / M(33, 33)
C     Upper part.
      temp = M(33, 31) * M(31, 112)
      M(33, 112) = ( M(33, 112) - temp ) / M(33, 33)

C     Upper part.
      M(34, 100) = M(34, 100) / M(34, 34)
C     Upper part.
      M(34, 111) = M(34, 111) / M(34, 34)
C     Upper part.
      M(34, 112) = M(34, 112) / M(34, 34)

C     Upper part.
      M(35, 105) = M(35, 105) / M(35, 35)
C     Upper part.
      M(35, 110) = M(35, 110) / M(35, 35)
C     Upper part.
      M(35, 112) = M(35, 112) / M(35, 35)

C     Upper part.
      M(36, 110) = M(36, 110) / M(36, 36)
C     Upper part.
      M(36, 111) = M(36, 111) / M(36, 36)
C     Upper part.
      M(36, 112) = M(36, 112) / M(36, 36)

C     Upper part.
      M(37, 98) = M(37, 98) / M(37, 37)
C     Upper part.
      M(37, 110) = M(37, 110) / M(37, 37)
C     Upper part.
      M(37, 112) = M(37, 112) / M(37, 37)

C     Upper part.
      M(38, 69) = M(38, 69) / M(38, 38)
C     Upper part.
      temp = M(38, 19) * M(19, 81)
      temp = temp + M(38, 20) * M(20, 81)
      temp = temp + M(38, 26) * M(26, 81)
      temp = temp + M(38, 27) * M(27, 81)
      temp = temp + M(38, 31) * M(31, 81)
      M(38, 81) = ( M(38, 81) - temp ) / M(38, 38)
C     Upper part.
      temp = M(38, 19) * M(19, 109)
      temp = temp + M(38, 20) * M(20, 109)
      temp = temp + M(38, 26) * M(26, 109)
      temp = temp + M(38, 27) * M(27, 109)
      temp = temp + M(38, 31) * M(31, 109)
      M(38, 109) = ( M(38, 109) - temp ) / M(38, 38)
C     Upper part.
      M(38, 111) = M(38, 111) / M(38, 38)
C     Upper part.
      temp = M(38, 19) * M(19, 112)
      temp = temp + M(38, 20) * M(20, 112)
      temp = temp + M(38, 26) * M(26, 112)
      temp = temp + M(38, 27) * M(27, 112)
      temp = temp + M(38, 31) * M(31, 112)
      M(38, 112) = ( M(38, 112) - temp ) / M(38, 38)

C     Lower part.
      temp = M(96, 17) * M(17, 39)
      M(96, 39) = M(96, 39) - temp
C     Lower part.
      temp = M(108, 17) * M(17, 39)
      M(108, 39) = M(108, 39) - temp
C     Lower part.
      temp = M(110, 17) * M(17, 39)
      M(110, 39) = M(110, 39) - temp
C     Lower part.
      temp = M(112, 17) * M(17, 39)
      M(112, 39) = M(112, 39) - temp
C     Upper part.
      M(39, 59) = M(39, 59) / M(39, 39)
C     Upper part.
      temp = M(39, 26) * M(26, 81)
      M(39, 81) = ( M(39, 81) - temp ) / M(39, 39)
C     Upper part.
      M(39, 102) = M(39, 102) / M(39, 39)
C     Upper part.
      temp = M(39, 26) * M(26, 109)
      M(39, 109) = ( M(39, 109) - temp ) / M(39, 39)
C     Upper part.
      temp = M(39, 26) * M(26, 112)
      M(39, 112) = ( M(39, 112) - temp ) / M(39, 39)

C     Upper part.
      M(40, 95) = M(40, 95) / M(40, 40)
C     Upper part.
      M(40, 109) = M(40, 109) / M(40, 40)
C     Upper part.
      M(40, 110) = M(40, 110) / M(40, 40)
C     Upper part.
      M(40, 112) = M(40, 112) / M(40, 40)

C     Upper part.
      M(41, 100) = M(41, 100) / M(41, 41)
C     Upper part.
      M(41, 102) = M(41, 102) / M(41, 41)
C     Upper part.
      M(41, 105) = M(41, 105) / M(41, 41)
C     Upper part.
      M(41, 109) = M(41, 109) / M(41, 41)
C     Upper part.
      temp = M(41, 10) * M(10, 112)
      M(41, 112) = ( M(41, 112) - temp ) / M(41, 41)

C     Upper part.
      temp = M(42, 41) * M(41, 100)
      M(42, 100) = ( M(42, 100) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 102)
      M(42, 102) = ( M(42, 102) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 105)
      M(42, 105) = ( M(42, 105) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 41) * M(41, 109)
      M(42, 109) = ( M(42, 109) - temp ) / M(42, 42)
C     Upper part.
      temp = M(42, 10) * M(10, 112)
      temp = temp + M(42, 41) * M(41, 112)
      M(42, 112) = ( M(42, 112) - temp ) / M(42, 42)

C     Upper part.
      M(43, 100) = M(43, 100) / M(43, 43)
C     Upper part.
      M(43, 102) = M(43, 102) / M(43, 43)
C     Upper part.
      M(43, 105) = M(43, 105) / M(43, 43)
C     Upper part.
      M(43, 109) = M(43, 109) / M(43, 43)
C     Upper part.
      temp = M(43, 12) * M(12, 112)
      M(43, 112) = ( M(43, 112) - temp ) / M(43, 43)

C     Upper part.
      temp = M(44, 1) * M(1, 81)
      temp = temp + M(44, 20) * M(20, 81)
      M(44, 81) = ( M(44, 81) - temp ) / M(44, 44)
C     Upper part.
      M(44, 102) = M(44, 102) / M(44, 44)
C     Upper part.
      temp = M(44, 20) * M(20, 109)
      M(44, 109) = ( M(44, 109) - temp ) / M(44, 44)
C     Upper part.
      M(44, 110) = M(44, 110) / M(44, 44)
C     Upper part.
      temp = M(44, 20) * M(20, 112)
      M(44, 112) = ( M(44, 112) - temp ) / M(44, 44)

C     Upper part.
      M(45, 54) = M(45, 54) / M(45, 45)
C     Upper part.
      M(45, 100) = M(45, 100) / M(45, 45)
C     Upper part.
      M(45, 102) = M(45, 102) / M(45, 45)
C     Upper part.
      M(45, 105) = M(45, 105) / M(45, 45)
C     Upper part.
      M(45, 109) = M(45, 109) / M(45, 45)

C     Upper part.
      temp = M(46, 45) * M(45, 54)
      M(46, 54) = ( M(46, 54) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 100)
      M(46, 100) = ( M(46, 100) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 102)
      M(46, 102) = ( M(46, 102) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 105)
      M(46, 105) = ( M(46, 105) - temp ) / M(46, 46)
C     Upper part.
      temp = M(46, 45) * M(45, 109)
      M(46, 109) = ( M(46, 109) - temp ) / M(46, 46)
C     Upper part.
      M(46, 110) = M(46, 110) / M(46, 46)

C     Lower part.
      temp = M(83, 29) * M(29, 47)
      M(83, 47) = M(83, 47) - temp
C     Lower part.
      temp = M(94, 29) * M(29, 47)
      M(94, 47) = M(94, 47) - temp
C     Lower part.
      temp = M(109, 29) * M(29, 47)
      M(109, 47) = M(109, 47) - temp
C     Lower part.
      temp = M(112, 29) * M(29, 47)
      M(112, 47) = M(112, 47) - temp
C     Upper part.
      M(47, 48) = M(47, 48) / M(47, 47)
C     Upper part.
      M(47, 55) = M(47, 55) / M(47, 47)
C     Upper part.
      temp = M(47, 41) * M(41, 100)
      temp = temp + M(47, 43) * M(43, 100)
      M(47, 100) = ( M(47, 100) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 41) * M(41, 102)
      temp = temp + M(47, 43) * M(43, 102)
      M(47, 102) = ( M(47, 102) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 41) * M(41, 105)
      temp = temp + M(47, 43) * M(43, 105)
      M(47, 105) = ( M(47, 105) - temp ) / M(47, 47)
C     Upper part.
      temp = M(47, 41) * M(41, 109)
      temp = temp + M(47, 43) * M(43, 109)
      M(47, 109) = ( M(47, 109) - temp ) / M(47, 47)
C     Upper part.
      M(47, 111) = M(47, 111) / M(47, 47)
C     Upper part.
      temp = M(47, 9) * M(9, 112)
      temp = temp + M(47, 10) * M(10, 112)
      temp = temp + M(47, 11) * M(11, 112)
      temp = temp + M(47, 12) * M(12, 112)
      temp = temp + M(47, 13) * M(13, 112)
      temp = temp + M(47, 14) * M(14, 112)
      temp = temp + M(47, 41) * M(41, 112)
      temp = temp + M(47, 43) * M(43, 112)
      M(47, 112) = ( M(47, 112) - temp ) / M(47, 47)

C     Lower part.
      temp = M(48, 47) * M(47, 48)
      M(48, 48) = M(48, 48) - temp
C     Lower part.
      temp = M(51, 47) * M(47, 48)
      M(51, 48) = M(51, 48) - temp
C     Lower part.
      temp = M(75, 47) * M(47, 48)
      M(75, 48) = M(75, 48) - temp
C     Lower part.
      temp = M(83, 47) * M(47, 48)
      M(83, 48) = M(83, 48) - temp
C     Lower part.
      temp = M(94, 47) * M(47, 48)
      M(94, 48) = M(94, 48) - temp
C     Lower part.
      temp = M(109, 47) * M(47, 48)
      M(109, 48) = M(109, 48) - temp
C     Lower part.
      temp = M(111, 47) * M(47, 48)
      M(111, 48) = M(111, 48) - temp
C     Lower part.
      temp = M(112, 47) * M(47, 48)
      M(112, 48) = M(112, 48) - temp
C     Upper part.
      M(48, 53) = M(48, 53) / M(48, 48)
C     Upper part.
      temp = M(48, 47) * M(47, 55)
      M(48, 55) = ( M(48, 55) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 47) * M(47, 100)
      M(48, 100) = ( M(48, 100) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 47) * M(47, 102)
      M(48, 102) = ( M(48, 102) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 47) * M(47, 105)
      M(48, 105) = ( M(48, 105) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 18) * M(18, 109)
      temp = temp + M(48, 47) * M(47, 109)
      M(48, 109) = ( M(48, 109) - temp ) / M(48, 48)
C     Upper part.
      M(48, 110) = M(48, 110) / M(48, 48)
C     Upper part.
      temp = M(48, 47) * M(47, 111)
      M(48, 111) = ( M(48, 111) - temp ) / M(48, 48)
C     Upper part.
      temp = M(48, 18) * M(18, 112)
      temp = temp + M(48, 47) * M(47, 112)
      M(48, 112) = ( M(48, 112) - temp ) / M(48, 48)

C     Upper part.
      M(49, 55) = M(49, 55) / M(49, 49)
C     Upper part.
      temp = M(49, 43) * M(43, 100)
      M(49, 100) = ( M(49, 100) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 43) * M(43, 102)
      M(49, 102) = ( M(49, 102) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 43) * M(43, 105)
      M(49, 105) = ( M(49, 105) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 43) * M(43, 109)
      M(49, 109) = ( M(49, 109) - temp ) / M(49, 49)
C     Upper part.
      temp = M(49, 12) * M(12, 112)
      temp = temp + M(49, 14) * M(14, 112)
      temp = temp + M(49, 43) * M(43, 112)
      M(49, 112) = ( M(49, 112) - temp ) / M(49, 49)

C     Upper part.
      M(50, 100) = M(50, 100) / M(50, 50)
C     Upper part.
      M(50, 102) = M(50, 102) / M(50, 50)
C     Upper part.
      M(50, 105) = M(50, 105) / M(50, 50)
C     Upper part.
      M(50, 109) = M(50, 109) / M(50, 50)
C     Upper part.
      temp = M(50, 9) * M(9, 112)
      M(50, 112) = ( M(50, 112) - temp ) / M(50, 50)

C     Upper part.
      temp = M(51, 48) * M(48, 53)
      M(51, 53) = ( M(51, 53) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 47) * M(47, 55)
      temp = temp + M(51, 48) * M(48, 55)
      M(51, 55) = ( M(51, 55) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 47) * M(47, 100)
      temp = temp + M(51, 48) * M(48, 100)
      M(51, 100) = ( M(51, 100) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 47) * M(47, 102)
      temp = temp + M(51, 48) * M(48, 102)
      M(51, 102) = ( M(51, 102) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 47) * M(47, 105)
      temp = temp + M(51, 48) * M(48, 105)
      M(51, 105) = ( M(51, 105) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 18) * M(18, 109)
      temp = temp + M(51, 47) * M(47, 109)
      temp = temp + M(51, 48) * M(48, 109)
      M(51, 109) = ( M(51, 109) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 48) * M(48, 110)
      M(51, 110) = ( M(51, 110) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 47) * M(47, 111)
      temp = temp + M(51, 48) * M(48, 111)
      M(51, 111) = ( M(51, 111) - temp ) / M(51, 51)
C     Upper part.
      temp = M(51, 18) * M(18, 112)
      temp = temp + M(51, 47) * M(47, 112)
      temp = temp + M(51, 48) * M(48, 112)
      M(51, 112) = ( M(51, 112) - temp ) / M(51, 51)

C     Upper part.
      M(52, 100) = M(52, 100) / M(52, 52)
C     Upper part.
      M(52, 102) = M(52, 102) / M(52, 52)
C     Upper part.
      M(52, 105) = M(52, 105) / M(52, 52)
C     Upper part.
      M(52, 109) = M(52, 109) / M(52, 52)
C     Upper part.
      temp = M(52, 11) * M(11, 112)
      temp = temp + M(52, 13) * M(13, 112)
      M(52, 112) = ( M(52, 112) - temp ) / M(52, 52)

C     Lower part.
      temp = M(75, 48) * M(48, 53)
      M(75, 53) = M(75, 53) - temp
C     Lower part.
      temp = M(83, 48) * M(48, 53)
      M(83, 53) = M(83, 53) - temp
C     Lower part.
      temp = M(91, 51) * M(51, 53)
      M(91, 53) = M(91, 53) - temp
C     Lower part.
      temp = M(94, 48) * M(48, 53)
      M(94, 53) = M(94, 53) - temp
C     Lower part.
      temp = M(100, 51) * M(51, 53)
      M(100, 53) = M(100, 53) - temp
C     Lower part.
      temp = M(102, 51) * M(51, 53)
      M(102, 53) = M(102, 53) - temp
C     Lower part.
      temp = M(105, 51) * M(51, 53)
      M(105, 53) = M(105, 53) - temp
C     Lower part.
      temp = M(106, 51) * M(51, 53)
      M(106, 53) = M(106, 53) - temp
C     Lower part.
      temp = M(108, 51) * M(51, 53)
      M(108, 53) = M(108, 53) - temp
C     Lower part.
      temp = M(109, 48) * M(48, 53)
      temp = temp + M(109, 51) * M(51, 53)
      M(109, 53) = M(109, 53) - temp
C     Lower part.
      temp = M(110, 48) * M(48, 53)
      temp = temp + M(110, 51) * M(51, 53)
      M(110, 53) = M(110, 53) - temp
C     Lower part.
      temp = M(111, 48) * M(48, 53)
      temp = temp + M(111, 51) * M(51, 53)
      M(111, 53) = M(111, 53) - temp
C     Lower part.
      temp = M(112, 48) * M(48, 53)
      M(112, 53) = M(112, 53) - temp
C     Lower part.
      temp = M(113, 48) * M(48, 53)
      temp = temp + M(113, 51) * M(51, 53)
      M(113, 53) = M(113, 53) - temp
C     Upper part.
      temp = M(53, 50) * M(50, 100)
      temp = temp + M(53, 52) * M(52, 100)
      M(53, 100) = ( M(53, 100) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 50) * M(50, 102)
      temp = temp + M(53, 52) * M(52, 102)
      M(53, 102) = ( M(53, 102) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 50) * M(50, 105)
      temp = temp + M(53, 52) * M(52, 105)
      M(53, 105) = ( M(53, 105) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 50) * M(50, 109)
      temp = temp + M(53, 52) * M(52, 109)
      M(53, 109) = ( M(53, 109) - temp ) / M(53, 53)
C     Upper part.
      temp = M(53, 50) * M(50, 112)
      temp = temp + M(53, 52) * M(52, 112)
      M(53, 112) = ( M(53, 112) - temp ) / M(53, 53)

C     Lower part.
      temp = M(100, 45) * M(45, 54)
      M(100, 54) = M(100, 54) - temp
C     Lower part.
      temp = M(102, 45) * M(45, 54)
      M(102, 54) = M(102, 54) - temp
C     Lower part.
      temp = M(105, 45) * M(45, 54)
      M(105, 54) = M(105, 54) - temp
C     Lower part.
      temp = M(108, 45) * M(45, 54)
      M(108, 54) = M(108, 54) - temp
C     Lower part.
      temp = M(109, 45) * M(45, 54)
      M(109, 54) = M(109, 54) - temp
C     Lower part.
      temp = M(110, 45) * M(45, 54)
      temp = temp + M(110, 46) * M(46, 54)
      M(110, 54) = M(110, 54) - temp
C     Lower part.
      temp = M(111, 45) * M(45, 54)
      M(111, 54) = M(111, 54) - temp
C     Lower part.
      temp = M(113, 46) * M(46, 54)
      M(113, 54) = M(113, 54) - temp
C     Upper part.
      temp = M(54, 53) * M(53, 100)
      M(54, 100) = ( M(54, 100) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 102)
      M(54, 102) = ( M(54, 102) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 105)
      M(54, 105) = ( M(54, 105) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 109)
      M(54, 109) = ( M(54, 109) - temp ) / M(54, 54)
C     Upper part.
      temp = M(54, 53) * M(53, 112)
      M(54, 112) = ( M(54, 112) - temp ) / M(54, 54)

C     Lower part.
      temp = M(75, 47) * M(47, 55)
      temp = temp + M(75, 48) * M(48, 55)
      M(75, 55) = M(75, 55) - temp
C     Lower part.
      temp = M(77, 49) * M(49, 55)
      M(77, 55) = M(77, 55) - temp
C     Lower part.
      temp = M(78, 49) * M(49, 55)
      M(78, 55) = M(78, 55) - temp
C     Lower part.
      temp = M(83, 47) * M(47, 55)
      temp = temp + M(83, 48) * M(48, 55)
      M(83, 55) = M(83, 55) - temp
C     Lower part.
      temp = M(91, 51) * M(51, 55)
      M(91, 55) = M(91, 55) - temp
C     Lower part.
      temp = M(93, 49) * M(49, 55)
      M(93, 55) = M(93, 55) - temp
C     Lower part.
      temp = M(94, 47) * M(47, 55)
      temp = temp + M(94, 48) * M(48, 55)
      M(94, 55) = M(94, 55) - temp
C     Lower part.
      temp = M(100, 49) * M(49, 55)
      temp = temp + M(100, 51) * M(51, 55)
      M(100, 55) = M(100, 55) - temp
C     Lower part.
      temp = M(102, 49) * M(49, 55)
      temp = temp + M(102, 51) * M(51, 55)
      M(102, 55) = M(102, 55) - temp
C     Lower part.
      temp = M(105, 49) * M(49, 55)
      temp = temp + M(105, 51) * M(51, 55)
      M(105, 55) = M(105, 55) - temp
C     Lower part.
      temp = M(106, 51) * M(51, 55)
      M(106, 55) = M(106, 55) - temp
C     Lower part.
      temp = M(108, 49) * M(49, 55)
      temp = temp + M(108, 51) * M(51, 55)
      M(108, 55) = M(108, 55) - temp
C     Lower part.
      temp = M(109, 47) * M(47, 55)
      temp = temp + M(109, 48) * M(48, 55)
      temp = temp + M(109, 49) * M(49, 55)
      temp = temp + M(109, 51) * M(51, 55)
      M(109, 55) = M(109, 55) - temp
C     Lower part.
      temp = M(110, 48) * M(48, 55)
      temp = temp + M(110, 49) * M(49, 55)
      temp = temp + M(110, 51) * M(51, 55)
      M(110, 55) = M(110, 55) - temp
C     Lower part.
      temp = M(111, 47) * M(47, 55)
      temp = temp + M(111, 48) * M(48, 55)
      temp = temp + M(111, 49) * M(49, 55)
      temp = temp + M(111, 51) * M(51, 55)
      M(111, 55) = M(111, 55) - temp
C     Lower part.
      temp = M(112, 47) * M(47, 55)
      temp = temp + M(112, 48) * M(48, 55)
      M(112, 55) = M(112, 55) - temp
C     Lower part.
      temp = M(113, 48) * M(48, 55)
      temp = temp + M(113, 49) * M(49, 55)
      temp = temp + M(113, 51) * M(51, 55)
      M(113, 55) = M(113, 55) - temp
C     Upper part.
      M(55, 100) = M(55, 100) / M(55, 55)
C     Upper part.
      M(55, 102) = M(55, 102) / M(55, 55)
C     Upper part.
      M(55, 105) = M(55, 105) / M(55, 55)
C     Upper part.
      M(55, 109) = M(55, 109) / M(55, 55)
C     Upper part.
      M(55, 111) = M(55, 111) / M(55, 55)
C     Upper part.
      temp = M(55, 14) * M(14, 112)
      M(55, 112) = ( M(55, 112) - temp ) / M(55, 55)

C     Upper part.
      temp = M(56, 41) * M(41, 100)
      temp = temp + M(56, 43) * M(43, 100)
      temp = temp + M(56, 55) * M(55, 100)
      M(56, 100) = ( M(56, 100) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 41) * M(41, 102)
      temp = temp + M(56, 43) * M(43, 102)
      temp = temp + M(56, 55) * M(55, 102)
      M(56, 102) = ( M(56, 102) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 41) * M(41, 105)
      temp = temp + M(56, 43) * M(43, 105)
      temp = temp + M(56, 55) * M(55, 105)
      M(56, 105) = ( M(56, 105) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 41) * M(41, 109)
      temp = temp + M(56, 43) * M(43, 109)
      temp = temp + M(56, 55) * M(55, 109)
      M(56, 109) = ( M(56, 109) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 55) * M(55, 111)
      M(56, 111) = ( M(56, 111) - temp ) / M(56, 56)
C     Upper part.
      temp = M(56, 10) * M(10, 112)
      temp = temp + M(56, 12) * M(12, 112)
      temp = temp + M(56, 14) * M(14, 112)
      temp = temp + M(56, 41) * M(41, 112)
      temp = temp + M(56, 43) * M(43, 112)
      temp = temp + M(56, 55) * M(55, 112)
      M(56, 112) = ( M(56, 112) - temp ) / M(56, 56)

C     Upper part.
      temp = M(57, 19) * M(19, 81)
      M(57, 81) = ( M(57, 81) - temp ) / M(57, 57)
C     Upper part.
      M(57, 100) = M(57, 100) / M(57, 57)
C     Upper part.
      M(57, 102) = M(57, 102) / M(57, 57)
C     Upper part.
      M(57, 105) = M(57, 105) / M(57, 57)
C     Upper part.
      temp = M(57, 19) * M(19, 109)
      M(57, 109) = ( M(57, 109) - temp ) / M(57, 57)
C     Upper part.
      M(57, 111) = M(57, 111) / M(57, 57)
C     Upper part.
      temp = M(57, 19) * M(19, 112)
      M(57, 112) = ( M(57, 112) - temp ) / M(57, 57)

C     Upper part.
      M(58, 60) = M(58, 60) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 81)
      M(58, 81) = ( M(58, 81) - temp ) / M(58, 58)
C     Upper part.
      M(58, 86) = M(58, 86) / M(58, 58)
C     Upper part.
      M(58, 99) = M(58, 99) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 100)
      M(58, 100) = ( M(58, 100) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 102)
      M(58, 102) = ( M(58, 102) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 105)
      M(58, 105) = ( M(58, 105) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 109)
      M(58, 109) = ( M(58, 109) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 111)
      M(58, 111) = ( M(58, 111) - temp ) / M(58, 58)
C     Upper part.
      temp = M(58, 57) * M(57, 112)
      M(58, 112) = ( M(58, 112) - temp ) / M(58, 58)

C     Lower part.
      temp = M(61, 25) * M(25, 59)
      M(61, 59) = M(61, 59) - temp
C     Lower part.
      temp = M(73, 39) * M(39, 59)
      M(73, 59) = M(73, 59) - temp
C     Lower part.
      temp = M(96, 39) * M(39, 59)
      M(96, 59) = M(96, 59) - temp
C     Lower part.
      temp = M(108, 39) * M(39, 59)
      M(108, 59) = M(108, 59) - temp
C     Lower part.
      temp = M(110, 39) * M(39, 59)
      M(110, 59) = M(110, 59) - temp
C     Lower part.
      temp = M(112, 39) * M(39, 59)
      M(112, 59) = M(112, 59) - temp
C     Upper part.
      temp = M(59, 26) * M(26, 81)
      M(59, 81) = ( M(59, 81) - temp ) / M(59, 59)
C     Upper part.
      M(59, 100) = M(59, 100) / M(59, 59)
C     Upper part.
      M(59, 102) = M(59, 102) / M(59, 59)
C     Upper part.
      M(59, 105) = M(59, 105) / M(59, 59)
C     Upper part.
      temp = M(59, 26) * M(26, 109)
      M(59, 109) = ( M(59, 109) - temp ) / M(59, 59)
C     Upper part.
      M(59, 111) = M(59, 111) / M(59, 59)
C     Upper part.
      temp = M(59, 26) * M(26, 112)
      M(59, 112) = ( M(59, 112) - temp ) / M(59, 59)

C     Lower part.
      temp = M(65, 58) * M(58, 60)
      M(65, 60) = M(65, 60) - temp
C     Lower part.
      temp = M(100, 58) * M(58, 60)
      M(100, 60) = M(100, 60) - temp
C     Lower part.
      temp = M(105, 58) * M(58, 60)
      M(105, 60) = M(105, 60) - temp
C     Lower part.
      temp = M(112, 58) * M(58, 60)
      M(112, 60) = M(112, 60) - temp
C     Upper part.
      temp = M(60, 27) * M(27, 81)
      M(60, 81) = ( M(60, 81) - temp ) / M(60, 60)
C     Upper part.
      M(60, 100) = M(60, 100) / M(60, 60)
C     Upper part.
      M(60, 102) = M(60, 102) / M(60, 60)
C     Upper part.
      M(60, 105) = M(60, 105) / M(60, 60)
C     Upper part.
      temp = M(60, 27) * M(27, 109)
      M(60, 109) = ( M(60, 109) - temp ) / M(60, 60)
C     Upper part.
      M(60, 111) = M(60, 111) / M(60, 60)
C     Upper part.
      temp = M(60, 27) * M(27, 112)
      M(60, 112) = ( M(60, 112) - temp ) / M(60, 60)

C     Upper part.
      temp = M(61, 20) * M(20, 81)
      temp = temp + M(61, 26) * M(26, 81)
      temp = temp + M(61, 27) * M(27, 81)
      temp = temp + M(61, 59) * M(59, 81)
      temp = temp + M(61, 60) * M(60, 81)
      M(61, 81) = ( M(61, 81) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 59) * M(59, 100)
      temp = temp + M(61, 60) * M(60, 100)
      M(61, 100) = ( M(61, 100) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 59) * M(59, 102)
      temp = temp + M(61, 60) * M(60, 102)
      M(61, 102) = ( M(61, 102) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 59) * M(59, 105)
      temp = temp + M(61, 60) * M(60, 105)
      M(61, 105) = ( M(61, 105) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 20) * M(20, 109)
      temp = temp + M(61, 26) * M(26, 109)
      temp = temp + M(61, 27) * M(27, 109)
      temp = temp + M(61, 59) * M(59, 109)
      temp = temp + M(61, 60) * M(60, 109)
      M(61, 109) = ( M(61, 109) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 25) * M(25, 111)
      temp = temp + M(61, 59) * M(59, 111)
      temp = temp + M(61, 60) * M(60, 111)
      M(61, 111) = ( M(61, 111) - temp ) / M(61, 61)
C     Upper part.
      temp = M(61, 20) * M(20, 112)
      temp = temp + M(61, 25) * M(25, 112)
      temp = temp + M(61, 26) * M(26, 112)
      temp = temp + M(61, 27) * M(27, 112)
      temp = temp + M(61, 59) * M(59, 112)
      temp = temp + M(61, 60) * M(60, 112)
      M(61, 112) = ( M(61, 112) - temp ) / M(61, 61)

C     Upper part.
      M(62, 100) = M(62, 100) / M(62, 62)
C     Upper part.
      M(62, 102) = M(62, 102) / M(62, 62)
C     Upper part.
      M(62, 105) = M(62, 105) / M(62, 62)
C     Upper part.
      M(62, 109) = M(62, 109) / M(62, 62)
C     Upper part.
      M(62, 111) = M(62, 111) / M(62, 62)
C     Upper part.
      temp = M(62, 8) * M(8, 112)
      M(62, 112) = ( M(62, 112) - temp ) / M(62, 62)

C     Upper part.
      M(63, 100) = M(63, 100) / M(63, 63)
C     Upper part.
      M(63, 102) = M(63, 102) / M(63, 63)
C     Upper part.
      M(63, 105) = M(63, 105) / M(63, 63)
C     Upper part.
      M(63, 109) = M(63, 109) / M(63, 63)
C     Upper part.
      M(63, 111) = M(63, 111) / M(63, 63)
C     Upper part.
      temp = M(63, 5) * M(5, 112)
      M(63, 112) = ( M(63, 112) - temp ) / M(63, 63)

C     Upper part.
      temp = M(64, 30) * M(30, 86)
      M(64, 86) = ( M(64, 86) - temp ) / M(64, 64)
C     Upper part.
      M(64, 100) = M(64, 100) / M(64, 64)
C     Upper part.
      temp = M(64, 30) * M(30, 102)
      M(64, 102) = ( M(64, 102) - temp ) / M(64, 64)
C     Upper part.
      M(64, 105) = M(64, 105) / M(64, 64)
C     Upper part.
      M(64, 109) = M(64, 109) / M(64, 64)
C     Upper part.
      M(64, 111) = M(64, 111) / M(64, 64)
C     Upper part.
      temp = M(64, 30) * M(30, 112)
      M(64, 112) = ( M(64, 112) - temp ) / M(64, 64)

C     Upper part.
      temp = M(65, 58) * M(58, 81)
      temp = temp + M(65, 60) * M(60, 81)
      M(65, 81) = ( M(65, 81) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 58) * M(58, 86)
      M(65, 86) = ( M(65, 86) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 58) * M(58, 99)
      M(65, 99) = ( M(65, 99) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 58) * M(58, 100)
      temp = temp + M(65, 60) * M(60, 100)
      M(65, 100) = ( M(65, 100) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 58) * M(58, 102)
      temp = temp + M(65, 60) * M(60, 102)
      M(65, 102) = ( M(65, 102) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 58) * M(58, 105)
      temp = temp + M(65, 60) * M(60, 105)
      M(65, 105) = ( M(65, 105) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 58) * M(58, 109)
      temp = temp + M(65, 60) * M(60, 109)
      M(65, 109) = ( M(65, 109) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 58) * M(58, 111)
      temp = temp + M(65, 60) * M(60, 111)
      M(65, 111) = ( M(65, 111) - temp ) / M(65, 65)
C     Upper part.
      temp = M(65, 58) * M(58, 112)
      temp = temp + M(65, 60) * M(60, 112)
      M(65, 112) = ( M(65, 112) - temp ) / M(65, 65)

C     Upper part.
      temp = M(66, 26) * M(26, 81)
      temp = temp + M(66, 59) * M(59, 81)
      M(66, 81) = ( M(66, 81) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 59) * M(59, 100)
      M(66, 100) = ( M(66, 100) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 59) * M(59, 102)
      M(66, 102) = ( M(66, 102) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 59) * M(59, 105)
      M(66, 105) = ( M(66, 105) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 26) * M(26, 109)
      temp = temp + M(66, 59) * M(59, 109)
      M(66, 109) = ( M(66, 109) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 59) * M(59, 111)
      M(66, 111) = ( M(66, 111) - temp ) / M(66, 66)
C     Upper part.
      temp = M(66, 26) * M(26, 112)
      temp = temp + M(66, 59) * M(59, 112)
      M(66, 112) = ( M(66, 112) - temp ) / M(66, 66)

C     Upper part.
      M(67, 78) = M(67, 78) / M(67, 67)
C     Upper part.
      M(67, 80) = M(67, 80) / M(67, 67)
C     Upper part.
      temp = M(67, 20) * M(20, 81)
      temp = temp + M(67, 23) * M(23, 81)
      temp = temp + M(67, 26) * M(26, 81)
      temp = temp + M(67, 27) * M(27, 81)
      temp = temp + M(67, 31) * M(31, 81)
      temp = temp + M(67, 57) * M(57, 81)
      temp = temp + M(67, 61) * M(61, 81)
      temp = temp + M(67, 66) * M(66, 81)
      M(67, 81) = ( M(67, 81) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 57) * M(57, 100)
      temp = temp + M(67, 61) * M(61, 100)
      temp = temp + M(67, 66) * M(66, 100)
      M(67, 100) = ( M(67, 100) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 57) * M(57, 102)
      temp = temp + M(67, 61) * M(61, 102)
      temp = temp + M(67, 66) * M(66, 102)
      M(67, 102) = ( M(67, 102) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 57) * M(57, 105)
      temp = temp + M(67, 61) * M(61, 105)
      temp = temp + M(67, 66) * M(66, 105)
      M(67, 105) = ( M(67, 105) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 20) * M(20, 109)
      temp = temp + M(67, 23) * M(23, 109)
      temp = temp + M(67, 26) * M(26, 109)
      temp = temp + M(67, 27) * M(27, 109)
      temp = temp + M(67, 31) * M(31, 109)
      temp = temp + M(67, 57) * M(57, 109)
      temp = temp + M(67, 61) * M(61, 109)
      temp = temp + M(67, 66) * M(66, 109)
      M(67, 109) = ( M(67, 109) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 57) * M(57, 111)
      temp = temp + M(67, 61) * M(61, 111)
      temp = temp + M(67, 66) * M(66, 111)
      M(67, 111) = ( M(67, 111) - temp ) / M(67, 67)
C     Upper part.
      temp = M(67, 4) * M(4, 112)
      temp = temp + M(67, 20) * M(20, 112)
      temp = temp + M(67, 23) * M(23, 112)
      temp = temp + M(67, 26) * M(26, 112)
      temp = temp + M(67, 27) * M(27, 112)
      temp = temp + M(67, 31) * M(31, 112)
      temp = temp + M(67, 57) * M(57, 112)
      temp = temp + M(67, 61) * M(61, 112)
      temp = temp + M(67, 66) * M(66, 112)
      M(67, 112) = ( M(67, 112) - temp ) / M(67, 67)

C     Upper part.
      temp = M(68, 66) * M(66, 81)
      M(68, 81) = ( M(68, 81) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 66) * M(66, 100)
      M(68, 100) = ( M(68, 100) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 66) * M(66, 102)
      M(68, 102) = ( M(68, 102) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 66) * M(66, 105)
      M(68, 105) = ( M(68, 105) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 66) * M(66, 109)
      M(68, 109) = ( M(68, 109) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 66) * M(66, 111)
      M(68, 111) = ( M(68, 111) - temp ) / M(68, 68)
C     Upper part.
      temp = M(68, 66) * M(66, 112)
      M(68, 112) = ( M(68, 112) - temp ) / M(68, 68)

C     Lower part.
      temp = M(100, 32) * M(32, 69)
      M(100, 69) = M(100, 69) - temp
C     Lower part.
      temp = M(104, 33) * M(33, 69)
      M(104, 69) = M(104, 69) - temp
C     Lower part.
      temp = M(111, 38) * M(38, 69)
      M(111, 69) = M(111, 69) - temp
C     Lower part.
      temp = M(112, 32) * M(32, 69)
      temp = temp + M(112, 33) * M(33, 69)
      temp = temp + M(112, 38) * M(38, 69)
      M(112, 69) = M(112, 69) - temp
C     Upper part.
      temp = M(69, 60) * M(60, 81)
      M(69, 81) = ( M(69, 81) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 60) * M(60, 100)
      temp = temp + M(69, 63) * M(63, 100)
      M(69, 100) = ( M(69, 100) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 60) * M(60, 102)
      temp = temp + M(69, 63) * M(63, 102)
      M(69, 102) = ( M(69, 102) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 60) * M(60, 105)
      temp = temp + M(69, 63) * M(63, 105)
      M(69, 105) = ( M(69, 105) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 60) * M(60, 109)
      temp = temp + M(69, 63) * M(63, 109)
      M(69, 109) = ( M(69, 109) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 60) * M(60, 111)
      temp = temp + M(69, 63) * M(63, 111)
      M(69, 111) = ( M(69, 111) - temp ) / M(69, 69)
C     Upper part.
      temp = M(69, 60) * M(60, 112)
      temp = temp + M(69, 63) * M(63, 112)
      M(69, 112) = ( M(69, 112) - temp ) / M(69, 69)

C     Upper part.
      M(70, 71) = M(70, 71) / M(70, 70)
C     Upper part.
      temp = M(70, 19) * M(19, 81)
      temp = temp + M(70, 20) * M(20, 81)
      temp = temp + M(70, 23) * M(23, 81)
      temp = temp + M(70, 27) * M(27, 81)
      temp = temp + M(70, 31) * M(31, 81)
      temp = temp + M(70, 69) * M(69, 81)
      M(70, 81) = ( M(70, 81) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 69) * M(69, 100)
      M(70, 100) = ( M(70, 100) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 69) * M(69, 102)
      M(70, 102) = ( M(70, 102) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 69) * M(69, 105)
      M(70, 105) = ( M(70, 105) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 19) * M(19, 109)
      temp = temp + M(70, 20) * M(20, 109)
      temp = temp + M(70, 23) * M(23, 109)
      temp = temp + M(70, 27) * M(27, 109)
      temp = temp + M(70, 31) * M(31, 109)
      temp = temp + M(70, 69) * M(69, 109)
      M(70, 109) = ( M(70, 109) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 69) * M(69, 111)
      M(70, 111) = ( M(70, 111) - temp ) / M(70, 70)
C     Upper part.
      temp = M(70, 19) * M(19, 112)
      temp = temp + M(70, 20) * M(20, 112)
      temp = temp + M(70, 23) * M(23, 112)
      temp = temp + M(70, 27) * M(27, 112)
      temp = temp + M(70, 31) * M(31, 112)
      temp = temp + M(70, 69) * M(69, 112)
      M(70, 112) = ( M(70, 112) - temp ) / M(70, 70)

C     Lower part.
      temp = M(71, 70) * M(70, 71)
      M(71, 71) = M(71, 71) - temp
C     Lower part.
      temp = M(85, 70) * M(70, 71)
      M(85, 71) = M(85, 71) - temp
C     Lower part.
      temp = M(89, 70) * M(70, 71)
      M(89, 71) = M(89, 71) - temp
C     Lower part.
      temp = M(97, 70) * M(70, 71)
      M(97, 71) = M(97, 71) - temp
C     Lower part.
      temp = M(100, 70) * M(70, 71)
      M(100, 71) = M(100, 71) - temp
C     Lower part.
      temp = M(102, 70) * M(70, 71)
      M(102, 71) = M(102, 71) - temp
C     Lower part.
      temp = M(103, 70) * M(70, 71)
      M(103, 71) = M(103, 71) - temp
C     Lower part.
      temp = M(105, 70) * M(70, 71)
      M(105, 71) = M(105, 71) - temp
C     Lower part.
      temp = M(107, 70) * M(70, 71)
      M(107, 71) = M(107, 71) - temp
C     Lower part.
      temp = M(108, 70) * M(70, 71)
      M(108, 71) = M(108, 71) - temp
C     Lower part.
      temp = M(109, 70) * M(70, 71)
      M(109, 71) = M(109, 71) - temp
C     Lower part.
      temp = M(110, 70) * M(70, 71)
      M(110, 71) = M(110, 71) - temp
C     Lower part.
      temp = M(111, 70) * M(70, 71)
      M(111, 71) = M(111, 71) - temp
C     Lower part.
      temp = M(113, 70) * M(70, 71)
      M(113, 71) = M(113, 71) - temp
C     Upper part.
      temp = M(71, 19) * M(19, 81)
      temp = temp + M(71, 20) * M(20, 81)
      temp = temp + M(71, 23) * M(23, 81)
      temp = temp + M(71, 27) * M(27, 81)
      temp = temp + M(71, 31) * M(31, 81)
      temp = temp + M(71, 69) * M(69, 81)
      temp = temp + M(71, 70) * M(70, 81)
      M(71, 81) = ( M(71, 81) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 100)
      temp = temp + M(71, 70) * M(70, 100)
      M(71, 100) = ( M(71, 100) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 102)
      temp = temp + M(71, 70) * M(70, 102)
      M(71, 102) = ( M(71, 102) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 105)
      temp = temp + M(71, 70) * M(70, 105)
      M(71, 105) = ( M(71, 105) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 19) * M(19, 109)
      temp = temp + M(71, 20) * M(20, 109)
      temp = temp + M(71, 23) * M(23, 109)
      temp = temp + M(71, 27) * M(27, 109)
      temp = temp + M(71, 31) * M(31, 109)
      temp = temp + M(71, 69) * M(69, 109)
      temp = temp + M(71, 70) * M(70, 109)
      M(71, 109) = ( M(71, 109) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 69) * M(69, 111)
      temp = temp + M(71, 70) * M(70, 111)
      M(71, 111) = ( M(71, 111) - temp ) / M(71, 71)
C     Upper part.
      temp = M(71, 19) * M(19, 112)
      temp = temp + M(71, 20) * M(20, 112)
      temp = temp + M(71, 23) * M(23, 112)
      temp = temp + M(71, 27) * M(27, 112)
      temp = temp + M(71, 31) * M(31, 112)
      temp = temp + M(71, 69) * M(69, 112)
      temp = temp + M(71, 70) * M(70, 112)
      M(71, 112) = ( M(71, 112) - temp ) / M(71, 71)

C     Upper part.
      temp = M(72, 31) * M(31, 81)
      M(72, 81) = ( M(72, 81) - temp ) / M(72, 72)
C     Upper part.
      M(72, 100) = M(72, 100) / M(72, 72)
C     Upper part.
      M(72, 102) = M(72, 102) / M(72, 72)
C     Upper part.
      M(72, 105) = M(72, 105) / M(72, 72)
C     Upper part.
      temp = M(72, 31) * M(31, 109)
      M(72, 109) = ( M(72, 109) - temp ) / M(72, 72)
C     Upper part.
      M(72, 111) = M(72, 111) / M(72, 72)
C     Upper part.
      temp = M(72, 31) * M(31, 112)
      M(72, 112) = ( M(72, 112) - temp ) / M(72, 72)

C     Upper part.
      temp = M(73, 39) * M(39, 81)
      temp = temp + M(73, 59) * M(59, 81)
      M(73, 81) = ( M(73, 81) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 40) * M(40, 95)
      M(73, 95) = ( M(73, 95) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 59) * M(59, 100)
      M(73, 100) = ( M(73, 100) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 39) * M(39, 102)
      temp = temp + M(73, 59) * M(59, 102)
      M(73, 102) = ( M(73, 102) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 59) * M(59, 105)
      M(73, 105) = ( M(73, 105) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 39) * M(39, 109)
      temp = temp + M(73, 40) * M(40, 109)
      temp = temp + M(73, 59) * M(59, 109)
      M(73, 109) = ( M(73, 109) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 40) * M(40, 110)
      M(73, 110) = ( M(73, 110) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 59) * M(59, 111)
      M(73, 111) = ( M(73, 111) - temp ) / M(73, 73)
C     Upper part.
      temp = M(73, 39) * M(39, 112)
      temp = temp + M(73, 40) * M(40, 112)
      temp = temp + M(73, 59) * M(59, 112)
      M(73, 112) = ( M(73, 112) - temp ) / M(73, 73)

C     Upper part.
      M(74, 78) = M(74, 78) / M(74, 74)
C     Upper part.
      M(74, 81) = M(74, 81) / M(74, 74)
C     Upper part.
      M(74, 98) = M(74, 98) / M(74, 74)
C     Upper part.
      M(74, 105) = M(74, 105) / M(74, 74)
C     Upper part.
      M(74, 111) = M(74, 111) / M(74, 74)
C     Upper part.
      M(74, 112) = M(74, 112) / M(74, 74)

C     Upper part.
      temp = M(75, 47) * M(47, 100)
      temp = temp + M(75, 48) * M(48, 100)
      temp = temp + M(75, 53) * M(53, 100)
      temp = temp + M(75, 55) * M(55, 100)
      M(75, 100) = ( M(75, 100) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 47) * M(47, 102)
      temp = temp + M(75, 48) * M(48, 102)
      temp = temp + M(75, 53) * M(53, 102)
      temp = temp + M(75, 55) * M(55, 102)
      M(75, 102) = ( M(75, 102) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 47) * M(47, 105)
      temp = temp + M(75, 48) * M(48, 105)
      temp = temp + M(75, 53) * M(53, 105)
      temp = temp + M(75, 55) * M(55, 105)
      M(75, 105) = ( M(75, 105) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 18) * M(18, 109)
      temp = temp + M(75, 47) * M(47, 109)
      temp = temp + M(75, 48) * M(48, 109)
      temp = temp + M(75, 53) * M(53, 109)
      temp = temp + M(75, 55) * M(55, 109)
      M(75, 109) = ( M(75, 109) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 48) * M(48, 110)
      M(75, 110) = ( M(75, 110) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 47) * M(47, 111)
      temp = temp + M(75, 48) * M(48, 111)
      temp = temp + M(75, 55) * M(55, 111)
      M(75, 111) = ( M(75, 111) - temp ) / M(75, 75)
C     Upper part.
      temp = M(75, 18) * M(18, 112)
      temp = temp + M(75, 47) * M(47, 112)
      temp = temp + M(75, 48) * M(48, 112)
      temp = temp + M(75, 53) * M(53, 112)
      temp = temp + M(75, 55) * M(55, 112)
      M(75, 112) = ( M(75, 112) - temp ) / M(75, 75)

C     Upper part.
      temp = M(76, 75) * M(75, 100)
      M(76, 100) = ( M(76, 100) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 75) * M(75, 102)
      M(76, 102) = ( M(76, 102) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 75) * M(75, 105)
      M(76, 105) = ( M(76, 105) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 75) * M(75, 109)
      M(76, 109) = ( M(76, 109) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 75) * M(75, 110)
      M(76, 110) = ( M(76, 110) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 75) * M(75, 111)
      M(76, 111) = ( M(76, 111) - temp ) / M(76, 76)
C     Upper part.
      temp = M(76, 8) * M(8, 112)
      temp = temp + M(76, 75) * M(75, 112)
      M(76, 112) = ( M(76, 112) - temp ) / M(76, 76)

C     Upper part.
      temp = M(77, 64) * M(64, 86)
      M(77, 86) = ( M(77, 86) - temp ) / M(77, 77)
C     Upper part.
      M(77, 92) = M(77, 92) / M(77, 77)
C     Upper part.
      temp = M(77, 42) * M(42, 100)
      temp = temp + M(77, 49) * M(49, 100)
      temp = temp + M(77, 55) * M(55, 100)
      temp = temp + M(77, 64) * M(64, 100)
      M(77, 100) = ( M(77, 100) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 42) * M(42, 102)
      temp = temp + M(77, 49) * M(49, 102)
      temp = temp + M(77, 55) * M(55, 102)
      temp = temp + M(77, 64) * M(64, 102)
      M(77, 102) = ( M(77, 102) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 42) * M(42, 105)
      temp = temp + M(77, 49) * M(49, 105)
      temp = temp + M(77, 55) * M(55, 105)
      temp = temp + M(77, 64) * M(64, 105)
      M(77, 105) = ( M(77, 105) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 42) * M(42, 109)
      temp = temp + M(77, 49) * M(49, 109)
      temp = temp + M(77, 55) * M(55, 109)
      temp = temp + M(77, 64) * M(64, 109)
      M(77, 109) = ( M(77, 109) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 55) * M(55, 111)
      temp = temp + M(77, 64) * M(64, 111)
      M(77, 111) = ( M(77, 111) - temp ) / M(77, 77)
C     Upper part.
      temp = M(77, 42) * M(42, 112)
      temp = temp + M(77, 49) * M(49, 112)
      temp = temp + M(77, 55) * M(55, 112)
      temp = temp + M(77, 64) * M(64, 112)
      M(77, 112) = ( M(77, 112) - temp ) / M(77, 77)

C     Lower part.
      temp = M(100, 74) * M(74, 78)
      M(100, 78) = M(100, 78) - temp
C     Lower part.
      temp = M(101, 74) * M(74, 78)
      M(101, 78) = M(101, 78) - temp
C     Lower part.
      temp = M(105, 74) * M(74, 78)
      M(105, 78) = M(105, 78) - temp
C     Lower part.
      temp = M(108, 74) * M(74, 78)
      M(108, 78) = M(108, 78) - temp
C     Lower part.
      temp = M(111, 67) * M(67, 78)
      M(111, 78) = M(111, 78) - temp
C     Lower part.
      temp = M(112, 67) * M(67, 78)
      temp = temp + M(112, 74) * M(74, 78)
      M(112, 78) = M(112, 78) - temp
C     Upper part.
      M(78, 81) = M(78, 81) / M(78, 78)
C     Upper part.
      temp = M(78, 49) * M(49, 100)
      temp = temp + M(78, 55) * M(55, 100)
      M(78, 100) = ( M(78, 100) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 49) * M(49, 102)
      temp = temp + M(78, 55) * M(55, 102)
      M(78, 102) = ( M(78, 102) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 49) * M(49, 105)
      temp = temp + M(78, 55) * M(55, 105)
      M(78, 105) = ( M(78, 105) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 49) * M(49, 109)
      temp = temp + M(78, 55) * M(55, 109)
      M(78, 109) = ( M(78, 109) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 55) * M(55, 111)
      M(78, 111) = ( M(78, 111) - temp ) / M(78, 78)
C     Upper part.
      temp = M(78, 49) * M(49, 112)
      temp = temp + M(78, 55) * M(55, 112)
      M(78, 112) = ( M(78, 112) - temp ) / M(78, 78)

C     Upper part.
      temp = M(79, 20) * M(20, 81)
      temp = temp + M(79, 69) * M(69, 81)
      temp = temp + M(79, 78) * M(78, 81)
      M(79, 81) = ( M(79, 81) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 69) * M(69, 100)
      temp = temp + M(79, 78) * M(78, 100)
      M(79, 100) = ( M(79, 100) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 69) * M(69, 102)
      temp = temp + M(79, 78) * M(78, 102)
      M(79, 102) = ( M(79, 102) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 69) * M(69, 105)
      temp = temp + M(79, 78) * M(78, 105)
      M(79, 105) = ( M(79, 105) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 20) * M(20, 109)
      temp = temp + M(79, 69) * M(69, 109)
      temp = temp + M(79, 78) * M(78, 109)
      M(79, 109) = ( M(79, 109) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 69) * M(69, 111)
      temp = temp + M(79, 78) * M(78, 111)
      M(79, 111) = ( M(79, 111) - temp ) / M(79, 79)
C     Upper part.
      temp = M(79, 20) * M(20, 112)
      temp = temp + M(79, 69) * M(69, 112)
      temp = temp + M(79, 78) * M(78, 112)
      M(79, 112) = ( M(79, 112) - temp ) / M(79, 79)

C     Lower part.
      temp = M(111, 67) * M(67, 80)
      M(111, 80) = M(111, 80) - temp
C     Lower part.
      temp = M(112, 67) * M(67, 80)
      M(112, 80) = M(112, 80) - temp
C     Upper part.
      temp = M(80, 66) * M(66, 81)
      M(80, 81) = ( M(80, 81) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 63) * M(63, 100)
      temp = temp + M(80, 66) * M(66, 100)
      M(80, 100) = ( M(80, 100) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 63) * M(63, 102)
      temp = temp + M(80, 66) * M(66, 102)
      M(80, 102) = ( M(80, 102) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 63) * M(63, 105)
      temp = temp + M(80, 66) * M(66, 105)
      M(80, 105) = ( M(80, 105) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 63) * M(63, 109)
      temp = temp + M(80, 66) * M(66, 109)
      M(80, 109) = ( M(80, 109) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 63) * M(63, 111)
      temp = temp + M(80, 66) * M(66, 111)
      M(80, 111) = ( M(80, 111) - temp ) / M(80, 80)
C     Upper part.
      temp = M(80, 5) * M(5, 112)
      temp = temp + M(80, 63) * M(63, 112)
      temp = temp + M(80, 66) * M(66, 112)
      M(80, 112) = ( M(80, 112) - temp ) / M(80, 80)

C     Lower part.
      temp = M(81, 19) * M(19, 81)
      temp = temp + M(81, 20) * M(20, 81)
      temp = temp + M(81, 22) * M(22, 81)
      temp = temp + M(81, 23) * M(23, 81)
      temp = temp + M(81, 26) * M(26, 81)
      temp = temp + M(81, 27) * M(27, 81)
      temp = temp + M(81, 31) * M(31, 81)
      temp = temp + M(81, 44) * M(44, 81)
      temp = temp + M(81, 61) * M(61, 81)
      temp = temp + M(81, 66) * M(66, 81)
      temp = temp + M(81, 69) * M(69, 81)
      temp = temp + M(81, 78) * M(78, 81)
      temp = temp + M(81, 80) * M(80, 81)
      M(81, 81) = M(81, 81) - temp
C     Lower part.
      temp = M(84, 80) * M(80, 81)
      M(84, 81) = M(84, 81) - temp
C     Lower part.
      temp = M(85, 57) * M(57, 81)
      temp = temp + M(85, 59) * M(59, 81)
      temp = temp + M(85, 60) * M(60, 81)
      temp = temp + M(85, 65) * M(65, 81)
      temp = temp + M(85, 68) * M(68, 81)
      temp = temp + M(85, 70) * M(70, 81)
      temp = temp + M(85, 71) * M(71, 81)
      temp = temp + M(85, 72) * M(72, 81)
      temp = temp + M(85, 79) * M(79, 81)
      M(85, 81) = M(85, 81) - temp
C     Lower part.
      temp = M(88, 23) * M(23, 81)
      M(88, 81) = M(88, 81) - temp
C     Lower part.
      temp = M(89, 57) * M(57, 81)
      temp = temp + M(89, 59) * M(59, 81)
      temp = temp + M(89, 60) * M(60, 81)
      temp = temp + M(89, 65) * M(65, 81)
      temp = temp + M(89, 68) * M(68, 81)
      temp = temp + M(89, 70) * M(70, 81)
      temp = temp + M(89, 71) * M(71, 81)
      temp = temp + M(89, 72) * M(72, 81)
      temp = temp + M(89, 79) * M(79, 81)
      M(89, 81) = M(89, 81) - temp
C     Lower part.
      temp = M(91, 22) * M(22, 81)
      temp = temp + M(91, 80) * M(80, 81)
      M(91, 81) = M(91, 81) - temp
C     Lower part.
      temp = M(92, 19) * M(19, 81)
      temp = temp + M(92, 20) * M(20, 81)
      temp = temp + M(92, 27) * M(27, 81)
      temp = temp + M(92, 31) * M(31, 81)
      temp = temp + M(92, 69) * M(69, 81)
      M(92, 81) = M(92, 81) - temp
C     Lower part.
      temp = M(93, 61) * M(61, 81)
      temp = temp + M(93, 66) * M(66, 81)
      temp = temp + M(93, 68) * M(68, 81)
      temp = temp + M(93, 73) * M(73, 81)
      temp = temp + M(93, 78) * M(78, 81)
      temp = temp + M(93, 80) * M(80, 81)
      M(93, 81) = M(93, 81) - temp
C     Lower part.
      temp = M(94, 22) * M(22, 81)
      temp = temp + M(94, 61) * M(61, 81)
      M(94, 81) = M(94, 81) - temp
C     Lower part.
      temp = M(95, 26) * M(26, 81)
      temp = temp + M(95, 61) * M(61, 81)
      temp = temp + M(95, 66) * M(66, 81)
      M(95, 81) = M(95, 81) - temp
C     Lower part.
      temp = M(96, 19) * M(19, 81)
      temp = temp + M(96, 20) * M(20, 81)
      temp = temp + M(96, 22) * M(22, 81)
      temp = temp + M(96, 23) * M(23, 81)
      temp = temp + M(96, 26) * M(26, 81)
      temp = temp + M(96, 27) * M(27, 81)
      temp = temp + M(96, 31) * M(31, 81)
      temp = temp + M(96, 39) * M(39, 81)
      temp = temp + M(96, 59) * M(59, 81)
      temp = temp + M(96, 61) * M(61, 81)
      temp = temp + M(96, 66) * M(66, 81)
      temp = temp + M(96, 69) * M(69, 81)
      temp = temp + M(96, 78) * M(78, 81)
      temp = temp + M(96, 80) * M(80, 81)
      M(96, 81) = M(96, 81) - temp
C     Lower part.
      temp = M(97, 27) * M(27, 81)
      temp = temp + M(97, 31) * M(31, 81)
      temp = temp + M(97, 57) * M(57, 81)
      temp = temp + M(97, 59) * M(59, 81)
      temp = temp + M(97, 60) * M(60, 81)
      temp = temp + M(97, 65) * M(65, 81)
      temp = temp + M(97, 68) * M(68, 81)
      temp = temp + M(97, 69) * M(69, 81)
      temp = temp + M(97, 70) * M(70, 81)
      temp = temp + M(97, 71) * M(71, 81)
      temp = temp + M(97, 72) * M(72, 81)
      temp = temp + M(97, 78) * M(78, 81)
      temp = temp + M(97, 79) * M(79, 81)
      M(97, 81) = M(97, 81) - temp
C     Lower part.
      temp = M(100, 20) * M(20, 81)
      temp = temp + M(100, 26) * M(26, 81)
      temp = temp + M(100, 31) * M(31, 81)
      temp = temp + M(100, 32) * M(32, 81)
      temp = temp + M(100, 57) * M(57, 81)
      temp = temp + M(100, 58) * M(58, 81)
      temp = temp + M(100, 59) * M(59, 81)
      temp = temp + M(100, 60) * M(60, 81)
      temp = temp + M(100, 65) * M(65, 81)
      temp = temp + M(100, 66) * M(66, 81)
      temp = temp + M(100, 68) * M(68, 81)
      temp = temp + M(100, 69) * M(69, 81)
      temp = temp + M(100, 70) * M(70, 81)
      temp = temp + M(100, 71) * M(71, 81)
      temp = temp + M(100, 72) * M(72, 81)
      temp = temp + M(100, 74) * M(74, 81)
      temp = temp + M(100, 78) * M(78, 81)
      temp = temp + M(100, 79) * M(79, 81)
      temp = temp + M(100, 80) * M(80, 81)
      M(100, 81) = M(100, 81) - temp
C     Lower part.
      temp = M(101, 20) * M(20, 81)
      temp = temp + M(101, 22) * M(22, 81)
      temp = temp + M(101, 61) * M(61, 81)
      temp = temp + M(101, 66) * M(66, 81)
      temp = temp + M(101, 68) * M(68, 81)
      temp = temp + M(101, 74) * M(74, 81)
      temp = temp + M(101, 78) * M(78, 81)
      temp = temp + M(101, 80) * M(80, 81)
      M(101, 81) = M(101, 81) - temp
C     Lower part.
      temp = M(102, 44) * M(44, 81)
      temp = temp + M(102, 57) * M(57, 81)
      temp = temp + M(102, 59) * M(59, 81)
      temp = temp + M(102, 60) * M(60, 81)
      temp = temp + M(102, 65) * M(65, 81)
      temp = temp + M(102, 68) * M(68, 81)
      temp = temp + M(102, 70) * M(70, 81)
      temp = temp + M(102, 71) * M(71, 81)
      temp = temp + M(102, 72) * M(72, 81)
      temp = temp + M(102, 79) * M(79, 81)
      M(102, 81) = M(102, 81) - temp
C     Lower part.
      temp = M(103, 19) * M(19, 81)
      temp = temp + M(103, 31) * M(31, 81)
      temp = temp + M(103, 57) * M(57, 81)
      temp = temp + M(103, 60) * M(60, 81)
      temp = temp + M(103, 69) * M(69, 81)
      temp = temp + M(103, 70) * M(70, 81)
      temp = temp + M(103, 71) * M(71, 81)
      temp = temp + M(103, 72) * M(72, 81)
      temp = temp + M(103, 79) * M(79, 81)
      temp = temp + M(103, 80) * M(80, 81)
      M(103, 81) = M(103, 81) - temp
C     Lower part.
      temp = M(104, 19) * M(19, 81)
      temp = temp + M(104, 27) * M(27, 81)
      temp = temp + M(104, 31) * M(31, 81)
      temp = temp + M(104, 33) * M(33, 81)
      temp = temp + M(104, 69) * M(69, 81)
      M(104, 81) = M(104, 81) - temp
C     Lower part.
      temp = M(105, 20) * M(20, 81)
      temp = temp + M(105, 26) * M(26, 81)
      temp = temp + M(105, 57) * M(57, 81)
      temp = temp + M(105, 58) * M(58, 81)
      temp = temp + M(105, 59) * M(59, 81)
      temp = temp + M(105, 60) * M(60, 81)
      temp = temp + M(105, 61) * M(61, 81)
      temp = temp + M(105, 65) * M(65, 81)
      temp = temp + M(105, 66) * M(66, 81)
      temp = temp + M(105, 68) * M(68, 81)
      temp = temp + M(105, 70) * M(70, 81)
      temp = temp + M(105, 71) * M(71, 81)
      temp = temp + M(105, 72) * M(72, 81)
      temp = temp + M(105, 74) * M(74, 81)
      temp = temp + M(105, 78) * M(78, 81)
      temp = temp + M(105, 79) * M(79, 81)
      temp = temp + M(105, 80) * M(80, 81)
      M(105, 81) = M(105, 81) - temp
C     Lower part.
      temp = M(106, 57) * M(57, 81)
      temp = temp + M(106, 60) * M(60, 81)
      temp = temp + M(106, 65) * M(65, 81)
      temp = temp + M(106, 68) * M(68, 81)
      temp = temp + M(106, 72) * M(72, 81)
      temp = temp + M(106, 79) * M(79, 81)
      M(106, 81) = M(106, 81) - temp
C     Lower part.
      temp = M(107, 19) * M(19, 81)
      temp = temp + M(107, 22) * M(22, 81)
      temp = temp + M(107, 31) * M(31, 81)
      temp = temp + M(107, 57) * M(57, 81)
      temp = temp + M(107, 68) * M(68, 81)
      temp = temp + M(107, 69) * M(69, 81)
      temp = temp + M(107, 70) * M(70, 81)
      temp = temp + M(107, 71) * M(71, 81)
      temp = temp + M(107, 72) * M(72, 81)
      temp = temp + M(107, 79) * M(79, 81)
      temp = temp + M(107, 80) * M(80, 81)
      M(107, 81) = M(107, 81) - temp
C     Lower part.
      temp = M(108, 20) * M(20, 81)
      temp = temp + M(108, 23) * M(23, 81)
      temp = temp + M(108, 26) * M(26, 81)
      temp = temp + M(108, 27) * M(27, 81)
      temp = temp + M(108, 31) * M(31, 81)
      temp = temp + M(108, 39) * M(39, 81)
      temp = temp + M(108, 57) * M(57, 81)
      temp = temp + M(108, 59) * M(59, 81)
      temp = temp + M(108, 60) * M(60, 81)
      temp = temp + M(108, 61) * M(61, 81)
      temp = temp + M(108, 65) * M(65, 81)
      temp = temp + M(108, 66) * M(66, 81)
      temp = temp + M(108, 68) * M(68, 81)
      temp = temp + M(108, 69) * M(69, 81)
      temp = temp + M(108, 70) * M(70, 81)
      temp = temp + M(108, 71) * M(71, 81)
      temp = temp + M(108, 72) * M(72, 81)
      temp = temp + M(108, 74) * M(74, 81)
      temp = temp + M(108, 78) * M(78, 81)
      temp = temp + M(108, 79) * M(79, 81)
      temp = temp + M(108, 80) * M(80, 81)
      M(108, 81) = M(108, 81) - temp
C     Lower part.
      temp = M(109, 19) * M(19, 81)
      temp = temp + M(109, 20) * M(20, 81)
      temp = temp + M(109, 22) * M(22, 81)
      temp = temp + M(109, 23) * M(23, 81)
      temp = temp + M(109, 26) * M(26, 81)
      temp = temp + M(109, 27) * M(27, 81)
      temp = temp + M(109, 31) * M(31, 81)
      temp = temp + M(109, 44) * M(44, 81)
      temp = temp + M(109, 57) * M(57, 81)
      temp = temp + M(109, 59) * M(59, 81)
      temp = temp + M(109, 60) * M(60, 81)
      temp = temp + M(109, 61) * M(61, 81)
      temp = temp + M(109, 65) * M(65, 81)
      temp = temp + M(109, 68) * M(68, 81)
      temp = temp + M(109, 69) * M(69, 81)
      temp = temp + M(109, 70) * M(70, 81)
      temp = temp + M(109, 71) * M(71, 81)
      temp = temp + M(109, 72) * M(72, 81)
      temp = temp + M(109, 79) * M(79, 81)
      temp = temp + M(109, 80) * M(80, 81)
      M(109, 81) = M(109, 81) - temp
C     Lower part.
      temp = M(110, 22) * M(22, 81)
      temp = temp + M(110, 39) * M(39, 81)
      temp = temp + M(110, 44) * M(44, 81)
      temp = temp + M(110, 57) * M(57, 81)
      temp = temp + M(110, 59) * M(59, 81)
      temp = temp + M(110, 60) * M(60, 81)
      temp = temp + M(110, 65) * M(65, 81)
      temp = temp + M(110, 68) * M(68, 81)
      temp = temp + M(110, 70) * M(70, 81)
      temp = temp + M(110, 71) * M(71, 81)
      temp = temp + M(110, 72) * M(72, 81)
      temp = temp + M(110, 79) * M(79, 81)
      M(110, 81) = M(110, 81) - temp
C     Lower part.
      temp = M(111, 19) * M(19, 81)
      temp = temp + M(111, 20) * M(20, 81)
      temp = temp + M(111, 22) * M(22, 81)
      temp = temp + M(111, 23) * M(23, 81)
      temp = temp + M(111, 26) * M(26, 81)
      temp = temp + M(111, 27) * M(27, 81)
      temp = temp + M(111, 31) * M(31, 81)
      temp = temp + M(111, 38) * M(38, 81)
      temp = temp + M(111, 57) * M(57, 81)
      temp = temp + M(111, 59) * M(59, 81)
      temp = temp + M(111, 60) * M(60, 81)
      temp = temp + M(111, 61) * M(61, 81)
      temp = temp + M(111, 65) * M(65, 81)
      temp = temp + M(111, 66) * M(66, 81)
      temp = temp + M(111, 67) * M(67, 81)
      temp = temp + M(111, 68) * M(68, 81)
      temp = temp + M(111, 69) * M(69, 81)
      temp = temp + M(111, 70) * M(70, 81)
      temp = temp + M(111, 71) * M(71, 81)
      temp = temp + M(111, 72) * M(72, 81)
      temp = temp + M(111, 73) * M(73, 81)
      temp = temp + M(111, 78) * M(78, 81)
      temp = temp + M(111, 79) * M(79, 81)
      temp = temp + M(111, 80) * M(80, 81)
      M(111, 81) = M(111, 81) - temp
C     Lower part.
      temp = M(112, 1) * M(1, 81)
      temp = temp + M(112, 19) * M(19, 81)
      temp = temp + M(112, 20) * M(20, 81)
      temp = temp + M(112, 22) * M(22, 81)
      temp = temp + M(112, 23) * M(23, 81)
      temp = temp + M(112, 26) * M(26, 81)
      temp = temp + M(112, 27) * M(27, 81)
      temp = temp + M(112, 31) * M(31, 81)
      temp = temp + M(112, 32) * M(32, 81)
      temp = temp + M(112, 33) * M(33, 81)
      temp = temp + M(112, 38) * M(38, 81)
      temp = temp + M(112, 39) * M(39, 81)
      temp = temp + M(112, 58) * M(58, 81)
      temp = temp + M(112, 59) * M(59, 81)
      temp = temp + M(112, 60) * M(60, 81)
      temp = temp + M(112, 61) * M(61, 81)
      temp = temp + M(112, 65) * M(65, 81)
      temp = temp + M(112, 66) * M(66, 81)
      temp = temp + M(112, 67) * M(67, 81)
      temp = temp + M(112, 69) * M(69, 81)
      temp = temp + M(112, 73) * M(73, 81)
      temp = temp + M(112, 74) * M(74, 81)
      temp = temp + M(112, 78) * M(78, 81)
      temp = temp + M(112, 80) * M(80, 81)
      M(112, 81) = M(112, 81) - temp
C     Lower part.
      temp = M(113, 57) * M(57, 81)
      temp = temp + M(113, 60) * M(60, 81)
      temp = temp + M(113, 61) * M(61, 81)
      temp = temp + M(113, 70) * M(70, 81)
      temp = temp + M(113, 71) * M(71, 81)
      temp = temp + M(113, 80) * M(80, 81)
      M(113, 81) = M(113, 81) - temp
C     Upper part.
      M(81, 83) = M(81, 83) / M(81, 81)
C     Upper part.
      temp = M(81, 61) * M(61, 100)
      temp = temp + M(81, 66) * M(66, 100)
      temp = temp + M(81, 69) * M(69, 100)
      temp = temp + M(81, 78) * M(78, 100)
      temp = temp + M(81, 80) * M(80, 100)
      M(81, 100) = ( M(81, 100) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 44) * M(44, 102)
      temp = temp + M(81, 61) * M(61, 102)
      temp = temp + M(81, 66) * M(66, 102)
      temp = temp + M(81, 69) * M(69, 102)
      temp = temp + M(81, 78) * M(78, 102)
      temp = temp + M(81, 80) * M(80, 102)
      M(81, 102) = ( M(81, 102) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 61) * M(61, 105)
      temp = temp + M(81, 66) * M(66, 105)
      temp = temp + M(81, 69) * M(69, 105)
      temp = temp + M(81, 78) * M(78, 105)
      temp = temp + M(81, 80) * M(80, 105)
      M(81, 105) = ( M(81, 105) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 19) * M(19, 109)
      temp = temp + M(81, 20) * M(20, 109)
      temp = temp + M(81, 22) * M(22, 109)
      temp = temp + M(81, 23) * M(23, 109)
      temp = temp + M(81, 26) * M(26, 109)
      temp = temp + M(81, 27) * M(27, 109)
      temp = temp + M(81, 31) * M(31, 109)
      temp = temp + M(81, 44) * M(44, 109)
      temp = temp + M(81, 61) * M(61, 109)
      temp = temp + M(81, 66) * M(66, 109)
      temp = temp + M(81, 69) * M(69, 109)
      temp = temp + M(81, 78) * M(78, 109)
      temp = temp + M(81, 80) * M(80, 109)
      M(81, 109) = ( M(81, 109) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 44) * M(44, 110)
      M(81, 110) = ( M(81, 110) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 61) * M(61, 111)
      temp = temp + M(81, 66) * M(66, 111)
      temp = temp + M(81, 69) * M(69, 111)
      temp = temp + M(81, 78) * M(78, 111)
      temp = temp + M(81, 80) * M(80, 111)
      M(81, 111) = ( M(81, 111) - temp ) / M(81, 81)
C     Upper part.
      temp = M(81, 19) * M(19, 112)
      temp = temp + M(81, 20) * M(20, 112)
      temp = temp + M(81, 22) * M(22, 112)
      temp = temp + M(81, 23) * M(23, 112)
      temp = temp + M(81, 26) * M(26, 112)
      temp = temp + M(81, 27) * M(27, 112)
      temp = temp + M(81, 31) * M(31, 112)
      temp = temp + M(81, 44) * M(44, 112)
      temp = temp + M(81, 61) * M(61, 112)
      temp = temp + M(81, 66) * M(66, 112)
      temp = temp + M(81, 69) * M(69, 112)
      temp = temp + M(81, 78) * M(78, 112)
      temp = temp + M(81, 80) * M(80, 112)
      M(81, 112) = ( M(81, 112) - temp ) / M(81, 81)

C     Upper part.
      temp = M(82, 81) * M(81, 83)
      M(82, 83) = ( M(82, 83) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 100)
      M(82, 100) = ( M(82, 100) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 102)
      M(82, 102) = ( M(82, 102) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 105)
      M(82, 105) = ( M(82, 105) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 109)
      M(82, 109) = ( M(82, 109) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 110)
      M(82, 110) = ( M(82, 110) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 111)
      M(82, 111) = ( M(82, 111) - temp ) / M(82, 82)
C     Upper part.
      temp = M(82, 81) * M(81, 112)
      M(82, 112) = ( M(82, 112) - temp ) / M(82, 82)

C     Lower part.
      temp = M(83, 81) * M(81, 83)
      temp = temp + M(83, 82) * M(82, 83)
      M(83, 83) = M(83, 83) - temp
C     Lower part.
      temp = M(84, 81) * M(81, 83)
      M(84, 83) = M(84, 83) - temp
C     Lower part.
      temp = M(85, 81) * M(81, 83)
      M(85, 83) = M(85, 83) - temp
C     Lower part.
      temp = M(88, 81) * M(81, 83)
      M(88, 83) = M(88, 83) - temp
C     Lower part.
      temp = M(89, 81) * M(81, 83)
      M(89, 83) = M(89, 83) - temp
C     Lower part.
      temp = M(91, 81) * M(81, 83)
      M(91, 83) = M(91, 83) - temp
C     Lower part.
      temp = M(92, 81) * M(81, 83)
      M(92, 83) = M(92, 83) - temp
C     Lower part.
      temp = M(93, 81) * M(81, 83)
      M(93, 83) = M(93, 83) - temp
C     Lower part.
      temp = M(94, 81) * M(81, 83)
      M(94, 83) = M(94, 83) - temp
C     Lower part.
      temp = M(95, 81) * M(81, 83)
      M(95, 83) = M(95, 83) - temp
C     Lower part.
      temp = M(96, 81) * M(81, 83)
      M(96, 83) = M(96, 83) - temp
C     Lower part.
      temp = M(97, 81) * M(81, 83)
      M(97, 83) = M(97, 83) - temp
C     Lower part.
      temp = M(100, 81) * M(81, 83)
      temp = temp + M(100, 82) * M(82, 83)
      M(100, 83) = M(100, 83) - temp
C     Lower part.
      temp = M(101, 81) * M(81, 83)
      M(101, 83) = M(101, 83) - temp
C     Lower part.
      temp = M(102, 81) * M(81, 83)
      temp = temp + M(102, 82) * M(82, 83)
      M(102, 83) = M(102, 83) - temp
C     Lower part.
      temp = M(103, 81) * M(81, 83)
      M(103, 83) = M(103, 83) - temp
C     Lower part.
      temp = M(104, 81) * M(81, 83)
      M(104, 83) = M(104, 83) - temp
C     Lower part.
      temp = M(105, 81) * M(81, 83)
      temp = temp + M(105, 82) * M(82, 83)
      M(105, 83) = M(105, 83) - temp
C     Lower part.
      temp = M(106, 81) * M(81, 83)
      temp = temp + M(106, 82) * M(82, 83)
      M(106, 83) = M(106, 83) - temp
C     Lower part.
      temp = M(107, 81) * M(81, 83)
      M(107, 83) = M(107, 83) - temp
C     Lower part.
      temp = M(108, 81) * M(81, 83)
      temp = temp + M(108, 82) * M(82, 83)
      M(108, 83) = M(108, 83) - temp
C     Lower part.
      temp = M(109, 81) * M(81, 83)
      temp = temp + M(109, 82) * M(82, 83)
      M(109, 83) = M(109, 83) - temp
C     Lower part.
      temp = M(110, 81) * M(81, 83)
      temp = temp + M(110, 82) * M(82, 83)
      M(110, 83) = M(110, 83) - temp
C     Lower part.
      temp = M(111, 81) * M(81, 83)
      temp = temp + M(111, 82) * M(82, 83)
      M(111, 83) = M(111, 83) - temp
C     Lower part.
      temp = M(112, 81) * M(81, 83)
      M(112, 83) = M(112, 83) - temp
C     Lower part.
      temp = M(113, 81) * M(81, 83)
      M(113, 83) = M(113, 83) - temp
C     Upper part.
      temp = M(83, 47) * M(47, 100)
      temp = temp + M(83, 48) * M(48, 100)
      temp = temp + M(83, 53) * M(53, 100)
      temp = temp + M(83, 55) * M(55, 100)
      temp = temp + M(83, 81) * M(81, 100)
      temp = temp + M(83, 82) * M(82, 100)
      M(83, 100) = ( M(83, 100) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 47) * M(47, 102)
      temp = temp + M(83, 48) * M(48, 102)
      temp = temp + M(83, 53) * M(53, 102)
      temp = temp + M(83, 55) * M(55, 102)
      temp = temp + M(83, 81) * M(81, 102)
      temp = temp + M(83, 82) * M(82, 102)
      M(83, 102) = ( M(83, 102) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 47) * M(47, 105)
      temp = temp + M(83, 48) * M(48, 105)
      temp = temp + M(83, 53) * M(53, 105)
      temp = temp + M(83, 55) * M(55, 105)
      temp = temp + M(83, 81) * M(81, 105)
      temp = temp + M(83, 82) * M(82, 105)
      M(83, 105) = ( M(83, 105) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 29) * M(29, 109)
      temp = temp + M(83, 47) * M(47, 109)
      temp = temp + M(83, 48) * M(48, 109)
      temp = temp + M(83, 53) * M(53, 109)
      temp = temp + M(83, 55) * M(55, 109)
      temp = temp + M(83, 81) * M(81, 109)
      temp = temp + M(83, 82) * M(82, 109)
      M(83, 109) = ( M(83, 109) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 48) * M(48, 110)
      temp = temp + M(83, 81) * M(81, 110)
      temp = temp + M(83, 82) * M(82, 110)
      M(83, 110) = ( M(83, 110) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 47) * M(47, 111)
      temp = temp + M(83, 48) * M(48, 111)
      temp = temp + M(83, 55) * M(55, 111)
      temp = temp + M(83, 81) * M(81, 111)
      temp = temp + M(83, 82) * M(82, 111)
      M(83, 111) = ( M(83, 111) - temp ) / M(83, 83)
C     Upper part.
      temp = M(83, 29) * M(29, 112)
      temp = temp + M(83, 47) * M(47, 112)
      temp = temp + M(83, 48) * M(48, 112)
      temp = temp + M(83, 53) * M(53, 112)
      temp = temp + M(83, 55) * M(55, 112)
      temp = temp + M(83, 81) * M(81, 112)
      temp = temp + M(83, 82) * M(82, 112)
      M(83, 112) = ( M(83, 112) - temp ) / M(83, 83)

C     Upper part.
      temp = M(84, 80) * M(80, 100)
      temp = temp + M(84, 81) * M(81, 100)
      temp = temp + M(84, 83) * M(83, 100)
      M(84, 100) = ( M(84, 100) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 80) * M(80, 102)
      temp = temp + M(84, 81) * M(81, 102)
      temp = temp + M(84, 83) * M(83, 102)
      M(84, 102) = ( M(84, 102) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 80) * M(80, 105)
      temp = temp + M(84, 81) * M(81, 105)
      temp = temp + M(84, 83) * M(83, 105)
      M(84, 105) = ( M(84, 105) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 80) * M(80, 109)
      temp = temp + M(84, 81) * M(81, 109)
      temp = temp + M(84, 83) * M(83, 109)
      M(84, 109) = ( M(84, 109) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 81) * M(81, 110)
      temp = temp + M(84, 83) * M(83, 110)
      M(84, 110) = ( M(84, 110) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 80) * M(80, 111)
      temp = temp + M(84, 81) * M(81, 111)
      temp = temp + M(84, 83) * M(83, 111)
      M(84, 111) = ( M(84, 111) - temp ) / M(84, 84)
C     Upper part.
      temp = M(84, 80) * M(80, 112)
      temp = temp + M(84, 81) * M(81, 112)
      temp = temp + M(84, 83) * M(83, 112)
      M(84, 112) = ( M(84, 112) - temp ) / M(84, 84)

C     Upper part.
      temp = M(85, 64) * M(64, 86)
      temp = temp + M(85, 65) * M(65, 86)
      M(85, 86) = ( M(85, 86) - temp ) / M(85, 85)
C     Upper part.
      M(85, 92) = M(85, 92) / M(85, 85)
C     Upper part.
      M(85, 95) = M(85, 95) / M(85, 85)
C     Upper part.
      temp = M(85, 65) * M(65, 99)
      M(85, 99) = ( M(85, 99) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 57) * M(57, 100)
      temp = temp + M(85, 59) * M(59, 100)
      temp = temp + M(85, 60) * M(60, 100)
      temp = temp + M(85, 62) * M(62, 100)
      temp = temp + M(85, 64) * M(64, 100)
      temp = temp + M(85, 65) * M(65, 100)
      temp = temp + M(85, 68) * M(68, 100)
      temp = temp + M(85, 70) * M(70, 100)
      temp = temp + M(85, 71) * M(71, 100)
      temp = temp + M(85, 72) * M(72, 100)
      temp = temp + M(85, 79) * M(79, 100)
      temp = temp + M(85, 81) * M(81, 100)
      temp = temp + M(85, 83) * M(83, 100)
      temp = temp + M(85, 84) * M(84, 100)
      M(85, 100) = ( M(85, 100) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 57) * M(57, 102)
      temp = temp + M(85, 59) * M(59, 102)
      temp = temp + M(85, 60) * M(60, 102)
      temp = temp + M(85, 62) * M(62, 102)
      temp = temp + M(85, 64) * M(64, 102)
      temp = temp + M(85, 65) * M(65, 102)
      temp = temp + M(85, 68) * M(68, 102)
      temp = temp + M(85, 70) * M(70, 102)
      temp = temp + M(85, 71) * M(71, 102)
      temp = temp + M(85, 72) * M(72, 102)
      temp = temp + M(85, 79) * M(79, 102)
      temp = temp + M(85, 81) * M(81, 102)
      temp = temp + M(85, 83) * M(83, 102)
      temp = temp + M(85, 84) * M(84, 102)
      M(85, 102) = ( M(85, 102) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 57) * M(57, 105)
      temp = temp + M(85, 59) * M(59, 105)
      temp = temp + M(85, 60) * M(60, 105)
      temp = temp + M(85, 62) * M(62, 105)
      temp = temp + M(85, 64) * M(64, 105)
      temp = temp + M(85, 65) * M(65, 105)
      temp = temp + M(85, 68) * M(68, 105)
      temp = temp + M(85, 70) * M(70, 105)
      temp = temp + M(85, 71) * M(71, 105)
      temp = temp + M(85, 72) * M(72, 105)
      temp = temp + M(85, 79) * M(79, 105)
      temp = temp + M(85, 81) * M(81, 105)
      temp = temp + M(85, 83) * M(83, 105)
      temp = temp + M(85, 84) * M(84, 105)
      M(85, 105) = ( M(85, 105) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 57) * M(57, 109)
      temp = temp + M(85, 59) * M(59, 109)
      temp = temp + M(85, 60) * M(60, 109)
      temp = temp + M(85, 62) * M(62, 109)
      temp = temp + M(85, 64) * M(64, 109)
      temp = temp + M(85, 65) * M(65, 109)
      temp = temp + M(85, 68) * M(68, 109)
      temp = temp + M(85, 70) * M(70, 109)
      temp = temp + M(85, 71) * M(71, 109)
      temp = temp + M(85, 72) * M(72, 109)
      temp = temp + M(85, 79) * M(79, 109)
      temp = temp + M(85, 81) * M(81, 109)
      temp = temp + M(85, 83) * M(83, 109)
      temp = temp + M(85, 84) * M(84, 109)
      M(85, 109) = ( M(85, 109) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 81) * M(81, 110)
      temp = temp + M(85, 83) * M(83, 110)
      temp = temp + M(85, 84) * M(84, 110)
      M(85, 110) = ( M(85, 110) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 57) * M(57, 111)
      temp = temp + M(85, 59) * M(59, 111)
      temp = temp + M(85, 60) * M(60, 111)
      temp = temp + M(85, 62) * M(62, 111)
      temp = temp + M(85, 64) * M(64, 111)
      temp = temp + M(85, 65) * M(65, 111)
      temp = temp + M(85, 68) * M(68, 111)
      temp = temp + M(85, 70) * M(70, 111)
      temp = temp + M(85, 71) * M(71, 111)
      temp = temp + M(85, 72) * M(72, 111)
      temp = temp + M(85, 79) * M(79, 111)
      temp = temp + M(85, 81) * M(81, 111)
      temp = temp + M(85, 83) * M(83, 111)
      temp = temp + M(85, 84) * M(84, 111)
      M(85, 111) = ( M(85, 111) - temp ) / M(85, 85)
C     Upper part.
      temp = M(85, 57) * M(57, 112)
      temp = temp + M(85, 59) * M(59, 112)
      temp = temp + M(85, 60) * M(60, 112)
      temp = temp + M(85, 62) * M(62, 112)
      temp = temp + M(85, 64) * M(64, 112)
      temp = temp + M(85, 65) * M(65, 112)
      temp = temp + M(85, 68) * M(68, 112)
      temp = temp + M(85, 70) * M(70, 112)
      temp = temp + M(85, 71) * M(71, 112)
      temp = temp + M(85, 72) * M(72, 112)
      temp = temp + M(85, 79) * M(79, 112)
      temp = temp + M(85, 81) * M(81, 112)
      temp = temp + M(85, 83) * M(83, 112)
      temp = temp + M(85, 84) * M(84, 112)
      M(85, 112) = ( M(85, 112) - temp ) / M(85, 85)

C     Lower part.
      temp = M(87, 85) * M(85, 86)
      M(87, 86) = M(87, 86) - temp
C     Lower part.
      temp = M(89, 64) * M(64, 86)
      temp = temp + M(89, 65) * M(65, 86)
      M(89, 86) = M(89, 86) - temp
C     Lower part.
      temp = M(91, 77) * M(77, 86)
      M(91, 86) = M(91, 86) - temp
C     Lower part.
      temp = M(93, 77) * M(77, 86)
      M(93, 86) = M(93, 86) - temp
C     Lower part.
      temp = M(96, 77) * M(77, 86)
      M(96, 86) = M(96, 86) - temp
C     Lower part.
      temp = M(97, 64) * M(64, 86)
      temp = temp + M(97, 65) * M(65, 86)
      M(97, 86) = M(97, 86) - temp
C     Lower part.
      temp = M(100, 30) * M(30, 86)
      temp = temp + M(100, 58) * M(58, 86)
      temp = temp + M(100, 64) * M(64, 86)
      temp = temp + M(100, 65) * M(65, 86)
      M(100, 86) = M(100, 86) - temp
C     Lower part.
      temp = M(101, 77) * M(77, 86)
      M(101, 86) = M(101, 86) - temp
C     Lower part.
      temp = M(102, 64) * M(64, 86)
      temp = temp + M(102, 65) * M(65, 86)
      M(102, 86) = M(102, 86) - temp
C     Lower part.
      temp = M(104, 30) * M(30, 86)
      M(104, 86) = M(104, 86) - temp
C     Lower part.
      temp = M(105, 30) * M(30, 86)
      temp = temp + M(105, 58) * M(58, 86)
      temp = temp + M(105, 64) * M(64, 86)
      temp = temp + M(105, 65) * M(65, 86)
      temp = temp + M(105, 77) * M(77, 86)
      M(105, 86) = M(105, 86) - temp
C     Lower part.
      temp = M(106, 64) * M(64, 86)
      temp = temp + M(106, 65) * M(65, 86)
      M(106, 86) = M(106, 86) - temp
C     Lower part.
      temp = M(107, 77) * M(77, 86)
      temp = temp + M(107, 85) * M(85, 86)
      M(107, 86) = M(107, 86) - temp
C     Lower part.
      temp = M(108, 64) * M(64, 86)
      temp = temp + M(108, 65) * M(65, 86)
      M(108, 86) = M(108, 86) - temp
C     Lower part.
      temp = M(109, 64) * M(64, 86)
      temp = temp + M(109, 65) * M(65, 86)
      M(109, 86) = M(109, 86) - temp
C     Lower part.
      temp = M(110, 64) * M(64, 86)
      temp = temp + M(110, 65) * M(65, 86)
      M(110, 86) = M(110, 86) - temp
C     Lower part.
      temp = M(111, 64) * M(64, 86)
      temp = temp + M(111, 65) * M(65, 86)
      temp = temp + M(111, 77) * M(77, 86)
      temp = temp + M(111, 85) * M(85, 86)
      M(111, 86) = M(111, 86) - temp
C     Lower part.
      temp = M(112, 30) * M(30, 86)
      temp = temp + M(112, 58) * M(58, 86)
      temp = temp + M(112, 65) * M(65, 86)
      temp = temp + M(112, 77) * M(77, 86)
      temp = temp + M(112, 85) * M(85, 86)
      M(112, 86) = M(112, 86) - temp
C     Upper part.
      M(86, 100) = M(86, 100) / M(86, 86)
C     Upper part.
      M(86, 102) = M(86, 102) / M(86, 86)
C     Upper part.
      M(86, 105) = M(86, 105) / M(86, 86)
C     Upper part.
      M(86, 109) = M(86, 109) / M(86, 86)
C     Upper part.
      M(86, 111) = M(86, 111) / M(86, 86)
C     Upper part.
      temp = M(86, 7) * M(7, 112)
      M(86, 112) = ( M(86, 112) - temp ) / M(86, 86)

C     Upper part.
      temp = M(87, 85) * M(85, 92)
      M(87, 92) = ( M(87, 92) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 85) * M(85, 95)
      M(87, 95) = ( M(87, 95) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 85) * M(85, 99)
      M(87, 99) = ( M(87, 99) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 21) * M(21, 100)
      temp = temp + M(87, 85) * M(85, 100)
      temp = temp + M(87, 86) * M(86, 100)
      M(87, 100) = ( M(87, 100) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 85) * M(85, 102)
      temp = temp + M(87, 86) * M(86, 102)
      M(87, 102) = ( M(87, 102) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 21) * M(21, 104)
      M(87, 104) = ( M(87, 104) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 85) * M(85, 105)
      temp = temp + M(87, 86) * M(86, 105)
      M(87, 105) = ( M(87, 105) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 85) * M(85, 109)
      temp = temp + M(87, 86) * M(86, 109)
      M(87, 109) = ( M(87, 109) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 85) * M(85, 110)
      M(87, 110) = ( M(87, 110) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 85) * M(85, 111)
      temp = temp + M(87, 86) * M(86, 111)
      M(87, 111) = ( M(87, 111) - temp ) / M(87, 87)
C     Upper part.
      temp = M(87, 21) * M(21, 112)
      temp = temp + M(87, 85) * M(85, 112)
      temp = temp + M(87, 86) * M(86, 112)
      M(87, 112) = ( M(87, 112) - temp ) / M(87, 87)

C     Lower part.
      temp = M(107, 24) * M(24, 88)
      M(107, 88) = M(107, 88) - temp
C     Lower part.
      temp = M(111, 24) * M(24, 88)
      M(111, 88) = M(111, 88) - temp
C     Lower part.
      temp = M(112, 24) * M(24, 88)
      M(112, 88) = M(112, 88) - temp
C     Upper part.
      temp = M(88, 81) * M(81, 100)
      temp = temp + M(88, 83) * M(83, 100)
      M(88, 100) = ( M(88, 100) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 81) * M(81, 102)
      temp = temp + M(88, 83) * M(83, 102)
      M(88, 102) = ( M(88, 102) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 81) * M(81, 105)
      temp = temp + M(88, 83) * M(83, 105)
      M(88, 105) = ( M(88, 105) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 23) * M(23, 109)
      temp = temp + M(88, 81) * M(81, 109)
      temp = temp + M(88, 83) * M(83, 109)
      M(88, 109) = ( M(88, 109) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 81) * M(81, 110)
      temp = temp + M(88, 83) * M(83, 110)
      M(88, 110) = ( M(88, 110) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 81) * M(81, 111)
      temp = temp + M(88, 83) * M(83, 111)
      M(88, 111) = ( M(88, 111) - temp ) / M(88, 88)
C     Upper part.
      temp = M(88, 23) * M(23, 112)
      temp = temp + M(88, 81) * M(81, 112)
      temp = temp + M(88, 83) * M(83, 112)
      M(88, 112) = ( M(88, 112) - temp ) / M(88, 88)

C     Upper part.
      M(89, 92) = M(89, 92) / M(89, 89)
C     Upper part.
      M(89, 95) = M(89, 95) / M(89, 89)
C     Upper part.
      temp = M(89, 65) * M(65, 99)
      M(89, 99) = ( M(89, 99) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 57) * M(57, 100)
      temp = temp + M(89, 59) * M(59, 100)
      temp = temp + M(89, 60) * M(60, 100)
      temp = temp + M(89, 62) * M(62, 100)
      temp = temp + M(89, 64) * M(64, 100)
      temp = temp + M(89, 65) * M(65, 100)
      temp = temp + M(89, 68) * M(68, 100)
      temp = temp + M(89, 70) * M(70, 100)
      temp = temp + M(89, 71) * M(71, 100)
      temp = temp + M(89, 72) * M(72, 100)
      temp = temp + M(89, 79) * M(79, 100)
      temp = temp + M(89, 81) * M(81, 100)
      temp = temp + M(89, 83) * M(83, 100)
      temp = temp + M(89, 84) * M(84, 100)
      temp = temp + M(89, 86) * M(86, 100)
      temp = temp + M(89, 88) * M(88, 100)
      M(89, 100) = ( M(89, 100) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 57) * M(57, 102)
      temp = temp + M(89, 59) * M(59, 102)
      temp = temp + M(89, 60) * M(60, 102)
      temp = temp + M(89, 62) * M(62, 102)
      temp = temp + M(89, 64) * M(64, 102)
      temp = temp + M(89, 65) * M(65, 102)
      temp = temp + M(89, 68) * M(68, 102)
      temp = temp + M(89, 70) * M(70, 102)
      temp = temp + M(89, 71) * M(71, 102)
      temp = temp + M(89, 72) * M(72, 102)
      temp = temp + M(89, 79) * M(79, 102)
      temp = temp + M(89, 81) * M(81, 102)
      temp = temp + M(89, 83) * M(83, 102)
      temp = temp + M(89, 84) * M(84, 102)
      temp = temp + M(89, 86) * M(86, 102)
      temp = temp + M(89, 88) * M(88, 102)
      M(89, 102) = ( M(89, 102) - temp ) / M(89, 89)
C     Upper part.
      M(89, 104) = M(89, 104) / M(89, 89)
C     Upper part.
      temp = M(89, 57) * M(57, 105)
      temp = temp + M(89, 59) * M(59, 105)
      temp = temp + M(89, 60) * M(60, 105)
      temp = temp + M(89, 62) * M(62, 105)
      temp = temp + M(89, 64) * M(64, 105)
      temp = temp + M(89, 65) * M(65, 105)
      temp = temp + M(89, 68) * M(68, 105)
      temp = temp + M(89, 70) * M(70, 105)
      temp = temp + M(89, 71) * M(71, 105)
      temp = temp + M(89, 72) * M(72, 105)
      temp = temp + M(89, 79) * M(79, 105)
      temp = temp + M(89, 81) * M(81, 105)
      temp = temp + M(89, 83) * M(83, 105)
      temp = temp + M(89, 84) * M(84, 105)
      temp = temp + M(89, 86) * M(86, 105)
      temp = temp + M(89, 88) * M(88, 105)
      M(89, 105) = ( M(89, 105) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 57) * M(57, 109)
      temp = temp + M(89, 59) * M(59, 109)
      temp = temp + M(89, 60) * M(60, 109)
      temp = temp + M(89, 62) * M(62, 109)
      temp = temp + M(89, 64) * M(64, 109)
      temp = temp + M(89, 65) * M(65, 109)
      temp = temp + M(89, 68) * M(68, 109)
      temp = temp + M(89, 70) * M(70, 109)
      temp = temp + M(89, 71) * M(71, 109)
      temp = temp + M(89, 72) * M(72, 109)
      temp = temp + M(89, 79) * M(79, 109)
      temp = temp + M(89, 81) * M(81, 109)
      temp = temp + M(89, 83) * M(83, 109)
      temp = temp + M(89, 84) * M(84, 109)
      temp = temp + M(89, 86) * M(86, 109)
      temp = temp + M(89, 88) * M(88, 109)
      M(89, 109) = ( M(89, 109) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 81) * M(81, 110)
      temp = temp + M(89, 83) * M(83, 110)
      temp = temp + M(89, 84) * M(84, 110)
      temp = temp + M(89, 88) * M(88, 110)
      M(89, 110) = ( M(89, 110) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 57) * M(57, 111)
      temp = temp + M(89, 59) * M(59, 111)
      temp = temp + M(89, 60) * M(60, 111)
      temp = temp + M(89, 62) * M(62, 111)
      temp = temp + M(89, 64) * M(64, 111)
      temp = temp + M(89, 65) * M(65, 111)
      temp = temp + M(89, 68) * M(68, 111)
      temp = temp + M(89, 70) * M(70, 111)
      temp = temp + M(89, 71) * M(71, 111)
      temp = temp + M(89, 72) * M(72, 111)
      temp = temp + M(89, 79) * M(79, 111)
      temp = temp + M(89, 81) * M(81, 111)
      temp = temp + M(89, 83) * M(83, 111)
      temp = temp + M(89, 84) * M(84, 111)
      temp = temp + M(89, 86) * M(86, 111)
      temp = temp + M(89, 88) * M(88, 111)
      M(89, 111) = ( M(89, 111) - temp ) / M(89, 89)
C     Upper part.
      temp = M(89, 57) * M(57, 112)
      temp = temp + M(89, 59) * M(59, 112)
      temp = temp + M(89, 60) * M(60, 112)
      temp = temp + M(89, 62) * M(62, 112)
      temp = temp + M(89, 64) * M(64, 112)
      temp = temp + M(89, 65) * M(65, 112)
      temp = temp + M(89, 68) * M(68, 112)
      temp = temp + M(89, 70) * M(70, 112)
      temp = temp + M(89, 71) * M(71, 112)
      temp = temp + M(89, 72) * M(72, 112)
      temp = temp + M(89, 79) * M(79, 112)
      temp = temp + M(89, 81) * M(81, 112)
      temp = temp + M(89, 83) * M(83, 112)
      temp = temp + M(89, 84) * M(84, 112)
      temp = temp + M(89, 86) * M(86, 112)
      temp = temp + M(89, 88) * M(88, 112)
      M(89, 112) = ( M(89, 112) - temp ) / M(89, 89)

C     Upper part.
      M(90, 97) = M(90, 97) / M(90, 90)
C     Upper part.
      M(90, 100) = M(90, 100) / M(90, 90)
C     Upper part.
      M(90, 102) = M(90, 102) / M(90, 90)
C     Upper part.
      M(90, 105) = M(90, 105) / M(90, 90)
C     Upper part.
      M(90, 109) = M(90, 109) / M(90, 90)
C     Upper part.
      M(90, 111) = M(90, 111) / M(90, 90)
C     Upper part.
      M(90, 112) = M(90, 112) / M(90, 90)

C     Upper part.
      temp = M(91, 77) * M(77, 92)
      M(91, 92) = ( M(91, 92) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 90) * M(90, 97)
      M(91, 97) = ( M(91, 97) - temp ) / M(91, 91)
C     Upper part.
      M(91, 99) = M(91, 99) / M(91, 91)
C     Upper part.
      temp = M(91, 41) * M(41, 100)
      temp = temp + M(91, 51) * M(51, 100)
      temp = temp + M(91, 53) * M(53, 100)
      temp = temp + M(91, 55) * M(55, 100)
      temp = temp + M(91, 56) * M(56, 100)
      temp = temp + M(91, 63) * M(63, 100)
      temp = temp + M(91, 75) * M(75, 100)
      temp = temp + M(91, 77) * M(77, 100)
      temp = temp + M(91, 80) * M(80, 100)
      temp = temp + M(91, 81) * M(81, 100)
      temp = temp + M(91, 83) * M(83, 100)
      temp = temp + M(91, 84) * M(84, 100)
      temp = temp + M(91, 86) * M(86, 100)
      temp = temp + M(91, 90) * M(90, 100)
      M(91, 100) = ( M(91, 100) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 41) * M(41, 102)
      temp = temp + M(91, 51) * M(51, 102)
      temp = temp + M(91, 53) * M(53, 102)
      temp = temp + M(91, 55) * M(55, 102)
      temp = temp + M(91, 56) * M(56, 102)
      temp = temp + M(91, 63) * M(63, 102)
      temp = temp + M(91, 75) * M(75, 102)
      temp = temp + M(91, 77) * M(77, 102)
      temp = temp + M(91, 80) * M(80, 102)
      temp = temp + M(91, 81) * M(81, 102)
      temp = temp + M(91, 83) * M(83, 102)
      temp = temp + M(91, 84) * M(84, 102)
      temp = temp + M(91, 86) * M(86, 102)
      temp = temp + M(91, 90) * M(90, 102)
      M(91, 102) = ( M(91, 102) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 41) * M(41, 105)
      temp = temp + M(91, 51) * M(51, 105)
      temp = temp + M(91, 53) * M(53, 105)
      temp = temp + M(91, 55) * M(55, 105)
      temp = temp + M(91, 56) * M(56, 105)
      temp = temp + M(91, 63) * M(63, 105)
      temp = temp + M(91, 75) * M(75, 105)
      temp = temp + M(91, 77) * M(77, 105)
      temp = temp + M(91, 80) * M(80, 105)
      temp = temp + M(91, 81) * M(81, 105)
      temp = temp + M(91, 83) * M(83, 105)
      temp = temp + M(91, 84) * M(84, 105)
      temp = temp + M(91, 86) * M(86, 105)
      temp = temp + M(91, 90) * M(90, 105)
      M(91, 105) = ( M(91, 105) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 22) * M(22, 109)
      temp = temp + M(91, 41) * M(41, 109)
      temp = temp + M(91, 51) * M(51, 109)
      temp = temp + M(91, 53) * M(53, 109)
      temp = temp + M(91, 55) * M(55, 109)
      temp = temp + M(91, 56) * M(56, 109)
      temp = temp + M(91, 63) * M(63, 109)
      temp = temp + M(91, 75) * M(75, 109)
      temp = temp + M(91, 77) * M(77, 109)
      temp = temp + M(91, 80) * M(80, 109)
      temp = temp + M(91, 81) * M(81, 109)
      temp = temp + M(91, 83) * M(83, 109)
      temp = temp + M(91, 84) * M(84, 109)
      temp = temp + M(91, 86) * M(86, 109)
      temp = temp + M(91, 90) * M(90, 109)
      M(91, 109) = ( M(91, 109) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 51) * M(51, 110)
      temp = temp + M(91, 75) * M(75, 110)
      temp = temp + M(91, 81) * M(81, 110)
      temp = temp + M(91, 83) * M(83, 110)
      temp = temp + M(91, 84) * M(84, 110)
      M(91, 110) = ( M(91, 110) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 51) * M(51, 111)
      temp = temp + M(91, 55) * M(55, 111)
      temp = temp + M(91, 56) * M(56, 111)
      temp = temp + M(91, 63) * M(63, 111)
      temp = temp + M(91, 75) * M(75, 111)
      temp = temp + M(91, 77) * M(77, 111)
      temp = temp + M(91, 80) * M(80, 111)
      temp = temp + M(91, 81) * M(81, 111)
      temp = temp + M(91, 83) * M(83, 111)
      temp = temp + M(91, 84) * M(84, 111)
      temp = temp + M(91, 86) * M(86, 111)
      temp = temp + M(91, 90) * M(90, 111)
      M(91, 111) = ( M(91, 111) - temp ) / M(91, 91)
C     Upper part.
      temp = M(91, 4) * M(4, 112)
      temp = temp + M(91, 22) * M(22, 112)
      temp = temp + M(91, 41) * M(41, 112)
      temp = temp + M(91, 51) * M(51, 112)
      temp = temp + M(91, 53) * M(53, 112)
      temp = temp + M(91, 55) * M(55, 112)
      temp = temp + M(91, 56) * M(56, 112)
      temp = temp + M(91, 63) * M(63, 112)
      temp = temp + M(91, 75) * M(75, 112)
      temp = temp + M(91, 77) * M(77, 112)
      temp = temp + M(91, 80) * M(80, 112)
      temp = temp + M(91, 81) * M(81, 112)
      temp = temp + M(91, 83) * M(83, 112)
      temp = temp + M(91, 84) * M(84, 112)
      temp = temp + M(91, 86) * M(86, 112)
      temp = temp + M(91, 90) * M(90, 112)
      M(91, 112) = ( M(91, 112) - temp ) / M(91, 91)

C     Lower part.
      temp = M(93, 77) * M(77, 92)
      M(93, 92) = M(93, 92) - temp
C     Lower part.
      temp = M(94, 87) * M(87, 92)
      temp = temp + M(94, 91) * M(91, 92)
      M(94, 92) = M(94, 92) - temp
C     Lower part.
      temp = M(96, 77) * M(77, 92)
      temp = temp + M(96, 87) * M(87, 92)
      temp = temp + M(96, 91) * M(91, 92)
      M(96, 92) = M(96, 92) - temp
C     Lower part.
      temp = M(100, 87) * M(87, 92)
      M(100, 92) = M(100, 92) - temp
C     Lower part.
      temp = M(101, 77) * M(77, 92)
      M(101, 92) = M(101, 92) - temp
C     Lower part.
      temp = M(105, 77) * M(77, 92)
      temp = temp + M(105, 87) * M(87, 92)
      M(105, 92) = M(105, 92) - temp
C     Lower part.
      temp = M(107, 77) * M(77, 92)
      temp = temp + M(107, 85) * M(85, 92)
      M(107, 92) = M(107, 92) - temp
C     Lower part.
      temp = M(108, 89) * M(89, 92)
      temp = temp + M(108, 91) * M(91, 92)
      M(108, 92) = M(108, 92) - temp
C     Lower part.
      temp = M(109, 87) * M(87, 92)
      temp = temp + M(109, 91) * M(91, 92)
      M(109, 92) = M(109, 92) - temp
C     Lower part.
      temp = M(111, 77) * M(77, 92)
      temp = temp + M(111, 85) * M(85, 92)
      temp = temp + M(111, 87) * M(87, 92)
      temp = temp + M(111, 89) * M(89, 92)
      temp = temp + M(111, 91) * M(91, 92)
      M(111, 92) = M(111, 92) - temp
C     Lower part.
      temp = M(112, 77) * M(77, 92)
      temp = temp + M(112, 85) * M(85, 92)
      temp = temp + M(112, 87) * M(87, 92)
      temp = temp + M(112, 89) * M(89, 92)
      temp = temp + M(112, 91) * M(91, 92)
      M(112, 92) = M(112, 92) - temp
C     Upper part.
      temp = M(92, 69) * M(69, 100)
      temp = temp + M(92, 81) * M(81, 100)
      temp = temp + M(92, 83) * M(83, 100)
      M(92, 100) = ( M(92, 100) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 69) * M(69, 102)
      temp = temp + M(92, 81) * M(81, 102)
      temp = temp + M(92, 83) * M(83, 102)
      M(92, 102) = ( M(92, 102) - temp ) / M(92, 92)
C     Upper part.
      M(92, 103) = M(92, 103) / M(92, 92)
C     Upper part.
      temp = M(92, 69) * M(69, 105)
      temp = temp + M(92, 81) * M(81, 105)
      temp = temp + M(92, 83) * M(83, 105)
      M(92, 105) = ( M(92, 105) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 19) * M(19, 109)
      temp = temp + M(92, 20) * M(20, 109)
      temp = temp + M(92, 27) * M(27, 109)
      temp = temp + M(92, 31) * M(31, 109)
      temp = temp + M(92, 69) * M(69, 109)
      temp = temp + M(92, 81) * M(81, 109)
      temp = temp + M(92, 83) * M(83, 109)
      M(92, 109) = ( M(92, 109) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 81) * M(81, 110)
      temp = temp + M(92, 83) * M(83, 110)
      M(92, 110) = ( M(92, 110) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 69) * M(69, 111)
      temp = temp + M(92, 81) * M(81, 111)
      temp = temp + M(92, 83) * M(83, 111)
      M(92, 111) = ( M(92, 111) - temp ) / M(92, 92)
C     Upper part.
      temp = M(92, 19) * M(19, 112)
      temp = temp + M(92, 20) * M(20, 112)
      temp = temp + M(92, 27) * M(27, 112)
      temp = temp + M(92, 31) * M(31, 112)
      temp = temp + M(92, 69) * M(69, 112)
      temp = temp + M(92, 81) * M(81, 112)
      temp = temp + M(92, 83) * M(83, 112)
      M(92, 112) = ( M(92, 112) - temp ) / M(92, 92)

C     Upper part.
      temp = M(93, 73) * M(73, 95)
      M(93, 95) = ( M(93, 95) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 42) * M(42, 100)
      temp = temp + M(93, 49) * M(49, 100)
      temp = temp + M(93, 55) * M(55, 100)
      temp = temp + M(93, 56) * M(56, 100)
      temp = temp + M(93, 61) * M(61, 100)
      temp = temp + M(93, 66) * M(66, 100)
      temp = temp + M(93, 68) * M(68, 100)
      temp = temp + M(93, 73) * M(73, 100)
      temp = temp + M(93, 76) * M(76, 100)
      temp = temp + M(93, 77) * M(77, 100)
      temp = temp + M(93, 78) * M(78, 100)
      temp = temp + M(93, 80) * M(80, 100)
      temp = temp + M(93, 81) * M(81, 100)
      temp = temp + M(93, 83) * M(83, 100)
      temp = temp + M(93, 84) * M(84, 100)
      temp = temp + M(93, 86) * M(86, 100)
      temp = temp + M(93, 92) * M(92, 100)
      M(93, 100) = ( M(93, 100) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 42) * M(42, 102)
      temp = temp + M(93, 49) * M(49, 102)
      temp = temp + M(93, 55) * M(55, 102)
      temp = temp + M(93, 56) * M(56, 102)
      temp = temp + M(93, 61) * M(61, 102)
      temp = temp + M(93, 66) * M(66, 102)
      temp = temp + M(93, 68) * M(68, 102)
      temp = temp + M(93, 73) * M(73, 102)
      temp = temp + M(93, 76) * M(76, 102)
      temp = temp + M(93, 77) * M(77, 102)
      temp = temp + M(93, 78) * M(78, 102)
      temp = temp + M(93, 80) * M(80, 102)
      temp = temp + M(93, 81) * M(81, 102)
      temp = temp + M(93, 83) * M(83, 102)
      temp = temp + M(93, 84) * M(84, 102)
      temp = temp + M(93, 86) * M(86, 102)
      temp = temp + M(93, 92) * M(92, 102)
      M(93, 102) = ( M(93, 102) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 92) * M(92, 103)
      M(93, 103) = ( M(93, 103) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 42) * M(42, 105)
      temp = temp + M(93, 49) * M(49, 105)
      temp = temp + M(93, 55) * M(55, 105)
      temp = temp + M(93, 56) * M(56, 105)
      temp = temp + M(93, 61) * M(61, 105)
      temp = temp + M(93, 66) * M(66, 105)
      temp = temp + M(93, 68) * M(68, 105)
      temp = temp + M(93, 73) * M(73, 105)
      temp = temp + M(93, 76) * M(76, 105)
      temp = temp + M(93, 77) * M(77, 105)
      temp = temp + M(93, 78) * M(78, 105)
      temp = temp + M(93, 80) * M(80, 105)
      temp = temp + M(93, 81) * M(81, 105)
      temp = temp + M(93, 83) * M(83, 105)
      temp = temp + M(93, 84) * M(84, 105)
      temp = temp + M(93, 86) * M(86, 105)
      temp = temp + M(93, 92) * M(92, 105)
      M(93, 105) = ( M(93, 105) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 42) * M(42, 109)
      temp = temp + M(93, 49) * M(49, 109)
      temp = temp + M(93, 55) * M(55, 109)
      temp = temp + M(93, 56) * M(56, 109)
      temp = temp + M(93, 61) * M(61, 109)
      temp = temp + M(93, 66) * M(66, 109)
      temp = temp + M(93, 68) * M(68, 109)
      temp = temp + M(93, 73) * M(73, 109)
      temp = temp + M(93, 76) * M(76, 109)
      temp = temp + M(93, 77) * M(77, 109)
      temp = temp + M(93, 78) * M(78, 109)
      temp = temp + M(93, 80) * M(80, 109)
      temp = temp + M(93, 81) * M(81, 109)
      temp = temp + M(93, 83) * M(83, 109)
      temp = temp + M(93, 84) * M(84, 109)
      temp = temp + M(93, 86) * M(86, 109)
      temp = temp + M(93, 92) * M(92, 109)
      M(93, 109) = ( M(93, 109) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 73) * M(73, 110)
      temp = temp + M(93, 76) * M(76, 110)
      temp = temp + M(93, 81) * M(81, 110)
      temp = temp + M(93, 83) * M(83, 110)
      temp = temp + M(93, 84) * M(84, 110)
      temp = temp + M(93, 92) * M(92, 110)
      M(93, 110) = ( M(93, 110) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 55) * M(55, 111)
      temp = temp + M(93, 56) * M(56, 111)
      temp = temp + M(93, 61) * M(61, 111)
      temp = temp + M(93, 66) * M(66, 111)
      temp = temp + M(93, 68) * M(68, 111)
      temp = temp + M(93, 73) * M(73, 111)
      temp = temp + M(93, 76) * M(76, 111)
      temp = temp + M(93, 77) * M(77, 111)
      temp = temp + M(93, 78) * M(78, 111)
      temp = temp + M(93, 80) * M(80, 111)
      temp = temp + M(93, 81) * M(81, 111)
      temp = temp + M(93, 83) * M(83, 111)
      temp = temp + M(93, 84) * M(84, 111)
      temp = temp + M(93, 86) * M(86, 111)
      temp = temp + M(93, 92) * M(92, 111)
      M(93, 111) = ( M(93, 111) - temp ) / M(93, 93)
C     Upper part.
      temp = M(93, 42) * M(42, 112)
      temp = temp + M(93, 49) * M(49, 112)
      temp = temp + M(93, 55) * M(55, 112)
      temp = temp + M(93, 56) * M(56, 112)
      temp = temp + M(93, 61) * M(61, 112)
      temp = temp + M(93, 66) * M(66, 112)
      temp = temp + M(93, 68) * M(68, 112)
      temp = temp + M(93, 73) * M(73, 112)
      temp = temp + M(93, 76) * M(76, 112)
      temp = temp + M(93, 77) * M(77, 112)
      temp = temp + M(93, 78) * M(78, 112)
      temp = temp + M(93, 80) * M(80, 112)
      temp = temp + M(93, 81) * M(81, 112)
      temp = temp + M(93, 83) * M(83, 112)
      temp = temp + M(93, 84) * M(84, 112)
      temp = temp + M(93, 86) * M(86, 112)
      temp = temp + M(93, 92) * M(92, 112)
      M(93, 112) = ( M(93, 112) - temp ) / M(93, 93)

C     Upper part.
      temp = M(94, 87) * M(87, 95)
      temp = temp + M(94, 93) * M(93, 95)
      M(94, 95) = ( M(94, 95) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 91) * M(91, 97)
      M(94, 97) = ( M(94, 97) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 87) * M(87, 99)
      temp = temp + M(94, 91) * M(91, 99)
      M(94, 99) = ( M(94, 99) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 47) * M(47, 100)
      temp = temp + M(94, 48) * M(48, 100)
      temp = temp + M(94, 53) * M(53, 100)
      temp = temp + M(94, 55) * M(55, 100)
      temp = temp + M(94, 61) * M(61, 100)
      temp = temp + M(94, 81) * M(81, 100)
      temp = temp + M(94, 83) * M(83, 100)
      temp = temp + M(94, 87) * M(87, 100)
      temp = temp + M(94, 91) * M(91, 100)
      temp = temp + M(94, 92) * M(92, 100)
      temp = temp + M(94, 93) * M(93, 100)
      M(94, 100) = ( M(94, 100) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 47) * M(47, 102)
      temp = temp + M(94, 48) * M(48, 102)
      temp = temp + M(94, 53) * M(53, 102)
      temp = temp + M(94, 55) * M(55, 102)
      temp = temp + M(94, 61) * M(61, 102)
      temp = temp + M(94, 81) * M(81, 102)
      temp = temp + M(94, 83) * M(83, 102)
      temp = temp + M(94, 87) * M(87, 102)
      temp = temp + M(94, 91) * M(91, 102)
      temp = temp + M(94, 92) * M(92, 102)
      temp = temp + M(94, 93) * M(93, 102)
      M(94, 102) = ( M(94, 102) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 92) * M(92, 103)
      temp = temp + M(94, 93) * M(93, 103)
      M(94, 103) = ( M(94, 103) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 87) * M(87, 104)
      M(94, 104) = ( M(94, 104) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 47) * M(47, 105)
      temp = temp + M(94, 48) * M(48, 105)
      temp = temp + M(94, 53) * M(53, 105)
      temp = temp + M(94, 55) * M(55, 105)
      temp = temp + M(94, 61) * M(61, 105)
      temp = temp + M(94, 81) * M(81, 105)
      temp = temp + M(94, 83) * M(83, 105)
      temp = temp + M(94, 87) * M(87, 105)
      temp = temp + M(94, 91) * M(91, 105)
      temp = temp + M(94, 92) * M(92, 105)
      temp = temp + M(94, 93) * M(93, 105)
      M(94, 105) = ( M(94, 105) - temp ) / M(94, 94)
C     Upper part.
      M(94, 107) = M(94, 107) / M(94, 94)
C     Upper part.
      M(94, 108) = M(94, 108) / M(94, 94)
C     Upper part.
      temp = M(94, 16) * M(16, 109)
      temp = temp + M(94, 18) * M(18, 109)
      temp = temp + M(94, 22) * M(22, 109)
      temp = temp + M(94, 29) * M(29, 109)
      temp = temp + M(94, 47) * M(47, 109)
      temp = temp + M(94, 48) * M(48, 109)
      temp = temp + M(94, 53) * M(53, 109)
      temp = temp + M(94, 55) * M(55, 109)
      temp = temp + M(94, 61) * M(61, 109)
      temp = temp + M(94, 81) * M(81, 109)
      temp = temp + M(94, 83) * M(83, 109)
      temp = temp + M(94, 87) * M(87, 109)
      temp = temp + M(94, 91) * M(91, 109)
      temp = temp + M(94, 92) * M(92, 109)
      temp = temp + M(94, 93) * M(93, 109)
      M(94, 109) = ( M(94, 109) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 16) * M(16, 110)
      temp = temp + M(94, 48) * M(48, 110)
      temp = temp + M(94, 81) * M(81, 110)
      temp = temp + M(94, 83) * M(83, 110)
      temp = temp + M(94, 87) * M(87, 110)
      temp = temp + M(94, 91) * M(91, 110)
      temp = temp + M(94, 92) * M(92, 110)
      temp = temp + M(94, 93) * M(93, 110)
      M(94, 110) = ( M(94, 110) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 47) * M(47, 111)
      temp = temp + M(94, 48) * M(48, 111)
      temp = temp + M(94, 55) * M(55, 111)
      temp = temp + M(94, 61) * M(61, 111)
      temp = temp + M(94, 81) * M(81, 111)
      temp = temp + M(94, 83) * M(83, 111)
      temp = temp + M(94, 87) * M(87, 111)
      temp = temp + M(94, 91) * M(91, 111)
      temp = temp + M(94, 92) * M(92, 111)
      temp = temp + M(94, 93) * M(93, 111)
      M(94, 111) = ( M(94, 111) - temp ) / M(94, 94)
C     Upper part.
      temp = M(94, 18) * M(18, 112)
      temp = temp + M(94, 22) * M(22, 112)
      temp = temp + M(94, 29) * M(29, 112)
      temp = temp + M(94, 47) * M(47, 112)
      temp = temp + M(94, 48) * M(48, 112)
      temp = temp + M(94, 53) * M(53, 112)
      temp = temp + M(94, 55) * M(55, 112)
      temp = temp + M(94, 61) * M(61, 112)
      temp = temp + M(94, 81) * M(81, 112)
      temp = temp + M(94, 83) * M(83, 112)
      temp = temp + M(94, 87) * M(87, 112)
      temp = temp + M(94, 91) * M(91, 112)
      temp = temp + M(94, 92) * M(92, 112)
      temp = temp + M(94, 93) * M(93, 112)
      M(94, 112) = ( M(94, 112) - temp ) / M(94, 94)

C     Lower part.
      temp = M(95, 28) * M(28, 95)
      temp = temp + M(95, 40) * M(40, 95)
      M(95, 95) = M(95, 95) - temp
C     Lower part.
      temp = M(96, 87) * M(87, 95)
      temp = temp + M(96, 93) * M(93, 95)
      M(96, 95) = M(96, 95) - temp
C     Lower part.
      temp = M(100, 87) * M(87, 95)
      M(100, 95) = M(100, 95) - temp
C     Lower part.
      temp = M(105, 87) * M(87, 95)
      temp = temp + M(105, 93) * M(93, 95)
      M(105, 95) = M(105, 95) - temp
C     Lower part.
      temp = M(107, 85) * M(85, 95)
      M(107, 95) = M(107, 95) - temp
C     Lower part.
      temp = M(108, 89) * M(89, 95)
      M(108, 95) = M(108, 95) - temp
C     Lower part.
      temp = M(109, 40) * M(40, 95)
      temp = temp + M(109, 87) * M(87, 95)
      temp = temp + M(109, 93) * M(93, 95)
      temp = temp + M(109, 94) * M(94, 95)
      M(109, 95) = M(109, 95) - temp
C     Lower part.
      temp = M(110, 40) * M(40, 95)
      temp = temp + M(110, 94) * M(94, 95)
      M(110, 95) = M(110, 95) - temp
C     Lower part.
      temp = M(111, 73) * M(73, 95)
      temp = temp + M(111, 85) * M(85, 95)
      temp = temp + M(111, 87) * M(87, 95)
      temp = temp + M(111, 89) * M(89, 95)
      temp = temp + M(111, 93) * M(93, 95)
      M(111, 95) = M(111, 95) - temp
C     Lower part.
      temp = M(112, 28) * M(28, 95)
      temp = temp + M(112, 40) * M(40, 95)
      temp = temp + M(112, 73) * M(73, 95)
      temp = temp + M(112, 85) * M(85, 95)
      temp = temp + M(112, 87) * M(87, 95)
      temp = temp + M(112, 89) * M(89, 95)
      temp = temp + M(112, 93) * M(93, 95)
      temp = temp + M(112, 94) * M(94, 95)
      M(112, 95) = M(112, 95) - temp
C     Upper part.
      temp = M(95, 61) * M(61, 100)
      temp = temp + M(95, 66) * M(66, 100)
      temp = temp + M(95, 81) * M(81, 100)
      temp = temp + M(95, 83) * M(83, 100)
      M(95, 100) = ( M(95, 100) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 61) * M(61, 102)
      temp = temp + M(95, 66) * M(66, 102)
      temp = temp + M(95, 81) * M(81, 102)
      temp = temp + M(95, 83) * M(83, 102)
      M(95, 102) = ( M(95, 102) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 61) * M(61, 105)
      temp = temp + M(95, 66) * M(66, 105)
      temp = temp + M(95, 81) * M(81, 105)
      temp = temp + M(95, 83) * M(83, 105)
      M(95, 105) = ( M(95, 105) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 26) * M(26, 109)
      temp = temp + M(95, 40) * M(40, 109)
      temp = temp + M(95, 61) * M(61, 109)
      temp = temp + M(95, 66) * M(66, 109)
      temp = temp + M(95, 81) * M(81, 109)
      temp = temp + M(95, 83) * M(83, 109)
      M(95, 109) = ( M(95, 109) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 40) * M(40, 110)
      temp = temp + M(95, 81) * M(81, 110)
      temp = temp + M(95, 83) * M(83, 110)
      M(95, 110) = ( M(95, 110) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 28) * M(28, 111)
      temp = temp + M(95, 61) * M(61, 111)
      temp = temp + M(95, 66) * M(66, 111)
      temp = temp + M(95, 81) * M(81, 111)
      temp = temp + M(95, 83) * M(83, 111)
      M(95, 111) = ( M(95, 111) - temp ) / M(95, 95)
C     Upper part.
      temp = M(95, 26) * M(26, 112)
      temp = temp + M(95, 28) * M(28, 112)
      temp = temp + M(95, 40) * M(40, 112)
      temp = temp + M(95, 61) * M(61, 112)
      temp = temp + M(95, 66) * M(66, 112)
      temp = temp + M(95, 81) * M(81, 112)
      temp = temp + M(95, 83) * M(83, 112)
      M(95, 112) = ( M(95, 112) - temp ) / M(95, 95)

C     Upper part.
      temp = M(96, 91) * M(91, 97)
      M(96, 97) = ( M(96, 97) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 87) * M(87, 99)
      temp = temp + M(96, 91) * M(91, 99)
      M(96, 99) = ( M(96, 99) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 53) * M(53, 100)
      temp = temp + M(96, 56) * M(56, 100)
      temp = temp + M(96, 59) * M(59, 100)
      temp = temp + M(96, 61) * M(61, 100)
      temp = temp + M(96, 66) * M(66, 100)
      temp = temp + M(96, 69) * M(69, 100)
      temp = temp + M(96, 77) * M(77, 100)
      temp = temp + M(96, 78) * M(78, 100)
      temp = temp + M(96, 80) * M(80, 100)
      temp = temp + M(96, 81) * M(81, 100)
      temp = temp + M(96, 83) * M(83, 100)
      temp = temp + M(96, 84) * M(84, 100)
      temp = temp + M(96, 86) * M(86, 100)
      temp = temp + M(96, 87) * M(87, 100)
      temp = temp + M(96, 91) * M(91, 100)
      temp = temp + M(96, 92) * M(92, 100)
      temp = temp + M(96, 93) * M(93, 100)
      temp = temp + M(96, 95) * M(95, 100)
      M(96, 100) = ( M(96, 100) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 39) * M(39, 102)
      temp = temp + M(96, 53) * M(53, 102)
      temp = temp + M(96, 56) * M(56, 102)
      temp = temp + M(96, 59) * M(59, 102)
      temp = temp + M(96, 61) * M(61, 102)
      temp = temp + M(96, 66) * M(66, 102)
      temp = temp + M(96, 69) * M(69, 102)
      temp = temp + M(96, 77) * M(77, 102)
      temp = temp + M(96, 78) * M(78, 102)
      temp = temp + M(96, 80) * M(80, 102)
      temp = temp + M(96, 81) * M(81, 102)
      temp = temp + M(96, 83) * M(83, 102)
      temp = temp + M(96, 84) * M(84, 102)
      temp = temp + M(96, 86) * M(86, 102)
      temp = temp + M(96, 87) * M(87, 102)
      temp = temp + M(96, 91) * M(91, 102)
      temp = temp + M(96, 92) * M(92, 102)
      temp = temp + M(96, 93) * M(93, 102)
      temp = temp + M(96, 95) * M(95, 102)
      M(96, 102) = ( M(96, 102) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 92) * M(92, 103)
      temp = temp + M(96, 93) * M(93, 103)
      M(96, 103) = ( M(96, 103) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 87) * M(87, 104)
      M(96, 104) = ( M(96, 104) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 53) * M(53, 105)
      temp = temp + M(96, 56) * M(56, 105)
      temp = temp + M(96, 59) * M(59, 105)
      temp = temp + M(96, 61) * M(61, 105)
      temp = temp + M(96, 66) * M(66, 105)
      temp = temp + M(96, 69) * M(69, 105)
      temp = temp + M(96, 77) * M(77, 105)
      temp = temp + M(96, 78) * M(78, 105)
      temp = temp + M(96, 80) * M(80, 105)
      temp = temp + M(96, 81) * M(81, 105)
      temp = temp + M(96, 83) * M(83, 105)
      temp = temp + M(96, 84) * M(84, 105)
      temp = temp + M(96, 86) * M(86, 105)
      temp = temp + M(96, 87) * M(87, 105)
      temp = temp + M(96, 91) * M(91, 105)
      temp = temp + M(96, 92) * M(92, 105)
      temp = temp + M(96, 93) * M(93, 105)
      temp = temp + M(96, 95) * M(95, 105)
      M(96, 105) = ( M(96, 105) - temp ) / M(96, 96)
C     Upper part.
      M(96, 107) = M(96, 107) / M(96, 96)
C     Upper part.
      M(96, 108) = M(96, 108) / M(96, 96)
C     Upper part.
      temp = M(96, 19) * M(19, 109)
      temp = temp + M(96, 20) * M(20, 109)
      temp = temp + M(96, 22) * M(22, 109)
      temp = temp + M(96, 23) * M(23, 109)
      temp = temp + M(96, 26) * M(26, 109)
      temp = temp + M(96, 27) * M(27, 109)
      temp = temp + M(96, 31) * M(31, 109)
      temp = temp + M(96, 39) * M(39, 109)
      temp = temp + M(96, 53) * M(53, 109)
      temp = temp + M(96, 56) * M(56, 109)
      temp = temp + M(96, 59) * M(59, 109)
      temp = temp + M(96, 61) * M(61, 109)
      temp = temp + M(96, 66) * M(66, 109)
      temp = temp + M(96, 69) * M(69, 109)
      temp = temp + M(96, 77) * M(77, 109)
      temp = temp + M(96, 78) * M(78, 109)
      temp = temp + M(96, 80) * M(80, 109)
      temp = temp + M(96, 81) * M(81, 109)
      temp = temp + M(96, 83) * M(83, 109)
      temp = temp + M(96, 84) * M(84, 109)
      temp = temp + M(96, 86) * M(86, 109)
      temp = temp + M(96, 87) * M(87, 109)
      temp = temp + M(96, 91) * M(91, 109)
      temp = temp + M(96, 92) * M(92, 109)
      temp = temp + M(96, 93) * M(93, 109)
      temp = temp + M(96, 95) * M(95, 109)
      M(96, 109) = ( M(96, 109) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 81) * M(81, 110)
      temp = temp + M(96, 83) * M(83, 110)
      temp = temp + M(96, 84) * M(84, 110)
      temp = temp + M(96, 87) * M(87, 110)
      temp = temp + M(96, 91) * M(91, 110)
      temp = temp + M(96, 92) * M(92, 110)
      temp = temp + M(96, 93) * M(93, 110)
      temp = temp + M(96, 95) * M(95, 110)
      M(96, 110) = ( M(96, 110) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 56) * M(56, 111)
      temp = temp + M(96, 59) * M(59, 111)
      temp = temp + M(96, 61) * M(61, 111)
      temp = temp + M(96, 66) * M(66, 111)
      temp = temp + M(96, 69) * M(69, 111)
      temp = temp + M(96, 77) * M(77, 111)
      temp = temp + M(96, 78) * M(78, 111)
      temp = temp + M(96, 80) * M(80, 111)
      temp = temp + M(96, 81) * M(81, 111)
      temp = temp + M(96, 83) * M(83, 111)
      temp = temp + M(96, 84) * M(84, 111)
      temp = temp + M(96, 86) * M(86, 111)
      temp = temp + M(96, 87) * M(87, 111)
      temp = temp + M(96, 91) * M(91, 111)
      temp = temp + M(96, 92) * M(92, 111)
      temp = temp + M(96, 93) * M(93, 111)
      temp = temp + M(96, 95) * M(95, 111)
      M(96, 111) = ( M(96, 111) - temp ) / M(96, 96)
C     Upper part.
      temp = M(96, 4) * M(4, 112)
      temp = temp + M(96, 17) * M(17, 112)
      temp = temp + M(96, 19) * M(19, 112)
      temp = temp + M(96, 20) * M(20, 112)
      temp = temp + M(96, 22) * M(22, 112)
      temp = temp + M(96, 23) * M(23, 112)
      temp = temp + M(96, 26) * M(26, 112)
      temp = temp + M(96, 27) * M(27, 112)
      temp = temp + M(96, 31) * M(31, 112)
      temp = temp + M(96, 39) * M(39, 112)
      temp = temp + M(96, 53) * M(53, 112)
      temp = temp + M(96, 56) * M(56, 112)
      temp = temp + M(96, 59) * M(59, 112)
      temp = temp + M(96, 61) * M(61, 112)
      temp = temp + M(96, 66) * M(66, 112)
      temp = temp + M(96, 69) * M(69, 112)
      temp = temp + M(96, 77) * M(77, 112)
      temp = temp + M(96, 78) * M(78, 112)
      temp = temp + M(96, 80) * M(80, 112)
      temp = temp + M(96, 81) * M(81, 112)
      temp = temp + M(96, 83) * M(83, 112)
      temp = temp + M(96, 84) * M(84, 112)
      temp = temp + M(96, 86) * M(86, 112)
      temp = temp + M(96, 87) * M(87, 112)
      temp = temp + M(96, 91) * M(91, 112)
      temp = temp + M(96, 92) * M(92, 112)
      temp = temp + M(96, 93) * M(93, 112)
      temp = temp + M(96, 95) * M(95, 112)
      M(96, 112) = ( M(96, 112) - temp ) / M(96, 96)

C     Lower part.
      temp = M(100, 90) * M(90, 97)
      M(100, 97) = M(100, 97) - temp
C     Lower part.
      temp = M(102, 90) * M(90, 97)
      M(102, 97) = M(102, 97) - temp
C     Lower part.
      temp = M(105, 90) * M(90, 97)
      M(105, 97) = M(105, 97) - temp
C     Lower part.
      temp = M(106, 90) * M(90, 97)
      M(106, 97) = M(106, 97) - temp
C     Lower part.
      temp = M(108, 90) * M(90, 97)
      temp = temp + M(108, 91) * M(91, 97)
      M(108, 97) = M(108, 97) - temp
C     Lower part.
      temp = M(109, 90) * M(90, 97)
      temp = temp + M(109, 91) * M(91, 97)
      temp = temp + M(109, 94) * M(94, 97)
      M(109, 97) = M(109, 97) - temp
C     Lower part.
      temp = M(110, 90) * M(90, 97)
      temp = temp + M(110, 94) * M(94, 97)
      M(110, 97) = M(110, 97) - temp
C     Lower part.
      temp = M(111, 90) * M(90, 97)
      temp = temp + M(111, 91) * M(91, 97)
      temp = temp + M(111, 96) * M(96, 97)
      M(111, 97) = M(111, 97) - temp
C     Lower part.
      temp = M(112, 91) * M(91, 97)
      temp = temp + M(112, 94) * M(94, 97)
      temp = temp + M(112, 96) * M(96, 97)
      M(112, 97) = M(112, 97) - temp
C     Upper part.
      M(97, 98) = M(97, 98) / M(97, 97)
C     Upper part.
      temp = M(97, 65) * M(65, 99)
      M(97, 99) = ( M(97, 99) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 57) * M(57, 100)
      temp = temp + M(97, 59) * M(59, 100)
      temp = temp + M(97, 60) * M(60, 100)
      temp = temp + M(97, 62) * M(62, 100)
      temp = temp + M(97, 64) * M(64, 100)
      temp = temp + M(97, 65) * M(65, 100)
      temp = temp + M(97, 68) * M(68, 100)
      temp = temp + M(97, 69) * M(69, 100)
      temp = temp + M(97, 70) * M(70, 100)
      temp = temp + M(97, 71) * M(71, 100)
      temp = temp + M(97, 72) * M(72, 100)
      temp = temp + M(97, 78) * M(78, 100)
      temp = temp + M(97, 79) * M(79, 100)
      temp = temp + M(97, 81) * M(81, 100)
      temp = temp + M(97, 83) * M(83, 100)
      temp = temp + M(97, 84) * M(84, 100)
      temp = temp + M(97, 86) * M(86, 100)
      temp = temp + M(97, 88) * M(88, 100)
      temp = temp + M(97, 92) * M(92, 100)
      temp = temp + M(97, 95) * M(95, 100)
      M(97, 100) = ( M(97, 100) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 57) * M(57, 102)
      temp = temp + M(97, 59) * M(59, 102)
      temp = temp + M(97, 60) * M(60, 102)
      temp = temp + M(97, 62) * M(62, 102)
      temp = temp + M(97, 64) * M(64, 102)
      temp = temp + M(97, 65) * M(65, 102)
      temp = temp + M(97, 68) * M(68, 102)
      temp = temp + M(97, 69) * M(69, 102)
      temp = temp + M(97, 70) * M(70, 102)
      temp = temp + M(97, 71) * M(71, 102)
      temp = temp + M(97, 72) * M(72, 102)
      temp = temp + M(97, 78) * M(78, 102)
      temp = temp + M(97, 79) * M(79, 102)
      temp = temp + M(97, 81) * M(81, 102)
      temp = temp + M(97, 83) * M(83, 102)
      temp = temp + M(97, 84) * M(84, 102)
      temp = temp + M(97, 86) * M(86, 102)
      temp = temp + M(97, 88) * M(88, 102)
      temp = temp + M(97, 92) * M(92, 102)
      temp = temp + M(97, 95) * M(95, 102)
      M(97, 102) = ( M(97, 102) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 92) * M(92, 103)
      M(97, 103) = ( M(97, 103) - temp ) / M(97, 97)
C     Upper part.
      M(97, 104) = M(97, 104) / M(97, 97)
C     Upper part.
      temp = M(97, 57) * M(57, 105)
      temp = temp + M(97, 59) * M(59, 105)
      temp = temp + M(97, 60) * M(60, 105)
      temp = temp + M(97, 62) * M(62, 105)
      temp = temp + M(97, 64) * M(64, 105)
      temp = temp + M(97, 65) * M(65, 105)
      temp = temp + M(97, 68) * M(68, 105)
      temp = temp + M(97, 69) * M(69, 105)
      temp = temp + M(97, 70) * M(70, 105)
      temp = temp + M(97, 71) * M(71, 105)
      temp = temp + M(97, 72) * M(72, 105)
      temp = temp + M(97, 78) * M(78, 105)
      temp = temp + M(97, 79) * M(79, 105)
      temp = temp + M(97, 81) * M(81, 105)
      temp = temp + M(97, 83) * M(83, 105)
      temp = temp + M(97, 84) * M(84, 105)
      temp = temp + M(97, 86) * M(86, 105)
      temp = temp + M(97, 88) * M(88, 105)
      temp = temp + M(97, 92) * M(92, 105)
      temp = temp + M(97, 95) * M(95, 105)
      M(97, 105) = ( M(97, 105) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 27) * M(27, 109)
      temp = temp + M(97, 31) * M(31, 109)
      temp = temp + M(97, 57) * M(57, 109)
      temp = temp + M(97, 59) * M(59, 109)
      temp = temp + M(97, 60) * M(60, 109)
      temp = temp + M(97, 62) * M(62, 109)
      temp = temp + M(97, 64) * M(64, 109)
      temp = temp + M(97, 65) * M(65, 109)
      temp = temp + M(97, 68) * M(68, 109)
      temp = temp + M(97, 69) * M(69, 109)
      temp = temp + M(97, 70) * M(70, 109)
      temp = temp + M(97, 71) * M(71, 109)
      temp = temp + M(97, 72) * M(72, 109)
      temp = temp + M(97, 78) * M(78, 109)
      temp = temp + M(97, 79) * M(79, 109)
      temp = temp + M(97, 81) * M(81, 109)
      temp = temp + M(97, 83) * M(83, 109)
      temp = temp + M(97, 84) * M(84, 109)
      temp = temp + M(97, 86) * M(86, 109)
      temp = temp + M(97, 88) * M(88, 109)
      temp = temp + M(97, 92) * M(92, 109)
      temp = temp + M(97, 95) * M(95, 109)
      M(97, 109) = ( M(97, 109) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 81) * M(81, 110)
      temp = temp + M(97, 83) * M(83, 110)
      temp = temp + M(97, 84) * M(84, 110)
      temp = temp + M(97, 88) * M(88, 110)
      temp = temp + M(97, 92) * M(92, 110)
      temp = temp + M(97, 95) * M(95, 110)
      M(97, 110) = ( M(97, 110) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 57) * M(57, 111)
      temp = temp + M(97, 59) * M(59, 111)
      temp = temp + M(97, 60) * M(60, 111)
      temp = temp + M(97, 62) * M(62, 111)
      temp = temp + M(97, 64) * M(64, 111)
      temp = temp + M(97, 65) * M(65, 111)
      temp = temp + M(97, 68) * M(68, 111)
      temp = temp + M(97, 69) * M(69, 111)
      temp = temp + M(97, 70) * M(70, 111)
      temp = temp + M(97, 71) * M(71, 111)
      temp = temp + M(97, 72) * M(72, 111)
      temp = temp + M(97, 78) * M(78, 111)
      temp = temp + M(97, 79) * M(79, 111)
      temp = temp + M(97, 81) * M(81, 111)
      temp = temp + M(97, 83) * M(83, 111)
      temp = temp + M(97, 84) * M(84, 111)
      temp = temp + M(97, 86) * M(86, 111)
      temp = temp + M(97, 88) * M(88, 111)
      temp = temp + M(97, 92) * M(92, 111)
      temp = temp + M(97, 95) * M(95, 111)
      M(97, 111) = ( M(97, 111) - temp ) / M(97, 97)
C     Upper part.
      temp = M(97, 27) * M(27, 112)
      temp = temp + M(97, 31) * M(31, 112)
      temp = temp + M(97, 57) * M(57, 112)
      temp = temp + M(97, 59) * M(59, 112)
      temp = temp + M(97, 60) * M(60, 112)
      temp = temp + M(97, 62) * M(62, 112)
      temp = temp + M(97, 64) * M(64, 112)
      temp = temp + M(97, 65) * M(65, 112)
      temp = temp + M(97, 68) * M(68, 112)
      temp = temp + M(97, 69) * M(69, 112)
      temp = temp + M(97, 70) * M(70, 112)
      temp = temp + M(97, 71) * M(71, 112)
      temp = temp + M(97, 72) * M(72, 112)
      temp = temp + M(97, 78) * M(78, 112)
      temp = temp + M(97, 79) * M(79, 112)
      temp = temp + M(97, 81) * M(81, 112)
      temp = temp + M(97, 83) * M(83, 112)
      temp = temp + M(97, 84) * M(84, 112)
      temp = temp + M(97, 86) * M(86, 112)
      temp = temp + M(97, 88) * M(88, 112)
      temp = temp + M(97, 92) * M(92, 112)
      temp = temp + M(97, 95) * M(95, 112)
      M(97, 112) = ( M(97, 112) - temp ) / M(97, 97)

C     Lower part.
      temp = M(98, 37) * M(37, 98)
      M(98, 98) = M(98, 98) - temp
C     Lower part.
      temp = M(100, 74) * M(74, 98)
      temp = temp + M(100, 97) * M(97, 98)
      M(100, 98) = M(100, 98) - temp
C     Lower part.
      temp = M(101, 37) * M(37, 98)
      temp = temp + M(101, 74) * M(74, 98)
      M(101, 98) = M(101, 98) - temp
C     Lower part.
      temp = M(102, 97) * M(97, 98)
      M(102, 98) = M(102, 98) - temp
C     Lower part.
      temp = M(105, 74) * M(74, 98)
      temp = temp + M(105, 97) * M(97, 98)
      M(105, 98) = M(105, 98) - temp
C     Lower part.
      temp = M(106, 97) * M(97, 98)
      M(106, 98) = M(106, 98) - temp
C     Lower part.
      temp = M(108, 37) * M(37, 98)
      temp = temp + M(108, 74) * M(74, 98)
      temp = temp + M(108, 97) * M(97, 98)
      M(108, 98) = M(108, 98) - temp
C     Lower part.
      temp = M(109, 37) * M(37, 98)
      temp = temp + M(109, 97) * M(97, 98)
      M(109, 98) = M(109, 98) - temp
C     Lower part.
      temp = M(110, 37) * M(37, 98)
      temp = temp + M(110, 97) * M(97, 98)
      M(110, 98) = M(110, 98) - temp
C     Lower part.
      temp = M(111, 97) * M(97, 98)
      M(111, 98) = M(111, 98) - temp
C     Lower part.
      temp = M(112, 37) * M(37, 98)
      temp = temp + M(112, 74) * M(74, 98)
      temp = temp + M(112, 97) * M(97, 98)
      M(112, 98) = M(112, 98) - temp
C     Upper part.
      M(98, 100) = M(98, 100) / M(98, 98)
C     Upper part.
      M(98, 102) = M(98, 102) / M(98, 98)
C     Upper part.
      M(98, 105) = M(98, 105) / M(98, 98)
C     Upper part.
      M(98, 107) = M(98, 107) / M(98, 98)
C     Upper part.
      M(98, 109) = M(98, 109) / M(98, 98)
C     Upper part.
      temp = M(98, 37) * M(37, 110)
      M(98, 110) = ( M(98, 110) - temp ) / M(98, 98)
C     Upper part.
      M(98, 111) = M(98, 111) / M(98, 98)
C     Upper part.
      temp = M(98, 37) * M(37, 112)
      M(98, 112) = ( M(98, 112) - temp ) / M(98, 98)

C     Lower part.
      temp = M(100, 58) * M(58, 99)
      temp = temp + M(100, 65) * M(65, 99)
      temp = temp + M(100, 87) * M(87, 99)
      temp = temp + M(100, 97) * M(97, 99)
      M(100, 99) = M(100, 99) - temp
C     Lower part.
      temp = M(102, 65) * M(65, 99)
      temp = temp + M(102, 97) * M(97, 99)
      M(102, 99) = M(102, 99) - temp
C     Lower part.
      temp = M(105, 58) * M(58, 99)
      temp = temp + M(105, 65) * M(65, 99)
      temp = temp + M(105, 87) * M(87, 99)
      temp = temp + M(105, 97) * M(97, 99)
      M(105, 99) = M(105, 99) - temp
C     Lower part.
      temp = M(106, 65) * M(65, 99)
      temp = temp + M(106, 97) * M(97, 99)
      M(106, 99) = M(106, 99) - temp
C     Lower part.
      temp = M(107, 85) * M(85, 99)
      M(107, 99) = M(107, 99) - temp
C     Lower part.
      temp = M(108, 65) * M(65, 99)
      temp = temp + M(108, 89) * M(89, 99)
      temp = temp + M(108, 91) * M(91, 99)
      temp = temp + M(108, 97) * M(97, 99)
      M(108, 99) = M(108, 99) - temp
C     Lower part.
      temp = M(109, 65) * M(65, 99)
      temp = temp + M(109, 87) * M(87, 99)
      temp = temp + M(109, 91) * M(91, 99)
      temp = temp + M(109, 94) * M(94, 99)
      temp = temp + M(109, 97) * M(97, 99)
      M(109, 99) = M(109, 99) - temp
C     Lower part.
      temp = M(110, 65) * M(65, 99)
      temp = temp + M(110, 94) * M(94, 99)
      temp = temp + M(110, 97) * M(97, 99)
      M(110, 99) = M(110, 99) - temp
C     Lower part.
      temp = M(111, 65) * M(65, 99)
      temp = temp + M(111, 85) * M(85, 99)
      temp = temp + M(111, 87) * M(87, 99)
      temp = temp + M(111, 89) * M(89, 99)
      temp = temp + M(111, 91) * M(91, 99)
      temp = temp + M(111, 96) * M(96, 99)
      temp = temp + M(111, 97) * M(97, 99)
      M(111, 99) = M(111, 99) - temp
C     Lower part.
      temp = M(112, 58) * M(58, 99)
      temp = temp + M(112, 65) * M(65, 99)
      temp = temp + M(112, 85) * M(85, 99)
      temp = temp + M(112, 87) * M(87, 99)
      temp = temp + M(112, 89) * M(89, 99)
      temp = temp + M(112, 91) * M(91, 99)
      temp = temp + M(112, 94) * M(94, 99)
      temp = temp + M(112, 96) * M(96, 99)
      temp = temp + M(112, 97) * M(97, 99)
      M(112, 99) = M(112, 99) - temp
C     Upper part.
      M(99, 100) = M(99, 100) / M(99, 99)
C     Upper part.
      M(99, 102) = M(99, 102) / M(99, 99)
C     Upper part.
      M(99, 105) = M(99, 105) / M(99, 99)
C     Upper part.
      M(99, 106) = M(99, 106) / M(99, 99)
C     Upper part.
      M(99, 109) = M(99, 109) / M(99, 99)
C     Upper part.
      M(99, 111) = M(99, 111) / M(99, 99)
C     Upper part.
      temp = M(99, 6) * M(6, 112)
      M(99, 112) = ( M(99, 112) - temp ) / M(99, 99)
C     Upper part.
      M(99, 113) = M(99, 113) / M(99, 99)

C     Lower part.
      temp = M(100, 34) * M(34, 100)
      temp = temp + M(100, 41) * M(41, 100)
      temp = temp + M(100, 42) * M(42, 100)
      temp = temp + M(100, 43) * M(43, 100)
      temp = temp + M(100, 45) * M(45, 100)
      temp = temp + M(100, 49) * M(49, 100)
      temp = temp + M(100, 50) * M(50, 100)
      temp = temp + M(100, 51) * M(51, 100)
      temp = temp + M(100, 52) * M(52, 100)
      temp = temp + M(100, 53) * M(53, 100)
      temp = temp + M(100, 54) * M(54, 100)
      temp = temp + M(100, 55) * M(55, 100)
      temp = temp + M(100, 57) * M(57, 100)
      temp = temp + M(100, 58) * M(58, 100)
      temp = temp + M(100, 59) * M(59, 100)
      temp = temp + M(100, 60) * M(60, 100)
      temp = temp + M(100, 62) * M(62, 100)
      temp = temp + M(100, 63) * M(63, 100)
      temp = temp + M(100, 64) * M(64, 100)
      temp = temp + M(100, 65) * M(65, 100)
      temp = temp + M(100, 66) * M(66, 100)
      temp = temp + M(100, 68) * M(68, 100)
      temp = temp + M(100, 69) * M(69, 100)
      temp = temp + M(100, 70) * M(70, 100)
      temp = temp + M(100, 71) * M(71, 100)
      temp = temp + M(100, 72) * M(72, 100)
      temp = temp + M(100, 75) * M(75, 100)
      temp = temp + M(100, 78) * M(78, 100)
      temp = temp + M(100, 79) * M(79, 100)
      temp = temp + M(100, 80) * M(80, 100)
      temp = temp + M(100, 81) * M(81, 100)
      temp = temp + M(100, 82) * M(82, 100)
      temp = temp + M(100, 83) * M(83, 100)
      temp = temp + M(100, 84) * M(84, 100)
      temp = temp + M(100, 86) * M(86, 100)
      temp = temp + M(100, 87) * M(87, 100)
      temp = temp + M(100, 88) * M(88, 100)
      temp = temp + M(100, 90) * M(90, 100)
      temp = temp + M(100, 92) * M(92, 100)
      temp = temp + M(100, 95) * M(95, 100)
      temp = temp + M(100, 97) * M(97, 100)
      temp = temp + M(100, 98) * M(98, 100)
      temp = temp + M(100, 99) * M(99, 100)
      M(100, 100) = M(100, 100) - temp
C     Lower part.
      temp = M(101, 56) * M(56, 100)
      temp = temp + M(101, 61) * M(61, 100)
      temp = temp + M(101, 62) * M(62, 100)
      temp = temp + M(101, 66) * M(66, 100)
      temp = temp + M(101, 68) * M(68, 100)
      temp = temp + M(101, 77) * M(77, 100)
      temp = temp + M(101, 78) * M(78, 100)
      temp = temp + M(101, 80) * M(80, 100)
      temp = temp + M(101, 81) * M(81, 100)
      temp = temp + M(101, 83) * M(83, 100)
      temp = temp + M(101, 86) * M(86, 100)
      temp = temp + M(101, 92) * M(92, 100)
      temp = temp + M(101, 98) * M(98, 100)
      temp = temp + M(101, 99) * M(99, 100)
      M(101, 100) = M(101, 100) - temp
C     Lower part.
      temp = M(102, 41) * M(41, 100)
      temp = temp + M(102, 42) * M(42, 100)
      temp = temp + M(102, 43) * M(43, 100)
      temp = temp + M(102, 45) * M(45, 100)
      temp = temp + M(102, 49) * M(49, 100)
      temp = temp + M(102, 50) * M(50, 100)
      temp = temp + M(102, 51) * M(51, 100)
      temp = temp + M(102, 52) * M(52, 100)
      temp = temp + M(102, 53) * M(53, 100)
      temp = temp + M(102, 54) * M(54, 100)
      temp = temp + M(102, 55) * M(55, 100)
      temp = temp + M(102, 57) * M(57, 100)
      temp = temp + M(102, 59) * M(59, 100)
      temp = temp + M(102, 60) * M(60, 100)
      temp = temp + M(102, 62) * M(62, 100)
      temp = temp + M(102, 63) * M(63, 100)
      temp = temp + M(102, 64) * M(64, 100)
      temp = temp + M(102, 65) * M(65, 100)
      temp = temp + M(102, 68) * M(68, 100)
      temp = temp + M(102, 70) * M(70, 100)
      temp = temp + M(102, 71) * M(71, 100)
      temp = temp + M(102, 72) * M(72, 100)
      temp = temp + M(102, 75) * M(75, 100)
      temp = temp + M(102, 79) * M(79, 100)
      temp = temp + M(102, 81) * M(81, 100)
      temp = temp + M(102, 82) * M(82, 100)
      temp = temp + M(102, 83) * M(83, 100)
      temp = temp + M(102, 84) * M(84, 100)
      temp = temp + M(102, 86) * M(86, 100)
      temp = temp + M(102, 88) * M(88, 100)
      temp = temp + M(102, 90) * M(90, 100)
      temp = temp + M(102, 92) * M(92, 100)
      temp = temp + M(102, 95) * M(95, 100)
      temp = temp + M(102, 97) * M(97, 100)
      temp = temp + M(102, 98) * M(98, 100)
      temp = temp + M(102, 99) * M(99, 100)
      M(102, 100) = M(102, 100) - temp
C     Lower part.
      temp = M(103, 57) * M(57, 100)
      temp = temp + M(103, 60) * M(60, 100)
      temp = temp + M(103, 62) * M(62, 100)
      temp = temp + M(103, 69) * M(69, 100)
      temp = temp + M(103, 70) * M(70, 100)
      temp = temp + M(103, 71) * M(71, 100)
      temp = temp + M(103, 72) * M(72, 100)
      temp = temp + M(103, 79) * M(79, 100)
      temp = temp + M(103, 80) * M(80, 100)
      temp = temp + M(103, 81) * M(81, 100)
      temp = temp + M(103, 83) * M(83, 100)
      temp = temp + M(103, 84) * M(84, 100)
      temp = temp + M(103, 86) * M(86, 100)
      temp = temp + M(103, 99) * M(99, 100)
      M(103, 100) = M(103, 100) - temp
C     Lower part.
      temp = M(104, 62) * M(62, 100)
      temp = temp + M(104, 69) * M(69, 100)
      temp = temp + M(104, 81) * M(81, 100)
      temp = temp + M(104, 83) * M(83, 100)
      temp = temp + M(104, 86) * M(86, 100)
      temp = temp + M(104, 98) * M(98, 100)
      temp = temp + M(104, 99) * M(99, 100)
      M(104, 100) = M(104, 100) - temp
C     Lower part.
      temp = M(105, 41) * M(41, 100)
      temp = temp + M(105, 42) * M(42, 100)
      temp = temp + M(105, 43) * M(43, 100)
      temp = temp + M(105, 45) * M(45, 100)
      temp = temp + M(105, 49) * M(49, 100)
      temp = temp + M(105, 50) * M(50, 100)
      temp = temp + M(105, 51) * M(51, 100)
      temp = temp + M(105, 52) * M(52, 100)
      temp = temp + M(105, 53) * M(53, 100)
      temp = temp + M(105, 54) * M(54, 100)
      temp = temp + M(105, 55) * M(55, 100)
      temp = temp + M(105, 56) * M(56, 100)
      temp = temp + M(105, 57) * M(57, 100)
      temp = temp + M(105, 58) * M(58, 100)
      temp = temp + M(105, 59) * M(59, 100)
      temp = temp + M(105, 60) * M(60, 100)
      temp = temp + M(105, 61) * M(61, 100)
      temp = temp + M(105, 62) * M(62, 100)
      temp = temp + M(105, 63) * M(63, 100)
      temp = temp + M(105, 64) * M(64, 100)
      temp = temp + M(105, 65) * M(65, 100)
      temp = temp + M(105, 66) * M(66, 100)
      temp = temp + M(105, 68) * M(68, 100)
      temp = temp + M(105, 70) * M(70, 100)
      temp = temp + M(105, 71) * M(71, 100)
      temp = temp + M(105, 72) * M(72, 100)
      temp = temp + M(105, 75) * M(75, 100)
      temp = temp + M(105, 76) * M(76, 100)
      temp = temp + M(105, 77) * M(77, 100)
      temp = temp + M(105, 78) * M(78, 100)
      temp = temp + M(105, 79) * M(79, 100)
      temp = temp + M(105, 80) * M(80, 100)
      temp = temp + M(105, 81) * M(81, 100)
      temp = temp + M(105, 82) * M(82, 100)
      temp = temp + M(105, 83) * M(83, 100)
      temp = temp + M(105, 84) * M(84, 100)
      temp = temp + M(105, 86) * M(86, 100)
      temp = temp + M(105, 87) * M(87, 100)
      temp = temp + M(105, 88) * M(88, 100)
      temp = temp + M(105, 90) * M(90, 100)
      temp = temp + M(105, 92) * M(92, 100)
      temp = temp + M(105, 93) * M(93, 100)
      temp = temp + M(105, 95) * M(95, 100)
      temp = temp + M(105, 97) * M(97, 100)
      temp = temp + M(105, 98) * M(98, 100)
      temp = temp + M(105, 99) * M(99, 100)
      M(105, 100) = M(105, 100) - temp
C     Lower part.
      temp = M(106, 51) * M(51, 100)
      temp = temp + M(106, 53) * M(53, 100)
      temp = temp + M(106, 55) * M(55, 100)
      temp = temp + M(106, 57) * M(57, 100)
      temp = temp + M(106, 60) * M(60, 100)
      temp = temp + M(106, 62) * M(62, 100)
      temp = temp + M(106, 63) * M(63, 100)
      temp = temp + M(106, 64) * M(64, 100)
      temp = temp + M(106, 65) * M(65, 100)
      temp = temp + M(106, 68) * M(68, 100)
      temp = temp + M(106, 72) * M(72, 100)
      temp = temp + M(106, 75) * M(75, 100)
      temp = temp + M(106, 79) * M(79, 100)
      temp = temp + M(106, 81) * M(81, 100)
      temp = temp + M(106, 82) * M(82, 100)
      temp = temp + M(106, 83) * M(83, 100)
      temp = temp + M(106, 84) * M(84, 100)
      temp = temp + M(106, 86) * M(86, 100)
      temp = temp + M(106, 88) * M(88, 100)
      temp = temp + M(106, 90) * M(90, 100)
      temp = temp + M(106, 92) * M(92, 100)
      temp = temp + M(106, 97) * M(97, 100)
      temp = temp + M(106, 98) * M(98, 100)
      temp = temp + M(106, 99) * M(99, 100)
      M(106, 100) = M(106, 100) - temp
C     Lower part.
      temp = M(107, 24) * M(24, 100)
      temp = temp + M(107, 56) * M(56, 100)
      temp = temp + M(107, 57) * M(57, 100)
      temp = temp + M(107, 62) * M(62, 100)
      temp = temp + M(107, 68) * M(68, 100)
      temp = temp + M(107, 69) * M(69, 100)
      temp = temp + M(107, 70) * M(70, 100)
      temp = temp + M(107, 71) * M(71, 100)
      temp = temp + M(107, 72) * M(72, 100)
      temp = temp + M(107, 77) * M(77, 100)
      temp = temp + M(107, 79) * M(79, 100)
      temp = temp + M(107, 80) * M(80, 100)
      temp = temp + M(107, 81) * M(81, 100)
      temp = temp + M(107, 83) * M(83, 100)
      temp = temp + M(107, 84) * M(84, 100)
      temp = temp + M(107, 85) * M(85, 100)
      temp = temp + M(107, 86) * M(86, 100)
      temp = temp + M(107, 88) * M(88, 100)
      temp = temp + M(107, 92) * M(92, 100)
      temp = temp + M(107, 95) * M(95, 100)
      temp = temp + M(107, 99) * M(99, 100)
      M(107, 100) = M(107, 100) - temp
C     Lower part.
      temp = M(108, 34) * M(34, 100)
      temp = temp + M(108, 41) * M(41, 100)
      temp = temp + M(108, 42) * M(42, 100)
      temp = temp + M(108, 43) * M(43, 100)
      temp = temp + M(108, 45) * M(45, 100)
      temp = temp + M(108, 49) * M(49, 100)
      temp = temp + M(108, 50) * M(50, 100)
      temp = temp + M(108, 51) * M(51, 100)
      temp = temp + M(108, 52) * M(52, 100)
      temp = temp + M(108, 53) * M(53, 100)
      temp = temp + M(108, 54) * M(54, 100)
      temp = temp + M(108, 55) * M(55, 100)
      temp = temp + M(108, 57) * M(57, 100)
      temp = temp + M(108, 59) * M(59, 100)
      temp = temp + M(108, 60) * M(60, 100)
      temp = temp + M(108, 61) * M(61, 100)
      temp = temp + M(108, 62) * M(62, 100)
      temp = temp + M(108, 63) * M(63, 100)
      temp = temp + M(108, 64) * M(64, 100)
      temp = temp + M(108, 65) * M(65, 100)
      temp = temp + M(108, 66) * M(66, 100)
      temp = temp + M(108, 68) * M(68, 100)
      temp = temp + M(108, 69) * M(69, 100)
      temp = temp + M(108, 70) * M(70, 100)
      temp = temp + M(108, 71) * M(71, 100)
      temp = temp + M(108, 72) * M(72, 100)
      temp = temp + M(108, 75) * M(75, 100)
      temp = temp + M(108, 76) * M(76, 100)
      temp = temp + M(108, 78) * M(78, 100)
      temp = temp + M(108, 79) * M(79, 100)
      temp = temp + M(108, 80) * M(80, 100)
      temp = temp + M(108, 81) * M(81, 100)
      temp = temp + M(108, 82) * M(82, 100)
      temp = temp + M(108, 83) * M(83, 100)
      temp = temp + M(108, 84) * M(84, 100)
      temp = temp + M(108, 86) * M(86, 100)
      temp = temp + M(108, 88) * M(88, 100)
      temp = temp + M(108, 89) * M(89, 100)
      temp = temp + M(108, 90) * M(90, 100)
      temp = temp + M(108, 91) * M(91, 100)
      temp = temp + M(108, 92) * M(92, 100)
      temp = temp + M(108, 95) * M(95, 100)
      temp = temp + M(108, 97) * M(97, 100)
      temp = temp + M(108, 98) * M(98, 100)
      temp = temp + M(108, 99) * M(99, 100)
      M(108, 100) = M(108, 100) - temp
C     Lower part.
      temp = M(109, 41) * M(41, 100)
      temp = temp + M(109, 42) * M(42, 100)
      temp = temp + M(109, 43) * M(43, 100)
      temp = temp + M(109, 45) * M(45, 100)
      temp = temp + M(109, 47) * M(47, 100)
      temp = temp + M(109, 48) * M(48, 100)
      temp = temp + M(109, 49) * M(49, 100)
      temp = temp + M(109, 50) * M(50, 100)
      temp = temp + M(109, 51) * M(51, 100)
      temp = temp + M(109, 52) * M(52, 100)
      temp = temp + M(109, 53) * M(53, 100)
      temp = temp + M(109, 54) * M(54, 100)
      temp = temp + M(109, 55) * M(55, 100)
      temp = temp + M(109, 57) * M(57, 100)
      temp = temp + M(109, 59) * M(59, 100)
      temp = temp + M(109, 60) * M(60, 100)
      temp = temp + M(109, 61) * M(61, 100)
      temp = temp + M(109, 62) * M(62, 100)
      temp = temp + M(109, 63) * M(63, 100)
      temp = temp + M(109, 64) * M(64, 100)
      temp = temp + M(109, 65) * M(65, 100)
      temp = temp + M(109, 68) * M(68, 100)
      temp = temp + M(109, 69) * M(69, 100)
      temp = temp + M(109, 70) * M(70, 100)
      temp = temp + M(109, 71) * M(71, 100)
      temp = temp + M(109, 72) * M(72, 100)
      temp = temp + M(109, 75) * M(75, 100)
      temp = temp + M(109, 79) * M(79, 100)
      temp = temp + M(109, 80) * M(80, 100)
      temp = temp + M(109, 81) * M(81, 100)
      temp = temp + M(109, 82) * M(82, 100)
      temp = temp + M(109, 83) * M(83, 100)
      temp = temp + M(109, 84) * M(84, 100)
      temp = temp + M(109, 86) * M(86, 100)
      temp = temp + M(109, 87) * M(87, 100)
      temp = temp + M(109, 88) * M(88, 100)
      temp = temp + M(109, 90) * M(90, 100)
      temp = temp + M(109, 91) * M(91, 100)
      temp = temp + M(109, 92) * M(92, 100)
      temp = temp + M(109, 93) * M(93, 100)
      temp = temp + M(109, 94) * M(94, 100)
      temp = temp + M(109, 95) * M(95, 100)
      temp = temp + M(109, 97) * M(97, 100)
      temp = temp + M(109, 98) * M(98, 100)
      temp = temp + M(109, 99) * M(99, 100)
      M(109, 100) = M(109, 100) - temp
C     Lower part.
      temp = M(110, 41) * M(41, 100)
      temp = temp + M(110, 42) * M(42, 100)
      temp = temp + M(110, 43) * M(43, 100)
      temp = temp + M(110, 45) * M(45, 100)
      temp = temp + M(110, 46) * M(46, 100)
      temp = temp + M(110, 48) * M(48, 100)
      temp = temp + M(110, 49) * M(49, 100)
      temp = temp + M(110, 50) * M(50, 100)
      temp = temp + M(110, 51) * M(51, 100)
      temp = temp + M(110, 52) * M(52, 100)
      temp = temp + M(110, 53) * M(53, 100)
      temp = temp + M(110, 54) * M(54, 100)
      temp = temp + M(110, 55) * M(55, 100)
      temp = temp + M(110, 57) * M(57, 100)
      temp = temp + M(110, 59) * M(59, 100)
      temp = temp + M(110, 60) * M(60, 100)
      temp = temp + M(110, 62) * M(62, 100)
      temp = temp + M(110, 63) * M(63, 100)
      temp = temp + M(110, 64) * M(64, 100)
      temp = temp + M(110, 65) * M(65, 100)
      temp = temp + M(110, 68) * M(68, 100)
      temp = temp + M(110, 70) * M(70, 100)
      temp = temp + M(110, 71) * M(71, 100)
      temp = temp + M(110, 72) * M(72, 100)
      temp = temp + M(110, 75) * M(75, 100)
      temp = temp + M(110, 79) * M(79, 100)
      temp = temp + M(110, 81) * M(81, 100)
      temp = temp + M(110, 82) * M(82, 100)
      temp = temp + M(110, 83) * M(83, 100)
      temp = temp + M(110, 84) * M(84, 100)
      temp = temp + M(110, 86) * M(86, 100)
      temp = temp + M(110, 88) * M(88, 100)
      temp = temp + M(110, 90) * M(90, 100)
      temp = temp + M(110, 92) * M(92, 100)
      temp = temp + M(110, 94) * M(94, 100)
      temp = temp + M(110, 95) * M(95, 100)
      temp = temp + M(110, 97) * M(97, 100)
      temp = temp + M(110, 98) * M(98, 100)
      temp = temp + M(110, 99) * M(99, 100)
      M(110, 100) = M(110, 100) - temp
C     Lower part.
      temp = M(111, 21) * M(21, 100)
      temp = temp + M(111, 24) * M(24, 100)
      temp = temp + M(111, 34) * M(34, 100)
      temp = temp + M(111, 41) * M(41, 100)
      temp = temp + M(111, 42) * M(42, 100)
      temp = temp + M(111, 43) * M(43, 100)
      temp = temp + M(111, 45) * M(45, 100)
      temp = temp + M(111, 47) * M(47, 100)
      temp = temp + M(111, 48) * M(48, 100)
      temp = temp + M(111, 49) * M(49, 100)
      temp = temp + M(111, 50) * M(50, 100)
      temp = temp + M(111, 51) * M(51, 100)
      temp = temp + M(111, 52) * M(52, 100)
      temp = temp + M(111, 53) * M(53, 100)
      temp = temp + M(111, 54) * M(54, 100)
      temp = temp + M(111, 55) * M(55, 100)
      temp = temp + M(111, 56) * M(56, 100)
      temp = temp + M(111, 57) * M(57, 100)
      temp = temp + M(111, 59) * M(59, 100)
      temp = temp + M(111, 60) * M(60, 100)
      temp = temp + M(111, 61) * M(61, 100)
      temp = temp + M(111, 62) * M(62, 100)
      temp = temp + M(111, 63) * M(63, 100)
      temp = temp + M(111, 64) * M(64, 100)
      temp = temp + M(111, 65) * M(65, 100)
      temp = temp + M(111, 66) * M(66, 100)
      temp = temp + M(111, 67) * M(67, 100)
      temp = temp + M(111, 68) * M(68, 100)
      temp = temp + M(111, 69) * M(69, 100)
      temp = temp + M(111, 70) * M(70, 100)
      temp = temp + M(111, 71) * M(71, 100)
      temp = temp + M(111, 72) * M(72, 100)
      temp = temp + M(111, 73) * M(73, 100)
      temp = temp + M(111, 75) * M(75, 100)
      temp = temp + M(111, 76) * M(76, 100)
      temp = temp + M(111, 77) * M(77, 100)
      temp = temp + M(111, 78) * M(78, 100)
      temp = temp + M(111, 79) * M(79, 100)
      temp = temp + M(111, 80) * M(80, 100)
      temp = temp + M(111, 81) * M(81, 100)
      temp = temp + M(111, 82) * M(82, 100)
      temp = temp + M(111, 83) * M(83, 100)
      temp = temp + M(111, 84) * M(84, 100)
      temp = temp + M(111, 85) * M(85, 100)
      temp = temp + M(111, 86) * M(86, 100)
      temp = temp + M(111, 87) * M(87, 100)
      temp = temp + M(111, 88) * M(88, 100)
      temp = temp + M(111, 89) * M(89, 100)
      temp = temp + M(111, 90) * M(90, 100)
      temp = temp + M(111, 91) * M(91, 100)
      temp = temp + M(111, 92) * M(92, 100)
      temp = temp + M(111, 93) * M(93, 100)
      temp = temp + M(111, 95) * M(95, 100)
      temp = temp + M(111, 96) * M(96, 100)
      temp = temp + M(111, 97) * M(97, 100)
      temp = temp + M(111, 98) * M(98, 100)
      temp = temp + M(111, 99) * M(99, 100)
      M(111, 100) = M(111, 100) - temp
C     Lower part.
      temp = M(112, 21) * M(21, 100)
      temp = temp + M(112, 24) * M(24, 100)
      temp = temp + M(112, 34) * M(34, 100)
      temp = temp + M(112, 41) * M(41, 100)
      temp = temp + M(112, 43) * M(43, 100)
      temp = temp + M(112, 47) * M(47, 100)
      temp = temp + M(112, 48) * M(48, 100)
      temp = temp + M(112, 53) * M(53, 100)
      temp = temp + M(112, 55) * M(55, 100)
      temp = temp + M(112, 56) * M(56, 100)
      temp = temp + M(112, 58) * M(58, 100)
      temp = temp + M(112, 59) * M(59, 100)
      temp = temp + M(112, 60) * M(60, 100)
      temp = temp + M(112, 61) * M(61, 100)
      temp = temp + M(112, 65) * M(65, 100)
      temp = temp + M(112, 66) * M(66, 100)
      temp = temp + M(112, 67) * M(67, 100)
      temp = temp + M(112, 69) * M(69, 100)
      temp = temp + M(112, 73) * M(73, 100)
      temp = temp + M(112, 76) * M(76, 100)
      temp = temp + M(112, 77) * M(77, 100)
      temp = temp + M(112, 78) * M(78, 100)
      temp = temp + M(112, 80) * M(80, 100)
      temp = temp + M(112, 81) * M(81, 100)
      temp = temp + M(112, 83) * M(83, 100)
      temp = temp + M(112, 85) * M(85, 100)
      temp = temp + M(112, 86) * M(86, 100)
      temp = temp + M(112, 87) * M(87, 100)
      temp = temp + M(112, 88) * M(88, 100)
      temp = temp + M(112, 89) * M(89, 100)
      temp = temp + M(112, 91) * M(91, 100)
      temp = temp + M(112, 92) * M(92, 100)
      temp = temp + M(112, 93) * M(93, 100)
      temp = temp + M(112, 94) * M(94, 100)
      temp = temp + M(112, 95) * M(95, 100)
      temp = temp + M(112, 96) * M(96, 100)
      temp = temp + M(112, 97) * M(97, 100)
      temp = temp + M(112, 98) * M(98, 100)
      temp = temp + M(112, 99) * M(99, 100)
      M(112, 100) = M(112, 100) - temp
C     Lower part.
      temp = M(113, 41) * M(41, 100)
      temp = temp + M(113, 42) * M(42, 100)
      temp = temp + M(113, 43) * M(43, 100)
      temp = temp + M(113, 46) * M(46, 100)
      temp = temp + M(113, 48) * M(48, 100)
      temp = temp + M(113, 49) * M(49, 100)
      temp = temp + M(113, 51) * M(51, 100)
      temp = temp + M(113, 53) * M(53, 100)
      temp = temp + M(113, 54) * M(54, 100)
      temp = temp + M(113, 55) * M(55, 100)
      temp = temp + M(113, 57) * M(57, 100)
      temp = temp + M(113, 60) * M(60, 100)
      temp = temp + M(113, 61) * M(61, 100)
      temp = temp + M(113, 62) * M(62, 100)
      temp = temp + M(113, 63) * M(63, 100)
      temp = temp + M(113, 70) * M(70, 100)
      temp = temp + M(113, 71) * M(71, 100)
      temp = temp + M(113, 80) * M(80, 100)
      temp = temp + M(113, 81) * M(81, 100)
      temp = temp + M(113, 83) * M(83, 100)
      temp = temp + M(113, 86) * M(86, 100)
      temp = temp + M(113, 99) * M(99, 100)
      M(113, 100) = M(113, 100) - temp
C     Upper part.
      M(100, 101) = M(100, 101) / M(100, 100)
C     Upper part.
      temp = M(100, 30) * M(30, 102)
      temp = temp + M(100, 41) * M(41, 102)
      temp = temp + M(100, 42) * M(42, 102)
      temp = temp + M(100, 43) * M(43, 102)
      temp = temp + M(100, 45) * M(45, 102)
      temp = temp + M(100, 49) * M(49, 102)
      temp = temp + M(100, 50) * M(50, 102)
      temp = temp + M(100, 51) * M(51, 102)
      temp = temp + M(100, 52) * M(52, 102)
      temp = temp + M(100, 53) * M(53, 102)
      temp = temp + M(100, 54) * M(54, 102)
      temp = temp + M(100, 55) * M(55, 102)
      temp = temp + M(100, 57) * M(57, 102)
      temp = temp + M(100, 58) * M(58, 102)
      temp = temp + M(100, 59) * M(59, 102)
      temp = temp + M(100, 60) * M(60, 102)
      temp = temp + M(100, 62) * M(62, 102)
      temp = temp + M(100, 63) * M(63, 102)
      temp = temp + M(100, 64) * M(64, 102)
      temp = temp + M(100, 65) * M(65, 102)
      temp = temp + M(100, 66) * M(66, 102)
      temp = temp + M(100, 68) * M(68, 102)
      temp = temp + M(100, 69) * M(69, 102)
      temp = temp + M(100, 70) * M(70, 102)
      temp = temp + M(100, 71) * M(71, 102)
      temp = temp + M(100, 72) * M(72, 102)
      temp = temp + M(100, 75) * M(75, 102)
      temp = temp + M(100, 78) * M(78, 102)
      temp = temp + M(100, 79) * M(79, 102)
      temp = temp + M(100, 80) * M(80, 102)
      temp = temp + M(100, 81) * M(81, 102)
      temp = temp + M(100, 82) * M(82, 102)
      temp = temp + M(100, 83) * M(83, 102)
      temp = temp + M(100, 84) * M(84, 102)
      temp = temp + M(100, 86) * M(86, 102)
      temp = temp + M(100, 87) * M(87, 102)
      temp = temp + M(100, 88) * M(88, 102)
      temp = temp + M(100, 90) * M(90, 102)
      temp = temp + M(100, 92) * M(92, 102)
      temp = temp + M(100, 95) * M(95, 102)
      temp = temp + M(100, 97) * M(97, 102)
      temp = temp + M(100, 98) * M(98, 102)
      temp = temp + M(100, 99) * M(99, 102)
      M(100, 102) = ( M(100, 102) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 92) * M(92, 103)
      temp = temp + M(100, 97) * M(97, 103)
      M(100, 103) = ( M(100, 103) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 87) * M(87, 104)
      temp = temp + M(100, 97) * M(97, 104)
      M(100, 104) = ( M(100, 104) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 35) * M(35, 105)
      temp = temp + M(100, 41) * M(41, 105)
      temp = temp + M(100, 42) * M(42, 105)
      temp = temp + M(100, 43) * M(43, 105)
      temp = temp + M(100, 45) * M(45, 105)
      temp = temp + M(100, 49) * M(49, 105)
      temp = temp + M(100, 50) * M(50, 105)
      temp = temp + M(100, 51) * M(51, 105)
      temp = temp + M(100, 52) * M(52, 105)
      temp = temp + M(100, 53) * M(53, 105)
      temp = temp + M(100, 54) * M(54, 105)
      temp = temp + M(100, 55) * M(55, 105)
      temp = temp + M(100, 57) * M(57, 105)
      temp = temp + M(100, 58) * M(58, 105)
      temp = temp + M(100, 59) * M(59, 105)
      temp = temp + M(100, 60) * M(60, 105)
      temp = temp + M(100, 62) * M(62, 105)
      temp = temp + M(100, 63) * M(63, 105)
      temp = temp + M(100, 64) * M(64, 105)
      temp = temp + M(100, 65) * M(65, 105)
      temp = temp + M(100, 66) * M(66, 105)
      temp = temp + M(100, 68) * M(68, 105)
      temp = temp + M(100, 69) * M(69, 105)
      temp = temp + M(100, 70) * M(70, 105)
      temp = temp + M(100, 71) * M(71, 105)
      temp = temp + M(100, 72) * M(72, 105)
      temp = temp + M(100, 74) * M(74, 105)
      temp = temp + M(100, 75) * M(75, 105)
      temp = temp + M(100, 78) * M(78, 105)
      temp = temp + M(100, 79) * M(79, 105)
      temp = temp + M(100, 80) * M(80, 105)
      temp = temp + M(100, 81) * M(81, 105)
      temp = temp + M(100, 82) * M(82, 105)
      temp = temp + M(100, 83) * M(83, 105)
      temp = temp + M(100, 84) * M(84, 105)
      temp = temp + M(100, 86) * M(86, 105)
      temp = temp + M(100, 87) * M(87, 105)
      temp = temp + M(100, 88) * M(88, 105)
      temp = temp + M(100, 90) * M(90, 105)
      temp = temp + M(100, 92) * M(92, 105)
      temp = temp + M(100, 95) * M(95, 105)
      temp = temp + M(100, 97) * M(97, 105)
      temp = temp + M(100, 98) * M(98, 105)
      temp = temp + M(100, 99) * M(99, 105)
      M(100, 105) = ( M(100, 105) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 99) * M(99, 106)
      M(100, 106) = ( M(100, 106) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 98) * M(98, 107)
      M(100, 107) = ( M(100, 107) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 20) * M(20, 109)
      temp = temp + M(100, 26) * M(26, 109)
      temp = temp + M(100, 31) * M(31, 109)
      temp = temp + M(100, 32) * M(32, 109)
      temp = temp + M(100, 41) * M(41, 109)
      temp = temp + M(100, 42) * M(42, 109)
      temp = temp + M(100, 43) * M(43, 109)
      temp = temp + M(100, 45) * M(45, 109)
      temp = temp + M(100, 49) * M(49, 109)
      temp = temp + M(100, 50) * M(50, 109)
      temp = temp + M(100, 51) * M(51, 109)
      temp = temp + M(100, 52) * M(52, 109)
      temp = temp + M(100, 53) * M(53, 109)
      temp = temp + M(100, 54) * M(54, 109)
      temp = temp + M(100, 55) * M(55, 109)
      temp = temp + M(100, 57) * M(57, 109)
      temp = temp + M(100, 58) * M(58, 109)
      temp = temp + M(100, 59) * M(59, 109)
      temp = temp + M(100, 60) * M(60, 109)
      temp = temp + M(100, 62) * M(62, 109)
      temp = temp + M(100, 63) * M(63, 109)
      temp = temp + M(100, 64) * M(64, 109)
      temp = temp + M(100, 65) * M(65, 109)
      temp = temp + M(100, 66) * M(66, 109)
      temp = temp + M(100, 68) * M(68, 109)
      temp = temp + M(100, 69) * M(69, 109)
      temp = temp + M(100, 70) * M(70, 109)
      temp = temp + M(100, 71) * M(71, 109)
      temp = temp + M(100, 72) * M(72, 109)
      temp = temp + M(100, 75) * M(75, 109)
      temp = temp + M(100, 78) * M(78, 109)
      temp = temp + M(100, 79) * M(79, 109)
      temp = temp + M(100, 80) * M(80, 109)
      temp = temp + M(100, 81) * M(81, 109)
      temp = temp + M(100, 82) * M(82, 109)
      temp = temp + M(100, 83) * M(83, 109)
      temp = temp + M(100, 84) * M(84, 109)
      temp = temp + M(100, 86) * M(86, 109)
      temp = temp + M(100, 87) * M(87, 109)
      temp = temp + M(100, 88) * M(88, 109)
      temp = temp + M(100, 90) * M(90, 109)
      temp = temp + M(100, 92) * M(92, 109)
      temp = temp + M(100, 95) * M(95, 109)
      temp = temp + M(100, 97) * M(97, 109)
      temp = temp + M(100, 98) * M(98, 109)
      temp = temp + M(100, 99) * M(99, 109)
      M(100, 109) = ( M(100, 109) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 35) * M(35, 110)
      temp = temp + M(100, 51) * M(51, 110)
      temp = temp + M(100, 75) * M(75, 110)
      temp = temp + M(100, 81) * M(81, 110)
      temp = temp + M(100, 82) * M(82, 110)
      temp = temp + M(100, 83) * M(83, 110)
      temp = temp + M(100, 84) * M(84, 110)
      temp = temp + M(100, 87) * M(87, 110)
      temp = temp + M(100, 88) * M(88, 110)
      temp = temp + M(100, 92) * M(92, 110)
      temp = temp + M(100, 95) * M(95, 110)
      temp = temp + M(100, 97) * M(97, 110)
      temp = temp + M(100, 98) * M(98, 110)
      M(100, 110) = ( M(100, 110) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 34) * M(34, 111)
      temp = temp + M(100, 51) * M(51, 111)
      temp = temp + M(100, 55) * M(55, 111)
      temp = temp + M(100, 57) * M(57, 111)
      temp = temp + M(100, 58) * M(58, 111)
      temp = temp + M(100, 59) * M(59, 111)
      temp = temp + M(100, 60) * M(60, 111)
      temp = temp + M(100, 62) * M(62, 111)
      temp = temp + M(100, 63) * M(63, 111)
      temp = temp + M(100, 64) * M(64, 111)
      temp = temp + M(100, 65) * M(65, 111)
      temp = temp + M(100, 66) * M(66, 111)
      temp = temp + M(100, 68) * M(68, 111)
      temp = temp + M(100, 69) * M(69, 111)
      temp = temp + M(100, 70) * M(70, 111)
      temp = temp + M(100, 71) * M(71, 111)
      temp = temp + M(100, 72) * M(72, 111)
      temp = temp + M(100, 74) * M(74, 111)
      temp = temp + M(100, 75) * M(75, 111)
      temp = temp + M(100, 78) * M(78, 111)
      temp = temp + M(100, 79) * M(79, 111)
      temp = temp + M(100, 80) * M(80, 111)
      temp = temp + M(100, 81) * M(81, 111)
      temp = temp + M(100, 82) * M(82, 111)
      temp = temp + M(100, 83) * M(83, 111)
      temp = temp + M(100, 84) * M(84, 111)
      temp = temp + M(100, 86) * M(86, 111)
      temp = temp + M(100, 87) * M(87, 111)
      temp = temp + M(100, 88) * M(88, 111)
      temp = temp + M(100, 90) * M(90, 111)
      temp = temp + M(100, 92) * M(92, 111)
      temp = temp + M(100, 95) * M(95, 111)
      temp = temp + M(100, 97) * M(97, 111)
      temp = temp + M(100, 98) * M(98, 111)
      temp = temp + M(100, 99) * M(99, 111)
      M(100, 111) = ( M(100, 111) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 20) * M(20, 112)
      temp = temp + M(100, 26) * M(26, 112)
      temp = temp + M(100, 30) * M(30, 112)
      temp = temp + M(100, 31) * M(31, 112)
      temp = temp + M(100, 32) * M(32, 112)
      temp = temp + M(100, 34) * M(34, 112)
      temp = temp + M(100, 35) * M(35, 112)
      temp = temp + M(100, 41) * M(41, 112)
      temp = temp + M(100, 42) * M(42, 112)
      temp = temp + M(100, 43) * M(43, 112)
      temp = temp + M(100, 49) * M(49, 112)
      temp = temp + M(100, 50) * M(50, 112)
      temp = temp + M(100, 51) * M(51, 112)
      temp = temp + M(100, 52) * M(52, 112)
      temp = temp + M(100, 53) * M(53, 112)
      temp = temp + M(100, 54) * M(54, 112)
      temp = temp + M(100, 55) * M(55, 112)
      temp = temp + M(100, 57) * M(57, 112)
      temp = temp + M(100, 58) * M(58, 112)
      temp = temp + M(100, 59) * M(59, 112)
      temp = temp + M(100, 60) * M(60, 112)
      temp = temp + M(100, 62) * M(62, 112)
      temp = temp + M(100, 63) * M(63, 112)
      temp = temp + M(100, 64) * M(64, 112)
      temp = temp + M(100, 65) * M(65, 112)
      temp = temp + M(100, 66) * M(66, 112)
      temp = temp + M(100, 68) * M(68, 112)
      temp = temp + M(100, 69) * M(69, 112)
      temp = temp + M(100, 70) * M(70, 112)
      temp = temp + M(100, 71) * M(71, 112)
      temp = temp + M(100, 72) * M(72, 112)
      temp = temp + M(100, 74) * M(74, 112)
      temp = temp + M(100, 75) * M(75, 112)
      temp = temp + M(100, 78) * M(78, 112)
      temp = temp + M(100, 79) * M(79, 112)
      temp = temp + M(100, 80) * M(80, 112)
      temp = temp + M(100, 81) * M(81, 112)
      temp = temp + M(100, 82) * M(82, 112)
      temp = temp + M(100, 83) * M(83, 112)
      temp = temp + M(100, 84) * M(84, 112)
      temp = temp + M(100, 86) * M(86, 112)
      temp = temp + M(100, 87) * M(87, 112)
      temp = temp + M(100, 88) * M(88, 112)
      temp = temp + M(100, 90) * M(90, 112)
      temp = temp + M(100, 92) * M(92, 112)
      temp = temp + M(100, 95) * M(95, 112)
      temp = temp + M(100, 97) * M(97, 112)
      temp = temp + M(100, 98) * M(98, 112)
      temp = temp + M(100, 99) * M(99, 112)
      M(100, 112) = ( M(100, 112) - temp ) / M(100, 100)
C     Upper part.
      temp = M(100, 99) * M(99, 113)
      M(100, 113) = ( M(100, 113) - temp ) / M(100, 100)

C     Lower part.
      temp = M(101, 100) * M(100, 101)
      M(101, 101) = M(101, 101) - temp
C     Lower part.
      temp = M(102, 100) * M(100, 101)
      M(102, 101) = M(102, 101) - temp
C     Lower part.
      temp = M(103, 100) * M(100, 101)
      M(103, 101) = M(103, 101) - temp
C     Lower part.
      temp = M(104, 100) * M(100, 101)
      M(104, 101) = M(104, 101) - temp
C     Lower part.
      temp = M(105, 100) * M(100, 101)
      M(105, 101) = M(105, 101) - temp
C     Lower part.
      temp = M(106, 100) * M(100, 101)
      M(106, 101) = M(106, 101) - temp
C     Lower part.
      temp = M(107, 100) * M(100, 101)
      M(107, 101) = M(107, 101) - temp
C     Lower part.
      temp = M(108, 100) * M(100, 101)
      M(108, 101) = M(108, 101) - temp
C     Lower part.
      temp = M(109, 100) * M(100, 101)
      M(109, 101) = M(109, 101) - temp
C     Lower part.
      temp = M(110, 100) * M(100, 101)
      M(110, 101) = M(110, 101) - temp
C     Lower part.
      temp = M(111, 100) * M(100, 101)
      M(111, 101) = M(111, 101) - temp
C     Lower part.
      temp = M(112, 100) * M(100, 101)
      M(112, 101) = M(112, 101) - temp
C     Lower part.
      temp = M(113, 100) * M(100, 101)
      M(113, 101) = M(113, 101) - temp
C     Upper part.
      temp = M(101, 56) * M(56, 102)
      temp = temp + M(101, 61) * M(61, 102)
      temp = temp + M(101, 62) * M(62, 102)
      temp = temp + M(101, 66) * M(66, 102)
      temp = temp + M(101, 68) * M(68, 102)
      temp = temp + M(101, 77) * M(77, 102)
      temp = temp + M(101, 78) * M(78, 102)
      temp = temp + M(101, 80) * M(80, 102)
      temp = temp + M(101, 81) * M(81, 102)
      temp = temp + M(101, 83) * M(83, 102)
      temp = temp + M(101, 86) * M(86, 102)
      temp = temp + M(101, 92) * M(92, 102)
      temp = temp + M(101, 98) * M(98, 102)
      temp = temp + M(101, 99) * M(99, 102)
      temp = temp + M(101, 100) * M(100, 102)
      M(101, 102) = ( M(101, 102) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 92) * M(92, 103)
      temp = temp + M(101, 100) * M(100, 103)
      M(101, 103) = ( M(101, 103) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 100) * M(100, 104)
      M(101, 104) = ( M(101, 104) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 35) * M(35, 105)
      temp = temp + M(101, 56) * M(56, 105)
      temp = temp + M(101, 61) * M(61, 105)
      temp = temp + M(101, 62) * M(62, 105)
      temp = temp + M(101, 66) * M(66, 105)
      temp = temp + M(101, 68) * M(68, 105)
      temp = temp + M(101, 74) * M(74, 105)
      temp = temp + M(101, 77) * M(77, 105)
      temp = temp + M(101, 78) * M(78, 105)
      temp = temp + M(101, 80) * M(80, 105)
      temp = temp + M(101, 81) * M(81, 105)
      temp = temp + M(101, 83) * M(83, 105)
      temp = temp + M(101, 86) * M(86, 105)
      temp = temp + M(101, 92) * M(92, 105)
      temp = temp + M(101, 98) * M(98, 105)
      temp = temp + M(101, 99) * M(99, 105)
      temp = temp + M(101, 100) * M(100, 105)
      M(101, 105) = ( M(101, 105) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 99) * M(99, 106)
      temp = temp + M(101, 100) * M(100, 106)
      M(101, 106) = ( M(101, 106) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 98) * M(98, 107)
      temp = temp + M(101, 100) * M(100, 107)
      M(101, 107) = ( M(101, 107) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 20) * M(20, 109)
      temp = temp + M(101, 22) * M(22, 109)
      temp = temp + M(101, 56) * M(56, 109)
      temp = temp + M(101, 61) * M(61, 109)
      temp = temp + M(101, 62) * M(62, 109)
      temp = temp + M(101, 66) * M(66, 109)
      temp = temp + M(101, 68) * M(68, 109)
      temp = temp + M(101, 77) * M(77, 109)
      temp = temp + M(101, 78) * M(78, 109)
      temp = temp + M(101, 80) * M(80, 109)
      temp = temp + M(101, 81) * M(81, 109)
      temp = temp + M(101, 83) * M(83, 109)
      temp = temp + M(101, 86) * M(86, 109)
      temp = temp + M(101, 92) * M(92, 109)
      temp = temp + M(101, 98) * M(98, 109)
      temp = temp + M(101, 99) * M(99, 109)
      temp = temp + M(101, 100) * M(100, 109)
      M(101, 109) = ( M(101, 109) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 35) * M(35, 110)
      temp = temp + M(101, 37) * M(37, 110)
      temp = temp + M(101, 81) * M(81, 110)
      temp = temp + M(101, 83) * M(83, 110)
      temp = temp + M(101, 92) * M(92, 110)
      temp = temp + M(101, 98) * M(98, 110)
      temp = temp + M(101, 100) * M(100, 110)
      M(101, 110) = ( M(101, 110) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 56) * M(56, 111)
      temp = temp + M(101, 61) * M(61, 111)
      temp = temp + M(101, 62) * M(62, 111)
      temp = temp + M(101, 66) * M(66, 111)
      temp = temp + M(101, 68) * M(68, 111)
      temp = temp + M(101, 74) * M(74, 111)
      temp = temp + M(101, 77) * M(77, 111)
      temp = temp + M(101, 78) * M(78, 111)
      temp = temp + M(101, 80) * M(80, 111)
      temp = temp + M(101, 81) * M(81, 111)
      temp = temp + M(101, 83) * M(83, 111)
      temp = temp + M(101, 86) * M(86, 111)
      temp = temp + M(101, 92) * M(92, 111)
      temp = temp + M(101, 98) * M(98, 111)
      temp = temp + M(101, 99) * M(99, 111)
      temp = temp + M(101, 100) * M(100, 111)
      M(101, 111) = ( M(101, 111) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 20) * M(20, 112)
      temp = temp + M(101, 22) * M(22, 112)
      temp = temp + M(101, 35) * M(35, 112)
      temp = temp + M(101, 37) * M(37, 112)
      temp = temp + M(101, 56) * M(56, 112)
      temp = temp + M(101, 61) * M(61, 112)
      temp = temp + M(101, 62) * M(62, 112)
      temp = temp + M(101, 66) * M(66, 112)
      temp = temp + M(101, 68) * M(68, 112)
      temp = temp + M(101, 74) * M(74, 112)
      temp = temp + M(101, 77) * M(77, 112)
      temp = temp + M(101, 78) * M(78, 112)
      temp = temp + M(101, 80) * M(80, 112)
      temp = temp + M(101, 81) * M(81, 112)
      temp = temp + M(101, 83) * M(83, 112)
      temp = temp + M(101, 86) * M(86, 112)
      temp = temp + M(101, 92) * M(92, 112)
      temp = temp + M(101, 98) * M(98, 112)
      temp = temp + M(101, 99) * M(99, 112)
      temp = temp + M(101, 100) * M(100, 112)
      M(101, 112) = ( M(101, 112) - temp ) / M(101, 101)
C     Upper part.
      temp = M(101, 99) * M(99, 113)
      temp = temp + M(101, 100) * M(100, 113)
      M(101, 113) = ( M(101, 113) - temp ) / M(101, 101)

C     Lower part.
      temp = M(102, 15) * M(15, 102)
      temp = temp + M(102, 41) * M(41, 102)
      temp = temp + M(102, 42) * M(42, 102)
      temp = temp + M(102, 43) * M(43, 102)
      temp = temp + M(102, 44) * M(44, 102)
      temp = temp + M(102, 45) * M(45, 102)
      temp = temp + M(102, 49) * M(49, 102)
      temp = temp + M(102, 50) * M(50, 102)
      temp = temp + M(102, 51) * M(51, 102)
      temp = temp + M(102, 52) * M(52, 102)
      temp = temp + M(102, 53) * M(53, 102)
      temp = temp + M(102, 54) * M(54, 102)
      temp = temp + M(102, 55) * M(55, 102)
      temp = temp + M(102, 57) * M(57, 102)
      temp = temp + M(102, 59) * M(59, 102)
      temp = temp + M(102, 60) * M(60, 102)
      temp = temp + M(102, 62) * M(62, 102)
      temp = temp + M(102, 63) * M(63, 102)
      temp = temp + M(102, 64) * M(64, 102)
      temp = temp + M(102, 65) * M(65, 102)
      temp = temp + M(102, 68) * M(68, 102)
      temp = temp + M(102, 70) * M(70, 102)
      temp = temp + M(102, 71) * M(71, 102)
      temp = temp + M(102, 72) * M(72, 102)
      temp = temp + M(102, 75) * M(75, 102)
      temp = temp + M(102, 79) * M(79, 102)
      temp = temp + M(102, 81) * M(81, 102)
      temp = temp + M(102, 82) * M(82, 102)
      temp = temp + M(102, 83) * M(83, 102)
      temp = temp + M(102, 84) * M(84, 102)
      temp = temp + M(102, 86) * M(86, 102)
      temp = temp + M(102, 88) * M(88, 102)
      temp = temp + M(102, 90) * M(90, 102)
      temp = temp + M(102, 92) * M(92, 102)
      temp = temp + M(102, 95) * M(95, 102)
      temp = temp + M(102, 97) * M(97, 102)
      temp = temp + M(102, 98) * M(98, 102)
      temp = temp + M(102, 99) * M(99, 102)
      temp = temp + M(102, 100) * M(100, 102)
      temp = temp + M(102, 101) * M(101, 102)
      M(102, 102) = M(102, 102) - temp
C     Lower part.
      temp = M(103, 57) * M(57, 102)
      temp = temp + M(103, 60) * M(60, 102)
      temp = temp + M(103, 62) * M(62, 102)
      temp = temp + M(103, 69) * M(69, 102)
      temp = temp + M(103, 70) * M(70, 102)
      temp = temp + M(103, 71) * M(71, 102)
      temp = temp + M(103, 72) * M(72, 102)
      temp = temp + M(103, 79) * M(79, 102)
      temp = temp + M(103, 80) * M(80, 102)
      temp = temp + M(103, 81) * M(81, 102)
      temp = temp + M(103, 83) * M(83, 102)
      temp = temp + M(103, 84) * M(84, 102)
      temp = temp + M(103, 86) * M(86, 102)
      temp = temp + M(103, 99) * M(99, 102)
      temp = temp + M(103, 100) * M(100, 102)
      temp = temp + M(103, 101) * M(101, 102)
      M(103, 102) = M(103, 102) - temp
C     Lower part.
      temp = M(104, 30) * M(30, 102)
      temp = temp + M(104, 62) * M(62, 102)
      temp = temp + M(104, 69) * M(69, 102)
      temp = temp + M(104, 81) * M(81, 102)
      temp = temp + M(104, 83) * M(83, 102)
      temp = temp + M(104, 86) * M(86, 102)
      temp = temp + M(104, 98) * M(98, 102)
      temp = temp + M(104, 99) * M(99, 102)
      temp = temp + M(104, 100) * M(100, 102)
      temp = temp + M(104, 101) * M(101, 102)
      M(104, 102) = M(104, 102) - temp
C     Lower part.
      temp = M(105, 30) * M(30, 102)
      temp = temp + M(105, 41) * M(41, 102)
      temp = temp + M(105, 42) * M(42, 102)
      temp = temp + M(105, 43) * M(43, 102)
      temp = temp + M(105, 45) * M(45, 102)
      temp = temp + M(105, 49) * M(49, 102)
      temp = temp + M(105, 50) * M(50, 102)
      temp = temp + M(105, 51) * M(51, 102)
      temp = temp + M(105, 52) * M(52, 102)
      temp = temp + M(105, 53) * M(53, 102)
      temp = temp + M(105, 54) * M(54, 102)
      temp = temp + M(105, 55) * M(55, 102)
      temp = temp + M(105, 56) * M(56, 102)
      temp = temp + M(105, 57) * M(57, 102)
      temp = temp + M(105, 58) * M(58, 102)
      temp = temp + M(105, 59) * M(59, 102)
      temp = temp + M(105, 60) * M(60, 102)
      temp = temp + M(105, 61) * M(61, 102)
      temp = temp + M(105, 62) * M(62, 102)
      temp = temp + M(105, 63) * M(63, 102)
      temp = temp + M(105, 64) * M(64, 102)
      temp = temp + M(105, 65) * M(65, 102)
      temp = temp + M(105, 66) * M(66, 102)
      temp = temp + M(105, 68) * M(68, 102)
      temp = temp + M(105, 70) * M(70, 102)
      temp = temp + M(105, 71) * M(71, 102)
      temp = temp + M(105, 72) * M(72, 102)
      temp = temp + M(105, 75) * M(75, 102)
      temp = temp + M(105, 76) * M(76, 102)
      temp = temp + M(105, 77) * M(77, 102)
      temp = temp + M(105, 78) * M(78, 102)
      temp = temp + M(105, 79) * M(79, 102)
      temp = temp + M(105, 80) * M(80, 102)
      temp = temp + M(105, 81) * M(81, 102)
      temp = temp + M(105, 82) * M(82, 102)
      temp = temp + M(105, 83) * M(83, 102)
      temp = temp + M(105, 84) * M(84, 102)
      temp = temp + M(105, 86) * M(86, 102)
      temp = temp + M(105, 87) * M(87, 102)
      temp = temp + M(105, 88) * M(88, 102)
      temp = temp + M(105, 90) * M(90, 102)
      temp = temp + M(105, 92) * M(92, 102)
      temp = temp + M(105, 93) * M(93, 102)
      temp = temp + M(105, 95) * M(95, 102)
      temp = temp + M(105, 97) * M(97, 102)
      temp = temp + M(105, 98) * M(98, 102)
      temp = temp + M(105, 99) * M(99, 102)
      temp = temp + M(105, 100) * M(100, 102)
      temp = temp + M(105, 101) * M(101, 102)
      M(105, 102) = M(105, 102) - temp
C     Lower part.
      temp = M(106, 51) * M(51, 102)
      temp = temp + M(106, 53) * M(53, 102)
      temp = temp + M(106, 55) * M(55, 102)
      temp = temp + M(106, 57) * M(57, 102)
      temp = temp + M(106, 60) * M(60, 102)
      temp = temp + M(106, 62) * M(62, 102)
      temp = temp + M(106, 63) * M(63, 102)
      temp = temp + M(106, 64) * M(64, 102)
      temp = temp + M(106, 65) * M(65, 102)
      temp = temp + M(106, 68) * M(68, 102)
      temp = temp + M(106, 72) * M(72, 102)
      temp = temp + M(106, 75) * M(75, 102)
      temp = temp + M(106, 79) * M(79, 102)
      temp = temp + M(106, 81) * M(81, 102)
      temp = temp + M(106, 82) * M(82, 102)
      temp = temp + M(106, 83) * M(83, 102)
      temp = temp + M(106, 84) * M(84, 102)
      temp = temp + M(106, 86) * M(86, 102)
      temp = temp + M(106, 88) * M(88, 102)
      temp = temp + M(106, 90) * M(90, 102)
      temp = temp + M(106, 92) * M(92, 102)
      temp = temp + M(106, 97) * M(97, 102)
      temp = temp + M(106, 98) * M(98, 102)
      temp = temp + M(106, 99) * M(99, 102)
      temp = temp + M(106, 100) * M(100, 102)
      temp = temp + M(106, 101) * M(101, 102)
      M(106, 102) = M(106, 102) - temp
C     Lower part.
      temp = M(107, 56) * M(56, 102)
      temp = temp + M(107, 57) * M(57, 102)
      temp = temp + M(107, 62) * M(62, 102)
      temp = temp + M(107, 68) * M(68, 102)
      temp = temp + M(107, 69) * M(69, 102)
      temp = temp + M(107, 70) * M(70, 102)
      temp = temp + M(107, 71) * M(71, 102)
      temp = temp + M(107, 72) * M(72, 102)
      temp = temp + M(107, 77) * M(77, 102)
      temp = temp + M(107, 79) * M(79, 102)
      temp = temp + M(107, 80) * M(80, 102)
      temp = temp + M(107, 81) * M(81, 102)
      temp = temp + M(107, 83) * M(83, 102)
      temp = temp + M(107, 84) * M(84, 102)
      temp = temp + M(107, 85) * M(85, 102)
      temp = temp + M(107, 86) * M(86, 102)
      temp = temp + M(107, 88) * M(88, 102)
      temp = temp + M(107, 92) * M(92, 102)
      temp = temp + M(107, 95) * M(95, 102)
      temp = temp + M(107, 99) * M(99, 102)
      temp = temp + M(107, 100) * M(100, 102)
      temp = temp + M(107, 101) * M(101, 102)
      M(107, 102) = M(107, 102) - temp
C     Lower part.
      temp = M(108, 39) * M(39, 102)
      temp = temp + M(108, 41) * M(41, 102)
      temp = temp + M(108, 42) * M(42, 102)
      temp = temp + M(108, 43) * M(43, 102)
      temp = temp + M(108, 45) * M(45, 102)
      temp = temp + M(108, 49) * M(49, 102)
      temp = temp + M(108, 50) * M(50, 102)
      temp = temp + M(108, 51) * M(51, 102)
      temp = temp + M(108, 52) * M(52, 102)
      temp = temp + M(108, 53) * M(53, 102)
      temp = temp + M(108, 54) * M(54, 102)
      temp = temp + M(108, 55) * M(55, 102)
      temp = temp + M(108, 57) * M(57, 102)
      temp = temp + M(108, 59) * M(59, 102)
      temp = temp + M(108, 60) * M(60, 102)
      temp = temp + M(108, 61) * M(61, 102)
      temp = temp + M(108, 62) * M(62, 102)
      temp = temp + M(108, 63) * M(63, 102)
      temp = temp + M(108, 64) * M(64, 102)
      temp = temp + M(108, 65) * M(65, 102)
      temp = temp + M(108, 66) * M(66, 102)
      temp = temp + M(108, 68) * M(68, 102)
      temp = temp + M(108, 69) * M(69, 102)
      temp = temp + M(108, 70) * M(70, 102)
      temp = temp + M(108, 71) * M(71, 102)
      temp = temp + M(108, 72) * M(72, 102)
      temp = temp + M(108, 75) * M(75, 102)
      temp = temp + M(108, 76) * M(76, 102)
      temp = temp + M(108, 78) * M(78, 102)
      temp = temp + M(108, 79) * M(79, 102)
      temp = temp + M(108, 80) * M(80, 102)
      temp = temp + M(108, 81) * M(81, 102)
      temp = temp + M(108, 82) * M(82, 102)
      temp = temp + M(108, 83) * M(83, 102)
      temp = temp + M(108, 84) * M(84, 102)
      temp = temp + M(108, 86) * M(86, 102)
      temp = temp + M(108, 88) * M(88, 102)
      temp = temp + M(108, 89) * M(89, 102)
      temp = temp + M(108, 90) * M(90, 102)
      temp = temp + M(108, 91) * M(91, 102)
      temp = temp + M(108, 92) * M(92, 102)
      temp = temp + M(108, 95) * M(95, 102)
      temp = temp + M(108, 97) * M(97, 102)
      temp = temp + M(108, 98) * M(98, 102)
      temp = temp + M(108, 99) * M(99, 102)
      temp = temp + M(108, 100) * M(100, 102)
      temp = temp + M(108, 101) * M(101, 102)
      M(108, 102) = M(108, 102) - temp
C     Lower part.
      temp = M(109, 41) * M(41, 102)
      temp = temp + M(109, 42) * M(42, 102)
      temp = temp + M(109, 43) * M(43, 102)
      temp = temp + M(109, 44) * M(44, 102)
      temp = temp + M(109, 45) * M(45, 102)
      temp = temp + M(109, 47) * M(47, 102)
      temp = temp + M(109, 48) * M(48, 102)
      temp = temp + M(109, 49) * M(49, 102)
      temp = temp + M(109, 50) * M(50, 102)
      temp = temp + M(109, 51) * M(51, 102)
      temp = temp + M(109, 52) * M(52, 102)
      temp = temp + M(109, 53) * M(53, 102)
      temp = temp + M(109, 54) * M(54, 102)
      temp = temp + M(109, 55) * M(55, 102)
      temp = temp + M(109, 57) * M(57, 102)
      temp = temp + M(109, 59) * M(59, 102)
      temp = temp + M(109, 60) * M(60, 102)
      temp = temp + M(109, 61) * M(61, 102)
      temp = temp + M(109, 62) * M(62, 102)
      temp = temp + M(109, 63) * M(63, 102)
      temp = temp + M(109, 64) * M(64, 102)
      temp = temp + M(109, 65) * M(65, 102)
      temp = temp + M(109, 68) * M(68, 102)
      temp = temp + M(109, 69) * M(69, 102)
      temp = temp + M(109, 70) * M(70, 102)
      temp = temp + M(109, 71) * M(71, 102)
      temp = temp + M(109, 72) * M(72, 102)
      temp = temp + M(109, 75) * M(75, 102)
      temp = temp + M(109, 79) * M(79, 102)
      temp = temp + M(109, 80) * M(80, 102)
      temp = temp + M(109, 81) * M(81, 102)
      temp = temp + M(109, 82) * M(82, 102)
      temp = temp + M(109, 83) * M(83, 102)
      temp = temp + M(109, 84) * M(84, 102)
      temp = temp + M(109, 86) * M(86, 102)
      temp = temp + M(109, 87) * M(87, 102)
      temp = temp + M(109, 88) * M(88, 102)
      temp = temp + M(109, 90) * M(90, 102)
      temp = temp + M(109, 91) * M(91, 102)
      temp = temp + M(109, 92) * M(92, 102)
      temp = temp + M(109, 93) * M(93, 102)
      temp = temp + M(109, 94) * M(94, 102)
      temp = temp + M(109, 95) * M(95, 102)
      temp = temp + M(109, 97) * M(97, 102)
      temp = temp + M(109, 98) * M(98, 102)
      temp = temp + M(109, 99) * M(99, 102)
      temp = temp + M(109, 100) * M(100, 102)
      temp = temp + M(109, 101) * M(101, 102)
      M(109, 102) = M(109, 102) - temp
C     Lower part.
      temp = M(110, 15) * M(15, 102)
      temp = temp + M(110, 39) * M(39, 102)
      temp = temp + M(110, 41) * M(41, 102)
      temp = temp + M(110, 42) * M(42, 102)
      temp = temp + M(110, 43) * M(43, 102)
      temp = temp + M(110, 44) * M(44, 102)
      temp = temp + M(110, 45) * M(45, 102)
      temp = temp + M(110, 46) * M(46, 102)
      temp = temp + M(110, 48) * M(48, 102)
      temp = temp + M(110, 49) * M(49, 102)
      temp = temp + M(110, 50) * M(50, 102)
      temp = temp + M(110, 51) * M(51, 102)
      temp = temp + M(110, 52) * M(52, 102)
      temp = temp + M(110, 53) * M(53, 102)
      temp = temp + M(110, 54) * M(54, 102)
      temp = temp + M(110, 55) * M(55, 102)
      temp = temp + M(110, 57) * M(57, 102)
      temp = temp + M(110, 59) * M(59, 102)
      temp = temp + M(110, 60) * M(60, 102)
      temp = temp + M(110, 62) * M(62, 102)
      temp = temp + M(110, 63) * M(63, 102)
      temp = temp + M(110, 64) * M(64, 102)
      temp = temp + M(110, 65) * M(65, 102)
      temp = temp + M(110, 68) * M(68, 102)
      temp = temp + M(110, 70) * M(70, 102)
      temp = temp + M(110, 71) * M(71, 102)
      temp = temp + M(110, 72) * M(72, 102)
      temp = temp + M(110, 75) * M(75, 102)
      temp = temp + M(110, 79) * M(79, 102)
      temp = temp + M(110, 81) * M(81, 102)
      temp = temp + M(110, 82) * M(82, 102)
      temp = temp + M(110, 83) * M(83, 102)
      temp = temp + M(110, 84) * M(84, 102)
      temp = temp + M(110, 86) * M(86, 102)
      temp = temp + M(110, 88) * M(88, 102)
      temp = temp + M(110, 90) * M(90, 102)
      temp = temp + M(110, 92) * M(92, 102)
      temp = temp + M(110, 94) * M(94, 102)
      temp = temp + M(110, 95) * M(95, 102)
      temp = temp + M(110, 97) * M(97, 102)
      temp = temp + M(110, 98) * M(98, 102)
      temp = temp + M(110, 99) * M(99, 102)
      temp = temp + M(110, 100) * M(100, 102)
      temp = temp + M(110, 101) * M(101, 102)
      M(110, 102) = M(110, 102) - temp
C     Lower part.
      temp = M(111, 41) * M(41, 102)
      temp = temp + M(111, 42) * M(42, 102)
      temp = temp + M(111, 43) * M(43, 102)
      temp = temp + M(111, 45) * M(45, 102)
      temp = temp + M(111, 47) * M(47, 102)
      temp = temp + M(111, 48) * M(48, 102)
      temp = temp + M(111, 49) * M(49, 102)
      temp = temp + M(111, 50) * M(50, 102)
      temp = temp + M(111, 51) * M(51, 102)
      temp = temp + M(111, 52) * M(52, 102)
      temp = temp + M(111, 53) * M(53, 102)
      temp = temp + M(111, 54) * M(54, 102)
      temp = temp + M(111, 55) * M(55, 102)
      temp = temp + M(111, 56) * M(56, 102)
      temp = temp + M(111, 57) * M(57, 102)
      temp = temp + M(111, 59) * M(59, 102)
      temp = temp + M(111, 60) * M(60, 102)
      temp = temp + M(111, 61) * M(61, 102)
      temp = temp + M(111, 62) * M(62, 102)
      temp = temp + M(111, 63) * M(63, 102)
      temp = temp + M(111, 64) * M(64, 102)
      temp = temp + M(111, 65) * M(65, 102)
      temp = temp + M(111, 66) * M(66, 102)
      temp = temp + M(111, 67) * M(67, 102)
      temp = temp + M(111, 68) * M(68, 102)
      temp = temp + M(111, 69) * M(69, 102)
      temp = temp + M(111, 70) * M(70, 102)
      temp = temp + M(111, 71) * M(71, 102)
      temp = temp + M(111, 72) * M(72, 102)
      temp = temp + M(111, 73) * M(73, 102)
      temp = temp + M(111, 75) * M(75, 102)
      temp = temp + M(111, 76) * M(76, 102)
      temp = temp + M(111, 77) * M(77, 102)
      temp = temp + M(111, 78) * M(78, 102)
      temp = temp + M(111, 79) * M(79, 102)
      temp = temp + M(111, 80) * M(80, 102)
      temp = temp + M(111, 81) * M(81, 102)
      temp = temp + M(111, 82) * M(82, 102)
      temp = temp + M(111, 83) * M(83, 102)
      temp = temp + M(111, 84) * M(84, 102)
      temp = temp + M(111, 85) * M(85, 102)
      temp = temp + M(111, 86) * M(86, 102)
      temp = temp + M(111, 87) * M(87, 102)
      temp = temp + M(111, 88) * M(88, 102)
      temp = temp + M(111, 89) * M(89, 102)
      temp = temp + M(111, 90) * M(90, 102)
      temp = temp + M(111, 91) * M(91, 102)
      temp = temp + M(111, 92) * M(92, 102)
      temp = temp + M(111, 93) * M(93, 102)
      temp = temp + M(111, 95) * M(95, 102)
      temp = temp + M(111, 96) * M(96, 102)
      temp = temp + M(111, 97) * M(97, 102)
      temp = temp + M(111, 98) * M(98, 102)
      temp = temp + M(111, 99) * M(99, 102)
      temp = temp + M(111, 100) * M(100, 102)
      temp = temp + M(111, 101) * M(101, 102)
      M(111, 102) = M(111, 102) - temp
C     Lower part.
      temp = M(112, 15) * M(15, 102)
      temp = temp + M(112, 30) * M(30, 102)
      temp = temp + M(112, 39) * M(39, 102)
      temp = temp + M(112, 41) * M(41, 102)
      temp = temp + M(112, 43) * M(43, 102)
      temp = temp + M(112, 47) * M(47, 102)
      temp = temp + M(112, 48) * M(48, 102)
      temp = temp + M(112, 53) * M(53, 102)
      temp = temp + M(112, 55) * M(55, 102)
      temp = temp + M(112, 56) * M(56, 102)
      temp = temp + M(112, 58) * M(58, 102)
      temp = temp + M(112, 59) * M(59, 102)
      temp = temp + M(112, 60) * M(60, 102)
      temp = temp + M(112, 61) * M(61, 102)
      temp = temp + M(112, 65) * M(65, 102)
      temp = temp + M(112, 66) * M(66, 102)
      temp = temp + M(112, 67) * M(67, 102)
      temp = temp + M(112, 69) * M(69, 102)
      temp = temp + M(112, 73) * M(73, 102)
      temp = temp + M(112, 76) * M(76, 102)
      temp = temp + M(112, 77) * M(77, 102)
      temp = temp + M(112, 78) * M(78, 102)
      temp = temp + M(112, 80) * M(80, 102)
      temp = temp + M(112, 81) * M(81, 102)
      temp = temp + M(112, 83) * M(83, 102)
      temp = temp + M(112, 85) * M(85, 102)
      temp = temp + M(112, 86) * M(86, 102)
      temp = temp + M(112, 87) * M(87, 102)
      temp = temp + M(112, 88) * M(88, 102)
      temp = temp + M(112, 89) * M(89, 102)
      temp = temp + M(112, 91) * M(91, 102)
      temp = temp + M(112, 92) * M(92, 102)
      temp = temp + M(112, 93) * M(93, 102)
      temp = temp + M(112, 94) * M(94, 102)
      temp = temp + M(112, 95) * M(95, 102)
      temp = temp + M(112, 96) * M(96, 102)
      temp = temp + M(112, 97) * M(97, 102)
      temp = temp + M(112, 98) * M(98, 102)
      temp = temp + M(112, 99) * M(99, 102)
      temp = temp + M(112, 100) * M(100, 102)
      temp = temp + M(112, 101) * M(101, 102)
      M(112, 102) = M(112, 102) - temp
C     Lower part.
      temp = M(113, 41) * M(41, 102)
      temp = temp + M(113, 42) * M(42, 102)
      temp = temp + M(113, 43) * M(43, 102)
      temp = temp + M(113, 46) * M(46, 102)
      temp = temp + M(113, 48) * M(48, 102)
      temp = temp + M(113, 49) * M(49, 102)
      temp = temp + M(113, 51) * M(51, 102)
      temp = temp + M(113, 53) * M(53, 102)
      temp = temp + M(113, 54) * M(54, 102)
      temp = temp + M(113, 55) * M(55, 102)
      temp = temp + M(113, 57) * M(57, 102)
      temp = temp + M(113, 60) * M(60, 102)
      temp = temp + M(113, 61) * M(61, 102)
      temp = temp + M(113, 62) * M(62, 102)
      temp = temp + M(113, 63) * M(63, 102)
      temp = temp + M(113, 70) * M(70, 102)
      temp = temp + M(113, 71) * M(71, 102)
      temp = temp + M(113, 80) * M(80, 102)
      temp = temp + M(113, 81) * M(81, 102)
      temp = temp + M(113, 83) * M(83, 102)
      temp = temp + M(113, 86) * M(86, 102)
      temp = temp + M(113, 99) * M(99, 102)
      temp = temp + M(113, 100) * M(100, 102)
      temp = temp + M(113, 101) * M(101, 102)
      M(113, 102) = M(113, 102) - temp
C     Upper part.
      temp = M(102, 92) * M(92, 103)
      temp = temp + M(102, 97) * M(97, 103)
      temp = temp + M(102, 100) * M(100, 103)
      temp = temp + M(102, 101) * M(101, 103)
      M(102, 103) = ( M(102, 103) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 97) * M(97, 104)
      temp = temp + M(102, 100) * M(100, 104)
      temp = temp + M(102, 101) * M(101, 104)
      M(102, 104) = ( M(102, 104) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 41) * M(41, 105)
      temp = temp + M(102, 42) * M(42, 105)
      temp = temp + M(102, 43) * M(43, 105)
      temp = temp + M(102, 45) * M(45, 105)
      temp = temp + M(102, 49) * M(49, 105)
      temp = temp + M(102, 50) * M(50, 105)
      temp = temp + M(102, 51) * M(51, 105)
      temp = temp + M(102, 52) * M(52, 105)
      temp = temp + M(102, 53) * M(53, 105)
      temp = temp + M(102, 54) * M(54, 105)
      temp = temp + M(102, 55) * M(55, 105)
      temp = temp + M(102, 57) * M(57, 105)
      temp = temp + M(102, 59) * M(59, 105)
      temp = temp + M(102, 60) * M(60, 105)
      temp = temp + M(102, 62) * M(62, 105)
      temp = temp + M(102, 63) * M(63, 105)
      temp = temp + M(102, 64) * M(64, 105)
      temp = temp + M(102, 65) * M(65, 105)
      temp = temp + M(102, 68) * M(68, 105)
      temp = temp + M(102, 70) * M(70, 105)
      temp = temp + M(102, 71) * M(71, 105)
      temp = temp + M(102, 72) * M(72, 105)
      temp = temp + M(102, 75) * M(75, 105)
      temp = temp + M(102, 79) * M(79, 105)
      temp = temp + M(102, 81) * M(81, 105)
      temp = temp + M(102, 82) * M(82, 105)
      temp = temp + M(102, 83) * M(83, 105)
      temp = temp + M(102, 84) * M(84, 105)
      temp = temp + M(102, 86) * M(86, 105)
      temp = temp + M(102, 88) * M(88, 105)
      temp = temp + M(102, 90) * M(90, 105)
      temp = temp + M(102, 92) * M(92, 105)
      temp = temp + M(102, 95) * M(95, 105)
      temp = temp + M(102, 97) * M(97, 105)
      temp = temp + M(102, 98) * M(98, 105)
      temp = temp + M(102, 99) * M(99, 105)
      temp = temp + M(102, 100) * M(100, 105)
      temp = temp + M(102, 101) * M(101, 105)
      M(102, 105) = ( M(102, 105) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 99) * M(99, 106)
      temp = temp + M(102, 100) * M(100, 106)
      temp = temp + M(102, 101) * M(101, 106)
      M(102, 106) = ( M(102, 106) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 98) * M(98, 107)
      temp = temp + M(102, 100) * M(100, 107)
      temp = temp + M(102, 101) * M(101, 107)
      M(102, 107) = ( M(102, 107) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 41) * M(41, 109)
      temp = temp + M(102, 42) * M(42, 109)
      temp = temp + M(102, 43) * M(43, 109)
      temp = temp + M(102, 44) * M(44, 109)
      temp = temp + M(102, 45) * M(45, 109)
      temp = temp + M(102, 49) * M(49, 109)
      temp = temp + M(102, 50) * M(50, 109)
      temp = temp + M(102, 51) * M(51, 109)
      temp = temp + M(102, 52) * M(52, 109)
      temp = temp + M(102, 53) * M(53, 109)
      temp = temp + M(102, 54) * M(54, 109)
      temp = temp + M(102, 55) * M(55, 109)
      temp = temp + M(102, 57) * M(57, 109)
      temp = temp + M(102, 59) * M(59, 109)
      temp = temp + M(102, 60) * M(60, 109)
      temp = temp + M(102, 62) * M(62, 109)
      temp = temp + M(102, 63) * M(63, 109)
      temp = temp + M(102, 64) * M(64, 109)
      temp = temp + M(102, 65) * M(65, 109)
      temp = temp + M(102, 68) * M(68, 109)
      temp = temp + M(102, 70) * M(70, 109)
      temp = temp + M(102, 71) * M(71, 109)
      temp = temp + M(102, 72) * M(72, 109)
      temp = temp + M(102, 75) * M(75, 109)
      temp = temp + M(102, 79) * M(79, 109)
      temp = temp + M(102, 81) * M(81, 109)
      temp = temp + M(102, 82) * M(82, 109)
      temp = temp + M(102, 83) * M(83, 109)
      temp = temp + M(102, 84) * M(84, 109)
      temp = temp + M(102, 86) * M(86, 109)
      temp = temp + M(102, 88) * M(88, 109)
      temp = temp + M(102, 90) * M(90, 109)
      temp = temp + M(102, 92) * M(92, 109)
      temp = temp + M(102, 95) * M(95, 109)
      temp = temp + M(102, 97) * M(97, 109)
      temp = temp + M(102, 98) * M(98, 109)
      temp = temp + M(102, 99) * M(99, 109)
      temp = temp + M(102, 100) * M(100, 109)
      temp = temp + M(102, 101) * M(101, 109)
      M(102, 109) = ( M(102, 109) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 44) * M(44, 110)
      temp = temp + M(102, 51) * M(51, 110)
      temp = temp + M(102, 75) * M(75, 110)
      temp = temp + M(102, 81) * M(81, 110)
      temp = temp + M(102, 82) * M(82, 110)
      temp = temp + M(102, 83) * M(83, 110)
      temp = temp + M(102, 84) * M(84, 110)
      temp = temp + M(102, 88) * M(88, 110)
      temp = temp + M(102, 92) * M(92, 110)
      temp = temp + M(102, 95) * M(95, 110)
      temp = temp + M(102, 97) * M(97, 110)
      temp = temp + M(102, 98) * M(98, 110)
      temp = temp + M(102, 100) * M(100, 110)
      temp = temp + M(102, 101) * M(101, 110)
      M(102, 110) = ( M(102, 110) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 51) * M(51, 111)
      temp = temp + M(102, 55) * M(55, 111)
      temp = temp + M(102, 57) * M(57, 111)
      temp = temp + M(102, 59) * M(59, 111)
      temp = temp + M(102, 60) * M(60, 111)
      temp = temp + M(102, 62) * M(62, 111)
      temp = temp + M(102, 63) * M(63, 111)
      temp = temp + M(102, 64) * M(64, 111)
      temp = temp + M(102, 65) * M(65, 111)
      temp = temp + M(102, 68) * M(68, 111)
      temp = temp + M(102, 70) * M(70, 111)
      temp = temp + M(102, 71) * M(71, 111)
      temp = temp + M(102, 72) * M(72, 111)
      temp = temp + M(102, 75) * M(75, 111)
      temp = temp + M(102, 79) * M(79, 111)
      temp = temp + M(102, 81) * M(81, 111)
      temp = temp + M(102, 82) * M(82, 111)
      temp = temp + M(102, 83) * M(83, 111)
      temp = temp + M(102, 84) * M(84, 111)
      temp = temp + M(102, 86) * M(86, 111)
      temp = temp + M(102, 88) * M(88, 111)
      temp = temp + M(102, 90) * M(90, 111)
      temp = temp + M(102, 92) * M(92, 111)
      temp = temp + M(102, 95) * M(95, 111)
      temp = temp + M(102, 97) * M(97, 111)
      temp = temp + M(102, 98) * M(98, 111)
      temp = temp + M(102, 99) * M(99, 111)
      temp = temp + M(102, 100) * M(100, 111)
      temp = temp + M(102, 101) * M(101, 111)
      M(102, 111) = ( M(102, 111) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 15) * M(15, 112)
      temp = temp + M(102, 41) * M(41, 112)
      temp = temp + M(102, 42) * M(42, 112)
      temp = temp + M(102, 43) * M(43, 112)
      temp = temp + M(102, 44) * M(44, 112)
      temp = temp + M(102, 49) * M(49, 112)
      temp = temp + M(102, 50) * M(50, 112)
      temp = temp + M(102, 51) * M(51, 112)
      temp = temp + M(102, 52) * M(52, 112)
      temp = temp + M(102, 53) * M(53, 112)
      temp = temp + M(102, 54) * M(54, 112)
      temp = temp + M(102, 55) * M(55, 112)
      temp = temp + M(102, 57) * M(57, 112)
      temp = temp + M(102, 59) * M(59, 112)
      temp = temp + M(102, 60) * M(60, 112)
      temp = temp + M(102, 62) * M(62, 112)
      temp = temp + M(102, 63) * M(63, 112)
      temp = temp + M(102, 64) * M(64, 112)
      temp = temp + M(102, 65) * M(65, 112)
      temp = temp + M(102, 68) * M(68, 112)
      temp = temp + M(102, 70) * M(70, 112)
      temp = temp + M(102, 71) * M(71, 112)
      temp = temp + M(102, 72) * M(72, 112)
      temp = temp + M(102, 75) * M(75, 112)
      temp = temp + M(102, 79) * M(79, 112)
      temp = temp + M(102, 81) * M(81, 112)
      temp = temp + M(102, 82) * M(82, 112)
      temp = temp + M(102, 83) * M(83, 112)
      temp = temp + M(102, 84) * M(84, 112)
      temp = temp + M(102, 86) * M(86, 112)
      temp = temp + M(102, 88) * M(88, 112)
      temp = temp + M(102, 90) * M(90, 112)
      temp = temp + M(102, 92) * M(92, 112)
      temp = temp + M(102, 95) * M(95, 112)
      temp = temp + M(102, 97) * M(97, 112)
      temp = temp + M(102, 98) * M(98, 112)
      temp = temp + M(102, 99) * M(99, 112)
      temp = temp + M(102, 100) * M(100, 112)
      temp = temp + M(102, 101) * M(101, 112)
      M(102, 112) = ( M(102, 112) - temp ) / M(102, 102)
C     Upper part.
      temp = M(102, 99) * M(99, 113)
      temp = temp + M(102, 100) * M(100, 113)
      temp = temp + M(102, 101) * M(101, 113)
      M(102, 113) = ( M(102, 113) - temp ) / M(102, 102)

C     Lower part.
      temp = M(103, 100) * M(100, 103)
      temp = temp + M(103, 101) * M(101, 103)
      temp = temp + M(103, 102) * M(102, 103)
      M(103, 103) = M(103, 103) - temp
C     Lower part.
      temp = M(104, 100) * M(100, 103)
      temp = temp + M(104, 101) * M(101, 103)
      temp = temp + M(104, 102) * M(102, 103)
      M(104, 103) = M(104, 103) - temp
C     Lower part.
      temp = M(105, 92) * M(92, 103)
      temp = temp + M(105, 93) * M(93, 103)
      temp = temp + M(105, 97) * M(97, 103)
      temp = temp + M(105, 100) * M(100, 103)
      temp = temp + M(105, 101) * M(101, 103)
      temp = temp + M(105, 102) * M(102, 103)
      M(105, 103) = M(105, 103) - temp
C     Lower part.
      temp = M(106, 92) * M(92, 103)
      temp = temp + M(106, 97) * M(97, 103)
      temp = temp + M(106, 100) * M(100, 103)
      temp = temp + M(106, 101) * M(101, 103)
      temp = temp + M(106, 102) * M(102, 103)
      M(106, 103) = M(106, 103) - temp
C     Lower part.
      temp = M(107, 92) * M(92, 103)
      temp = temp + M(107, 100) * M(100, 103)
      temp = temp + M(107, 101) * M(101, 103)
      temp = temp + M(107, 102) * M(102, 103)
      M(107, 103) = M(107, 103) - temp
C     Lower part.
      temp = M(108, 92) * M(92, 103)
      temp = temp + M(108, 97) * M(97, 103)
      temp = temp + M(108, 100) * M(100, 103)
      temp = temp + M(108, 101) * M(101, 103)
      temp = temp + M(108, 102) * M(102, 103)
      M(108, 103) = M(108, 103) - temp
C     Lower part.
      temp = M(109, 92) * M(92, 103)
      temp = temp + M(109, 93) * M(93, 103)
      temp = temp + M(109, 94) * M(94, 103)
      temp = temp + M(109, 97) * M(97, 103)
      temp = temp + M(109, 100) * M(100, 103)
      temp = temp + M(109, 101) * M(101, 103)
      temp = temp + M(109, 102) * M(102, 103)
      M(109, 103) = M(109, 103) - temp
C     Lower part.
      temp = M(110, 92) * M(92, 103)
      temp = temp + M(110, 94) * M(94, 103)
      temp = temp + M(110, 97) * M(97, 103)
      temp = temp + M(110, 100) * M(100, 103)
      temp = temp + M(110, 101) * M(101, 103)
      temp = temp + M(110, 102) * M(102, 103)
      M(110, 103) = M(110, 103) - temp
C     Lower part.
      temp = M(111, 92) * M(92, 103)
      temp = temp + M(111, 93) * M(93, 103)
      temp = temp + M(111, 96) * M(96, 103)
      temp = temp + M(111, 97) * M(97, 103)
      temp = temp + M(111, 100) * M(100, 103)
      temp = temp + M(111, 101) * M(101, 103)
      temp = temp + M(111, 102) * M(102, 103)
      M(111, 103) = M(111, 103) - temp
C     Lower part.
      temp = M(112, 92) * M(92, 103)
      temp = temp + M(112, 93) * M(93, 103)
      temp = temp + M(112, 94) * M(94, 103)
      temp = temp + M(112, 96) * M(96, 103)
      temp = temp + M(112, 97) * M(97, 103)
      temp = temp + M(112, 100) * M(100, 103)
      temp = temp + M(112, 101) * M(101, 103)
      temp = temp + M(112, 102) * M(102, 103)
      M(112, 103) = M(112, 103) - temp
C     Lower part.
      temp = M(113, 100) * M(100, 103)
      temp = temp + M(113, 101) * M(101, 103)
      temp = temp + M(113, 102) * M(102, 103)
      M(113, 103) = M(113, 103) - temp
C     Upper part.
      temp = M(103, 100) * M(100, 104)
      temp = temp + M(103, 101) * M(101, 104)
      temp = temp + M(103, 102) * M(102, 104)
      M(103, 104) = ( M(103, 104) - temp ) / M(103, 103)
C     Upper part.
      temp = M(103, 57) * M(57, 105)
      temp = temp + M(103, 60) * M(60, 105)
      temp = temp + M(103, 62) * M(62, 105)
      temp = temp + M(103, 69) * M(69, 105)
      temp = temp + M(103, 70) * M(70, 105)
      temp = temp + M(103, 71) * M(71, 105)
      temp = temp + M(103, 72) * M(72, 105)
      temp = temp + M(103, 79) * M(79, 105)
      temp = temp + M(103, 80) * M(80, 105)
      temp = temp + M(103, 81) * M(81, 105)
      temp = temp + M(103, 83) * M(83, 105)
      temp = temp + M(103, 84) * M(84, 105)
      temp = temp + M(103, 86) * M(86, 105)
      temp = temp + M(103, 99) * M(99, 105)
      temp = temp + M(103, 100) * M(100, 105)
      temp = temp + M(103, 101) * M(101, 105)
      temp = temp + M(103, 102) * M(102, 105)
      M(103, 105) = ( M(103, 105) - temp ) / M(103, 103)
C     Upper part.
      temp = M(103, 99) * M(99, 106)
      temp = temp + M(103, 100) * M(100, 106)
      temp = temp + M(103, 101) * M(101, 106)
      temp = temp + M(103, 102) * M(102, 106)
      M(103, 106) = ( M(103, 106) - temp ) / M(103, 103)
C     Upper part.
      temp = M(103, 100) * M(100, 107)
      temp = temp + M(103, 101) * M(101, 107)
      temp = temp + M(103, 102) * M(102, 107)
      M(103, 107) = ( M(103, 107) - temp ) / M(103, 103)
C     Upper part.
      temp = M(103, 19) * M(19, 109)
      temp = temp + M(103, 31) * M(31, 109)
      temp = temp + M(103, 57) * M(57, 109)
      temp = temp + M(103, 60) * M(60, 109)
      temp = temp + M(103, 62) * M(62, 109)
      temp = temp + M(103, 69) * M(69, 109)
      temp = temp + M(103, 70) * M(70, 109)
      temp = temp + M(103, 71) * M(71, 109)
      temp = temp + M(103, 72) * M(72, 109)
      temp = temp + M(103, 79) * M(79, 109)
      temp = temp + M(103, 80) * M(80, 109)
      temp = temp + M(103, 81) * M(81, 109)
      temp = temp + M(103, 83) * M(83, 109)
      temp = temp + M(103, 84) * M(84, 109)
      temp = temp + M(103, 86) * M(86, 109)
      temp = temp + M(103, 99) * M(99, 109)
      temp = temp + M(103, 100) * M(100, 109)
      temp = temp + M(103, 101) * M(101, 109)
      temp = temp + M(103, 102) * M(102, 109)
      M(103, 109) = ( M(103, 109) - temp ) / M(103, 103)
C     Upper part.
      temp = M(103, 81) * M(81, 110)
      temp = temp + M(103, 83) * M(83, 110)
      temp = temp + M(103, 84) * M(84, 110)
      temp = temp + M(103, 100) * M(100, 110)
      temp = temp + M(103, 101) * M(101, 110)
      temp = temp + M(103, 102) * M(102, 110)
      M(103, 110) = ( M(103, 110) - temp ) / M(103, 103)
C     Upper part.
      temp = M(103, 57) * M(57, 111)
      temp = temp + M(103, 60) * M(60, 111)
      temp = temp + M(103, 62) * M(62, 111)
      temp = temp + M(103, 69) * M(69, 111)
      temp = temp + M(103, 70) * M(70, 111)
      temp = temp + M(103, 71) * M(71, 111)
      temp = temp + M(103, 72) * M(72, 111)
      temp = temp + M(103, 79) * M(79, 111)
      temp = temp + M(103, 80) * M(80, 111)
      temp = temp + M(103, 81) * M(81, 111)
      temp = temp + M(103, 83) * M(83, 111)
      temp = temp + M(103, 84) * M(84, 111)
      temp = temp + M(103, 86) * M(86, 111)
      temp = temp + M(103, 99) * M(99, 111)
      temp = temp + M(103, 100) * M(100, 111)
      temp = temp + M(103, 101) * M(101, 111)
      temp = temp + M(103, 102) * M(102, 111)
      M(103, 111) = ( M(103, 111) - temp ) / M(103, 103)
C     Upper part.
      temp = M(103, 19) * M(19, 112)
      temp = temp + M(103, 31) * M(31, 112)
      temp = temp + M(103, 57) * M(57, 112)
      temp = temp + M(103, 60) * M(60, 112)
      temp = temp + M(103, 62) * M(62, 112)
      temp = temp + M(103, 69) * M(69, 112)
      temp = temp + M(103, 70) * M(70, 112)
      temp = temp + M(103, 71) * M(71, 112)
      temp = temp + M(103, 72) * M(72, 112)
      temp = temp + M(103, 79) * M(79, 112)
      temp = temp + M(103, 80) * M(80, 112)
      temp = temp + M(103, 81) * M(81, 112)
      temp = temp + M(103, 83) * M(83, 112)
      temp = temp + M(103, 84) * M(84, 112)
      temp = temp + M(103, 86) * M(86, 112)
      temp = temp + M(103, 99) * M(99, 112)
      temp = temp + M(103, 100) * M(100, 112)
      temp = temp + M(103, 101) * M(101, 112)
      temp = temp + M(103, 102) * M(102, 112)
      M(103, 112) = ( M(103, 112) - temp ) / M(103, 103)
C     Upper part.
      temp = M(103, 99) * M(99, 113)
      temp = temp + M(103, 100) * M(100, 113)
      temp = temp + M(103, 101) * M(101, 113)
      temp = temp + M(103, 102) * M(102, 113)
      M(103, 113) = ( M(103, 113) - temp ) / M(103, 103)

C     Lower part.
      temp = M(104, 100) * M(100, 104)
      temp = temp + M(104, 101) * M(101, 104)
      temp = temp + M(104, 102) * M(102, 104)
      temp = temp + M(104, 103) * M(103, 104)
      M(104, 104) = M(104, 104) - temp
C     Lower part.
      temp = M(105, 87) * M(87, 104)
      temp = temp + M(105, 97) * M(97, 104)
      temp = temp + M(105, 100) * M(100, 104)
      temp = temp + M(105, 101) * M(101, 104)
      temp = temp + M(105, 102) * M(102, 104)
      temp = temp + M(105, 103) * M(103, 104)
      M(105, 104) = M(105, 104) - temp
C     Lower part.
      temp = M(106, 97) * M(97, 104)
      temp = temp + M(106, 100) * M(100, 104)
      temp = temp + M(106, 101) * M(101, 104)
      temp = temp + M(106, 102) * M(102, 104)
      temp = temp + M(106, 103) * M(103, 104)
      M(106, 104) = M(106, 104) - temp
C     Lower part.
      temp = M(107, 100) * M(100, 104)
      temp = temp + M(107, 101) * M(101, 104)
      temp = temp + M(107, 102) * M(102, 104)
      temp = temp + M(107, 103) * M(103, 104)
      M(107, 104) = M(107, 104) - temp
C     Lower part.
      temp = M(108, 89) * M(89, 104)
      temp = temp + M(108, 97) * M(97, 104)
      temp = temp + M(108, 100) * M(100, 104)
      temp = temp + M(108, 101) * M(101, 104)
      temp = temp + M(108, 102) * M(102, 104)
      temp = temp + M(108, 103) * M(103, 104)
      M(108, 104) = M(108, 104) - temp
C     Lower part.
      temp = M(109, 87) * M(87, 104)
      temp = temp + M(109, 94) * M(94, 104)
      temp = temp + M(109, 97) * M(97, 104)
      temp = temp + M(109, 100) * M(100, 104)
      temp = temp + M(109, 101) * M(101, 104)
      temp = temp + M(109, 102) * M(102, 104)
      temp = temp + M(109, 103) * M(103, 104)
      M(109, 104) = M(109, 104) - temp
C     Lower part.
      temp = M(110, 94) * M(94, 104)
      temp = temp + M(110, 97) * M(97, 104)
      temp = temp + M(110, 100) * M(100, 104)
      temp = temp + M(110, 101) * M(101, 104)
      temp = temp + M(110, 102) * M(102, 104)
      temp = temp + M(110, 103) * M(103, 104)
      M(110, 104) = M(110, 104) - temp
C     Lower part.
      temp = M(111, 21) * M(21, 104)
      temp = temp + M(111, 87) * M(87, 104)
      temp = temp + M(111, 89) * M(89, 104)
      temp = temp + M(111, 96) * M(96, 104)
      temp = temp + M(111, 97) * M(97, 104)
      temp = temp + M(111, 100) * M(100, 104)
      temp = temp + M(111, 101) * M(101, 104)
      temp = temp + M(111, 102) * M(102, 104)
      temp = temp + M(111, 103) * M(103, 104)
      M(111, 104) = M(111, 104) - temp
C     Lower part.
      temp = M(112, 21) * M(21, 104)
      temp = temp + M(112, 87) * M(87, 104)
      temp = temp + M(112, 89) * M(89, 104)
      temp = temp + M(112, 94) * M(94, 104)
      temp = temp + M(112, 96) * M(96, 104)
      temp = temp + M(112, 97) * M(97, 104)
      temp = temp + M(112, 100) * M(100, 104)
      temp = temp + M(112, 101) * M(101, 104)
      temp = temp + M(112, 102) * M(102, 104)
      temp = temp + M(112, 103) * M(103, 104)
      M(112, 104) = M(112, 104) - temp
C     Lower part.
      temp = M(113, 100) * M(100, 104)
      temp = temp + M(113, 101) * M(101, 104)
      temp = temp + M(113, 102) * M(102, 104)
      temp = temp + M(113, 103) * M(103, 104)
      M(113, 104) = M(113, 104) - temp
C     Upper part.
      temp = M(104, 62) * M(62, 105)
      temp = temp + M(104, 69) * M(69, 105)
      temp = temp + M(104, 81) * M(81, 105)
      temp = temp + M(104, 83) * M(83, 105)
      temp = temp + M(104, 86) * M(86, 105)
      temp = temp + M(104, 98) * M(98, 105)
      temp = temp + M(104, 99) * M(99, 105)
      temp = temp + M(104, 100) * M(100, 105)
      temp = temp + M(104, 101) * M(101, 105)
      temp = temp + M(104, 102) * M(102, 105)
      temp = temp + M(104, 103) * M(103, 105)
      M(104, 105) = ( M(104, 105) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 99) * M(99, 106)
      temp = temp + M(104, 100) * M(100, 106)
      temp = temp + M(104, 101) * M(101, 106)
      temp = temp + M(104, 102) * M(102, 106)
      temp = temp + M(104, 103) * M(103, 106)
      M(104, 106) = ( M(104, 106) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 98) * M(98, 107)
      temp = temp + M(104, 100) * M(100, 107)
      temp = temp + M(104, 101) * M(101, 107)
      temp = temp + M(104, 102) * M(102, 107)
      temp = temp + M(104, 103) * M(103, 107)
      M(104, 107) = ( M(104, 107) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 19) * M(19, 109)
      temp = temp + M(104, 27) * M(27, 109)
      temp = temp + M(104, 31) * M(31, 109)
      temp = temp + M(104, 33) * M(33, 109)
      temp = temp + M(104, 62) * M(62, 109)
      temp = temp + M(104, 69) * M(69, 109)
      temp = temp + M(104, 81) * M(81, 109)
      temp = temp + M(104, 83) * M(83, 109)
      temp = temp + M(104, 86) * M(86, 109)
      temp = temp + M(104, 98) * M(98, 109)
      temp = temp + M(104, 99) * M(99, 109)
      temp = temp + M(104, 100) * M(100, 109)
      temp = temp + M(104, 101) * M(101, 109)
      temp = temp + M(104, 102) * M(102, 109)
      temp = temp + M(104, 103) * M(103, 109)
      M(104, 109) = ( M(104, 109) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 81) * M(81, 110)
      temp = temp + M(104, 83) * M(83, 110)
      temp = temp + M(104, 98) * M(98, 110)
      temp = temp + M(104, 100) * M(100, 110)
      temp = temp + M(104, 101) * M(101, 110)
      temp = temp + M(104, 102) * M(102, 110)
      temp = temp + M(104, 103) * M(103, 110)
      M(104, 110) = ( M(104, 110) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 62) * M(62, 111)
      temp = temp + M(104, 69) * M(69, 111)
      temp = temp + M(104, 81) * M(81, 111)
      temp = temp + M(104, 83) * M(83, 111)
      temp = temp + M(104, 86) * M(86, 111)
      temp = temp + M(104, 98) * M(98, 111)
      temp = temp + M(104, 99) * M(99, 111)
      temp = temp + M(104, 100) * M(100, 111)
      temp = temp + M(104, 101) * M(101, 111)
      temp = temp + M(104, 102) * M(102, 111)
      temp = temp + M(104, 103) * M(103, 111)
      M(104, 111) = ( M(104, 111) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 19) * M(19, 112)
      temp = temp + M(104, 27) * M(27, 112)
      temp = temp + M(104, 30) * M(30, 112)
      temp = temp + M(104, 31) * M(31, 112)
      temp = temp + M(104, 33) * M(33, 112)
      temp = temp + M(104, 62) * M(62, 112)
      temp = temp + M(104, 69) * M(69, 112)
      temp = temp + M(104, 81) * M(81, 112)
      temp = temp + M(104, 83) * M(83, 112)
      temp = temp + M(104, 86) * M(86, 112)
      temp = temp + M(104, 98) * M(98, 112)
      temp = temp + M(104, 99) * M(99, 112)
      temp = temp + M(104, 100) * M(100, 112)
      temp = temp + M(104, 101) * M(101, 112)
      temp = temp + M(104, 102) * M(102, 112)
      temp = temp + M(104, 103) * M(103, 112)
      M(104, 112) = ( M(104, 112) - temp ) / M(104, 104)
C     Upper part.
      temp = M(104, 99) * M(99, 113)
      temp = temp + M(104, 100) * M(100, 113)
      temp = temp + M(104, 101) * M(101, 113)
      temp = temp + M(104, 102) * M(102, 113)
      temp = temp + M(104, 103) * M(103, 113)
      M(104, 113) = ( M(104, 113) - temp ) / M(104, 104)

C     Lower part.
      temp = M(105, 35) * M(35, 105)
      temp = temp + M(105, 41) * M(41, 105)
      temp = temp + M(105, 42) * M(42, 105)
      temp = temp + M(105, 43) * M(43, 105)
      temp = temp + M(105, 45) * M(45, 105)
      temp = temp + M(105, 49) * M(49, 105)
      temp = temp + M(105, 50) * M(50, 105)
      temp = temp + M(105, 51) * M(51, 105)
      temp = temp + M(105, 52) * M(52, 105)
      temp = temp + M(105, 53) * M(53, 105)
      temp = temp + M(105, 54) * M(54, 105)
      temp = temp + M(105, 55) * M(55, 105)
      temp = temp + M(105, 56) * M(56, 105)
      temp = temp + M(105, 57) * M(57, 105)
      temp = temp + M(105, 58) * M(58, 105)
      temp = temp + M(105, 59) * M(59, 105)
      temp = temp + M(105, 60) * M(60, 105)
      temp = temp + M(105, 61) * M(61, 105)
      temp = temp + M(105, 62) * M(62, 105)
      temp = temp + M(105, 63) * M(63, 105)
      temp = temp + M(105, 64) * M(64, 105)
      temp = temp + M(105, 65) * M(65, 105)
      temp = temp + M(105, 66) * M(66, 105)
      temp = temp + M(105, 68) * M(68, 105)
      temp = temp + M(105, 70) * M(70, 105)
      temp = temp + M(105, 71) * M(71, 105)
      temp = temp + M(105, 72) * M(72, 105)
      temp = temp + M(105, 74) * M(74, 105)
      temp = temp + M(105, 75) * M(75, 105)
      temp = temp + M(105, 76) * M(76, 105)
      temp = temp + M(105, 77) * M(77, 105)
      temp = temp + M(105, 78) * M(78, 105)
      temp = temp + M(105, 79) * M(79, 105)
      temp = temp + M(105, 80) * M(80, 105)
      temp = temp + M(105, 81) * M(81, 105)
      temp = temp + M(105, 82) * M(82, 105)
      temp = temp + M(105, 83) * M(83, 105)
      temp = temp + M(105, 84) * M(84, 105)
      temp = temp + M(105, 86) * M(86, 105)
      temp = temp + M(105, 87) * M(87, 105)
      temp = temp + M(105, 88) * M(88, 105)
      temp = temp + M(105, 90) * M(90, 105)
      temp = temp + M(105, 92) * M(92, 105)
      temp = temp + M(105, 93) * M(93, 105)
      temp = temp + M(105, 95) * M(95, 105)
      temp = temp + M(105, 97) * M(97, 105)
      temp = temp + M(105, 98) * M(98, 105)
      temp = temp + M(105, 99) * M(99, 105)
      temp = temp + M(105, 100) * M(100, 105)
      temp = temp + M(105, 101) * M(101, 105)
      temp = temp + M(105, 102) * M(102, 105)
      temp = temp + M(105, 103) * M(103, 105)
      temp = temp + M(105, 104) * M(104, 105)
      M(105, 105) = M(105, 105) - temp
C     Lower part.
      temp = M(106, 51) * M(51, 105)
      temp = temp + M(106, 53) * M(53, 105)
      temp = temp + M(106, 55) * M(55, 105)
      temp = temp + M(106, 57) * M(57, 105)
      temp = temp + M(106, 60) * M(60, 105)
      temp = temp + M(106, 62) * M(62, 105)
      temp = temp + M(106, 63) * M(63, 105)
      temp = temp + M(106, 64) * M(64, 105)
      temp = temp + M(106, 65) * M(65, 105)
      temp = temp + M(106, 68) * M(68, 105)
      temp = temp + M(106, 72) * M(72, 105)
      temp = temp + M(106, 75) * M(75, 105)
      temp = temp + M(106, 79) * M(79, 105)
      temp = temp + M(106, 81) * M(81, 105)
      temp = temp + M(106, 82) * M(82, 105)
      temp = temp + M(106, 83) * M(83, 105)
      temp = temp + M(106, 84) * M(84, 105)
      temp = temp + M(106, 86) * M(86, 105)
      temp = temp + M(106, 88) * M(88, 105)
      temp = temp + M(106, 90) * M(90, 105)
      temp = temp + M(106, 92) * M(92, 105)
      temp = temp + M(106, 97) * M(97, 105)
      temp = temp + M(106, 98) * M(98, 105)
      temp = temp + M(106, 99) * M(99, 105)
      temp = temp + M(106, 100) * M(100, 105)
      temp = temp + M(106, 101) * M(101, 105)
      temp = temp + M(106, 102) * M(102, 105)
      temp = temp + M(106, 103) * M(103, 105)
      temp = temp + M(106, 104) * M(104, 105)
      M(106, 105) = M(106, 105) - temp
C     Lower part.
      temp = M(107, 56) * M(56, 105)
      temp = temp + M(107, 57) * M(57, 105)
      temp = temp + M(107, 62) * M(62, 105)
      temp = temp + M(107, 68) * M(68, 105)
      temp = temp + M(107, 69) * M(69, 105)
      temp = temp + M(107, 70) * M(70, 105)
      temp = temp + M(107, 71) * M(71, 105)
      temp = temp + M(107, 72) * M(72, 105)
      temp = temp + M(107, 77) * M(77, 105)
      temp = temp + M(107, 79) * M(79, 105)
      temp = temp + M(107, 80) * M(80, 105)
      temp = temp + M(107, 81) * M(81, 105)
      temp = temp + M(107, 83) * M(83, 105)
      temp = temp + M(107, 84) * M(84, 105)
      temp = temp + M(107, 85) * M(85, 105)
      temp = temp + M(107, 86) * M(86, 105)
      temp = temp + M(107, 88) * M(88, 105)
      temp = temp + M(107, 92) * M(92, 105)
      temp = temp + M(107, 95) * M(95, 105)
      temp = temp + M(107, 99) * M(99, 105)
      temp = temp + M(107, 100) * M(100, 105)
      temp = temp + M(107, 101) * M(101, 105)
      temp = temp + M(107, 102) * M(102, 105)
      temp = temp + M(107, 103) * M(103, 105)
      temp = temp + M(107, 104) * M(104, 105)
      M(107, 105) = M(107, 105) - temp
C     Lower part.
      temp = M(108, 35) * M(35, 105)
      temp = temp + M(108, 41) * M(41, 105)
      temp = temp + M(108, 42) * M(42, 105)
      temp = temp + M(108, 43) * M(43, 105)
      temp = temp + M(108, 45) * M(45, 105)
      temp = temp + M(108, 49) * M(49, 105)
      temp = temp + M(108, 50) * M(50, 105)
      temp = temp + M(108, 51) * M(51, 105)
      temp = temp + M(108, 52) * M(52, 105)
      temp = temp + M(108, 53) * M(53, 105)
      temp = temp + M(108, 54) * M(54, 105)
      temp = temp + M(108, 55) * M(55, 105)
      temp = temp + M(108, 57) * M(57, 105)
      temp = temp + M(108, 59) * M(59, 105)
      temp = temp + M(108, 60) * M(60, 105)
      temp = temp + M(108, 61) * M(61, 105)
      temp = temp + M(108, 62) * M(62, 105)
      temp = temp + M(108, 63) * M(63, 105)
      temp = temp + M(108, 64) * M(64, 105)
      temp = temp + M(108, 65) * M(65, 105)
      temp = temp + M(108, 66) * M(66, 105)
      temp = temp + M(108, 68) * M(68, 105)
      temp = temp + M(108, 69) * M(69, 105)
      temp = temp + M(108, 70) * M(70, 105)
      temp = temp + M(108, 71) * M(71, 105)
      temp = temp + M(108, 72) * M(72, 105)
      temp = temp + M(108, 74) * M(74, 105)
      temp = temp + M(108, 75) * M(75, 105)
      temp = temp + M(108, 76) * M(76, 105)
      temp = temp + M(108, 78) * M(78, 105)
      temp = temp + M(108, 79) * M(79, 105)
      temp = temp + M(108, 80) * M(80, 105)
      temp = temp + M(108, 81) * M(81, 105)
      temp = temp + M(108, 82) * M(82, 105)
      temp = temp + M(108, 83) * M(83, 105)
      temp = temp + M(108, 84) * M(84, 105)
      temp = temp + M(108, 86) * M(86, 105)
      temp = temp + M(108, 88) * M(88, 105)
      temp = temp + M(108, 89) * M(89, 105)
      temp = temp + M(108, 90) * M(90, 105)
      temp = temp + M(108, 91) * M(91, 105)
      temp = temp + M(108, 92) * M(92, 105)
      temp = temp + M(108, 95) * M(95, 105)
      temp = temp + M(108, 97) * M(97, 105)
      temp = temp + M(108, 98) * M(98, 105)
      temp = temp + M(108, 99) * M(99, 105)
      temp = temp + M(108, 100) * M(100, 105)
      temp = temp + M(108, 101) * M(101, 105)
      temp = temp + M(108, 102) * M(102, 105)
      temp = temp + M(108, 103) * M(103, 105)
      temp = temp + M(108, 104) * M(104, 105)
      M(108, 105) = M(108, 105) - temp
C     Lower part.
      temp = M(109, 35) * M(35, 105)
      temp = temp + M(109, 41) * M(41, 105)
      temp = temp + M(109, 42) * M(42, 105)
      temp = temp + M(109, 43) * M(43, 105)
      temp = temp + M(109, 45) * M(45, 105)
      temp = temp + M(109, 47) * M(47, 105)
      temp = temp + M(109, 48) * M(48, 105)
      temp = temp + M(109, 49) * M(49, 105)
      temp = temp + M(109, 50) * M(50, 105)
      temp = temp + M(109, 51) * M(51, 105)
      temp = temp + M(109, 52) * M(52, 105)
      temp = temp + M(109, 53) * M(53, 105)
      temp = temp + M(109, 54) * M(54, 105)
      temp = temp + M(109, 55) * M(55, 105)
      temp = temp + M(109, 57) * M(57, 105)
      temp = temp + M(109, 59) * M(59, 105)
      temp = temp + M(109, 60) * M(60, 105)
      temp = temp + M(109, 61) * M(61, 105)
      temp = temp + M(109, 62) * M(62, 105)
      temp = temp + M(109, 63) * M(63, 105)
      temp = temp + M(109, 64) * M(64, 105)
      temp = temp + M(109, 65) * M(65, 105)
      temp = temp + M(109, 68) * M(68, 105)
      temp = temp + M(109, 69) * M(69, 105)
      temp = temp + M(109, 70) * M(70, 105)
      temp = temp + M(109, 71) * M(71, 105)
      temp = temp + M(109, 72) * M(72, 105)
      temp = temp + M(109, 75) * M(75, 105)
      temp = temp + M(109, 79) * M(79, 105)
      temp = temp + M(109, 80) * M(80, 105)
      temp = temp + M(109, 81) * M(81, 105)
      temp = temp + M(109, 82) * M(82, 105)
      temp = temp + M(109, 83) * M(83, 105)
      temp = temp + M(109, 84) * M(84, 105)
      temp = temp + M(109, 86) * M(86, 105)
      temp = temp + M(109, 87) * M(87, 105)
      temp = temp + M(109, 88) * M(88, 105)
      temp = temp + M(109, 90) * M(90, 105)
      temp = temp + M(109, 91) * M(91, 105)
      temp = temp + M(109, 92) * M(92, 105)
      temp = temp + M(109, 93) * M(93, 105)
      temp = temp + M(109, 94) * M(94, 105)
      temp = temp + M(109, 95) * M(95, 105)
      temp = temp + M(109, 97) * M(97, 105)
      temp = temp + M(109, 98) * M(98, 105)
      temp = temp + M(109, 99) * M(99, 105)
      temp = temp + M(109, 100) * M(100, 105)
      temp = temp + M(109, 101) * M(101, 105)
      temp = temp + M(109, 102) * M(102, 105)
      temp = temp + M(109, 103) * M(103, 105)
      temp = temp + M(109, 104) * M(104, 105)
      M(109, 105) = M(109, 105) - temp
C     Lower part.
      temp = M(110, 35) * M(35, 105)
      temp = temp + M(110, 41) * M(41, 105)
      temp = temp + M(110, 42) * M(42, 105)
      temp = temp + M(110, 43) * M(43, 105)
      temp = temp + M(110, 45) * M(45, 105)
      temp = temp + M(110, 46) * M(46, 105)
      temp = temp + M(110, 48) * M(48, 105)
      temp = temp + M(110, 49) * M(49, 105)
      temp = temp + M(110, 50) * M(50, 105)
      temp = temp + M(110, 51) * M(51, 105)
      temp = temp + M(110, 52) * M(52, 105)
      temp = temp + M(110, 53) * M(53, 105)
      temp = temp + M(110, 54) * M(54, 105)
      temp = temp + M(110, 55) * M(55, 105)
      temp = temp + M(110, 57) * M(57, 105)
      temp = temp + M(110, 59) * M(59, 105)
      temp = temp + M(110, 60) * M(60, 105)
      temp = temp + M(110, 62) * M(62, 105)
      temp = temp + M(110, 63) * M(63, 105)
      temp = temp + M(110, 64) * M(64, 105)
      temp = temp + M(110, 65) * M(65, 105)
      temp = temp + M(110, 68) * M(68, 105)
      temp = temp + M(110, 70) * M(70, 105)
      temp = temp + M(110, 71) * M(71, 105)
      temp = temp + M(110, 72) * M(72, 105)
      temp = temp + M(110, 75) * M(75, 105)
      temp = temp + M(110, 79) * M(79, 105)
      temp = temp + M(110, 81) * M(81, 105)
      temp = temp + M(110, 82) * M(82, 105)
      temp = temp + M(110, 83) * M(83, 105)
      temp = temp + M(110, 84) * M(84, 105)
      temp = temp + M(110, 86) * M(86, 105)
      temp = temp + M(110, 88) * M(88, 105)
      temp = temp + M(110, 90) * M(90, 105)
      temp = temp + M(110, 92) * M(92, 105)
      temp = temp + M(110, 94) * M(94, 105)
      temp = temp + M(110, 95) * M(95, 105)
      temp = temp + M(110, 97) * M(97, 105)
      temp = temp + M(110, 98) * M(98, 105)
      temp = temp + M(110, 99) * M(99, 105)
      temp = temp + M(110, 100) * M(100, 105)
      temp = temp + M(110, 101) * M(101, 105)
      temp = temp + M(110, 102) * M(102, 105)
      temp = temp + M(110, 103) * M(103, 105)
      temp = temp + M(110, 104) * M(104, 105)
      M(110, 105) = M(110, 105) - temp
C     Lower part.
      temp = M(111, 41) * M(41, 105)
      temp = temp + M(111, 42) * M(42, 105)
      temp = temp + M(111, 43) * M(43, 105)
      temp = temp + M(111, 45) * M(45, 105)
      temp = temp + M(111, 47) * M(47, 105)
      temp = temp + M(111, 48) * M(48, 105)
      temp = temp + M(111, 49) * M(49, 105)
      temp = temp + M(111, 50) * M(50, 105)
      temp = temp + M(111, 51) * M(51, 105)
      temp = temp + M(111, 52) * M(52, 105)
      temp = temp + M(111, 53) * M(53, 105)
      temp = temp + M(111, 54) * M(54, 105)
      temp = temp + M(111, 55) * M(55, 105)
      temp = temp + M(111, 56) * M(56, 105)
      temp = temp + M(111, 57) * M(57, 105)
      temp = temp + M(111, 59) * M(59, 105)
      temp = temp + M(111, 60) * M(60, 105)
      temp = temp + M(111, 61) * M(61, 105)
      temp = temp + M(111, 62) * M(62, 105)
      temp = temp + M(111, 63) * M(63, 105)
      temp = temp + M(111, 64) * M(64, 105)
      temp = temp + M(111, 65) * M(65, 105)
      temp = temp + M(111, 66) * M(66, 105)
      temp = temp + M(111, 67) * M(67, 105)
      temp = temp + M(111, 68) * M(68, 105)
      temp = temp + M(111, 69) * M(69, 105)
      temp = temp + M(111, 70) * M(70, 105)
      temp = temp + M(111, 71) * M(71, 105)
      temp = temp + M(111, 72) * M(72, 105)
      temp = temp + M(111, 73) * M(73, 105)
      temp = temp + M(111, 75) * M(75, 105)
      temp = temp + M(111, 76) * M(76, 105)
      temp = temp + M(111, 77) * M(77, 105)
      temp = temp + M(111, 78) * M(78, 105)
      temp = temp + M(111, 79) * M(79, 105)
      temp = temp + M(111, 80) * M(80, 105)
      temp = temp + M(111, 81) * M(81, 105)
      temp = temp + M(111, 82) * M(82, 105)
      temp = temp + M(111, 83) * M(83, 105)
      temp = temp + M(111, 84) * M(84, 105)
      temp = temp + M(111, 85) * M(85, 105)
      temp = temp + M(111, 86) * M(86, 105)
      temp = temp + M(111, 87) * M(87, 105)
      temp = temp + M(111, 88) * M(88, 105)
      temp = temp + M(111, 89) * M(89, 105)
      temp = temp + M(111, 90) * M(90, 105)
      temp = temp + M(111, 91) * M(91, 105)
      temp = temp + M(111, 92) * M(92, 105)
      temp = temp + M(111, 93) * M(93, 105)
      temp = temp + M(111, 95) * M(95, 105)
      temp = temp + M(111, 96) * M(96, 105)
      temp = temp + M(111, 97) * M(97, 105)
      temp = temp + M(111, 98) * M(98, 105)
      temp = temp + M(111, 99) * M(99, 105)
      temp = temp + M(111, 100) * M(100, 105)
      temp = temp + M(111, 101) * M(101, 105)
      temp = temp + M(111, 102) * M(102, 105)
      temp = temp + M(111, 103) * M(103, 105)
      temp = temp + M(111, 104) * M(104, 105)
      M(111, 105) = M(111, 105) - temp
C     Lower part.
      temp = M(112, 35) * M(35, 105)
      temp = temp + M(112, 41) * M(41, 105)
      temp = temp + M(112, 43) * M(43, 105)
      temp = temp + M(112, 47) * M(47, 105)
      temp = temp + M(112, 48) * M(48, 105)
      temp = temp + M(112, 53) * M(53, 105)
      temp = temp + M(112, 55) * M(55, 105)
      temp = temp + M(112, 56) * M(56, 105)
      temp = temp + M(112, 58) * M(58, 105)
      temp = temp + M(112, 59) * M(59, 105)
      temp = temp + M(112, 60) * M(60, 105)
      temp = temp + M(112, 61) * M(61, 105)
      temp = temp + M(112, 65) * M(65, 105)
      temp = temp + M(112, 66) * M(66, 105)
      temp = temp + M(112, 67) * M(67, 105)
      temp = temp + M(112, 69) * M(69, 105)
      temp = temp + M(112, 73) * M(73, 105)
      temp = temp + M(112, 74) * M(74, 105)
      temp = temp + M(112, 76) * M(76, 105)
      temp = temp + M(112, 77) * M(77, 105)
      temp = temp + M(112, 78) * M(78, 105)
      temp = temp + M(112, 80) * M(80, 105)
      temp = temp + M(112, 81) * M(81, 105)
      temp = temp + M(112, 83) * M(83, 105)
      temp = temp + M(112, 85) * M(85, 105)
      temp = temp + M(112, 86) * M(86, 105)
      temp = temp + M(112, 87) * M(87, 105)
      temp = temp + M(112, 88) * M(88, 105)
      temp = temp + M(112, 89) * M(89, 105)
      temp = temp + M(112, 91) * M(91, 105)
      temp = temp + M(112, 92) * M(92, 105)
      temp = temp + M(112, 93) * M(93, 105)
      temp = temp + M(112, 94) * M(94, 105)
      temp = temp + M(112, 95) * M(95, 105)
      temp = temp + M(112, 96) * M(96, 105)
      temp = temp + M(112, 97) * M(97, 105)
      temp = temp + M(112, 98) * M(98, 105)
      temp = temp + M(112, 99) * M(99, 105)
      temp = temp + M(112, 100) * M(100, 105)
      temp = temp + M(112, 101) * M(101, 105)
      temp = temp + M(112, 102) * M(102, 105)
      temp = temp + M(112, 103) * M(103, 105)
      temp = temp + M(112, 104) * M(104, 105)
      M(112, 105) = M(112, 105) - temp
C     Lower part.
      temp = M(113, 41) * M(41, 105)
      temp = temp + M(113, 42) * M(42, 105)
      temp = temp + M(113, 43) * M(43, 105)
      temp = temp + M(113, 46) * M(46, 105)
      temp = temp + M(113, 48) * M(48, 105)
      temp = temp + M(113, 49) * M(49, 105)
      temp = temp + M(113, 51) * M(51, 105)
      temp = temp + M(113, 53) * M(53, 105)
      temp = temp + M(113, 54) * M(54, 105)
      temp = temp + M(113, 55) * M(55, 105)
      temp = temp + M(113, 57) * M(57, 105)
      temp = temp + M(113, 60) * M(60, 105)
      temp = temp + M(113, 61) * M(61, 105)
      temp = temp + M(113, 62) * M(62, 105)
      temp = temp + M(113, 63) * M(63, 105)
      temp = temp + M(113, 70) * M(70, 105)
      temp = temp + M(113, 71) * M(71, 105)
      temp = temp + M(113, 80) * M(80, 105)
      temp = temp + M(113, 81) * M(81, 105)
      temp = temp + M(113, 83) * M(83, 105)
      temp = temp + M(113, 86) * M(86, 105)
      temp = temp + M(113, 99) * M(99, 105)
      temp = temp + M(113, 100) * M(100, 105)
      temp = temp + M(113, 101) * M(101, 105)
      temp = temp + M(113, 102) * M(102, 105)
      temp = temp + M(113, 103) * M(103, 105)
      temp = temp + M(113, 104) * M(104, 105)
      M(113, 105) = M(113, 105) - temp
C     Upper part.
      temp = M(105, 99) * M(99, 106)
      temp = temp + M(105, 100) * M(100, 106)
      temp = temp + M(105, 101) * M(101, 106)
      temp = temp + M(105, 102) * M(102, 106)
      temp = temp + M(105, 103) * M(103, 106)
      temp = temp + M(105, 104) * M(104, 106)
      M(105, 106) = ( M(105, 106) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 98) * M(98, 107)
      temp = temp + M(105, 100) * M(100, 107)
      temp = temp + M(105, 101) * M(101, 107)
      temp = temp + M(105, 102) * M(102, 107)
      temp = temp + M(105, 103) * M(103, 107)
      temp = temp + M(105, 104) * M(104, 107)
      M(105, 107) = ( M(105, 107) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 20) * M(20, 109)
      temp = temp + M(105, 26) * M(26, 109)
      temp = temp + M(105, 41) * M(41, 109)
      temp = temp + M(105, 42) * M(42, 109)
      temp = temp + M(105, 43) * M(43, 109)
      temp = temp + M(105, 45) * M(45, 109)
      temp = temp + M(105, 49) * M(49, 109)
      temp = temp + M(105, 50) * M(50, 109)
      temp = temp + M(105, 51) * M(51, 109)
      temp = temp + M(105, 52) * M(52, 109)
      temp = temp + M(105, 53) * M(53, 109)
      temp = temp + M(105, 54) * M(54, 109)
      temp = temp + M(105, 55) * M(55, 109)
      temp = temp + M(105, 56) * M(56, 109)
      temp = temp + M(105, 57) * M(57, 109)
      temp = temp + M(105, 58) * M(58, 109)
      temp = temp + M(105, 59) * M(59, 109)
      temp = temp + M(105, 60) * M(60, 109)
      temp = temp + M(105, 61) * M(61, 109)
      temp = temp + M(105, 62) * M(62, 109)
      temp = temp + M(105, 63) * M(63, 109)
      temp = temp + M(105, 64) * M(64, 109)
      temp = temp + M(105, 65) * M(65, 109)
      temp = temp + M(105, 66) * M(66, 109)
      temp = temp + M(105, 68) * M(68, 109)
      temp = temp + M(105, 70) * M(70, 109)
      temp = temp + M(105, 71) * M(71, 109)
      temp = temp + M(105, 72) * M(72, 109)
      temp = temp + M(105, 75) * M(75, 109)
      temp = temp + M(105, 76) * M(76, 109)
      temp = temp + M(105, 77) * M(77, 109)
      temp = temp + M(105, 78) * M(78, 109)
      temp = temp + M(105, 79) * M(79, 109)
      temp = temp + M(105, 80) * M(80, 109)
      temp = temp + M(105, 81) * M(81, 109)
      temp = temp + M(105, 82) * M(82, 109)
      temp = temp + M(105, 83) * M(83, 109)
      temp = temp + M(105, 84) * M(84, 109)
      temp = temp + M(105, 86) * M(86, 109)
      temp = temp + M(105, 87) * M(87, 109)
      temp = temp + M(105, 88) * M(88, 109)
      temp = temp + M(105, 90) * M(90, 109)
      temp = temp + M(105, 92) * M(92, 109)
      temp = temp + M(105, 93) * M(93, 109)
      temp = temp + M(105, 95) * M(95, 109)
      temp = temp + M(105, 97) * M(97, 109)
      temp = temp + M(105, 98) * M(98, 109)
      temp = temp + M(105, 99) * M(99, 109)
      temp = temp + M(105, 100) * M(100, 109)
      temp = temp + M(105, 101) * M(101, 109)
      temp = temp + M(105, 102) * M(102, 109)
      temp = temp + M(105, 103) * M(103, 109)
      temp = temp + M(105, 104) * M(104, 109)
      M(105, 109) = ( M(105, 109) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 35) * M(35, 110)
      temp = temp + M(105, 51) * M(51, 110)
      temp = temp + M(105, 75) * M(75, 110)
      temp = temp + M(105, 76) * M(76, 110)
      temp = temp + M(105, 81) * M(81, 110)
      temp = temp + M(105, 82) * M(82, 110)
      temp = temp + M(105, 83) * M(83, 110)
      temp = temp + M(105, 84) * M(84, 110)
      temp = temp + M(105, 87) * M(87, 110)
      temp = temp + M(105, 88) * M(88, 110)
      temp = temp + M(105, 92) * M(92, 110)
      temp = temp + M(105, 93) * M(93, 110)
      temp = temp + M(105, 95) * M(95, 110)
      temp = temp + M(105, 97) * M(97, 110)
      temp = temp + M(105, 98) * M(98, 110)
      temp = temp + M(105, 100) * M(100, 110)
      temp = temp + M(105, 101) * M(101, 110)
      temp = temp + M(105, 102) * M(102, 110)
      temp = temp + M(105, 103) * M(103, 110)
      temp = temp + M(105, 104) * M(104, 110)
      M(105, 110) = ( M(105, 110) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 51) * M(51, 111)
      temp = temp + M(105, 55) * M(55, 111)
      temp = temp + M(105, 56) * M(56, 111)
      temp = temp + M(105, 57) * M(57, 111)
      temp = temp + M(105, 58) * M(58, 111)
      temp = temp + M(105, 59) * M(59, 111)
      temp = temp + M(105, 60) * M(60, 111)
      temp = temp + M(105, 61) * M(61, 111)
      temp = temp + M(105, 62) * M(62, 111)
      temp = temp + M(105, 63) * M(63, 111)
      temp = temp + M(105, 64) * M(64, 111)
      temp = temp + M(105, 65) * M(65, 111)
      temp = temp + M(105, 66) * M(66, 111)
      temp = temp + M(105, 68) * M(68, 111)
      temp = temp + M(105, 70) * M(70, 111)
      temp = temp + M(105, 71) * M(71, 111)
      temp = temp + M(105, 72) * M(72, 111)
      temp = temp + M(105, 74) * M(74, 111)
      temp = temp + M(105, 75) * M(75, 111)
      temp = temp + M(105, 76) * M(76, 111)
      temp = temp + M(105, 77) * M(77, 111)
      temp = temp + M(105, 78) * M(78, 111)
      temp = temp + M(105, 79) * M(79, 111)
      temp = temp + M(105, 80) * M(80, 111)
      temp = temp + M(105, 81) * M(81, 111)
      temp = temp + M(105, 82) * M(82, 111)
      temp = temp + M(105, 83) * M(83, 111)
      temp = temp + M(105, 84) * M(84, 111)
      temp = temp + M(105, 86) * M(86, 111)
      temp = temp + M(105, 87) * M(87, 111)
      temp = temp + M(105, 88) * M(88, 111)
      temp = temp + M(105, 90) * M(90, 111)
      temp = temp + M(105, 92) * M(92, 111)
      temp = temp + M(105, 93) * M(93, 111)
      temp = temp + M(105, 95) * M(95, 111)
      temp = temp + M(105, 97) * M(97, 111)
      temp = temp + M(105, 98) * M(98, 111)
      temp = temp + M(105, 99) * M(99, 111)
      temp = temp + M(105, 100) * M(100, 111)
      temp = temp + M(105, 101) * M(101, 111)
      temp = temp + M(105, 102) * M(102, 111)
      temp = temp + M(105, 103) * M(103, 111)
      temp = temp + M(105, 104) * M(104, 111)
      M(105, 111) = ( M(105, 111) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 20) * M(20, 112)
      temp = temp + M(105, 26) * M(26, 112)
      temp = temp + M(105, 30) * M(30, 112)
      temp = temp + M(105, 35) * M(35, 112)
      temp = temp + M(105, 41) * M(41, 112)
      temp = temp + M(105, 42) * M(42, 112)
      temp = temp + M(105, 43) * M(43, 112)
      temp = temp + M(105, 49) * M(49, 112)
      temp = temp + M(105, 50) * M(50, 112)
      temp = temp + M(105, 51) * M(51, 112)
      temp = temp + M(105, 52) * M(52, 112)
      temp = temp + M(105, 53) * M(53, 112)
      temp = temp + M(105, 54) * M(54, 112)
      temp = temp + M(105, 55) * M(55, 112)
      temp = temp + M(105, 56) * M(56, 112)
      temp = temp + M(105, 57) * M(57, 112)
      temp = temp + M(105, 58) * M(58, 112)
      temp = temp + M(105, 59) * M(59, 112)
      temp = temp + M(105, 60) * M(60, 112)
      temp = temp + M(105, 61) * M(61, 112)
      temp = temp + M(105, 62) * M(62, 112)
      temp = temp + M(105, 63) * M(63, 112)
      temp = temp + M(105, 64) * M(64, 112)
      temp = temp + M(105, 65) * M(65, 112)
      temp = temp + M(105, 66) * M(66, 112)
      temp = temp + M(105, 68) * M(68, 112)
      temp = temp + M(105, 70) * M(70, 112)
      temp = temp + M(105, 71) * M(71, 112)
      temp = temp + M(105, 72) * M(72, 112)
      temp = temp + M(105, 74) * M(74, 112)
      temp = temp + M(105, 75) * M(75, 112)
      temp = temp + M(105, 76) * M(76, 112)
      temp = temp + M(105, 77) * M(77, 112)
      temp = temp + M(105, 78) * M(78, 112)
      temp = temp + M(105, 79) * M(79, 112)
      temp = temp + M(105, 80) * M(80, 112)
      temp = temp + M(105, 81) * M(81, 112)
      temp = temp + M(105, 82) * M(82, 112)
      temp = temp + M(105, 83) * M(83, 112)
      temp = temp + M(105, 84) * M(84, 112)
      temp = temp + M(105, 86) * M(86, 112)
      temp = temp + M(105, 87) * M(87, 112)
      temp = temp + M(105, 88) * M(88, 112)
      temp = temp + M(105, 90) * M(90, 112)
      temp = temp + M(105, 92) * M(92, 112)
      temp = temp + M(105, 93) * M(93, 112)
      temp = temp + M(105, 95) * M(95, 112)
      temp = temp + M(105, 97) * M(97, 112)
      temp = temp + M(105, 98) * M(98, 112)
      temp = temp + M(105, 99) * M(99, 112)
      temp = temp + M(105, 100) * M(100, 112)
      temp = temp + M(105, 101) * M(101, 112)
      temp = temp + M(105, 102) * M(102, 112)
      temp = temp + M(105, 103) * M(103, 112)
      temp = temp + M(105, 104) * M(104, 112)
      M(105, 112) = ( M(105, 112) - temp ) / M(105, 105)
C     Upper part.
      temp = M(105, 99) * M(99, 113)
      temp = temp + M(105, 100) * M(100, 113)
      temp = temp + M(105, 101) * M(101, 113)
      temp = temp + M(105, 102) * M(102, 113)
      temp = temp + M(105, 103) * M(103, 113)
      temp = temp + M(105, 104) * M(104, 113)
      M(105, 113) = ( M(105, 113) - temp ) / M(105, 105)

C     Lower part.
      temp = M(106, 99) * M(99, 106)
      temp = temp + M(106, 100) * M(100, 106)
      temp = temp + M(106, 101) * M(101, 106)
      temp = temp + M(106, 102) * M(102, 106)
      temp = temp + M(106, 103) * M(103, 106)
      temp = temp + M(106, 104) * M(104, 106)
      temp = temp + M(106, 105) * M(105, 106)
      M(106, 106) = M(106, 106) - temp
C     Lower part.
      temp = M(107, 99) * M(99, 106)
      temp = temp + M(107, 100) * M(100, 106)
      temp = temp + M(107, 101) * M(101, 106)
      temp = temp + M(107, 102) * M(102, 106)
      temp = temp + M(107, 103) * M(103, 106)
      temp = temp + M(107, 104) * M(104, 106)
      temp = temp + M(107, 105) * M(105, 106)
      M(107, 106) = M(107, 106) - temp
C     Lower part.
      temp = M(108, 99) * M(99, 106)
      temp = temp + M(108, 100) * M(100, 106)
      temp = temp + M(108, 101) * M(101, 106)
      temp = temp + M(108, 102) * M(102, 106)
      temp = temp + M(108, 103) * M(103, 106)
      temp = temp + M(108, 104) * M(104, 106)
      temp = temp + M(108, 105) * M(105, 106)
      M(108, 106) = M(108, 106) - temp
C     Lower part.
      temp = M(109, 99) * M(99, 106)
      temp = temp + M(109, 100) * M(100, 106)
      temp = temp + M(109, 101) * M(101, 106)
      temp = temp + M(109, 102) * M(102, 106)
      temp = temp + M(109, 103) * M(103, 106)
      temp = temp + M(109, 104) * M(104, 106)
      temp = temp + M(109, 105) * M(105, 106)
      M(109, 106) = M(109, 106) - temp
C     Lower part.
      temp = M(110, 99) * M(99, 106)
      temp = temp + M(110, 100) * M(100, 106)
      temp = temp + M(110, 101) * M(101, 106)
      temp = temp + M(110, 102) * M(102, 106)
      temp = temp + M(110, 103) * M(103, 106)
      temp = temp + M(110, 104) * M(104, 106)
      temp = temp + M(110, 105) * M(105, 106)
      M(110, 106) = M(110, 106) - temp
C     Lower part.
      temp = M(111, 99) * M(99, 106)
      temp = temp + M(111, 100) * M(100, 106)
      temp = temp + M(111, 101) * M(101, 106)
      temp = temp + M(111, 102) * M(102, 106)
      temp = temp + M(111, 103) * M(103, 106)
      temp = temp + M(111, 104) * M(104, 106)
      temp = temp + M(111, 105) * M(105, 106)
      M(111, 106) = M(111, 106) - temp
C     Lower part.
      temp = M(112, 99) * M(99, 106)
      temp = temp + M(112, 100) * M(100, 106)
      temp = temp + M(112, 101) * M(101, 106)
      temp = temp + M(112, 102) * M(102, 106)
      temp = temp + M(112, 103) * M(103, 106)
      temp = temp + M(112, 104) * M(104, 106)
      temp = temp + M(112, 105) * M(105, 106)
      M(112, 106) = M(112, 106) - temp
C     Lower part.
      temp = M(113, 99) * M(99, 106)
      temp = temp + M(113, 100) * M(100, 106)
      temp = temp + M(113, 101) * M(101, 106)
      temp = temp + M(113, 102) * M(102, 106)
      temp = temp + M(113, 103) * M(103, 106)
      temp = temp + M(113, 104) * M(104, 106)
      temp = temp + M(113, 105) * M(105, 106)
      M(113, 106) = M(113, 106) - temp
C     Upper part.
      temp = M(106, 98) * M(98, 107)
      temp = temp + M(106, 100) * M(100, 107)
      temp = temp + M(106, 101) * M(101, 107)
      temp = temp + M(106, 102) * M(102, 107)
      temp = temp + M(106, 103) * M(103, 107)
      temp = temp + M(106, 104) * M(104, 107)
      temp = temp + M(106, 105) * M(105, 107)
      M(106, 107) = ( M(106, 107) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 51) * M(51, 109)
      temp = temp + M(106, 53) * M(53, 109)
      temp = temp + M(106, 55) * M(55, 109)
      temp = temp + M(106, 57) * M(57, 109)
      temp = temp + M(106, 60) * M(60, 109)
      temp = temp + M(106, 62) * M(62, 109)
      temp = temp + M(106, 63) * M(63, 109)
      temp = temp + M(106, 64) * M(64, 109)
      temp = temp + M(106, 65) * M(65, 109)
      temp = temp + M(106, 68) * M(68, 109)
      temp = temp + M(106, 72) * M(72, 109)
      temp = temp + M(106, 75) * M(75, 109)
      temp = temp + M(106, 79) * M(79, 109)
      temp = temp + M(106, 81) * M(81, 109)
      temp = temp + M(106, 82) * M(82, 109)
      temp = temp + M(106, 83) * M(83, 109)
      temp = temp + M(106, 84) * M(84, 109)
      temp = temp + M(106, 86) * M(86, 109)
      temp = temp + M(106, 88) * M(88, 109)
      temp = temp + M(106, 90) * M(90, 109)
      temp = temp + M(106, 92) * M(92, 109)
      temp = temp + M(106, 97) * M(97, 109)
      temp = temp + M(106, 98) * M(98, 109)
      temp = temp + M(106, 99) * M(99, 109)
      temp = temp + M(106, 100) * M(100, 109)
      temp = temp + M(106, 101) * M(101, 109)
      temp = temp + M(106, 102) * M(102, 109)
      temp = temp + M(106, 103) * M(103, 109)
      temp = temp + M(106, 104) * M(104, 109)
      temp = temp + M(106, 105) * M(105, 109)
      M(106, 109) = ( M(106, 109) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 51) * M(51, 110)
      temp = temp + M(106, 75) * M(75, 110)
      temp = temp + M(106, 81) * M(81, 110)
      temp = temp + M(106, 82) * M(82, 110)
      temp = temp + M(106, 83) * M(83, 110)
      temp = temp + M(106, 84) * M(84, 110)
      temp = temp + M(106, 88) * M(88, 110)
      temp = temp + M(106, 92) * M(92, 110)
      temp = temp + M(106, 97) * M(97, 110)
      temp = temp + M(106, 98) * M(98, 110)
      temp = temp + M(106, 100) * M(100, 110)
      temp = temp + M(106, 101) * M(101, 110)
      temp = temp + M(106, 102) * M(102, 110)
      temp = temp + M(106, 103) * M(103, 110)
      temp = temp + M(106, 104) * M(104, 110)
      temp = temp + M(106, 105) * M(105, 110)
      M(106, 110) = ( M(106, 110) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 51) * M(51, 111)
      temp = temp + M(106, 55) * M(55, 111)
      temp = temp + M(106, 57) * M(57, 111)
      temp = temp + M(106, 60) * M(60, 111)
      temp = temp + M(106, 62) * M(62, 111)
      temp = temp + M(106, 63) * M(63, 111)
      temp = temp + M(106, 64) * M(64, 111)
      temp = temp + M(106, 65) * M(65, 111)
      temp = temp + M(106, 68) * M(68, 111)
      temp = temp + M(106, 72) * M(72, 111)
      temp = temp + M(106, 75) * M(75, 111)
      temp = temp + M(106, 79) * M(79, 111)
      temp = temp + M(106, 81) * M(81, 111)
      temp = temp + M(106, 82) * M(82, 111)
      temp = temp + M(106, 83) * M(83, 111)
      temp = temp + M(106, 84) * M(84, 111)
      temp = temp + M(106, 86) * M(86, 111)
      temp = temp + M(106, 88) * M(88, 111)
      temp = temp + M(106, 90) * M(90, 111)
      temp = temp + M(106, 92) * M(92, 111)
      temp = temp + M(106, 97) * M(97, 111)
      temp = temp + M(106, 98) * M(98, 111)
      temp = temp + M(106, 99) * M(99, 111)
      temp = temp + M(106, 100) * M(100, 111)
      temp = temp + M(106, 101) * M(101, 111)
      temp = temp + M(106, 102) * M(102, 111)
      temp = temp + M(106, 103) * M(103, 111)
      temp = temp + M(106, 104) * M(104, 111)
      temp = temp + M(106, 105) * M(105, 111)
      M(106, 111) = ( M(106, 111) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 51) * M(51, 112)
      temp = temp + M(106, 53) * M(53, 112)
      temp = temp + M(106, 55) * M(55, 112)
      temp = temp + M(106, 57) * M(57, 112)
      temp = temp + M(106, 60) * M(60, 112)
      temp = temp + M(106, 62) * M(62, 112)
      temp = temp + M(106, 63) * M(63, 112)
      temp = temp + M(106, 64) * M(64, 112)
      temp = temp + M(106, 65) * M(65, 112)
      temp = temp + M(106, 68) * M(68, 112)
      temp = temp + M(106, 72) * M(72, 112)
      temp = temp + M(106, 75) * M(75, 112)
      temp = temp + M(106, 79) * M(79, 112)
      temp = temp + M(106, 81) * M(81, 112)
      temp = temp + M(106, 82) * M(82, 112)
      temp = temp + M(106, 83) * M(83, 112)
      temp = temp + M(106, 84) * M(84, 112)
      temp = temp + M(106, 86) * M(86, 112)
      temp = temp + M(106, 88) * M(88, 112)
      temp = temp + M(106, 90) * M(90, 112)
      temp = temp + M(106, 92) * M(92, 112)
      temp = temp + M(106, 97) * M(97, 112)
      temp = temp + M(106, 98) * M(98, 112)
      temp = temp + M(106, 99) * M(99, 112)
      temp = temp + M(106, 100) * M(100, 112)
      temp = temp + M(106, 101) * M(101, 112)
      temp = temp + M(106, 102) * M(102, 112)
      temp = temp + M(106, 103) * M(103, 112)
      temp = temp + M(106, 104) * M(104, 112)
      temp = temp + M(106, 105) * M(105, 112)
      M(106, 112) = ( M(106, 112) - temp ) / M(106, 106)
C     Upper part.
      temp = M(106, 99) * M(99, 113)
      temp = temp + M(106, 100) * M(100, 113)
      temp = temp + M(106, 101) * M(101, 113)
      temp = temp + M(106, 102) * M(102, 113)
      temp = temp + M(106, 103) * M(103, 113)
      temp = temp + M(106, 104) * M(104, 113)
      temp = temp + M(106, 105) * M(105, 113)
      M(106, 113) = ( M(106, 113) - temp ) / M(106, 106)

C     Lower part.
      temp = M(107, 100) * M(100, 107)
      temp = temp + M(107, 101) * M(101, 107)
      temp = temp + M(107, 102) * M(102, 107)
      temp = temp + M(107, 103) * M(103, 107)
      temp = temp + M(107, 104) * M(104, 107)
      temp = temp + M(107, 105) * M(105, 107)
      temp = temp + M(107, 106) * M(106, 107)
      M(107, 107) = M(107, 107) - temp
C     Lower part.
      temp = M(108, 98) * M(98, 107)
      temp = temp + M(108, 100) * M(100, 107)
      temp = temp + M(108, 101) * M(101, 107)
      temp = temp + M(108, 102) * M(102, 107)
      temp = temp + M(108, 103) * M(103, 107)
      temp = temp + M(108, 104) * M(104, 107)
      temp = temp + M(108, 105) * M(105, 107)
      temp = temp + M(108, 106) * M(106, 107)
      M(108, 107) = M(108, 107) - temp
C     Lower part.
      temp = M(109, 94) * M(94, 107)
      temp = temp + M(109, 98) * M(98, 107)
      temp = temp + M(109, 100) * M(100, 107)
      temp = temp + M(109, 101) * M(101, 107)
      temp = temp + M(109, 102) * M(102, 107)
      temp = temp + M(109, 103) * M(103, 107)
      temp = temp + M(109, 104) * M(104, 107)
      temp = temp + M(109, 105) * M(105, 107)
      temp = temp + M(109, 106) * M(106, 107)
      M(109, 107) = M(109, 107) - temp
C     Lower part.
      temp = M(110, 94) * M(94, 107)
      temp = temp + M(110, 98) * M(98, 107)
      temp = temp + M(110, 100) * M(100, 107)
      temp = temp + M(110, 101) * M(101, 107)
      temp = temp + M(110, 102) * M(102, 107)
      temp = temp + M(110, 103) * M(103, 107)
      temp = temp + M(110, 104) * M(104, 107)
      temp = temp + M(110, 105) * M(105, 107)
      temp = temp + M(110, 106) * M(106, 107)
      M(110, 107) = M(110, 107) - temp
C     Lower part.
      temp = M(111, 96) * M(96, 107)
      temp = temp + M(111, 98) * M(98, 107)
      temp = temp + M(111, 100) * M(100, 107)
      temp = temp + M(111, 101) * M(101, 107)
      temp = temp + M(111, 102) * M(102, 107)
      temp = temp + M(111, 103) * M(103, 107)
      temp = temp + M(111, 104) * M(104, 107)
      temp = temp + M(111, 105) * M(105, 107)
      temp = temp + M(111, 106) * M(106, 107)
      M(111, 107) = M(111, 107) - temp
C     Lower part.
      temp = M(112, 94) * M(94, 107)
      temp = temp + M(112, 96) * M(96, 107)
      temp = temp + M(112, 98) * M(98, 107)
      temp = temp + M(112, 100) * M(100, 107)
      temp = temp + M(112, 101) * M(101, 107)
      temp = temp + M(112, 102) * M(102, 107)
      temp = temp + M(112, 103) * M(103, 107)
      temp = temp + M(112, 104) * M(104, 107)
      temp = temp + M(112, 105) * M(105, 107)
      temp = temp + M(112, 106) * M(106, 107)
      M(112, 107) = M(112, 107) - temp
C     Lower part.
      temp = M(113, 100) * M(100, 107)
      temp = temp + M(113, 101) * M(101, 107)
      temp = temp + M(113, 102) * M(102, 107)
      temp = temp + M(113, 103) * M(103, 107)
      temp = temp + M(113, 104) * M(104, 107)
      temp = temp + M(113, 105) * M(105, 107)
      temp = temp + M(113, 106) * M(106, 107)
      M(113, 107) = M(113, 107) - temp
C     Upper part.
      temp = M(107, 19) * M(19, 109)
      temp = temp + M(107, 22) * M(22, 109)
      temp = temp + M(107, 31) * M(31, 109)
      temp = temp + M(107, 56) * M(56, 109)
      temp = temp + M(107, 57) * M(57, 109)
      temp = temp + M(107, 62) * M(62, 109)
      temp = temp + M(107, 68) * M(68, 109)
      temp = temp + M(107, 69) * M(69, 109)
      temp = temp + M(107, 70) * M(70, 109)
      temp = temp + M(107, 71) * M(71, 109)
      temp = temp + M(107, 72) * M(72, 109)
      temp = temp + M(107, 77) * M(77, 109)
      temp = temp + M(107, 79) * M(79, 109)
      temp = temp + M(107, 80) * M(80, 109)
      temp = temp + M(107, 81) * M(81, 109)
      temp = temp + M(107, 83) * M(83, 109)
      temp = temp + M(107, 84) * M(84, 109)
      temp = temp + M(107, 85) * M(85, 109)
      temp = temp + M(107, 86) * M(86, 109)
      temp = temp + M(107, 88) * M(88, 109)
      temp = temp + M(107, 92) * M(92, 109)
      temp = temp + M(107, 95) * M(95, 109)
      temp = temp + M(107, 99) * M(99, 109)
      temp = temp + M(107, 100) * M(100, 109)
      temp = temp + M(107, 101) * M(101, 109)
      temp = temp + M(107, 102) * M(102, 109)
      temp = temp + M(107, 103) * M(103, 109)
      temp = temp + M(107, 104) * M(104, 109)
      temp = temp + M(107, 105) * M(105, 109)
      temp = temp + M(107, 106) * M(106, 109)
      M(107, 109) = ( M(107, 109) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 81) * M(81, 110)
      temp = temp + M(107, 83) * M(83, 110)
      temp = temp + M(107, 84) * M(84, 110)
      temp = temp + M(107, 85) * M(85, 110)
      temp = temp + M(107, 88) * M(88, 110)
      temp = temp + M(107, 92) * M(92, 110)
      temp = temp + M(107, 95) * M(95, 110)
      temp = temp + M(107, 100) * M(100, 110)
      temp = temp + M(107, 101) * M(101, 110)
      temp = temp + M(107, 102) * M(102, 110)
      temp = temp + M(107, 103) * M(103, 110)
      temp = temp + M(107, 104) * M(104, 110)
      temp = temp + M(107, 105) * M(105, 110)
      temp = temp + M(107, 106) * M(106, 110)
      M(107, 110) = ( M(107, 110) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 56) * M(56, 111)
      temp = temp + M(107, 57) * M(57, 111)
      temp = temp + M(107, 62) * M(62, 111)
      temp = temp + M(107, 68) * M(68, 111)
      temp = temp + M(107, 69) * M(69, 111)
      temp = temp + M(107, 70) * M(70, 111)
      temp = temp + M(107, 71) * M(71, 111)
      temp = temp + M(107, 72) * M(72, 111)
      temp = temp + M(107, 77) * M(77, 111)
      temp = temp + M(107, 79) * M(79, 111)
      temp = temp + M(107, 80) * M(80, 111)
      temp = temp + M(107, 81) * M(81, 111)
      temp = temp + M(107, 83) * M(83, 111)
      temp = temp + M(107, 84) * M(84, 111)
      temp = temp + M(107, 85) * M(85, 111)
      temp = temp + M(107, 86) * M(86, 111)
      temp = temp + M(107, 88) * M(88, 111)
      temp = temp + M(107, 92) * M(92, 111)
      temp = temp + M(107, 95) * M(95, 111)
      temp = temp + M(107, 99) * M(99, 111)
      temp = temp + M(107, 100) * M(100, 111)
      temp = temp + M(107, 101) * M(101, 111)
      temp = temp + M(107, 102) * M(102, 111)
      temp = temp + M(107, 103) * M(103, 111)
      temp = temp + M(107, 104) * M(104, 111)
      temp = temp + M(107, 105) * M(105, 111)
      temp = temp + M(107, 106) * M(106, 111)
      M(107, 111) = ( M(107, 111) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 8) * M(8, 112)
      temp = temp + M(107, 19) * M(19, 112)
      temp = temp + M(107, 22) * M(22, 112)
      temp = temp + M(107, 24) * M(24, 112)
      temp = temp + M(107, 31) * M(31, 112)
      temp = temp + M(107, 56) * M(56, 112)
      temp = temp + M(107, 57) * M(57, 112)
      temp = temp + M(107, 62) * M(62, 112)
      temp = temp + M(107, 68) * M(68, 112)
      temp = temp + M(107, 69) * M(69, 112)
      temp = temp + M(107, 70) * M(70, 112)
      temp = temp + M(107, 71) * M(71, 112)
      temp = temp + M(107, 72) * M(72, 112)
      temp = temp + M(107, 77) * M(77, 112)
      temp = temp + M(107, 79) * M(79, 112)
      temp = temp + M(107, 80) * M(80, 112)
      temp = temp + M(107, 81) * M(81, 112)
      temp = temp + M(107, 83) * M(83, 112)
      temp = temp + M(107, 84) * M(84, 112)
      temp = temp + M(107, 85) * M(85, 112)
      temp = temp + M(107, 86) * M(86, 112)
      temp = temp + M(107, 88) * M(88, 112)
      temp = temp + M(107, 92) * M(92, 112)
      temp = temp + M(107, 95) * M(95, 112)
      temp = temp + M(107, 99) * M(99, 112)
      temp = temp + M(107, 100) * M(100, 112)
      temp = temp + M(107, 101) * M(101, 112)
      temp = temp + M(107, 102) * M(102, 112)
      temp = temp + M(107, 103) * M(103, 112)
      temp = temp + M(107, 104) * M(104, 112)
      temp = temp + M(107, 105) * M(105, 112)
      temp = temp + M(107, 106) * M(106, 112)
      M(107, 112) = ( M(107, 112) - temp ) / M(107, 107)
C     Upper part.
      temp = M(107, 99) * M(99, 113)
      temp = temp + M(107, 100) * M(100, 113)
      temp = temp + M(107, 101) * M(101, 113)
      temp = temp + M(107, 102) * M(102, 113)
      temp = temp + M(107, 103) * M(103, 113)
      temp = temp + M(107, 104) * M(104, 113)
      temp = temp + M(107, 105) * M(105, 113)
      temp = temp + M(107, 106) * M(106, 113)
      M(107, 113) = ( M(107, 113) - temp ) / M(107, 107)

C     Lower part.
      temp = M(109, 94) * M(94, 108)
      M(109, 108) = M(109, 108) - temp
C     Lower part.
      temp = M(110, 94) * M(94, 108)
      M(110, 108) = M(110, 108) - temp
C     Lower part.
      temp = M(111, 96) * M(96, 108)
      M(111, 108) = M(111, 108) - temp
C     Lower part.
      temp = M(112, 94) * M(94, 108)
      temp = temp + M(112, 96) * M(96, 108)
      M(112, 108) = M(112, 108) - temp
C     Upper part.
      temp = M(108, 20) * M(20, 109)
      temp = temp + M(108, 23) * M(23, 109)
      temp = temp + M(108, 26) * M(26, 109)
      temp = temp + M(108, 27) * M(27, 109)
      temp = temp + M(108, 31) * M(31, 109)
      temp = temp + M(108, 39) * M(39, 109)
      temp = temp + M(108, 41) * M(41, 109)
      temp = temp + M(108, 42) * M(42, 109)
      temp = temp + M(108, 43) * M(43, 109)
      temp = temp + M(108, 45) * M(45, 109)
      temp = temp + M(108, 49) * M(49, 109)
      temp = temp + M(108, 50) * M(50, 109)
      temp = temp + M(108, 51) * M(51, 109)
      temp = temp + M(108, 52) * M(52, 109)
      temp = temp + M(108, 53) * M(53, 109)
      temp = temp + M(108, 54) * M(54, 109)
      temp = temp + M(108, 55) * M(55, 109)
      temp = temp + M(108, 57) * M(57, 109)
      temp = temp + M(108, 59) * M(59, 109)
      temp = temp + M(108, 60) * M(60, 109)
      temp = temp + M(108, 61) * M(61, 109)
      temp = temp + M(108, 62) * M(62, 109)
      temp = temp + M(108, 63) * M(63, 109)
      temp = temp + M(108, 64) * M(64, 109)
      temp = temp + M(108, 65) * M(65, 109)
      temp = temp + M(108, 66) * M(66, 109)
      temp = temp + M(108, 68) * M(68, 109)
      temp = temp + M(108, 69) * M(69, 109)
      temp = temp + M(108, 70) * M(70, 109)
      temp = temp + M(108, 71) * M(71, 109)
      temp = temp + M(108, 72) * M(72, 109)
      temp = temp + M(108, 75) * M(75, 109)
      temp = temp + M(108, 76) * M(76, 109)
      temp = temp + M(108, 78) * M(78, 109)
      temp = temp + M(108, 79) * M(79, 109)
      temp = temp + M(108, 80) * M(80, 109)
      temp = temp + M(108, 81) * M(81, 109)
      temp = temp + M(108, 82) * M(82, 109)
      temp = temp + M(108, 83) * M(83, 109)
      temp = temp + M(108, 84) * M(84, 109)
      temp = temp + M(108, 86) * M(86, 109)
      temp = temp + M(108, 88) * M(88, 109)
      temp = temp + M(108, 89) * M(89, 109)
      temp = temp + M(108, 90) * M(90, 109)
      temp = temp + M(108, 91) * M(91, 109)
      temp = temp + M(108, 92) * M(92, 109)
      temp = temp + M(108, 95) * M(95, 109)
      temp = temp + M(108, 97) * M(97, 109)
      temp = temp + M(108, 98) * M(98, 109)
      temp = temp + M(108, 99) * M(99, 109)
      temp = temp + M(108, 100) * M(100, 109)
      temp = temp + M(108, 101) * M(101, 109)
      temp = temp + M(108, 102) * M(102, 109)
      temp = temp + M(108, 103) * M(103, 109)
      temp = temp + M(108, 104) * M(104, 109)
      temp = temp + M(108, 105) * M(105, 109)
      temp = temp + M(108, 106) * M(106, 109)
      temp = temp + M(108, 107) * M(107, 109)
      M(108, 109) = ( M(108, 109) - temp ) / M(108, 108)
C     Upper part.
      temp = M(108, 35) * M(35, 110)
      temp = temp + M(108, 37) * M(37, 110)
      temp = temp + M(108, 51) * M(51, 110)
      temp = temp + M(108, 75) * M(75, 110)
      temp = temp + M(108, 76) * M(76, 110)
      temp = temp + M(108, 81) * M(81, 110)
      temp = temp + M(108, 82) * M(82, 110)
      temp = temp + M(108, 83) * M(83, 110)
      temp = temp + M(108, 84) * M(84, 110)
      temp = temp + M(108, 88) * M(88, 110)
      temp = temp + M(108, 89) * M(89, 110)
      temp = temp + M(108, 91) * M(91, 110)
      temp = temp + M(108, 92) * M(92, 110)
      temp = temp + M(108, 95) * M(95, 110)
      temp = temp + M(108, 97) * M(97, 110)
      temp = temp + M(108, 98) * M(98, 110)
      temp = temp + M(108, 100) * M(100, 110)
      temp = temp + M(108, 101) * M(101, 110)
      temp = temp + M(108, 102) * M(102, 110)
      temp = temp + M(108, 103) * M(103, 110)
      temp = temp + M(108, 104) * M(104, 110)
      temp = temp + M(108, 105) * M(105, 110)
      temp = temp + M(108, 106) * M(106, 110)
      temp = temp + M(108, 107) * M(107, 110)
      M(108, 110) = ( M(108, 110) - temp ) / M(108, 108)
C     Upper part.
      temp = M(108, 34) * M(34, 111)
      temp = temp + M(108, 51) * M(51, 111)
      temp = temp + M(108, 55) * M(55, 111)
      temp = temp + M(108, 57) * M(57, 111)
      temp = temp + M(108, 59) * M(59, 111)
      temp = temp + M(108, 60) * M(60, 111)
      temp = temp + M(108, 61) * M(61, 111)
      temp = temp + M(108, 62) * M(62, 111)
      temp = temp + M(108, 63) * M(63, 111)
      temp = temp + M(108, 64) * M(64, 111)
      temp = temp + M(108, 65) * M(65, 111)
      temp = temp + M(108, 66) * M(66, 111)
      temp = temp + M(108, 68) * M(68, 111)
      temp = temp + M(108, 69) * M(69, 111)
      temp = temp + M(108, 70) * M(70, 111)
      temp = temp + M(108, 71) * M(71, 111)
      temp = temp + M(108, 72) * M(72, 111)
      temp = temp + M(108, 74) * M(74, 111)
      temp = temp + M(108, 75) * M(75, 111)
      temp = temp + M(108, 76) * M(76, 111)
      temp = temp + M(108, 78) * M(78, 111)
      temp = temp + M(108, 79) * M(79, 111)
      temp = temp + M(108, 80) * M(80, 111)
      temp = temp + M(108, 81) * M(81, 111)
      temp = temp + M(108, 82) * M(82, 111)
      temp = temp + M(108, 83) * M(83, 111)
      temp = temp + M(108, 84) * M(84, 111)
      temp = temp + M(108, 86) * M(86, 111)
      temp = temp + M(108, 88) * M(88, 111)
      temp = temp + M(108, 89) * M(89, 111)
      temp = temp + M(108, 90) * M(90, 111)
      temp = temp + M(108, 91) * M(91, 111)
      temp = temp + M(108, 92) * M(92, 111)
      temp = temp + M(108, 95) * M(95, 111)
      temp = temp + M(108, 97) * M(97, 111)
      temp = temp + M(108, 98) * M(98, 111)
      temp = temp + M(108, 99) * M(99, 111)
      temp = temp + M(108, 100) * M(100, 111)
      temp = temp + M(108, 101) * M(101, 111)
      temp = temp + M(108, 102) * M(102, 111)
      temp = temp + M(108, 103) * M(103, 111)
      temp = temp + M(108, 104) * M(104, 111)
      temp = temp + M(108, 105) * M(105, 111)
      temp = temp + M(108, 106) * M(106, 111)
      temp = temp + M(108, 107) * M(107, 111)
      M(108, 111) = ( M(108, 111) - temp ) / M(108, 108)
C     Upper part.
      temp = M(108, 17) * M(17, 112)
      temp = temp + M(108, 20) * M(20, 112)
      temp = temp + M(108, 23) * M(23, 112)
      temp = temp + M(108, 26) * M(26, 112)
      temp = temp + M(108, 27) * M(27, 112)
      temp = temp + M(108, 31) * M(31, 112)
      temp = temp + M(108, 34) * M(34, 112)
      temp = temp + M(108, 35) * M(35, 112)
      temp = temp + M(108, 37) * M(37, 112)
      temp = temp + M(108, 39) * M(39, 112)
      temp = temp + M(108, 41) * M(41, 112)
      temp = temp + M(108, 42) * M(42, 112)
      temp = temp + M(108, 43) * M(43, 112)
      temp = temp + M(108, 49) * M(49, 112)
      temp = temp + M(108, 50) * M(50, 112)
      temp = temp + M(108, 51) * M(51, 112)
      temp = temp + M(108, 52) * M(52, 112)
      temp = temp + M(108, 53) * M(53, 112)
      temp = temp + M(108, 54) * M(54, 112)
      temp = temp + M(108, 55) * M(55, 112)
      temp = temp + M(108, 57) * M(57, 112)
      temp = temp + M(108, 59) * M(59, 112)
      temp = temp + M(108, 60) * M(60, 112)
      temp = temp + M(108, 61) * M(61, 112)
      temp = temp + M(108, 62) * M(62, 112)
      temp = temp + M(108, 63) * M(63, 112)
      temp = temp + M(108, 64) * M(64, 112)
      temp = temp + M(108, 65) * M(65, 112)
      temp = temp + M(108, 66) * M(66, 112)
      temp = temp + M(108, 68) * M(68, 112)
      temp = temp + M(108, 69) * M(69, 112)
      temp = temp + M(108, 70) * M(70, 112)
      temp = temp + M(108, 71) * M(71, 112)
      temp = temp + M(108, 72) * M(72, 112)
      temp = temp + M(108, 74) * M(74, 112)
      temp = temp + M(108, 75) * M(75, 112)
      temp = temp + M(108, 76) * M(76, 112)
      temp = temp + M(108, 78) * M(78, 112)
      temp = temp + M(108, 79) * M(79, 112)
      temp = temp + M(108, 80) * M(80, 112)
      temp = temp + M(108, 81) * M(81, 112)
      temp = temp + M(108, 82) * M(82, 112)
      temp = temp + M(108, 83) * M(83, 112)
      temp = temp + M(108, 84) * M(84, 112)
      temp = temp + M(108, 86) * M(86, 112)
      temp = temp + M(108, 88) * M(88, 112)
      temp = temp + M(108, 89) * M(89, 112)
      temp = temp + M(108, 90) * M(90, 112)
      temp = temp + M(108, 91) * M(91, 112)
      temp = temp + M(108, 92) * M(92, 112)
      temp = temp + M(108, 95) * M(95, 112)
      temp = temp + M(108, 97) * M(97, 112)
      temp = temp + M(108, 98) * M(98, 112)
      temp = temp + M(108, 99) * M(99, 112)
      temp = temp + M(108, 100) * M(100, 112)
      temp = temp + M(108, 101) * M(101, 112)
      temp = temp + M(108, 102) * M(102, 112)
      temp = temp + M(108, 103) * M(103, 112)
      temp = temp + M(108, 104) * M(104, 112)
      temp = temp + M(108, 105) * M(105, 112)
      temp = temp + M(108, 106) * M(106, 112)
      temp = temp + M(108, 107) * M(107, 112)
      M(108, 112) = ( M(108, 112) - temp ) / M(108, 108)
C     Upper part.
      temp = M(108, 99) * M(99, 113)
      temp = temp + M(108, 100) * M(100, 113)
      temp = temp + M(108, 101) * M(101, 113)
      temp = temp + M(108, 102) * M(102, 113)
      temp = temp + M(108, 103) * M(103, 113)
      temp = temp + M(108, 104) * M(104, 113)
      temp = temp + M(108, 105) * M(105, 113)
      temp = temp + M(108, 106) * M(106, 113)
      temp = temp + M(108, 107) * M(107, 113)
      M(108, 113) = ( M(108, 113) - temp ) / M(108, 108)

C     Lower part.
      temp = M(109, 16) * M(16, 109)
      temp = temp + M(109, 18) * M(18, 109)
      temp = temp + M(109, 19) * M(19, 109)
      temp = temp + M(109, 20) * M(20, 109)
      temp = temp + M(109, 22) * M(22, 109)
      temp = temp + M(109, 23) * M(23, 109)
      temp = temp + M(109, 26) * M(26, 109)
      temp = temp + M(109, 27) * M(27, 109)
      temp = temp + M(109, 29) * M(29, 109)
      temp = temp + M(109, 31) * M(31, 109)
      temp = temp + M(109, 40) * M(40, 109)
      temp = temp + M(109, 41) * M(41, 109)
      temp = temp + M(109, 42) * M(42, 109)
      temp = temp + M(109, 43) * M(43, 109)
      temp = temp + M(109, 44) * M(44, 109)
      temp = temp + M(109, 45) * M(45, 109)
      temp = temp + M(109, 47) * M(47, 109)
      temp = temp + M(109, 48) * M(48, 109)
      temp = temp + M(109, 49) * M(49, 109)
      temp = temp + M(109, 50) * M(50, 109)
      temp = temp + M(109, 51) * M(51, 109)
      temp = temp + M(109, 52) * M(52, 109)
      temp = temp + M(109, 53) * M(53, 109)
      temp = temp + M(109, 54) * M(54, 109)
      temp = temp + M(109, 55) * M(55, 109)
      temp = temp + M(109, 57) * M(57, 109)
      temp = temp + M(109, 59) * M(59, 109)
      temp = temp + M(109, 60) * M(60, 109)
      temp = temp + M(109, 61) * M(61, 109)
      temp = temp + M(109, 62) * M(62, 109)
      temp = temp + M(109, 63) * M(63, 109)
      temp = temp + M(109, 64) * M(64, 109)
      temp = temp + M(109, 65) * M(65, 109)
      temp = temp + M(109, 68) * M(68, 109)
      temp = temp + M(109, 69) * M(69, 109)
      temp = temp + M(109, 70) * M(70, 109)
      temp = temp + M(109, 71) * M(71, 109)
      temp = temp + M(109, 72) * M(72, 109)
      temp = temp + M(109, 75) * M(75, 109)
      temp = temp + M(109, 79) * M(79, 109)
      temp = temp + M(109, 80) * M(80, 109)
      temp = temp + M(109, 81) * M(81, 109)
      temp = temp + M(109, 82) * M(82, 109)
      temp = temp + M(109, 83) * M(83, 109)
      temp = temp + M(109, 84) * M(84, 109)
      temp = temp + M(109, 86) * M(86, 109)
      temp = temp + M(109, 87) * M(87, 109)
      temp = temp + M(109, 88) * M(88, 109)
      temp = temp + M(109, 90) * M(90, 109)
      temp = temp + M(109, 91) * M(91, 109)
      temp = temp + M(109, 92) * M(92, 109)
      temp = temp + M(109, 93) * M(93, 109)
      temp = temp + M(109, 94) * M(94, 109)
      temp = temp + M(109, 95) * M(95, 109)
      temp = temp + M(109, 97) * M(97, 109)
      temp = temp + M(109, 98) * M(98, 109)
      temp = temp + M(109, 99) * M(99, 109)
      temp = temp + M(109, 100) * M(100, 109)
      temp = temp + M(109, 101) * M(101, 109)
      temp = temp + M(109, 102) * M(102, 109)
      temp = temp + M(109, 103) * M(103, 109)
      temp = temp + M(109, 104) * M(104, 109)
      temp = temp + M(109, 105) * M(105, 109)
      temp = temp + M(109, 106) * M(106, 109)
      temp = temp + M(109, 107) * M(107, 109)
      temp = temp + M(109, 108) * M(108, 109)
      M(109, 109) = M(109, 109) - temp
C     Lower part.
      temp = M(110, 16) * M(16, 109)
      temp = temp + M(110, 22) * M(22, 109)
      temp = temp + M(110, 39) * M(39, 109)
      temp = temp + M(110, 40) * M(40, 109)
      temp = temp + M(110, 41) * M(41, 109)
      temp = temp + M(110, 42) * M(42, 109)
      temp = temp + M(110, 43) * M(43, 109)
      temp = temp + M(110, 44) * M(44, 109)
      temp = temp + M(110, 45) * M(45, 109)
      temp = temp + M(110, 46) * M(46, 109)
      temp = temp + M(110, 48) * M(48, 109)
      temp = temp + M(110, 49) * M(49, 109)
      temp = temp + M(110, 50) * M(50, 109)
      temp = temp + M(110, 51) * M(51, 109)
      temp = temp + M(110, 52) * M(52, 109)
      temp = temp + M(110, 53) * M(53, 109)
      temp = temp + M(110, 54) * M(54, 109)
      temp = temp + M(110, 55) * M(55, 109)
      temp = temp + M(110, 57) * M(57, 109)
      temp = temp + M(110, 59) * M(59, 109)
      temp = temp + M(110, 60) * M(60, 109)
      temp = temp + M(110, 62) * M(62, 109)
      temp = temp + M(110, 63) * M(63, 109)
      temp = temp + M(110, 64) * M(64, 109)
      temp = temp + M(110, 65) * M(65, 109)
      temp = temp + M(110, 68) * M(68, 109)
      temp = temp + M(110, 70) * M(70, 109)
      temp = temp + M(110, 71) * M(71, 109)
      temp = temp + M(110, 72) * M(72, 109)
      temp = temp + M(110, 75) * M(75, 109)
      temp = temp + M(110, 79) * M(79, 109)
      temp = temp + M(110, 81) * M(81, 109)
      temp = temp + M(110, 82) * M(82, 109)
      temp = temp + M(110, 83) * M(83, 109)
      temp = temp + M(110, 84) * M(84, 109)
      temp = temp + M(110, 86) * M(86, 109)
      temp = temp + M(110, 88) * M(88, 109)
      temp = temp + M(110, 90) * M(90, 109)
      temp = temp + M(110, 92) * M(92, 109)
      temp = temp + M(110, 94) * M(94, 109)
      temp = temp + M(110, 95) * M(95, 109)
      temp = temp + M(110, 97) * M(97, 109)
      temp = temp + M(110, 98) * M(98, 109)
      temp = temp + M(110, 99) * M(99, 109)
      temp = temp + M(110, 100) * M(100, 109)
      temp = temp + M(110, 101) * M(101, 109)
      temp = temp + M(110, 102) * M(102, 109)
      temp = temp + M(110, 103) * M(103, 109)
      temp = temp + M(110, 104) * M(104, 109)
      temp = temp + M(110, 105) * M(105, 109)
      temp = temp + M(110, 106) * M(106, 109)
      temp = temp + M(110, 107) * M(107, 109)
      temp = temp + M(110, 108) * M(108, 109)
      M(110, 109) = M(110, 109) - temp
C     Lower part.
      temp = M(111, 18) * M(18, 109)
      temp = temp + M(111, 19) * M(19, 109)
      temp = temp + M(111, 20) * M(20, 109)
      temp = temp + M(111, 22) * M(22, 109)
      temp = temp + M(111, 23) * M(23, 109)
      temp = temp + M(111, 26) * M(26, 109)
      temp = temp + M(111, 27) * M(27, 109)
      temp = temp + M(111, 31) * M(31, 109)
      temp = temp + M(111, 38) * M(38, 109)
      temp = temp + M(111, 41) * M(41, 109)
      temp = temp + M(111, 42) * M(42, 109)
      temp = temp + M(111, 43) * M(43, 109)
      temp = temp + M(111, 45) * M(45, 109)
      temp = temp + M(111, 47) * M(47, 109)
      temp = temp + M(111, 48) * M(48, 109)
      temp = temp + M(111, 49) * M(49, 109)
      temp = temp + M(111, 50) * M(50, 109)
      temp = temp + M(111, 51) * M(51, 109)
      temp = temp + M(111, 52) * M(52, 109)
      temp = temp + M(111, 53) * M(53, 109)
      temp = temp + M(111, 54) * M(54, 109)
      temp = temp + M(111, 55) * M(55, 109)
      temp = temp + M(111, 56) * M(56, 109)
      temp = temp + M(111, 57) * M(57, 109)
      temp = temp + M(111, 59) * M(59, 109)
      temp = temp + M(111, 60) * M(60, 109)
      temp = temp + M(111, 61) * M(61, 109)
      temp = temp + M(111, 62) * M(62, 109)
      temp = temp + M(111, 63) * M(63, 109)
      temp = temp + M(111, 64) * M(64, 109)
      temp = temp + M(111, 65) * M(65, 109)
      temp = temp + M(111, 66) * M(66, 109)
      temp = temp + M(111, 67) * M(67, 109)
      temp = temp + M(111, 68) * M(68, 109)
      temp = temp + M(111, 69) * M(69, 109)
      temp = temp + M(111, 70) * M(70, 109)
      temp = temp + M(111, 71) * M(71, 109)
      temp = temp + M(111, 72) * M(72, 109)
      temp = temp + M(111, 73) * M(73, 109)
      temp = temp + M(111, 75) * M(75, 109)
      temp = temp + M(111, 76) * M(76, 109)
      temp = temp + M(111, 77) * M(77, 109)
      temp = temp + M(111, 78) * M(78, 109)
      temp = temp + M(111, 79) * M(79, 109)
      temp = temp + M(111, 80) * M(80, 109)
      temp = temp + M(111, 81) * M(81, 109)
      temp = temp + M(111, 82) * M(82, 109)
      temp = temp + M(111, 83) * M(83, 109)
      temp = temp + M(111, 84) * M(84, 109)
      temp = temp + M(111, 85) * M(85, 109)
      temp = temp + M(111, 86) * M(86, 109)
      temp = temp + M(111, 87) * M(87, 109)
      temp = temp + M(111, 88) * M(88, 109)
      temp = temp + M(111, 89) * M(89, 109)
      temp = temp + M(111, 90) * M(90, 109)
      temp = temp + M(111, 91) * M(91, 109)
      temp = temp + M(111, 92) * M(92, 109)
      temp = temp + M(111, 93) * M(93, 109)
      temp = temp + M(111, 95) * M(95, 109)
      temp = temp + M(111, 96) * M(96, 109)
      temp = temp + M(111, 97) * M(97, 109)
      temp = temp + M(111, 98) * M(98, 109)
      temp = temp + M(111, 99) * M(99, 109)
      temp = temp + M(111, 100) * M(100, 109)
      temp = temp + M(111, 101) * M(101, 109)
      temp = temp + M(111, 102) * M(102, 109)
      temp = temp + M(111, 103) * M(103, 109)
      temp = temp + M(111, 104) * M(104, 109)
      temp = temp + M(111, 105) * M(105, 109)
      temp = temp + M(111, 106) * M(106, 109)
      temp = temp + M(111, 107) * M(107, 109)
      temp = temp + M(111, 108) * M(108, 109)
      M(111, 109) = M(111, 109) - temp
C     Lower part.
      temp = M(112, 18) * M(18, 109)
      temp = temp + M(112, 19) * M(19, 109)
      temp = temp + M(112, 20) * M(20, 109)
      temp = temp + M(112, 22) * M(22, 109)
      temp = temp + M(112, 23) * M(23, 109)
      temp = temp + M(112, 26) * M(26, 109)
      temp = temp + M(112, 27) * M(27, 109)
      temp = temp + M(112, 29) * M(29, 109)
      temp = temp + M(112, 31) * M(31, 109)
      temp = temp + M(112, 32) * M(32, 109)
      temp = temp + M(112, 33) * M(33, 109)
      temp = temp + M(112, 38) * M(38, 109)
      temp = temp + M(112, 39) * M(39, 109)
      temp = temp + M(112, 40) * M(40, 109)
      temp = temp + M(112, 41) * M(41, 109)
      temp = temp + M(112, 43) * M(43, 109)
      temp = temp + M(112, 47) * M(47, 109)
      temp = temp + M(112, 48) * M(48, 109)
      temp = temp + M(112, 53) * M(53, 109)
      temp = temp + M(112, 55) * M(55, 109)
      temp = temp + M(112, 56) * M(56, 109)
      temp = temp + M(112, 58) * M(58, 109)
      temp = temp + M(112, 59) * M(59, 109)
      temp = temp + M(112, 60) * M(60, 109)
      temp = temp + M(112, 61) * M(61, 109)
      temp = temp + M(112, 65) * M(65, 109)
      temp = temp + M(112, 66) * M(66, 109)
      temp = temp + M(112, 67) * M(67, 109)
      temp = temp + M(112, 69) * M(69, 109)
      temp = temp + M(112, 73) * M(73, 109)
      temp = temp + M(112, 76) * M(76, 109)
      temp = temp + M(112, 77) * M(77, 109)
      temp = temp + M(112, 78) * M(78, 109)
      temp = temp + M(112, 80) * M(80, 109)
      temp = temp + M(112, 81) * M(81, 109)
      temp = temp + M(112, 83) * M(83, 109)
      temp = temp + M(112, 85) * M(85, 109)
      temp = temp + M(112, 86) * M(86, 109)
      temp = temp + M(112, 87) * M(87, 109)
      temp = temp + M(112, 88) * M(88, 109)
      temp = temp + M(112, 89) * M(89, 109)
      temp = temp + M(112, 91) * M(91, 109)
      temp = temp + M(112, 92) * M(92, 109)
      temp = temp + M(112, 93) * M(93, 109)
      temp = temp + M(112, 94) * M(94, 109)
      temp = temp + M(112, 95) * M(95, 109)
      temp = temp + M(112, 96) * M(96, 109)
      temp = temp + M(112, 97) * M(97, 109)
      temp = temp + M(112, 98) * M(98, 109)
      temp = temp + M(112, 99) * M(99, 109)
      temp = temp + M(112, 100) * M(100, 109)
      temp = temp + M(112, 101) * M(101, 109)
      temp = temp + M(112, 102) * M(102, 109)
      temp = temp + M(112, 103) * M(103, 109)
      temp = temp + M(112, 104) * M(104, 109)
      temp = temp + M(112, 105) * M(105, 109)
      temp = temp + M(112, 106) * M(106, 109)
      temp = temp + M(112, 107) * M(107, 109)
      temp = temp + M(112, 108) * M(108, 109)
      M(112, 109) = M(112, 109) - temp
C     Lower part.
      temp = M(113, 41) * M(41, 109)
      temp = temp + M(113, 42) * M(42, 109)
      temp = temp + M(113, 43) * M(43, 109)
      temp = temp + M(113, 46) * M(46, 109)
      temp = temp + M(113, 48) * M(48, 109)
      temp = temp + M(113, 49) * M(49, 109)
      temp = temp + M(113, 51) * M(51, 109)
      temp = temp + M(113, 53) * M(53, 109)
      temp = temp + M(113, 54) * M(54, 109)
      temp = temp + M(113, 55) * M(55, 109)
      temp = temp + M(113, 57) * M(57, 109)
      temp = temp + M(113, 60) * M(60, 109)
      temp = temp + M(113, 61) * M(61, 109)
      temp = temp + M(113, 62) * M(62, 109)
      temp = temp + M(113, 63) * M(63, 109)
      temp = temp + M(113, 70) * M(70, 109)
      temp = temp + M(113, 71) * M(71, 109)
      temp = temp + M(113, 80) * M(80, 109)
      temp = temp + M(113, 81) * M(81, 109)
      temp = temp + M(113, 83) * M(83, 109)
      temp = temp + M(113, 86) * M(86, 109)
      temp = temp + M(113, 99) * M(99, 109)
      temp = temp + M(113, 100) * M(100, 109)
      temp = temp + M(113, 101) * M(101, 109)
      temp = temp + M(113, 102) * M(102, 109)
      temp = temp + M(113, 103) * M(103, 109)
      temp = temp + M(113, 104) * M(104, 109)
      temp = temp + M(113, 105) * M(105, 109)
      temp = temp + M(113, 106) * M(106, 109)
      temp = temp + M(113, 107) * M(107, 109)
      M(113, 109) = M(113, 109) - temp
C     Upper part.
      temp = M(109, 16) * M(16, 110)
      temp = temp + M(109, 35) * M(35, 110)
      temp = temp + M(109, 36) * M(36, 110)
      temp = temp + M(109, 37) * M(37, 110)
      temp = temp + M(109, 40) * M(40, 110)
      temp = temp + M(109, 44) * M(44, 110)
      temp = temp + M(109, 48) * M(48, 110)
      temp = temp + M(109, 51) * M(51, 110)
      temp = temp + M(109, 75) * M(75, 110)
      temp = temp + M(109, 81) * M(81, 110)
      temp = temp + M(109, 82) * M(82, 110)
      temp = temp + M(109, 83) * M(83, 110)
      temp = temp + M(109, 84) * M(84, 110)
      temp = temp + M(109, 87) * M(87, 110)
      temp = temp + M(109, 88) * M(88, 110)
      temp = temp + M(109, 91) * M(91, 110)
      temp = temp + M(109, 92) * M(92, 110)
      temp = temp + M(109, 93) * M(93, 110)
      temp = temp + M(109, 94) * M(94, 110)
      temp = temp + M(109, 95) * M(95, 110)
      temp = temp + M(109, 97) * M(97, 110)
      temp = temp + M(109, 98) * M(98, 110)
      temp = temp + M(109, 100) * M(100, 110)
      temp = temp + M(109, 101) * M(101, 110)
      temp = temp + M(109, 102) * M(102, 110)
      temp = temp + M(109, 103) * M(103, 110)
      temp = temp + M(109, 104) * M(104, 110)
      temp = temp + M(109, 105) * M(105, 110)
      temp = temp + M(109, 106) * M(106, 110)
      temp = temp + M(109, 107) * M(107, 110)
      temp = temp + M(109, 108) * M(108, 110)
      M(109, 110) = ( M(109, 110) - temp ) / M(109, 109)
C     Upper part.
      temp = M(109, 36) * M(36, 111)
      temp = temp + M(109, 47) * M(47, 111)
      temp = temp + M(109, 48) * M(48, 111)
      temp = temp + M(109, 51) * M(51, 111)
      temp = temp + M(109, 55) * M(55, 111)
      temp = temp + M(109, 57) * M(57, 111)
      temp = temp + M(109, 59) * M(59, 111)
      temp = temp + M(109, 60) * M(60, 111)
      temp = temp + M(109, 61) * M(61, 111)
      temp = temp + M(109, 62) * M(62, 111)
      temp = temp + M(109, 63) * M(63, 111)
      temp = temp + M(109, 64) * M(64, 111)
      temp = temp + M(109, 65) * M(65, 111)
      temp = temp + M(109, 68) * M(68, 111)
      temp = temp + M(109, 69) * M(69, 111)
      temp = temp + M(109, 70) * M(70, 111)
      temp = temp + M(109, 71) * M(71, 111)
      temp = temp + M(109, 72) * M(72, 111)
      temp = temp + M(109, 75) * M(75, 111)
      temp = temp + M(109, 79) * M(79, 111)
      temp = temp + M(109, 80) * M(80, 111)
      temp = temp + M(109, 81) * M(81, 111)
      temp = temp + M(109, 82) * M(82, 111)
      temp = temp + M(109, 83) * M(83, 111)
      temp = temp + M(109, 84) * M(84, 111)
      temp = temp + M(109, 86) * M(86, 111)
      temp = temp + M(109, 87) * M(87, 111)
      temp = temp + M(109, 88) * M(88, 111)
      temp = temp + M(109, 90) * M(90, 111)
      temp = temp + M(109, 91) * M(91, 111)
      temp = temp + M(109, 92) * M(92, 111)
      temp = temp + M(109, 93) * M(93, 111)
      temp = temp + M(109, 94) * M(94, 111)
      temp = temp + M(109, 95) * M(95, 111)
      temp = temp + M(109, 97) * M(97, 111)
      temp = temp + M(109, 98) * M(98, 111)
      temp = temp + M(109, 99) * M(99, 111)
      temp = temp + M(109, 100) * M(100, 111)
      temp = temp + M(109, 101) * M(101, 111)
      temp = temp + M(109, 102) * M(102, 111)
      temp = temp + M(109, 103) * M(103, 111)
      temp = temp + M(109, 104) * M(104, 111)
      temp = temp + M(109, 105) * M(105, 111)
      temp = temp + M(109, 106) * M(106, 111)
      temp = temp + M(109, 107) * M(107, 111)
      temp = temp + M(109, 108) * M(108, 111)
      M(109, 111) = ( M(109, 111) - temp ) / M(109, 109)
C     Upper part.
      temp = M(109, 18) * M(18, 112)
      temp = temp + M(109, 19) * M(19, 112)
      temp = temp + M(109, 20) * M(20, 112)
      temp = temp + M(109, 22) * M(22, 112)
      temp = temp + M(109, 23) * M(23, 112)
      temp = temp + M(109, 26) * M(26, 112)
      temp = temp + M(109, 27) * M(27, 112)
      temp = temp + M(109, 29) * M(29, 112)
      temp = temp + M(109, 31) * M(31, 112)
      temp = temp + M(109, 35) * M(35, 112)
      temp = temp + M(109, 36) * M(36, 112)
      temp = temp + M(109, 37) * M(37, 112)
      temp = temp + M(109, 40) * M(40, 112)
      temp = temp + M(109, 41) * M(41, 112)
      temp = temp + M(109, 42) * M(42, 112)
      temp = temp + M(109, 43) * M(43, 112)
      temp = temp + M(109, 44) * M(44, 112)
      temp = temp + M(109, 47) * M(47, 112)
      temp = temp + M(109, 48) * M(48, 112)
      temp = temp + M(109, 49) * M(49, 112)
      temp = temp + M(109, 50) * M(50, 112)
      temp = temp + M(109, 51) * M(51, 112)
      temp = temp + M(109, 52) * M(52, 112)
      temp = temp + M(109, 53) * M(53, 112)
      temp = temp + M(109, 54) * M(54, 112)
      temp = temp + M(109, 55) * M(55, 112)
      temp = temp + M(109, 57) * M(57, 112)
      temp = temp + M(109, 59) * M(59, 112)
      temp = temp + M(109, 60) * M(60, 112)
      temp = temp + M(109, 61) * M(61, 112)
      temp = temp + M(109, 62) * M(62, 112)
      temp = temp + M(109, 63) * M(63, 112)
      temp = temp + M(109, 64) * M(64, 112)
      temp = temp + M(109, 65) * M(65, 112)
      temp = temp + M(109, 68) * M(68, 112)
      temp = temp + M(109, 69) * M(69, 112)
      temp = temp + M(109, 70) * M(70, 112)
      temp = temp + M(109, 71) * M(71, 112)
      temp = temp + M(109, 72) * M(72, 112)
      temp = temp + M(109, 75) * M(75, 112)
      temp = temp + M(109, 79) * M(79, 112)
      temp = temp + M(109, 80) * M(80, 112)
      temp = temp + M(109, 81) * M(81, 112)
      temp = temp + M(109, 82) * M(82, 112)
      temp = temp + M(109, 83) * M(83, 112)
      temp = temp + M(109, 84) * M(84, 112)
      temp = temp + M(109, 86) * M(86, 112)
      temp = temp + M(109, 87) * M(87, 112)
      temp = temp + M(109, 88) * M(88, 112)
      temp = temp + M(109, 90) * M(90, 112)
      temp = temp + M(109, 91) * M(91, 112)
      temp = temp + M(109, 92) * M(92, 112)
      temp = temp + M(109, 93) * M(93, 112)
      temp = temp + M(109, 94) * M(94, 112)
      temp = temp + M(109, 95) * M(95, 112)
      temp = temp + M(109, 97) * M(97, 112)
      temp = temp + M(109, 98) * M(98, 112)
      temp = temp + M(109, 99) * M(99, 112)
      temp = temp + M(109, 100) * M(100, 112)
      temp = temp + M(109, 101) * M(101, 112)
      temp = temp + M(109, 102) * M(102, 112)
      temp = temp + M(109, 103) * M(103, 112)
      temp = temp + M(109, 104) * M(104, 112)
      temp = temp + M(109, 105) * M(105, 112)
      temp = temp + M(109, 106) * M(106, 112)
      temp = temp + M(109, 107) * M(107, 112)
      temp = temp + M(109, 108) * M(108, 112)
      M(109, 112) = ( M(109, 112) - temp ) / M(109, 109)
C     Upper part.
      temp = M(109, 99) * M(99, 113)
      temp = temp + M(109, 100) * M(100, 113)
      temp = temp + M(109, 101) * M(101, 113)
      temp = temp + M(109, 102) * M(102, 113)
      temp = temp + M(109, 103) * M(103, 113)
      temp = temp + M(109, 104) * M(104, 113)
      temp = temp + M(109, 105) * M(105, 113)
      temp = temp + M(109, 106) * M(106, 113)
      temp = temp + M(109, 107) * M(107, 113)
      temp = temp + M(109, 108) * M(108, 113)
      M(109, 113) = ( M(109, 113) - temp ) / M(109, 109)

C     Lower part.
      temp = M(110, 16) * M(16, 110)
      temp = temp + M(110, 35) * M(35, 110)
      temp = temp + M(110, 36) * M(36, 110)
      temp = temp + M(110, 37) * M(37, 110)
      temp = temp + M(110, 40) * M(40, 110)
      temp = temp + M(110, 44) * M(44, 110)
      temp = temp + M(110, 46) * M(46, 110)
      temp = temp + M(110, 48) * M(48, 110)
      temp = temp + M(110, 51) * M(51, 110)
      temp = temp + M(110, 75) * M(75, 110)
      temp = temp + M(110, 81) * M(81, 110)
      temp = temp + M(110, 82) * M(82, 110)
      temp = temp + M(110, 83) * M(83, 110)
      temp = temp + M(110, 84) * M(84, 110)
      temp = temp + M(110, 88) * M(88, 110)
      temp = temp + M(110, 92) * M(92, 110)
      temp = temp + M(110, 94) * M(94, 110)
      temp = temp + M(110, 95) * M(95, 110)
      temp = temp + M(110, 97) * M(97, 110)
      temp = temp + M(110, 98) * M(98, 110)
      temp = temp + M(110, 100) * M(100, 110)
      temp = temp + M(110, 101) * M(101, 110)
      temp = temp + M(110, 102) * M(102, 110)
      temp = temp + M(110, 103) * M(103, 110)
      temp = temp + M(110, 104) * M(104, 110)
      temp = temp + M(110, 105) * M(105, 110)
      temp = temp + M(110, 106) * M(106, 110)
      temp = temp + M(110, 107) * M(107, 110)
      temp = temp + M(110, 108) * M(108, 110)
      temp = temp + M(110, 109) * M(109, 110)
      M(110, 110) = M(110, 110) - temp
C     Lower part.
      temp = M(111, 36) * M(36, 110)
      temp = temp + M(111, 48) * M(48, 110)
      temp = temp + M(111, 51) * M(51, 110)
      temp = temp + M(111, 73) * M(73, 110)
      temp = temp + M(111, 75) * M(75, 110)
      temp = temp + M(111, 76) * M(76, 110)
      temp = temp + M(111, 81) * M(81, 110)
      temp = temp + M(111, 82) * M(82, 110)
      temp = temp + M(111, 83) * M(83, 110)
      temp = temp + M(111, 84) * M(84, 110)
      temp = temp + M(111, 85) * M(85, 110)
      temp = temp + M(111, 87) * M(87, 110)
      temp = temp + M(111, 88) * M(88, 110)
      temp = temp + M(111, 89) * M(89, 110)
      temp = temp + M(111, 91) * M(91, 110)
      temp = temp + M(111, 92) * M(92, 110)
      temp = temp + M(111, 93) * M(93, 110)
      temp = temp + M(111, 95) * M(95, 110)
      temp = temp + M(111, 96) * M(96, 110)
      temp = temp + M(111, 97) * M(97, 110)
      temp = temp + M(111, 98) * M(98, 110)
      temp = temp + M(111, 100) * M(100, 110)
      temp = temp + M(111, 101) * M(101, 110)
      temp = temp + M(111, 102) * M(102, 110)
      temp = temp + M(111, 103) * M(103, 110)
      temp = temp + M(111, 104) * M(104, 110)
      temp = temp + M(111, 105) * M(105, 110)
      temp = temp + M(111, 106) * M(106, 110)
      temp = temp + M(111, 107) * M(107, 110)
      temp = temp + M(111, 108) * M(108, 110)
      temp = temp + M(111, 109) * M(109, 110)
      M(111, 110) = M(111, 110) - temp
C     Lower part.
      temp = M(112, 35) * M(35, 110)
      temp = temp + M(112, 36) * M(36, 110)
      temp = temp + M(112, 37) * M(37, 110)
      temp = temp + M(112, 40) * M(40, 110)
      temp = temp + M(112, 48) * M(48, 110)
      temp = temp + M(112, 73) * M(73, 110)
      temp = temp + M(112, 76) * M(76, 110)
      temp = temp + M(112, 81) * M(81, 110)
      temp = temp + M(112, 83) * M(83, 110)
      temp = temp + M(112, 85) * M(85, 110)
      temp = temp + M(112, 87) * M(87, 110)
      temp = temp + M(112, 88) * M(88, 110)
      temp = temp + M(112, 89) * M(89, 110)
      temp = temp + M(112, 91) * M(91, 110)
      temp = temp + M(112, 92) * M(92, 110)
      temp = temp + M(112, 93) * M(93, 110)
      temp = temp + M(112, 94) * M(94, 110)
      temp = temp + M(112, 95) * M(95, 110)
      temp = temp + M(112, 96) * M(96, 110)
      temp = temp + M(112, 97) * M(97, 110)
      temp = temp + M(112, 98) * M(98, 110)
      temp = temp + M(112, 100) * M(100, 110)
      temp = temp + M(112, 101) * M(101, 110)
      temp = temp + M(112, 102) * M(102, 110)
      temp = temp + M(112, 103) * M(103, 110)
      temp = temp + M(112, 104) * M(104, 110)
      temp = temp + M(112, 105) * M(105, 110)
      temp = temp + M(112, 106) * M(106, 110)
      temp = temp + M(112, 107) * M(107, 110)
      temp = temp + M(112, 108) * M(108, 110)
      temp = temp + M(112, 109) * M(109, 110)
      M(112, 110) = M(112, 110) - temp
C     Lower part.
      temp = M(113, 46) * M(46, 110)
      temp = temp + M(113, 48) * M(48, 110)
      temp = temp + M(113, 51) * M(51, 110)
      temp = temp + M(113, 81) * M(81, 110)
      temp = temp + M(113, 83) * M(83, 110)
      temp = temp + M(113, 100) * M(100, 110)
      temp = temp + M(113, 101) * M(101, 110)
      temp = temp + M(113, 102) * M(102, 110)
      temp = temp + M(113, 103) * M(103, 110)
      temp = temp + M(113, 104) * M(104, 110)
      temp = temp + M(113, 105) * M(105, 110)
      temp = temp + M(113, 106) * M(106, 110)
      temp = temp + M(113, 107) * M(107, 110)
      temp = temp + M(113, 109) * M(109, 110)
      M(113, 110) = M(113, 110) - temp
C     Upper part.
      temp = M(110, 36) * M(36, 111)
      temp = temp + M(110, 48) * M(48, 111)
      temp = temp + M(110, 51) * M(51, 111)
      temp = temp + M(110, 55) * M(55, 111)
      temp = temp + M(110, 57) * M(57, 111)
      temp = temp + M(110, 59) * M(59, 111)
      temp = temp + M(110, 60) * M(60, 111)
      temp = temp + M(110, 62) * M(62, 111)
      temp = temp + M(110, 63) * M(63, 111)
      temp = temp + M(110, 64) * M(64, 111)
      temp = temp + M(110, 65) * M(65, 111)
      temp = temp + M(110, 68) * M(68, 111)
      temp = temp + M(110, 70) * M(70, 111)
      temp = temp + M(110, 71) * M(71, 111)
      temp = temp + M(110, 72) * M(72, 111)
      temp = temp + M(110, 75) * M(75, 111)
      temp = temp + M(110, 79) * M(79, 111)
      temp = temp + M(110, 81) * M(81, 111)
      temp = temp + M(110, 82) * M(82, 111)
      temp = temp + M(110, 83) * M(83, 111)
      temp = temp + M(110, 84) * M(84, 111)
      temp = temp + M(110, 86) * M(86, 111)
      temp = temp + M(110, 88) * M(88, 111)
      temp = temp + M(110, 90) * M(90, 111)
      temp = temp + M(110, 92) * M(92, 111)
      temp = temp + M(110, 94) * M(94, 111)
      temp = temp + M(110, 95) * M(95, 111)
      temp = temp + M(110, 97) * M(97, 111)
      temp = temp + M(110, 98) * M(98, 111)
      temp = temp + M(110, 99) * M(99, 111)
      temp = temp + M(110, 100) * M(100, 111)
      temp = temp + M(110, 101) * M(101, 111)
      temp = temp + M(110, 102) * M(102, 111)
      temp = temp + M(110, 103) * M(103, 111)
      temp = temp + M(110, 104) * M(104, 111)
      temp = temp + M(110, 105) * M(105, 111)
      temp = temp + M(110, 106) * M(106, 111)
      temp = temp + M(110, 107) * M(107, 111)
      temp = temp + M(110, 108) * M(108, 111)
      temp = temp + M(110, 109) * M(109, 111)
      M(110, 111) = ( M(110, 111) - temp ) / M(110, 110)
C     Upper part.
      temp = M(110, 15) * M(15, 112)
      temp = temp + M(110, 17) * M(17, 112)
      temp = temp + M(110, 22) * M(22, 112)
      temp = temp + M(110, 35) * M(35, 112)
      temp = temp + M(110, 36) * M(36, 112)
      temp = temp + M(110, 37) * M(37, 112)
      temp = temp + M(110, 39) * M(39, 112)
      temp = temp + M(110, 40) * M(40, 112)
      temp = temp + M(110, 41) * M(41, 112)
      temp = temp + M(110, 42) * M(42, 112)
      temp = temp + M(110, 43) * M(43, 112)
      temp = temp + M(110, 44) * M(44, 112)
      temp = temp + M(110, 48) * M(48, 112)
      temp = temp + M(110, 49) * M(49, 112)
      temp = temp + M(110, 50) * M(50, 112)
      temp = temp + M(110, 51) * M(51, 112)
      temp = temp + M(110, 52) * M(52, 112)
      temp = temp + M(110, 53) * M(53, 112)
      temp = temp + M(110, 54) * M(54, 112)
      temp = temp + M(110, 55) * M(55, 112)
      temp = temp + M(110, 57) * M(57, 112)
      temp = temp + M(110, 59) * M(59, 112)
      temp = temp + M(110, 60) * M(60, 112)
      temp = temp + M(110, 62) * M(62, 112)
      temp = temp + M(110, 63) * M(63, 112)
      temp = temp + M(110, 64) * M(64, 112)
      temp = temp + M(110, 65) * M(65, 112)
      temp = temp + M(110, 68) * M(68, 112)
      temp = temp + M(110, 70) * M(70, 112)
      temp = temp + M(110, 71) * M(71, 112)
      temp = temp + M(110, 72) * M(72, 112)
      temp = temp + M(110, 75) * M(75, 112)
      temp = temp + M(110, 79) * M(79, 112)
      temp = temp + M(110, 81) * M(81, 112)
      temp = temp + M(110, 82) * M(82, 112)
      temp = temp + M(110, 83) * M(83, 112)
      temp = temp + M(110, 84) * M(84, 112)
      temp = temp + M(110, 86) * M(86, 112)
      temp = temp + M(110, 88) * M(88, 112)
      temp = temp + M(110, 90) * M(90, 112)
      temp = temp + M(110, 92) * M(92, 112)
      temp = temp + M(110, 94) * M(94, 112)
      temp = temp + M(110, 95) * M(95, 112)
      temp = temp + M(110, 97) * M(97, 112)
      temp = temp + M(110, 98) * M(98, 112)
      temp = temp + M(110, 99) * M(99, 112)
      temp = temp + M(110, 100) * M(100, 112)
      temp = temp + M(110, 101) * M(101, 112)
      temp = temp + M(110, 102) * M(102, 112)
      temp = temp + M(110, 103) * M(103, 112)
      temp = temp + M(110, 104) * M(104, 112)
      temp = temp + M(110, 105) * M(105, 112)
      temp = temp + M(110, 106) * M(106, 112)
      temp = temp + M(110, 107) * M(107, 112)
      temp = temp + M(110, 108) * M(108, 112)
      temp = temp + M(110, 109) * M(109, 112)
      M(110, 112) = ( M(110, 112) - temp ) / M(110, 110)
C     Upper part.
      temp = M(110, 99) * M(99, 113)
      temp = temp + M(110, 100) * M(100, 113)
      temp = temp + M(110, 101) * M(101, 113)
      temp = temp + M(110, 102) * M(102, 113)
      temp = temp + M(110, 103) * M(103, 113)
      temp = temp + M(110, 104) * M(104, 113)
      temp = temp + M(110, 105) * M(105, 113)
      temp = temp + M(110, 106) * M(106, 113)
      temp = temp + M(110, 107) * M(107, 113)
      temp = temp + M(110, 108) * M(108, 113)
      temp = temp + M(110, 109) * M(109, 113)
      M(110, 113) = ( M(110, 113) - temp ) / M(110, 110)

C     Lower part.
      temp = M(111, 34) * M(34, 111)
      temp = temp + M(111, 36) * M(36, 111)
      temp = temp + M(111, 38) * M(38, 111)
      temp = temp + M(111, 47) * M(47, 111)
      temp = temp + M(111, 48) * M(48, 111)
      temp = temp + M(111, 51) * M(51, 111)
      temp = temp + M(111, 55) * M(55, 111)
      temp = temp + M(111, 56) * M(56, 111)
      temp = temp + M(111, 57) * M(57, 111)
      temp = temp + M(111, 59) * M(59, 111)
      temp = temp + M(111, 60) * M(60, 111)
      temp = temp + M(111, 61) * M(61, 111)
      temp = temp + M(111, 62) * M(62, 111)
      temp = temp + M(111, 63) * M(63, 111)
      temp = temp + M(111, 64) * M(64, 111)
      temp = temp + M(111, 65) * M(65, 111)
      temp = temp + M(111, 66) * M(66, 111)
      temp = temp + M(111, 67) * M(67, 111)
      temp = temp + M(111, 68) * M(68, 111)
      temp = temp + M(111, 69) * M(69, 111)
      temp = temp + M(111, 70) * M(70, 111)
      temp = temp + M(111, 71) * M(71, 111)
      temp = temp + M(111, 72) * M(72, 111)
      temp = temp + M(111, 73) * M(73, 111)
      temp = temp + M(111, 75) * M(75, 111)
      temp = temp + M(111, 76) * M(76, 111)
      temp = temp + M(111, 77) * M(77, 111)
      temp = temp + M(111, 78) * M(78, 111)
      temp = temp + M(111, 79) * M(79, 111)
      temp = temp + M(111, 80) * M(80, 111)
      temp = temp + M(111, 81) * M(81, 111)
      temp = temp + M(111, 82) * M(82, 111)
      temp = temp + M(111, 83) * M(83, 111)
      temp = temp + M(111, 84) * M(84, 111)
      temp = temp + M(111, 85) * M(85, 111)
      temp = temp + M(111, 86) * M(86, 111)
      temp = temp + M(111, 87) * M(87, 111)
      temp = temp + M(111, 88) * M(88, 111)
      temp = temp + M(111, 89) * M(89, 111)
      temp = temp + M(111, 90) * M(90, 111)
      temp = temp + M(111, 91) * M(91, 111)
      temp = temp + M(111, 92) * M(92, 111)
      temp = temp + M(111, 93) * M(93, 111)
      temp = temp + M(111, 95) * M(95, 111)
      temp = temp + M(111, 96) * M(96, 111)
      temp = temp + M(111, 97) * M(97, 111)
      temp = temp + M(111, 98) * M(98, 111)
      temp = temp + M(111, 99) * M(99, 111)
      temp = temp + M(111, 100) * M(100, 111)
      temp = temp + M(111, 101) * M(101, 111)
      temp = temp + M(111, 102) * M(102, 111)
      temp = temp + M(111, 103) * M(103, 111)
      temp = temp + M(111, 104) * M(104, 111)
      temp = temp + M(111, 105) * M(105, 111)
      temp = temp + M(111, 106) * M(106, 111)
      temp = temp + M(111, 107) * M(107, 111)
      temp = temp + M(111, 108) * M(108, 111)
      temp = temp + M(111, 109) * M(109, 111)
      temp = temp + M(111, 110) * M(110, 111)
      M(111, 111) = M(111, 111) - temp
C     Lower part.
      temp = M(112, 28) * M(28, 111)
      temp = temp + M(112, 34) * M(34, 111)
      temp = temp + M(112, 36) * M(36, 111)
      temp = temp + M(112, 38) * M(38, 111)
      temp = temp + M(112, 47) * M(47, 111)
      temp = temp + M(112, 48) * M(48, 111)
      temp = temp + M(112, 55) * M(55, 111)
      temp = temp + M(112, 56) * M(56, 111)
      temp = temp + M(112, 58) * M(58, 111)
      temp = temp + M(112, 59) * M(59, 111)
      temp = temp + M(112, 60) * M(60, 111)
      temp = temp + M(112, 61) * M(61, 111)
      temp = temp + M(112, 65) * M(65, 111)
      temp = temp + M(112, 66) * M(66, 111)
      temp = temp + M(112, 67) * M(67, 111)
      temp = temp + M(112, 69) * M(69, 111)
      temp = temp + M(112, 73) * M(73, 111)
      temp = temp + M(112, 74) * M(74, 111)
      temp = temp + M(112, 76) * M(76, 111)
      temp = temp + M(112, 77) * M(77, 111)
      temp = temp + M(112, 78) * M(78, 111)
      temp = temp + M(112, 80) * M(80, 111)
      temp = temp + M(112, 81) * M(81, 111)
      temp = temp + M(112, 83) * M(83, 111)
      temp = temp + M(112, 85) * M(85, 111)
      temp = temp + M(112, 86) * M(86, 111)
      temp = temp + M(112, 87) * M(87, 111)
      temp = temp + M(112, 88) * M(88, 111)
      temp = temp + M(112, 89) * M(89, 111)
      temp = temp + M(112, 91) * M(91, 111)
      temp = temp + M(112, 92) * M(92, 111)
      temp = temp + M(112, 93) * M(93, 111)
      temp = temp + M(112, 94) * M(94, 111)
      temp = temp + M(112, 95) * M(95, 111)
      temp = temp + M(112, 96) * M(96, 111)
      temp = temp + M(112, 97) * M(97, 111)
      temp = temp + M(112, 98) * M(98, 111)
      temp = temp + M(112, 99) * M(99, 111)
      temp = temp + M(112, 100) * M(100, 111)
      temp = temp + M(112, 101) * M(101, 111)
      temp = temp + M(112, 102) * M(102, 111)
      temp = temp + M(112, 103) * M(103, 111)
      temp = temp + M(112, 104) * M(104, 111)
      temp = temp + M(112, 105) * M(105, 111)
      temp = temp + M(112, 106) * M(106, 111)
      temp = temp + M(112, 107) * M(107, 111)
      temp = temp + M(112, 108) * M(108, 111)
      temp = temp + M(112, 109) * M(109, 111)
      temp = temp + M(112, 110) * M(110, 111)
      M(112, 111) = M(112, 111) - temp
C     Lower part.
      temp = M(113, 48) * M(48, 111)
      temp = temp + M(113, 51) * M(51, 111)
      temp = temp + M(113, 55) * M(55, 111)
      temp = temp + M(113, 57) * M(57, 111)
      temp = temp + M(113, 60) * M(60, 111)
      temp = temp + M(113, 61) * M(61, 111)
      temp = temp + M(113, 62) * M(62, 111)
      temp = temp + M(113, 63) * M(63, 111)
      temp = temp + M(113, 70) * M(70, 111)
      temp = temp + M(113, 71) * M(71, 111)
      temp = temp + M(113, 80) * M(80, 111)
      temp = temp + M(113, 81) * M(81, 111)
      temp = temp + M(113, 83) * M(83, 111)
      temp = temp + M(113, 86) * M(86, 111)
      temp = temp + M(113, 99) * M(99, 111)
      temp = temp + M(113, 100) * M(100, 111)
      temp = temp + M(113, 101) * M(101, 111)
      temp = temp + M(113, 102) * M(102, 111)
      temp = temp + M(113, 103) * M(103, 111)
      temp = temp + M(113, 104) * M(104, 111)
      temp = temp + M(113, 105) * M(105, 111)
      temp = temp + M(113, 106) * M(106, 111)
      temp = temp + M(113, 107) * M(107, 111)
      temp = temp + M(113, 109) * M(109, 111)
      temp = temp + M(113, 110) * M(110, 111)
      M(113, 111) = M(113, 111) - temp
C     Upper part.
      temp = M(111, 2) * M(2, 112)
      temp = temp + M(111, 4) * M(4, 112)
      temp = temp + M(111, 5) * M(5, 112)
      temp = temp + M(111, 8) * M(8, 112)
      temp = temp + M(111, 9) * M(9, 112)
      temp = temp + M(111, 10) * M(10, 112)
      temp = temp + M(111, 11) * M(11, 112)
      temp = temp + M(111, 12) * M(12, 112)
      temp = temp + M(111, 13) * M(13, 112)
      temp = temp + M(111, 14) * M(14, 112)
      temp = temp + M(111, 18) * M(18, 112)
      temp = temp + M(111, 19) * M(19, 112)
      temp = temp + M(111, 20) * M(20, 112)
      temp = temp + M(111, 21) * M(21, 112)
      temp = temp + M(111, 22) * M(22, 112)
      temp = temp + M(111, 23) * M(23, 112)
      temp = temp + M(111, 24) * M(24, 112)
      temp = temp + M(111, 26) * M(26, 112)
      temp = temp + M(111, 27) * M(27, 112)
      temp = temp + M(111, 31) * M(31, 112)
      temp = temp + M(111, 34) * M(34, 112)
      temp = temp + M(111, 36) * M(36, 112)
      temp = temp + M(111, 38) * M(38, 112)
      temp = temp + M(111, 41) * M(41, 112)
      temp = temp + M(111, 42) * M(42, 112)
      temp = temp + M(111, 43) * M(43, 112)
      temp = temp + M(111, 47) * M(47, 112)
      temp = temp + M(111, 48) * M(48, 112)
      temp = temp + M(111, 49) * M(49, 112)
      temp = temp + M(111, 50) * M(50, 112)
      temp = temp + M(111, 51) * M(51, 112)
      temp = temp + M(111, 52) * M(52, 112)
      temp = temp + M(111, 53) * M(53, 112)
      temp = temp + M(111, 54) * M(54, 112)
      temp = temp + M(111, 55) * M(55, 112)
      temp = temp + M(111, 56) * M(56, 112)
      temp = temp + M(111, 57) * M(57, 112)
      temp = temp + M(111, 59) * M(59, 112)
      temp = temp + M(111, 60) * M(60, 112)
      temp = temp + M(111, 61) * M(61, 112)
      temp = temp + M(111, 62) * M(62, 112)
      temp = temp + M(111, 63) * M(63, 112)
      temp = temp + M(111, 64) * M(64, 112)
      temp = temp + M(111, 65) * M(65, 112)
      temp = temp + M(111, 66) * M(66, 112)
      temp = temp + M(111, 67) * M(67, 112)
      temp = temp + M(111, 68) * M(68, 112)
      temp = temp + M(111, 69) * M(69, 112)
      temp = temp + M(111, 70) * M(70, 112)
      temp = temp + M(111, 71) * M(71, 112)
      temp = temp + M(111, 72) * M(72, 112)
      temp = temp + M(111, 73) * M(73, 112)
      temp = temp + M(111, 75) * M(75, 112)
      temp = temp + M(111, 76) * M(76, 112)
      temp = temp + M(111, 77) * M(77, 112)
      temp = temp + M(111, 78) * M(78, 112)
      temp = temp + M(111, 79) * M(79, 112)
      temp = temp + M(111, 80) * M(80, 112)
      temp = temp + M(111, 81) * M(81, 112)
      temp = temp + M(111, 82) * M(82, 112)
      temp = temp + M(111, 83) * M(83, 112)
      temp = temp + M(111, 84) * M(84, 112)
      temp = temp + M(111, 85) * M(85, 112)
      temp = temp + M(111, 86) * M(86, 112)
      temp = temp + M(111, 87) * M(87, 112)
      temp = temp + M(111, 88) * M(88, 112)
      temp = temp + M(111, 89) * M(89, 112)
      temp = temp + M(111, 90) * M(90, 112)
      temp = temp + M(111, 91) * M(91, 112)
      temp = temp + M(111, 92) * M(92, 112)
      temp = temp + M(111, 93) * M(93, 112)
      temp = temp + M(111, 95) * M(95, 112)
      temp = temp + M(111, 96) * M(96, 112)
      temp = temp + M(111, 97) * M(97, 112)
      temp = temp + M(111, 98) * M(98, 112)
      temp = temp + M(111, 99) * M(99, 112)
      temp = temp + M(111, 100) * M(100, 112)
      temp = temp + M(111, 101) * M(101, 112)
      temp = temp + M(111, 102) * M(102, 112)
      temp = temp + M(111, 103) * M(103, 112)
      temp = temp + M(111, 104) * M(104, 112)
      temp = temp + M(111, 105) * M(105, 112)
      temp = temp + M(111, 106) * M(106, 112)
      temp = temp + M(111, 107) * M(107, 112)
      temp = temp + M(111, 108) * M(108, 112)
      temp = temp + M(111, 109) * M(109, 112)
      temp = temp + M(111, 110) * M(110, 112)
      M(111, 112) = ( M(111, 112) - temp ) / M(111, 111)
C     Upper part.
      temp = M(111, 99) * M(99, 113)
      temp = temp + M(111, 100) * M(100, 113)
      temp = temp + M(111, 101) * M(101, 113)
      temp = temp + M(111, 102) * M(102, 113)
      temp = temp + M(111, 103) * M(103, 113)
      temp = temp + M(111, 104) * M(104, 113)
      temp = temp + M(111, 105) * M(105, 113)
      temp = temp + M(111, 106) * M(106, 113)
      temp = temp + M(111, 107) * M(107, 113)
      temp = temp + M(111, 108) * M(108, 113)
      temp = temp + M(111, 109) * M(109, 113)
      temp = temp + M(111, 110) * M(110, 113)
      M(111, 113) = ( M(111, 113) - temp ) / M(111, 111)

C     Lower part.
      temp = M(112, 2) * M(2, 112)
      temp = temp + M(112, 4) * M(4, 112)
      temp = temp + M(112, 5) * M(5, 112)
      temp = temp + M(112, 6) * M(6, 112)
      temp = temp + M(112, 7) * M(7, 112)
      temp = temp + M(112, 8) * M(8, 112)
      temp = temp + M(112, 9) * M(9, 112)
      temp = temp + M(112, 10) * M(10, 112)
      temp = temp + M(112, 11) * M(11, 112)
      temp = temp + M(112, 12) * M(12, 112)
      temp = temp + M(112, 13) * M(13, 112)
      temp = temp + M(112, 14) * M(14, 112)
      temp = temp + M(112, 15) * M(15, 112)
      temp = temp + M(112, 17) * M(17, 112)
      temp = temp + M(112, 18) * M(18, 112)
      temp = temp + M(112, 19) * M(19, 112)
      temp = temp + M(112, 20) * M(20, 112)
      temp = temp + M(112, 21) * M(21, 112)
      temp = temp + M(112, 22) * M(22, 112)
      temp = temp + M(112, 23) * M(23, 112)
      temp = temp + M(112, 24) * M(24, 112)
      temp = temp + M(112, 26) * M(26, 112)
      temp = temp + M(112, 27) * M(27, 112)
      temp = temp + M(112, 28) * M(28, 112)
      temp = temp + M(112, 29) * M(29, 112)
      temp = temp + M(112, 30) * M(30, 112)
      temp = temp + M(112, 31) * M(31, 112)
      temp = temp + M(112, 32) * M(32, 112)
      temp = temp + M(112, 33) * M(33, 112)
      temp = temp + M(112, 34) * M(34, 112)
      temp = temp + M(112, 35) * M(35, 112)
      temp = temp + M(112, 36) * M(36, 112)
      temp = temp + M(112, 37) * M(37, 112)
      temp = temp + M(112, 38) * M(38, 112)
      temp = temp + M(112, 39) * M(39, 112)
      temp = temp + M(112, 40) * M(40, 112)
      temp = temp + M(112, 41) * M(41, 112)
      temp = temp + M(112, 43) * M(43, 112)
      temp = temp + M(112, 47) * M(47, 112)
      temp = temp + M(112, 48) * M(48, 112)
      temp = temp + M(112, 53) * M(53, 112)
      temp = temp + M(112, 55) * M(55, 112)
      temp = temp + M(112, 56) * M(56, 112)
      temp = temp + M(112, 58) * M(58, 112)
      temp = temp + M(112, 59) * M(59, 112)
      temp = temp + M(112, 60) * M(60, 112)
      temp = temp + M(112, 61) * M(61, 112)
      temp = temp + M(112, 65) * M(65, 112)
      temp = temp + M(112, 66) * M(66, 112)
      temp = temp + M(112, 67) * M(67, 112)
      temp = temp + M(112, 69) * M(69, 112)
      temp = temp + M(112, 73) * M(73, 112)
      temp = temp + M(112, 74) * M(74, 112)
      temp = temp + M(112, 76) * M(76, 112)
      temp = temp + M(112, 77) * M(77, 112)
      temp = temp + M(112, 78) * M(78, 112)
      temp = temp + M(112, 80) * M(80, 112)
      temp = temp + M(112, 81) * M(81, 112)
      temp = temp + M(112, 83) * M(83, 112)
      temp = temp + M(112, 85) * M(85, 112)
      temp = temp + M(112, 86) * M(86, 112)
      temp = temp + M(112, 87) * M(87, 112)
      temp = temp + M(112, 88) * M(88, 112)
      temp = temp + M(112, 89) * M(89, 112)
      temp = temp + M(112, 91) * M(91, 112)
      temp = temp + M(112, 92) * M(92, 112)
      temp = temp + M(112, 93) * M(93, 112)
      temp = temp + M(112, 94) * M(94, 112)
      temp = temp + M(112, 95) * M(95, 112)
      temp = temp + M(112, 96) * M(96, 112)
      temp = temp + M(112, 97) * M(97, 112)
      temp = temp + M(112, 98) * M(98, 112)
      temp = temp + M(112, 99) * M(99, 112)
      temp = temp + M(112, 100) * M(100, 112)
      temp = temp + M(112, 101) * M(101, 112)
      temp = temp + M(112, 102) * M(102, 112)
      temp = temp + M(112, 103) * M(103, 112)
      temp = temp + M(112, 104) * M(104, 112)
      temp = temp + M(112, 105) * M(105, 112)
      temp = temp + M(112, 106) * M(106, 112)
      temp = temp + M(112, 107) * M(107, 112)
      temp = temp + M(112, 108) * M(108, 112)
      temp = temp + M(112, 109) * M(109, 112)
      temp = temp + M(112, 110) * M(110, 112)
      temp = temp + M(112, 111) * M(111, 112)
      M(112, 112) = M(112, 112) - temp
C     Lower part.
      temp = M(113, 41) * M(41, 112)
      temp = temp + M(113, 42) * M(42, 112)
      temp = temp + M(113, 43) * M(43, 112)
      temp = temp + M(113, 48) * M(48, 112)
      temp = temp + M(113, 49) * M(49, 112)
      temp = temp + M(113, 51) * M(51, 112)
      temp = temp + M(113, 53) * M(53, 112)
      temp = temp + M(113, 54) * M(54, 112)
      temp = temp + M(113, 55) * M(55, 112)
      temp = temp + M(113, 57) * M(57, 112)
      temp = temp + M(113, 60) * M(60, 112)
      temp = temp + M(113, 61) * M(61, 112)
      temp = temp + M(113, 62) * M(62, 112)
      temp = temp + M(113, 63) * M(63, 112)
      temp = temp + M(113, 70) * M(70, 112)
      temp = temp + M(113, 71) * M(71, 112)
      temp = temp + M(113, 80) * M(80, 112)
      temp = temp + M(113, 81) * M(81, 112)
      temp = temp + M(113, 83) * M(83, 112)
      temp = temp + M(113, 86) * M(86, 112)
      temp = temp + M(113, 99) * M(99, 112)
      temp = temp + M(113, 100) * M(100, 112)
      temp = temp + M(113, 101) * M(101, 112)
      temp = temp + M(113, 102) * M(102, 112)
      temp = temp + M(113, 103) * M(103, 112)
      temp = temp + M(113, 104) * M(104, 112)
      temp = temp + M(113, 105) * M(105, 112)
      temp = temp + M(113, 106) * M(106, 112)
      temp = temp + M(113, 107) * M(107, 112)
      temp = temp + M(113, 109) * M(109, 112)
      temp = temp + M(113, 110) * M(110, 112)
      temp = temp + M(113, 111) * M(111, 112)
      M(113, 112) = M(113, 112) - temp
C     Upper part.
      temp = M(112, 99) * M(99, 113)
      temp = temp + M(112, 100) * M(100, 113)
      temp = temp + M(112, 101) * M(101, 113)
      temp = temp + M(112, 102) * M(102, 113)
      temp = temp + M(112, 103) * M(103, 113)
      temp = temp + M(112, 104) * M(104, 113)
      temp = temp + M(112, 105) * M(105, 113)
      temp = temp + M(112, 106) * M(106, 113)
      temp = temp + M(112, 107) * M(107, 113)
      temp = temp + M(112, 108) * M(108, 113)
      temp = temp + M(112, 109) * M(109, 113)
      temp = temp + M(112, 110) * M(110, 113)
      temp = temp + M(112, 111) * M(111, 113)
      M(112, 113) = ( M(112, 113) - temp ) / M(112, 112)

C     Lower part.
      temp = M(113, 99) * M(99, 113)
      temp = temp + M(113, 100) * M(100, 113)
      temp = temp + M(113, 101) * M(101, 113)
      temp = temp + M(113, 102) * M(102, 113)
      temp = temp + M(113, 103) * M(103, 113)
      temp = temp + M(113, 104) * M(104, 113)
      temp = temp + M(113, 105) * M(105, 113)
      temp = temp + M(113, 106) * M(106, 113)
      temp = temp + M(113, 107) * M(107, 113)
      temp = temp + M(113, 109) * M(109, 113)
      temp = temp + M(113, 110) * M(110, 113)
      temp = temp + M(113, 111) * M(111, 113)
      temp = temp + M(113, 112) * M(112, 113)
      M(113, 113) = M(113, 113) - temp


      END
